# bash completion for stripe                               -*- shell-script -*-

__stripe_debug()
{
    if [[ -n ${BASH_COMP_DEBUG_FILE:-} ]]; then
        echo "$*" >> "${BASH_COMP_DEBUG_FILE}"
    fi
}

# Homebrew on Macs have version 1.3 of bash-completion which doesn't include
# _init_completion. This is a very minimal version of that function.
__stripe_init_completion()
{
    COMPREPLY=()
    _get_comp_words_by_ref "$@" cur prev words cword
}

__stripe_index_of_word()
{
    local w word=$1
    shift
    index=0
    for w in "$@"; do
        [[ $w = "$word" ]] && return
        index=$((index+1))
    done
    index=-1
}

__stripe_contains_word()
{
    local w word=$1; shift
    for w in "$@"; do
        [[ $w = "$word" ]] && return
    done
    return 1
}

__stripe_handle_go_custom_completion()
{
    __stripe_debug "${FUNCNAME[0]}: cur is ${cur}, words[*] is ${words[*]}, #words[@] is ${#words[@]}"

    local shellCompDirectiveError=1
    local shellCompDirectiveNoSpace=2
    local shellCompDirectiveNoFileComp=4
    local shellCompDirectiveFilterFileExt=8
    local shellCompDirectiveFilterDirs=16

    local out requestComp lastParam lastChar comp directive args

    # Prepare the command to request completions for the program.
    # Calling ${words[0]} instead of directly stripe allows to handle aliases
    args=("${words[@]:1}")
    # Disable ActiveHelp which is not supported for bash completion v1
    requestComp="STRIPE_ACTIVE_HELP=0 ${words[0]} __completeNoDesc ${args[*]}"

    lastParam=${words[$((${#words[@]}-1))]}
    lastChar=${lastParam:$((${#lastParam}-1)):1}
    __stripe_debug "${FUNCNAME[0]}: lastParam ${lastParam}, lastChar ${lastChar}"

    if [ -z "${cur}" ] && [ "${lastChar}" != "=" ]; then
        # If the last parameter is complete (there is a space following it)
        # We add an extra empty parameter so we can indicate this to the go method.
        __stripe_debug "${FUNCNAME[0]}: Adding extra empty parameter"
        requestComp="${requestComp} \"\""
    fi

    __stripe_debug "${FUNCNAME[0]}: calling ${requestComp}"
    # Use eval to handle any environment variables and such
    out=$(eval "${requestComp}" 2>/dev/null)

    # Extract the directive integer at the very end of the output following a colon (:)
    directive=${out##*:}
    # Remove the directive
    out=${out%:*}
    if [ "${directive}" = "${out}" ]; then
        # There is not directive specified
        directive=0
    fi
    __stripe_debug "${FUNCNAME[0]}: the completion directive is: ${directive}"
    __stripe_debug "${FUNCNAME[0]}: the completions are: ${out}"

    if [ $((directive & shellCompDirectiveError)) -ne 0 ]; then
        # Error code.  No completion.
        __stripe_debug "${FUNCNAME[0]}: received error from custom completion go code"
        return
    else
        if [ $((directive & shellCompDirectiveNoSpace)) -ne 0 ]; then
            if [[ $(type -t compopt) = "builtin" ]]; then
                __stripe_debug "${FUNCNAME[0]}: activating no space"
                compopt -o nospace
            fi
        fi
        if [ $((directive & shellCompDirectiveNoFileComp)) -ne 0 ]; then
            if [[ $(type -t compopt) = "builtin" ]]; then
                __stripe_debug "${FUNCNAME[0]}: activating no file completion"
                compopt +o default
            fi
        fi
    fi

    if [ $((directive & shellCompDirectiveFilterFileExt)) -ne 0 ]; then
        # File extension filtering
        local fullFilter filter filteringCmd
        # Do not use quotes around the $out variable or else newline
        # characters will be kept.
        for filter in ${out}; do
            fullFilter+="$filter|"
        done

        filteringCmd="_filedir $fullFilter"
        __stripe_debug "File filtering command: $filteringCmd"
        $filteringCmd
    elif [ $((directive & shellCompDirectiveFilterDirs)) -ne 0 ]; then
        # File completion for directories only
        local subdir
        # Use printf to strip any trailing newline
        subdir=$(printf "%s" "${out}")
        if [ -n "$subdir" ]; then
            __stripe_debug "Listing directories in $subdir"
            __stripe_handle_subdirs_in_dir_flag "$subdir"
        else
            __stripe_debug "Listing directories in ."
            _filedir -d
        fi
    else
        while IFS='' read -r comp; do
            COMPREPLY+=("$comp")
        done < <(compgen -W "${out}" -- "$cur")
    fi
}

__stripe_handle_reply()
{
    __stripe_debug "${FUNCNAME[0]}"
    local comp
    case $cur in
        -*)
            if [[ $(type -t compopt) = "builtin" ]]; then
                compopt -o nospace
            fi
            local allflags
            if [ ${#must_have_one_flag[@]} -ne 0 ]; then
                allflags=("${must_have_one_flag[@]}")
            else
                allflags=("${flags[*]} ${two_word_flags[*]}")
            fi
            while IFS='' read -r comp; do
                COMPREPLY+=("$comp")
            done < <(compgen -W "${allflags[*]}" -- "$cur")
            if [[ $(type -t compopt) = "builtin" ]]; then
                [[ "${COMPREPLY[0]}" == *= ]] || compopt +o nospace
            fi

            # complete after --flag=abc
            if [[ $cur == *=* ]]; then
                if [[ $(type -t compopt) = "builtin" ]]; then
                    compopt +o nospace
                fi

                local index flag
                flag="${cur%=*}"
                __stripe_index_of_word "${flag}" "${flags_with_completion[@]}"
                COMPREPLY=()
                if [[ ${index} -ge 0 ]]; then
                    PREFIX=""
                    cur="${cur#*=}"
                    ${flags_completion[${index}]}
                    if [ -n "${ZSH_VERSION:-}" ]; then
                        # zsh completion needs --flag= prefix
                        eval "COMPREPLY=( \"\${COMPREPLY[@]/#/${flag}=}\" )"
                    fi
                fi
            fi

            if [[ -z "${flag_parsing_disabled}" ]]; then
                # If flag parsing is enabled, we have completed the flags and can return.
                # If flag parsing is disabled, we may not know all (or any) of the flags, so we fallthrough
                # to possibly call handle_go_custom_completion.
                return 0;
            fi
            ;;
    esac

    # check if we are handling a flag with special work handling
    local index
    __stripe_index_of_word "${prev}" "${flags_with_completion[@]}"
    if [[ ${index} -ge 0 ]]; then
        ${flags_completion[${index}]}
        return
    fi

    # we are parsing a flag and don't have a special handler, no completion
    if [[ ${cur} != "${words[cword]}" ]]; then
        return
    fi

    local completions
    completions=("${commands[@]}")
    if [[ ${#must_have_one_noun[@]} -ne 0 ]]; then
        completions+=("${must_have_one_noun[@]}")
    elif [[ -n "${has_completion_function}" ]]; then
        # if a go completion function is provided, defer to that function
        __stripe_handle_go_custom_completion
    fi
    if [[ ${#must_have_one_flag[@]} -ne 0 ]]; then
        completions+=("${must_have_one_flag[@]}")
    fi
    while IFS='' read -r comp; do
        COMPREPLY+=("$comp")
    done < <(compgen -W "${completions[*]}" -- "$cur")

    if [[ ${#COMPREPLY[@]} -eq 0 && ${#noun_aliases[@]} -gt 0 && ${#must_have_one_noun[@]} -ne 0 ]]; then
        while IFS='' read -r comp; do
            COMPREPLY+=("$comp")
        done < <(compgen -W "${noun_aliases[*]}" -- "$cur")
    fi

    if [[ ${#COMPREPLY[@]} -eq 0 ]]; then
        if declare -F __stripe_custom_func >/dev/null; then
            # try command name qualified custom func
            __stripe_custom_func
        else
            # otherwise fall back to unqualified for compatibility
            declare -F __custom_func >/dev/null && __custom_func
        fi
    fi

    # available in bash-completion >= 2, not always present on macOS
    if declare -F __ltrim_colon_completions >/dev/null; then
        __ltrim_colon_completions "$cur"
    fi

    # If there is only 1 completion and it is a flag with an = it will be completed
    # but we don't want a space after the =
    if [[ "${#COMPREPLY[@]}" -eq "1" ]] && [[ $(type -t compopt) = "builtin" ]] && [[ "${COMPREPLY[0]}" == --*= ]]; then
       compopt -o nospace
    fi
}

# The arguments should be in the form "ext1|ext2|extn"
__stripe_handle_filename_extension_flag()
{
    local ext="$1"
    _filedir "@(${ext})"
}

__stripe_handle_subdirs_in_dir_flag()
{
    local dir="$1"
    pushd "${dir}" >/dev/null 2>&1 && _filedir -d && popd >/dev/null 2>&1 || return
}

__stripe_handle_flag()
{
    __stripe_debug "${FUNCNAME[0]}: c is $c words[c] is ${words[c]}"

    # if a command required a flag, and we found it, unset must_have_one_flag()
    local flagname=${words[c]}
    local flagvalue=""
    # if the word contained an =
    if [[ ${words[c]} == *"="* ]]; then
        flagvalue=${flagname#*=} # take in as flagvalue after the =
        flagname=${flagname%=*} # strip everything after the =
        flagname="${flagname}=" # but put the = back
    fi
    __stripe_debug "${FUNCNAME[0]}: looking for ${flagname}"
    if __stripe_contains_word "${flagname}" "${must_have_one_flag[@]}"; then
        must_have_one_flag=()
    fi

    # if you set a flag which only applies to this command, don't show subcommands
    if __stripe_contains_word "${flagname}" "${local_nonpersistent_flags[@]}"; then
      commands=()
    fi

    # keep flag value with flagname as flaghash
    # flaghash variable is an associative array which is only supported in bash > 3.
    if [[ -z "${BASH_VERSION:-}" || "${BASH_VERSINFO[0]:-}" -gt 3 ]]; then
        if [ -n "${flagvalue}" ] ; then
            flaghash[${flagname}]=${flagvalue}
        elif [ -n "${words[ $((c+1)) ]}" ] ; then
            flaghash[${flagname}]=${words[ $((c+1)) ]}
        else
            flaghash[${flagname}]="true" # pad "true" for bool flag
        fi
    fi

    # skip the argument to a two word flag
    if [[ ${words[c]} != *"="* ]] && __stripe_contains_word "${words[c]}" "${two_word_flags[@]}"; then
        __stripe_debug "${FUNCNAME[0]}: found a flag ${words[c]}, skip the next argument"
        c=$((c+1))
        # if we are looking for a flags value, don't show commands
        if [[ $c -eq $cword ]]; then
            commands=()
        fi
    fi

    c=$((c+1))

}

__stripe_handle_noun()
{
    __stripe_debug "${FUNCNAME[0]}: c is $c words[c] is ${words[c]}"

    if __stripe_contains_word "${words[c]}" "${must_have_one_noun[@]}"; then
        must_have_one_noun=()
    elif __stripe_contains_word "${words[c]}" "${noun_aliases[@]}"; then
        must_have_one_noun=()
    fi

    nouns+=("${words[c]}")
    c=$((c+1))
}

__stripe_handle_command()
{
    __stripe_debug "${FUNCNAME[0]}: c is $c words[c] is ${words[c]}"

    local next_command
    if [[ -n ${last_command} ]]; then
        next_command="_${last_command}_${words[c]//:/__}"
    else
        if [[ $c -eq 0 ]]; then
            next_command="_stripe_root_command"
        else
            next_command="_${words[c]//:/__}"
        fi
    fi
    c=$((c+1))
    __stripe_debug "${FUNCNAME[0]}: looking for ${next_command}"
    declare -F "$next_command" >/dev/null && $next_command
}

__stripe_handle_word()
{
    if [[ $c -ge $cword ]]; then
        __stripe_handle_reply
        return
    fi
    __stripe_debug "${FUNCNAME[0]}: c is $c words[c] is ${words[c]}"
    if [[ "${words[c]}" == -* ]]; then
        __stripe_handle_flag
    elif __stripe_contains_word "${words[c]}" "${commands[@]}"; then
        __stripe_handle_command
    elif [[ $c -eq 0 ]]; then
        __stripe_handle_command
    elif __stripe_contains_word "${words[c]}" "${command_aliases[@]}"; then
        # aliashash variable is an associative array which is only supported in bash > 3.
        if [[ -z "${BASH_VERSION:-}" || "${BASH_VERSINFO[0]:-}" -gt 3 ]]; then
            words[c]=${aliashash[${words[c]}]}
            __stripe_handle_command
        else
            __stripe_handle_noun
        fi
    else
        __stripe_handle_noun
    fi
    __stripe_handle_word
}

_stripe_account_links_create()
{
    last_command="stripe_account_links_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--account=")
    two_word_flags+=("--account")
    local_nonpersistent_flags+=("--account")
    local_nonpersistent_flags+=("--account=")
    flags+=("--collect=")
    two_word_flags+=("--collect")
    local_nonpersistent_flags+=("--collect")
    local_nonpersistent_flags+=("--collect=")
    flags+=("--collection-options.fields=")
    two_word_flags+=("--collection-options.fields")
    local_nonpersistent_flags+=("--collection-options.fields")
    local_nonpersistent_flags+=("--collection-options.fields=")
    flags+=("--collection-options.future-requirements=")
    two_word_flags+=("--collection-options.future-requirements")
    local_nonpersistent_flags+=("--collection-options.future-requirements")
    local_nonpersistent_flags+=("--collection-options.future-requirements=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--refresh-url=")
    two_word_flags+=("--refresh-url")
    local_nonpersistent_flags+=("--refresh-url")
    local_nonpersistent_flags+=("--refresh-url=")
    flags+=("--return-url=")
    two_word_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_account_links()
{
    last_command="stripe_account_links"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_account_sessions_create()
{
    last_command="stripe_account_sessions_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--account=")
    two_word_flags+=("--account")
    local_nonpersistent_flags+=("--account")
    local_nonpersistent_flags+=("--account=")
    flags+=("--components.account-management.enabled=")
    two_word_flags+=("--components.account-management.enabled")
    local_nonpersistent_flags+=("--components.account-management.enabled")
    local_nonpersistent_flags+=("--components.account-management.enabled=")
    flags+=("--components.account-management.features.disable-stripe-user-authentication=")
    two_word_flags+=("--components.account-management.features.disable-stripe-user-authentication")
    local_nonpersistent_flags+=("--components.account-management.features.disable-stripe-user-authentication")
    local_nonpersistent_flags+=("--components.account-management.features.disable-stripe-user-authentication=")
    flags+=("--components.account-management.features.external-account-collection=")
    two_word_flags+=("--components.account-management.features.external-account-collection")
    local_nonpersistent_flags+=("--components.account-management.features.external-account-collection")
    local_nonpersistent_flags+=("--components.account-management.features.external-account-collection=")
    flags+=("--components.account-onboarding.enabled=")
    two_word_flags+=("--components.account-onboarding.enabled")
    local_nonpersistent_flags+=("--components.account-onboarding.enabled")
    local_nonpersistent_flags+=("--components.account-onboarding.enabled=")
    flags+=("--components.account-onboarding.features.disable-stripe-user-authentication=")
    two_word_flags+=("--components.account-onboarding.features.disable-stripe-user-authentication")
    local_nonpersistent_flags+=("--components.account-onboarding.features.disable-stripe-user-authentication")
    local_nonpersistent_flags+=("--components.account-onboarding.features.disable-stripe-user-authentication=")
    flags+=("--components.account-onboarding.features.external-account-collection=")
    two_word_flags+=("--components.account-onboarding.features.external-account-collection")
    local_nonpersistent_flags+=("--components.account-onboarding.features.external-account-collection")
    local_nonpersistent_flags+=("--components.account-onboarding.features.external-account-collection=")
    flags+=("--components.balances.enabled=")
    two_word_flags+=("--components.balances.enabled")
    local_nonpersistent_flags+=("--components.balances.enabled")
    local_nonpersistent_flags+=("--components.balances.enabled=")
    flags+=("--components.balances.features.disable-stripe-user-authentication=")
    two_word_flags+=("--components.balances.features.disable-stripe-user-authentication")
    local_nonpersistent_flags+=("--components.balances.features.disable-stripe-user-authentication")
    local_nonpersistent_flags+=("--components.balances.features.disable-stripe-user-authentication=")
    flags+=("--components.balances.features.edit-payout-schedule=")
    two_word_flags+=("--components.balances.features.edit-payout-schedule")
    local_nonpersistent_flags+=("--components.balances.features.edit-payout-schedule")
    local_nonpersistent_flags+=("--components.balances.features.edit-payout-schedule=")
    flags+=("--components.balances.features.external-account-collection=")
    two_word_flags+=("--components.balances.features.external-account-collection")
    local_nonpersistent_flags+=("--components.balances.features.external-account-collection")
    local_nonpersistent_flags+=("--components.balances.features.external-account-collection=")
    flags+=("--components.balances.features.instant-payouts=")
    two_word_flags+=("--components.balances.features.instant-payouts")
    local_nonpersistent_flags+=("--components.balances.features.instant-payouts")
    local_nonpersistent_flags+=("--components.balances.features.instant-payouts=")
    flags+=("--components.balances.features.standard-payouts=")
    two_word_flags+=("--components.balances.features.standard-payouts")
    local_nonpersistent_flags+=("--components.balances.features.standard-payouts")
    local_nonpersistent_flags+=("--components.balances.features.standard-payouts=")
    flags+=("--components.documents.enabled=")
    two_word_flags+=("--components.documents.enabled")
    local_nonpersistent_flags+=("--components.documents.enabled")
    local_nonpersistent_flags+=("--components.documents.enabled=")
    flags+=("--components.notification-banner.enabled=")
    two_word_flags+=("--components.notification-banner.enabled")
    local_nonpersistent_flags+=("--components.notification-banner.enabled")
    local_nonpersistent_flags+=("--components.notification-banner.enabled=")
    flags+=("--components.notification-banner.features.disable-stripe-user-authentication=")
    two_word_flags+=("--components.notification-banner.features.disable-stripe-user-authentication")
    local_nonpersistent_flags+=("--components.notification-banner.features.disable-stripe-user-authentication")
    local_nonpersistent_flags+=("--components.notification-banner.features.disable-stripe-user-authentication=")
    flags+=("--components.notification-banner.features.external-account-collection=")
    two_word_flags+=("--components.notification-banner.features.external-account-collection")
    local_nonpersistent_flags+=("--components.notification-banner.features.external-account-collection")
    local_nonpersistent_flags+=("--components.notification-banner.features.external-account-collection=")
    flags+=("--components.payment-details.enabled=")
    two_word_flags+=("--components.payment-details.enabled")
    local_nonpersistent_flags+=("--components.payment-details.enabled")
    local_nonpersistent_flags+=("--components.payment-details.enabled=")
    flags+=("--components.payment-details.features.capture-payments=")
    two_word_flags+=("--components.payment-details.features.capture-payments")
    local_nonpersistent_flags+=("--components.payment-details.features.capture-payments")
    local_nonpersistent_flags+=("--components.payment-details.features.capture-payments=")
    flags+=("--components.payment-details.features.destination-on-behalf-of-charge-management=")
    two_word_flags+=("--components.payment-details.features.destination-on-behalf-of-charge-management")
    local_nonpersistent_flags+=("--components.payment-details.features.destination-on-behalf-of-charge-management")
    local_nonpersistent_flags+=("--components.payment-details.features.destination-on-behalf-of-charge-management=")
    flags+=("--components.payment-details.features.dispute-management=")
    two_word_flags+=("--components.payment-details.features.dispute-management")
    local_nonpersistent_flags+=("--components.payment-details.features.dispute-management")
    local_nonpersistent_flags+=("--components.payment-details.features.dispute-management=")
    flags+=("--components.payment-details.features.refund-management=")
    two_word_flags+=("--components.payment-details.features.refund-management")
    local_nonpersistent_flags+=("--components.payment-details.features.refund-management")
    local_nonpersistent_flags+=("--components.payment-details.features.refund-management=")
    flags+=("--components.payments.enabled=")
    two_word_flags+=("--components.payments.enabled")
    local_nonpersistent_flags+=("--components.payments.enabled")
    local_nonpersistent_flags+=("--components.payments.enabled=")
    flags+=("--components.payments.features.capture-payments=")
    two_word_flags+=("--components.payments.features.capture-payments")
    local_nonpersistent_flags+=("--components.payments.features.capture-payments")
    local_nonpersistent_flags+=("--components.payments.features.capture-payments=")
    flags+=("--components.payments.features.destination-on-behalf-of-charge-management=")
    two_word_flags+=("--components.payments.features.destination-on-behalf-of-charge-management")
    local_nonpersistent_flags+=("--components.payments.features.destination-on-behalf-of-charge-management")
    local_nonpersistent_flags+=("--components.payments.features.destination-on-behalf-of-charge-management=")
    flags+=("--components.payments.features.dispute-management=")
    two_word_flags+=("--components.payments.features.dispute-management")
    local_nonpersistent_flags+=("--components.payments.features.dispute-management")
    local_nonpersistent_flags+=("--components.payments.features.dispute-management=")
    flags+=("--components.payments.features.refund-management=")
    two_word_flags+=("--components.payments.features.refund-management")
    local_nonpersistent_flags+=("--components.payments.features.refund-management")
    local_nonpersistent_flags+=("--components.payments.features.refund-management=")
    flags+=("--components.payouts-list.enabled=")
    two_word_flags+=("--components.payouts-list.enabled")
    local_nonpersistent_flags+=("--components.payouts-list.enabled")
    local_nonpersistent_flags+=("--components.payouts-list.enabled=")
    flags+=("--components.payouts.enabled=")
    two_word_flags+=("--components.payouts.enabled")
    local_nonpersistent_flags+=("--components.payouts.enabled")
    local_nonpersistent_flags+=("--components.payouts.enabled=")
    flags+=("--components.payouts.features.disable-stripe-user-authentication=")
    two_word_flags+=("--components.payouts.features.disable-stripe-user-authentication")
    local_nonpersistent_flags+=("--components.payouts.features.disable-stripe-user-authentication")
    local_nonpersistent_flags+=("--components.payouts.features.disable-stripe-user-authentication=")
    flags+=("--components.payouts.features.edit-payout-schedule=")
    two_word_flags+=("--components.payouts.features.edit-payout-schedule")
    local_nonpersistent_flags+=("--components.payouts.features.edit-payout-schedule")
    local_nonpersistent_flags+=("--components.payouts.features.edit-payout-schedule=")
    flags+=("--components.payouts.features.external-account-collection=")
    two_word_flags+=("--components.payouts.features.external-account-collection")
    local_nonpersistent_flags+=("--components.payouts.features.external-account-collection")
    local_nonpersistent_flags+=("--components.payouts.features.external-account-collection=")
    flags+=("--components.payouts.features.instant-payouts=")
    two_word_flags+=("--components.payouts.features.instant-payouts")
    local_nonpersistent_flags+=("--components.payouts.features.instant-payouts")
    local_nonpersistent_flags+=("--components.payouts.features.instant-payouts=")
    flags+=("--components.payouts.features.standard-payouts=")
    two_word_flags+=("--components.payouts.features.standard-payouts")
    local_nonpersistent_flags+=("--components.payouts.features.standard-payouts")
    local_nonpersistent_flags+=("--components.payouts.features.standard-payouts=")
    flags+=("--components.tax-registrations.enabled=")
    two_word_flags+=("--components.tax-registrations.enabled")
    local_nonpersistent_flags+=("--components.tax-registrations.enabled")
    local_nonpersistent_flags+=("--components.tax-registrations.enabled=")
    flags+=("--components.tax-settings.enabled=")
    two_word_flags+=("--components.tax-settings.enabled")
    local_nonpersistent_flags+=("--components.tax-settings.enabled")
    local_nonpersistent_flags+=("--components.tax-settings.enabled=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_account_sessions()
{
    last_command="stripe_account_sessions"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_accounts_capabilities()
{
    last_command="stripe_accounts_capabilities"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_accounts_create()
{
    last_command="stripe_accounts_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--account-token=")
    two_word_flags+=("--account-token")
    local_nonpersistent_flags+=("--account-token")
    local_nonpersistent_flags+=("--account-token=")
    flags+=("--business-profile.annual-revenue.amount=")
    two_word_flags+=("--business-profile.annual-revenue.amount")
    local_nonpersistent_flags+=("--business-profile.annual-revenue.amount")
    local_nonpersistent_flags+=("--business-profile.annual-revenue.amount=")
    flags+=("--business-profile.annual-revenue.currency=")
    two_word_flags+=("--business-profile.annual-revenue.currency")
    local_nonpersistent_flags+=("--business-profile.annual-revenue.currency")
    local_nonpersistent_flags+=("--business-profile.annual-revenue.currency=")
    flags+=("--business-profile.annual-revenue.fiscal-year-end=")
    two_word_flags+=("--business-profile.annual-revenue.fiscal-year-end")
    local_nonpersistent_flags+=("--business-profile.annual-revenue.fiscal-year-end")
    local_nonpersistent_flags+=("--business-profile.annual-revenue.fiscal-year-end=")
    flags+=("--business-profile.estimated-worker-count=")
    two_word_flags+=("--business-profile.estimated-worker-count")
    local_nonpersistent_flags+=("--business-profile.estimated-worker-count")
    local_nonpersistent_flags+=("--business-profile.estimated-worker-count=")
    flags+=("--business-profile.mcc=")
    two_word_flags+=("--business-profile.mcc")
    local_nonpersistent_flags+=("--business-profile.mcc")
    local_nonpersistent_flags+=("--business-profile.mcc=")
    flags+=("--business-profile.monthly-estimated-revenue.amount=")
    two_word_flags+=("--business-profile.monthly-estimated-revenue.amount")
    local_nonpersistent_flags+=("--business-profile.monthly-estimated-revenue.amount")
    local_nonpersistent_flags+=("--business-profile.monthly-estimated-revenue.amount=")
    flags+=("--business-profile.monthly-estimated-revenue.currency=")
    two_word_flags+=("--business-profile.monthly-estimated-revenue.currency")
    local_nonpersistent_flags+=("--business-profile.monthly-estimated-revenue.currency")
    local_nonpersistent_flags+=("--business-profile.monthly-estimated-revenue.currency=")
    flags+=("--business-profile.name=")
    two_word_flags+=("--business-profile.name")
    local_nonpersistent_flags+=("--business-profile.name")
    local_nonpersistent_flags+=("--business-profile.name=")
    flags+=("--business-profile.product-description=")
    two_word_flags+=("--business-profile.product-description")
    local_nonpersistent_flags+=("--business-profile.product-description")
    local_nonpersistent_flags+=("--business-profile.product-description=")
    flags+=("--business-profile.support-address.city=")
    two_word_flags+=("--business-profile.support-address.city")
    local_nonpersistent_flags+=("--business-profile.support-address.city")
    local_nonpersistent_flags+=("--business-profile.support-address.city=")
    flags+=("--business-profile.support-address.country=")
    two_word_flags+=("--business-profile.support-address.country")
    local_nonpersistent_flags+=("--business-profile.support-address.country")
    local_nonpersistent_flags+=("--business-profile.support-address.country=")
    flags+=("--business-profile.support-address.line1=")
    two_word_flags+=("--business-profile.support-address.line1")
    local_nonpersistent_flags+=("--business-profile.support-address.line1")
    local_nonpersistent_flags+=("--business-profile.support-address.line1=")
    flags+=("--business-profile.support-address.line2=")
    two_word_flags+=("--business-profile.support-address.line2")
    local_nonpersistent_flags+=("--business-profile.support-address.line2")
    local_nonpersistent_flags+=("--business-profile.support-address.line2=")
    flags+=("--business-profile.support-address.postal-code=")
    two_word_flags+=("--business-profile.support-address.postal-code")
    local_nonpersistent_flags+=("--business-profile.support-address.postal-code")
    local_nonpersistent_flags+=("--business-profile.support-address.postal-code=")
    flags+=("--business-profile.support-address.state=")
    two_word_flags+=("--business-profile.support-address.state")
    local_nonpersistent_flags+=("--business-profile.support-address.state")
    local_nonpersistent_flags+=("--business-profile.support-address.state=")
    flags+=("--business-profile.support-email=")
    two_word_flags+=("--business-profile.support-email")
    local_nonpersistent_flags+=("--business-profile.support-email")
    local_nonpersistent_flags+=("--business-profile.support-email=")
    flags+=("--business-profile.support-phone=")
    two_word_flags+=("--business-profile.support-phone")
    local_nonpersistent_flags+=("--business-profile.support-phone")
    local_nonpersistent_flags+=("--business-profile.support-phone=")
    flags+=("--business-profile.support-url=")
    two_word_flags+=("--business-profile.support-url")
    local_nonpersistent_flags+=("--business-profile.support-url")
    local_nonpersistent_flags+=("--business-profile.support-url=")
    flags+=("--business-profile.url=")
    two_word_flags+=("--business-profile.url")
    local_nonpersistent_flags+=("--business-profile.url")
    local_nonpersistent_flags+=("--business-profile.url=")
    flags+=("--business-type=")
    two_word_flags+=("--business-type")
    local_nonpersistent_flags+=("--business-type")
    local_nonpersistent_flags+=("--business-type=")
    flags+=("--capabilities.acss-debit-payments.requested=")
    two_word_flags+=("--capabilities.acss-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.acss-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.acss-debit-payments.requested=")
    flags+=("--capabilities.affirm-payments.requested=")
    two_word_flags+=("--capabilities.affirm-payments.requested")
    local_nonpersistent_flags+=("--capabilities.affirm-payments.requested")
    local_nonpersistent_flags+=("--capabilities.affirm-payments.requested=")
    flags+=("--capabilities.afterpay-clearpay-payments.requested=")
    two_word_flags+=("--capabilities.afterpay-clearpay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.afterpay-clearpay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.afterpay-clearpay-payments.requested=")
    flags+=("--capabilities.alma-payments.requested=")
    two_word_flags+=("--capabilities.alma-payments.requested")
    local_nonpersistent_flags+=("--capabilities.alma-payments.requested")
    local_nonpersistent_flags+=("--capabilities.alma-payments.requested=")
    flags+=("--capabilities.amazon-pay-payments.requested=")
    two_word_flags+=("--capabilities.amazon-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.amazon-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.amazon-pay-payments.requested=")
    flags+=("--capabilities.au-becs-debit-payments.requested=")
    two_word_flags+=("--capabilities.au-becs-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.au-becs-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.au-becs-debit-payments.requested=")
    flags+=("--capabilities.bacs-debit-payments.requested=")
    two_word_flags+=("--capabilities.bacs-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.bacs-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.bacs-debit-payments.requested=")
    flags+=("--capabilities.bancontact-payments.requested=")
    two_word_flags+=("--capabilities.bancontact-payments.requested")
    local_nonpersistent_flags+=("--capabilities.bancontact-payments.requested")
    local_nonpersistent_flags+=("--capabilities.bancontact-payments.requested=")
    flags+=("--capabilities.bank-transfer-payments.requested=")
    two_word_flags+=("--capabilities.bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.bank-transfer-payments.requested=")
    flags+=("--capabilities.blik-payments.requested=")
    two_word_flags+=("--capabilities.blik-payments.requested")
    local_nonpersistent_flags+=("--capabilities.blik-payments.requested")
    local_nonpersistent_flags+=("--capabilities.blik-payments.requested=")
    flags+=("--capabilities.boleto-payments.requested=")
    two_word_flags+=("--capabilities.boleto-payments.requested")
    local_nonpersistent_flags+=("--capabilities.boleto-payments.requested")
    local_nonpersistent_flags+=("--capabilities.boleto-payments.requested=")
    flags+=("--capabilities.card-issuing.requested=")
    two_word_flags+=("--capabilities.card-issuing.requested")
    local_nonpersistent_flags+=("--capabilities.card-issuing.requested")
    local_nonpersistent_flags+=("--capabilities.card-issuing.requested=")
    flags+=("--capabilities.card-payments.requested=")
    two_word_flags+=("--capabilities.card-payments.requested")
    local_nonpersistent_flags+=("--capabilities.card-payments.requested")
    local_nonpersistent_flags+=("--capabilities.card-payments.requested=")
    flags+=("--capabilities.cartes-bancaires-payments.requested=")
    two_word_flags+=("--capabilities.cartes-bancaires-payments.requested")
    local_nonpersistent_flags+=("--capabilities.cartes-bancaires-payments.requested")
    local_nonpersistent_flags+=("--capabilities.cartes-bancaires-payments.requested=")
    flags+=("--capabilities.cashapp-payments.requested=")
    two_word_flags+=("--capabilities.cashapp-payments.requested")
    local_nonpersistent_flags+=("--capabilities.cashapp-payments.requested")
    local_nonpersistent_flags+=("--capabilities.cashapp-payments.requested=")
    flags+=("--capabilities.eps-payments.requested=")
    two_word_flags+=("--capabilities.eps-payments.requested")
    local_nonpersistent_flags+=("--capabilities.eps-payments.requested")
    local_nonpersistent_flags+=("--capabilities.eps-payments.requested=")
    flags+=("--capabilities.fpx-payments.requested=")
    two_word_flags+=("--capabilities.fpx-payments.requested")
    local_nonpersistent_flags+=("--capabilities.fpx-payments.requested")
    local_nonpersistent_flags+=("--capabilities.fpx-payments.requested=")
    flags+=("--capabilities.gb-bank-transfer-payments.requested=")
    two_word_flags+=("--capabilities.gb-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.gb-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.gb-bank-transfer-payments.requested=")
    flags+=("--capabilities.giropay-payments.requested=")
    two_word_flags+=("--capabilities.giropay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.giropay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.giropay-payments.requested=")
    flags+=("--capabilities.grabpay-payments.requested=")
    two_word_flags+=("--capabilities.grabpay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.grabpay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.grabpay-payments.requested=")
    flags+=("--capabilities.ideal-payments.requested=")
    two_word_flags+=("--capabilities.ideal-payments.requested")
    local_nonpersistent_flags+=("--capabilities.ideal-payments.requested")
    local_nonpersistent_flags+=("--capabilities.ideal-payments.requested=")
    flags+=("--capabilities.india-international-payments.requested=")
    two_word_flags+=("--capabilities.india-international-payments.requested")
    local_nonpersistent_flags+=("--capabilities.india-international-payments.requested")
    local_nonpersistent_flags+=("--capabilities.india-international-payments.requested=")
    flags+=("--capabilities.jcb-payments.requested=")
    two_word_flags+=("--capabilities.jcb-payments.requested")
    local_nonpersistent_flags+=("--capabilities.jcb-payments.requested")
    local_nonpersistent_flags+=("--capabilities.jcb-payments.requested=")
    flags+=("--capabilities.jp-bank-transfer-payments.requested=")
    two_word_flags+=("--capabilities.jp-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.jp-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.jp-bank-transfer-payments.requested=")
    flags+=("--capabilities.kakao-pay-payments.requested=")
    two_word_flags+=("--capabilities.kakao-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.kakao-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.kakao-pay-payments.requested=")
    flags+=("--capabilities.klarna-payments.requested=")
    two_word_flags+=("--capabilities.klarna-payments.requested")
    local_nonpersistent_flags+=("--capabilities.klarna-payments.requested")
    local_nonpersistent_flags+=("--capabilities.klarna-payments.requested=")
    flags+=("--capabilities.konbini-payments.requested=")
    two_word_flags+=("--capabilities.konbini-payments.requested")
    local_nonpersistent_flags+=("--capabilities.konbini-payments.requested")
    local_nonpersistent_flags+=("--capabilities.konbini-payments.requested=")
    flags+=("--capabilities.kr-card-payments.requested=")
    two_word_flags+=("--capabilities.kr-card-payments.requested")
    local_nonpersistent_flags+=("--capabilities.kr-card-payments.requested")
    local_nonpersistent_flags+=("--capabilities.kr-card-payments.requested=")
    flags+=("--capabilities.legacy-payments.requested=")
    two_word_flags+=("--capabilities.legacy-payments.requested")
    local_nonpersistent_flags+=("--capabilities.legacy-payments.requested")
    local_nonpersistent_flags+=("--capabilities.legacy-payments.requested=")
    flags+=("--capabilities.link-payments.requested=")
    two_word_flags+=("--capabilities.link-payments.requested")
    local_nonpersistent_flags+=("--capabilities.link-payments.requested")
    local_nonpersistent_flags+=("--capabilities.link-payments.requested=")
    flags+=("--capabilities.mobilepay-payments.requested=")
    two_word_flags+=("--capabilities.mobilepay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.mobilepay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.mobilepay-payments.requested=")
    flags+=("--capabilities.multibanco-payments.requested=")
    two_word_flags+=("--capabilities.multibanco-payments.requested")
    local_nonpersistent_flags+=("--capabilities.multibanco-payments.requested")
    local_nonpersistent_flags+=("--capabilities.multibanco-payments.requested=")
    flags+=("--capabilities.mx-bank-transfer-payments.requested=")
    two_word_flags+=("--capabilities.mx-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.mx-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.mx-bank-transfer-payments.requested=")
    flags+=("--capabilities.naver-pay-payments.requested=")
    two_word_flags+=("--capabilities.naver-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.naver-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.naver-pay-payments.requested=")
    flags+=("--capabilities.oxxo-payments.requested=")
    two_word_flags+=("--capabilities.oxxo-payments.requested")
    local_nonpersistent_flags+=("--capabilities.oxxo-payments.requested")
    local_nonpersistent_flags+=("--capabilities.oxxo-payments.requested=")
    flags+=("--capabilities.p24-payments.requested=")
    two_word_flags+=("--capabilities.p24-payments.requested")
    local_nonpersistent_flags+=("--capabilities.p24-payments.requested")
    local_nonpersistent_flags+=("--capabilities.p24-payments.requested=")
    flags+=("--capabilities.payco-payments.requested=")
    two_word_flags+=("--capabilities.payco-payments.requested")
    local_nonpersistent_flags+=("--capabilities.payco-payments.requested")
    local_nonpersistent_flags+=("--capabilities.payco-payments.requested=")
    flags+=("--capabilities.paynow-payments.requested=")
    two_word_flags+=("--capabilities.paynow-payments.requested")
    local_nonpersistent_flags+=("--capabilities.paynow-payments.requested")
    local_nonpersistent_flags+=("--capabilities.paynow-payments.requested=")
    flags+=("--capabilities.promptpay-payments.requested=")
    two_word_flags+=("--capabilities.promptpay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.promptpay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.promptpay-payments.requested=")
    flags+=("--capabilities.revolut-pay-payments.requested=")
    two_word_flags+=("--capabilities.revolut-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.revolut-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.revolut-pay-payments.requested=")
    flags+=("--capabilities.samsung-pay-payments.requested=")
    two_word_flags+=("--capabilities.samsung-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.samsung-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.samsung-pay-payments.requested=")
    flags+=("--capabilities.sepa-bank-transfer-payments.requested=")
    two_word_flags+=("--capabilities.sepa-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.sepa-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.sepa-bank-transfer-payments.requested=")
    flags+=("--capabilities.sepa-debit-payments.requested=")
    two_word_flags+=("--capabilities.sepa-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.sepa-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.sepa-debit-payments.requested=")
    flags+=("--capabilities.sofort-payments.requested=")
    two_word_flags+=("--capabilities.sofort-payments.requested")
    local_nonpersistent_flags+=("--capabilities.sofort-payments.requested")
    local_nonpersistent_flags+=("--capabilities.sofort-payments.requested=")
    flags+=("--capabilities.swish-payments.requested=")
    two_word_flags+=("--capabilities.swish-payments.requested")
    local_nonpersistent_flags+=("--capabilities.swish-payments.requested")
    local_nonpersistent_flags+=("--capabilities.swish-payments.requested=")
    flags+=("--capabilities.tax-reporting-us-1099-k.requested=")
    two_word_flags+=("--capabilities.tax-reporting-us-1099-k.requested")
    local_nonpersistent_flags+=("--capabilities.tax-reporting-us-1099-k.requested")
    local_nonpersistent_flags+=("--capabilities.tax-reporting-us-1099-k.requested=")
    flags+=("--capabilities.tax-reporting-us-1099-misc.requested=")
    two_word_flags+=("--capabilities.tax-reporting-us-1099-misc.requested")
    local_nonpersistent_flags+=("--capabilities.tax-reporting-us-1099-misc.requested")
    local_nonpersistent_flags+=("--capabilities.tax-reporting-us-1099-misc.requested=")
    flags+=("--capabilities.transfers.requested=")
    two_word_flags+=("--capabilities.transfers.requested")
    local_nonpersistent_flags+=("--capabilities.transfers.requested")
    local_nonpersistent_flags+=("--capabilities.transfers.requested=")
    flags+=("--capabilities.treasury.requested=")
    two_word_flags+=("--capabilities.treasury.requested")
    local_nonpersistent_flags+=("--capabilities.treasury.requested")
    local_nonpersistent_flags+=("--capabilities.treasury.requested=")
    flags+=("--capabilities.twint-payments.requested=")
    two_word_flags+=("--capabilities.twint-payments.requested")
    local_nonpersistent_flags+=("--capabilities.twint-payments.requested")
    local_nonpersistent_flags+=("--capabilities.twint-payments.requested=")
    flags+=("--capabilities.us-bank-account-ach-payments.requested=")
    two_word_flags+=("--capabilities.us-bank-account-ach-payments.requested")
    local_nonpersistent_flags+=("--capabilities.us-bank-account-ach-payments.requested")
    local_nonpersistent_flags+=("--capabilities.us-bank-account-ach-payments.requested=")
    flags+=("--capabilities.us-bank-transfer-payments.requested=")
    two_word_flags+=("--capabilities.us-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.us-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.us-bank-transfer-payments.requested=")
    flags+=("--capabilities.zip-payments.requested=")
    two_word_flags+=("--capabilities.zip-payments.requested")
    local_nonpersistent_flags+=("--capabilities.zip-payments.requested")
    local_nonpersistent_flags+=("--capabilities.zip-payments.requested=")
    flags+=("--company.address-kana.city=")
    two_word_flags+=("--company.address-kana.city")
    local_nonpersistent_flags+=("--company.address-kana.city")
    local_nonpersistent_flags+=("--company.address-kana.city=")
    flags+=("--company.address-kana.country=")
    two_word_flags+=("--company.address-kana.country")
    local_nonpersistent_flags+=("--company.address-kana.country")
    local_nonpersistent_flags+=("--company.address-kana.country=")
    flags+=("--company.address-kana.line1=")
    two_word_flags+=("--company.address-kana.line1")
    local_nonpersistent_flags+=("--company.address-kana.line1")
    local_nonpersistent_flags+=("--company.address-kana.line1=")
    flags+=("--company.address-kana.line2=")
    two_word_flags+=("--company.address-kana.line2")
    local_nonpersistent_flags+=("--company.address-kana.line2")
    local_nonpersistent_flags+=("--company.address-kana.line2=")
    flags+=("--company.address-kana.postal-code=")
    two_word_flags+=("--company.address-kana.postal-code")
    local_nonpersistent_flags+=("--company.address-kana.postal-code")
    local_nonpersistent_flags+=("--company.address-kana.postal-code=")
    flags+=("--company.address-kana.state=")
    two_word_flags+=("--company.address-kana.state")
    local_nonpersistent_flags+=("--company.address-kana.state")
    local_nonpersistent_flags+=("--company.address-kana.state=")
    flags+=("--company.address-kana.town=")
    two_word_flags+=("--company.address-kana.town")
    local_nonpersistent_flags+=("--company.address-kana.town")
    local_nonpersistent_flags+=("--company.address-kana.town=")
    flags+=("--company.address-kanji.city=")
    two_word_flags+=("--company.address-kanji.city")
    local_nonpersistent_flags+=("--company.address-kanji.city")
    local_nonpersistent_flags+=("--company.address-kanji.city=")
    flags+=("--company.address-kanji.country=")
    two_word_flags+=("--company.address-kanji.country")
    local_nonpersistent_flags+=("--company.address-kanji.country")
    local_nonpersistent_flags+=("--company.address-kanji.country=")
    flags+=("--company.address-kanji.line1=")
    two_word_flags+=("--company.address-kanji.line1")
    local_nonpersistent_flags+=("--company.address-kanji.line1")
    local_nonpersistent_flags+=("--company.address-kanji.line1=")
    flags+=("--company.address-kanji.line2=")
    two_word_flags+=("--company.address-kanji.line2")
    local_nonpersistent_flags+=("--company.address-kanji.line2")
    local_nonpersistent_flags+=("--company.address-kanji.line2=")
    flags+=("--company.address-kanji.postal-code=")
    two_word_flags+=("--company.address-kanji.postal-code")
    local_nonpersistent_flags+=("--company.address-kanji.postal-code")
    local_nonpersistent_flags+=("--company.address-kanji.postal-code=")
    flags+=("--company.address-kanji.state=")
    two_word_flags+=("--company.address-kanji.state")
    local_nonpersistent_flags+=("--company.address-kanji.state")
    local_nonpersistent_flags+=("--company.address-kanji.state=")
    flags+=("--company.address-kanji.town=")
    two_word_flags+=("--company.address-kanji.town")
    local_nonpersistent_flags+=("--company.address-kanji.town")
    local_nonpersistent_flags+=("--company.address-kanji.town=")
    flags+=("--company.address.city=")
    two_word_flags+=("--company.address.city")
    local_nonpersistent_flags+=("--company.address.city")
    local_nonpersistent_flags+=("--company.address.city=")
    flags+=("--company.address.country=")
    two_word_flags+=("--company.address.country")
    local_nonpersistent_flags+=("--company.address.country")
    local_nonpersistent_flags+=("--company.address.country=")
    flags+=("--company.address.line1=")
    two_word_flags+=("--company.address.line1")
    local_nonpersistent_flags+=("--company.address.line1")
    local_nonpersistent_flags+=("--company.address.line1=")
    flags+=("--company.address.line2=")
    two_word_flags+=("--company.address.line2")
    local_nonpersistent_flags+=("--company.address.line2")
    local_nonpersistent_flags+=("--company.address.line2=")
    flags+=("--company.address.postal-code=")
    two_word_flags+=("--company.address.postal-code")
    local_nonpersistent_flags+=("--company.address.postal-code")
    local_nonpersistent_flags+=("--company.address.postal-code=")
    flags+=("--company.address.state=")
    two_word_flags+=("--company.address.state")
    local_nonpersistent_flags+=("--company.address.state")
    local_nonpersistent_flags+=("--company.address.state=")
    flags+=("--company.directors-provided=")
    two_word_flags+=("--company.directors-provided")
    local_nonpersistent_flags+=("--company.directors-provided")
    local_nonpersistent_flags+=("--company.directors-provided=")
    flags+=("--company.executives-provided=")
    two_word_flags+=("--company.executives-provided")
    local_nonpersistent_flags+=("--company.executives-provided")
    local_nonpersistent_flags+=("--company.executives-provided=")
    flags+=("--company.export-license-id=")
    two_word_flags+=("--company.export-license-id")
    local_nonpersistent_flags+=("--company.export-license-id")
    local_nonpersistent_flags+=("--company.export-license-id=")
    flags+=("--company.export-purpose-code=")
    two_word_flags+=("--company.export-purpose-code")
    local_nonpersistent_flags+=("--company.export-purpose-code")
    local_nonpersistent_flags+=("--company.export-purpose-code=")
    flags+=("--company.name=")
    two_word_flags+=("--company.name")
    local_nonpersistent_flags+=("--company.name")
    local_nonpersistent_flags+=("--company.name=")
    flags+=("--company.name-kana=")
    two_word_flags+=("--company.name-kana")
    local_nonpersistent_flags+=("--company.name-kana")
    local_nonpersistent_flags+=("--company.name-kana=")
    flags+=("--company.name-kanji=")
    two_word_flags+=("--company.name-kanji")
    local_nonpersistent_flags+=("--company.name-kanji")
    local_nonpersistent_flags+=("--company.name-kanji=")
    flags+=("--company.owners-provided=")
    two_word_flags+=("--company.owners-provided")
    local_nonpersistent_flags+=("--company.owners-provided")
    local_nonpersistent_flags+=("--company.owners-provided=")
    flags+=("--company.ownership-declaration.date=")
    two_word_flags+=("--company.ownership-declaration.date")
    local_nonpersistent_flags+=("--company.ownership-declaration.date")
    local_nonpersistent_flags+=("--company.ownership-declaration.date=")
    flags+=("--company.ownership-declaration.ip=")
    two_word_flags+=("--company.ownership-declaration.ip")
    local_nonpersistent_flags+=("--company.ownership-declaration.ip")
    local_nonpersistent_flags+=("--company.ownership-declaration.ip=")
    flags+=("--company.ownership-declaration.user-agent=")
    two_word_flags+=("--company.ownership-declaration.user-agent")
    local_nonpersistent_flags+=("--company.ownership-declaration.user-agent")
    local_nonpersistent_flags+=("--company.ownership-declaration.user-agent=")
    flags+=("--company.phone=")
    two_word_flags+=("--company.phone")
    local_nonpersistent_flags+=("--company.phone")
    local_nonpersistent_flags+=("--company.phone=")
    flags+=("--company.registration-number=")
    two_word_flags+=("--company.registration-number")
    local_nonpersistent_flags+=("--company.registration-number")
    local_nonpersistent_flags+=("--company.registration-number=")
    flags+=("--company.structure=")
    two_word_flags+=("--company.structure")
    local_nonpersistent_flags+=("--company.structure")
    local_nonpersistent_flags+=("--company.structure=")
    flags+=("--company.tax-id=")
    two_word_flags+=("--company.tax-id")
    local_nonpersistent_flags+=("--company.tax-id")
    local_nonpersistent_flags+=("--company.tax-id=")
    flags+=("--company.tax-id-registrar=")
    two_word_flags+=("--company.tax-id-registrar")
    local_nonpersistent_flags+=("--company.tax-id-registrar")
    local_nonpersistent_flags+=("--company.tax-id-registrar=")
    flags+=("--company.vat-id=")
    two_word_flags+=("--company.vat-id")
    local_nonpersistent_flags+=("--company.vat-id")
    local_nonpersistent_flags+=("--company.vat-id=")
    flags+=("--company.verification.document.back=")
    two_word_flags+=("--company.verification.document.back")
    local_nonpersistent_flags+=("--company.verification.document.back")
    local_nonpersistent_flags+=("--company.verification.document.back=")
    flags+=("--company.verification.document.front=")
    two_word_flags+=("--company.verification.document.front")
    local_nonpersistent_flags+=("--company.verification.document.front")
    local_nonpersistent_flags+=("--company.verification.document.front=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--controller.fees.payer=")
    two_word_flags+=("--controller.fees.payer")
    local_nonpersistent_flags+=("--controller.fees.payer")
    local_nonpersistent_flags+=("--controller.fees.payer=")
    flags+=("--controller.losses.payments=")
    two_word_flags+=("--controller.losses.payments")
    local_nonpersistent_flags+=("--controller.losses.payments")
    local_nonpersistent_flags+=("--controller.losses.payments=")
    flags+=("--controller.requirement-collection=")
    two_word_flags+=("--controller.requirement-collection")
    local_nonpersistent_flags+=("--controller.requirement-collection")
    local_nonpersistent_flags+=("--controller.requirement-collection=")
    flags+=("--controller.stripe-dashboard.type=")
    two_word_flags+=("--controller.stripe-dashboard.type")
    local_nonpersistent_flags+=("--controller.stripe-dashboard.type")
    local_nonpersistent_flags+=("--controller.stripe-dashboard.type=")
    flags+=("--country=")
    two_word_flags+=("--country")
    local_nonpersistent_flags+=("--country")
    local_nonpersistent_flags+=("--country=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-currency=")
    two_word_flags+=("--default-currency")
    local_nonpersistent_flags+=("--default-currency")
    local_nonpersistent_flags+=("--default-currency=")
    flags+=("--documents.bank-account-ownership-verification.files=")
    two_word_flags+=("--documents.bank-account-ownership-verification.files")
    local_nonpersistent_flags+=("--documents.bank-account-ownership-verification.files")
    local_nonpersistent_flags+=("--documents.bank-account-ownership-verification.files=")
    flags+=("--documents.company-license.files=")
    two_word_flags+=("--documents.company-license.files")
    local_nonpersistent_flags+=("--documents.company-license.files")
    local_nonpersistent_flags+=("--documents.company-license.files=")
    flags+=("--documents.company-memorandum-of-association.files=")
    two_word_flags+=("--documents.company-memorandum-of-association.files")
    local_nonpersistent_flags+=("--documents.company-memorandum-of-association.files")
    local_nonpersistent_flags+=("--documents.company-memorandum-of-association.files=")
    flags+=("--documents.company-ministerial-decree.files=")
    two_word_flags+=("--documents.company-ministerial-decree.files")
    local_nonpersistent_flags+=("--documents.company-ministerial-decree.files")
    local_nonpersistent_flags+=("--documents.company-ministerial-decree.files=")
    flags+=("--documents.company-registration-verification.files=")
    two_word_flags+=("--documents.company-registration-verification.files")
    local_nonpersistent_flags+=("--documents.company-registration-verification.files")
    local_nonpersistent_flags+=("--documents.company-registration-verification.files=")
    flags+=("--documents.company-tax-id-verification.files=")
    two_word_flags+=("--documents.company-tax-id-verification.files")
    local_nonpersistent_flags+=("--documents.company-tax-id-verification.files")
    local_nonpersistent_flags+=("--documents.company-tax-id-verification.files=")
    flags+=("--documents.proof-of-registration.files=")
    two_word_flags+=("--documents.proof-of-registration.files")
    local_nonpersistent_flags+=("--documents.proof-of-registration.files")
    local_nonpersistent_flags+=("--documents.proof-of-registration.files=")
    flags+=("--email=")
    two_word_flags+=("--email")
    local_nonpersistent_flags+=("--email")
    local_nonpersistent_flags+=("--email=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--external-account=")
    two_word_flags+=("--external-account")
    local_nonpersistent_flags+=("--external-account")
    local_nonpersistent_flags+=("--external-account=")
    flags+=("--groups.payments-pricing=")
    two_word_flags+=("--groups.payments-pricing")
    local_nonpersistent_flags+=("--groups.payments-pricing")
    local_nonpersistent_flags+=("--groups.payments-pricing=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--individual.address-kana.city=")
    two_word_flags+=("--individual.address-kana.city")
    local_nonpersistent_flags+=("--individual.address-kana.city")
    local_nonpersistent_flags+=("--individual.address-kana.city=")
    flags+=("--individual.address-kana.country=")
    two_word_flags+=("--individual.address-kana.country")
    local_nonpersistent_flags+=("--individual.address-kana.country")
    local_nonpersistent_flags+=("--individual.address-kana.country=")
    flags+=("--individual.address-kana.line1=")
    two_word_flags+=("--individual.address-kana.line1")
    local_nonpersistent_flags+=("--individual.address-kana.line1")
    local_nonpersistent_flags+=("--individual.address-kana.line1=")
    flags+=("--individual.address-kana.line2=")
    two_word_flags+=("--individual.address-kana.line2")
    local_nonpersistent_flags+=("--individual.address-kana.line2")
    local_nonpersistent_flags+=("--individual.address-kana.line2=")
    flags+=("--individual.address-kana.postal-code=")
    two_word_flags+=("--individual.address-kana.postal-code")
    local_nonpersistent_flags+=("--individual.address-kana.postal-code")
    local_nonpersistent_flags+=("--individual.address-kana.postal-code=")
    flags+=("--individual.address-kana.state=")
    two_word_flags+=("--individual.address-kana.state")
    local_nonpersistent_flags+=("--individual.address-kana.state")
    local_nonpersistent_flags+=("--individual.address-kana.state=")
    flags+=("--individual.address-kana.town=")
    two_word_flags+=("--individual.address-kana.town")
    local_nonpersistent_flags+=("--individual.address-kana.town")
    local_nonpersistent_flags+=("--individual.address-kana.town=")
    flags+=("--individual.address-kanji.city=")
    two_word_flags+=("--individual.address-kanji.city")
    local_nonpersistent_flags+=("--individual.address-kanji.city")
    local_nonpersistent_flags+=("--individual.address-kanji.city=")
    flags+=("--individual.address-kanji.country=")
    two_word_flags+=("--individual.address-kanji.country")
    local_nonpersistent_flags+=("--individual.address-kanji.country")
    local_nonpersistent_flags+=("--individual.address-kanji.country=")
    flags+=("--individual.address-kanji.line1=")
    two_word_flags+=("--individual.address-kanji.line1")
    local_nonpersistent_flags+=("--individual.address-kanji.line1")
    local_nonpersistent_flags+=("--individual.address-kanji.line1=")
    flags+=("--individual.address-kanji.line2=")
    two_word_flags+=("--individual.address-kanji.line2")
    local_nonpersistent_flags+=("--individual.address-kanji.line2")
    local_nonpersistent_flags+=("--individual.address-kanji.line2=")
    flags+=("--individual.address-kanji.postal-code=")
    two_word_flags+=("--individual.address-kanji.postal-code")
    local_nonpersistent_flags+=("--individual.address-kanji.postal-code")
    local_nonpersistent_flags+=("--individual.address-kanji.postal-code=")
    flags+=("--individual.address-kanji.state=")
    two_word_flags+=("--individual.address-kanji.state")
    local_nonpersistent_flags+=("--individual.address-kanji.state")
    local_nonpersistent_flags+=("--individual.address-kanji.state=")
    flags+=("--individual.address-kanji.town=")
    two_word_flags+=("--individual.address-kanji.town")
    local_nonpersistent_flags+=("--individual.address-kanji.town")
    local_nonpersistent_flags+=("--individual.address-kanji.town=")
    flags+=("--individual.address.city=")
    two_word_flags+=("--individual.address.city")
    local_nonpersistent_flags+=("--individual.address.city")
    local_nonpersistent_flags+=("--individual.address.city=")
    flags+=("--individual.address.country=")
    two_word_flags+=("--individual.address.country")
    local_nonpersistent_flags+=("--individual.address.country")
    local_nonpersistent_flags+=("--individual.address.country=")
    flags+=("--individual.address.line1=")
    two_word_flags+=("--individual.address.line1")
    local_nonpersistent_flags+=("--individual.address.line1")
    local_nonpersistent_flags+=("--individual.address.line1=")
    flags+=("--individual.address.line2=")
    two_word_flags+=("--individual.address.line2")
    local_nonpersistent_flags+=("--individual.address.line2")
    local_nonpersistent_flags+=("--individual.address.line2=")
    flags+=("--individual.address.postal-code=")
    two_word_flags+=("--individual.address.postal-code")
    local_nonpersistent_flags+=("--individual.address.postal-code")
    local_nonpersistent_flags+=("--individual.address.postal-code=")
    flags+=("--individual.address.state=")
    two_word_flags+=("--individual.address.state")
    local_nonpersistent_flags+=("--individual.address.state")
    local_nonpersistent_flags+=("--individual.address.state=")
    flags+=("--individual.email=")
    two_word_flags+=("--individual.email")
    local_nonpersistent_flags+=("--individual.email")
    local_nonpersistent_flags+=("--individual.email=")
    flags+=("--individual.first-name=")
    two_word_flags+=("--individual.first-name")
    local_nonpersistent_flags+=("--individual.first-name")
    local_nonpersistent_flags+=("--individual.first-name=")
    flags+=("--individual.first-name-kana=")
    two_word_flags+=("--individual.first-name-kana")
    local_nonpersistent_flags+=("--individual.first-name-kana")
    local_nonpersistent_flags+=("--individual.first-name-kana=")
    flags+=("--individual.first-name-kanji=")
    two_word_flags+=("--individual.first-name-kanji")
    local_nonpersistent_flags+=("--individual.first-name-kanji")
    local_nonpersistent_flags+=("--individual.first-name-kanji=")
    flags+=("--individual.full-name-aliases=")
    two_word_flags+=("--individual.full-name-aliases")
    local_nonpersistent_flags+=("--individual.full-name-aliases")
    local_nonpersistent_flags+=("--individual.full-name-aliases=")
    flags+=("--individual.gender=")
    two_word_flags+=("--individual.gender")
    local_nonpersistent_flags+=("--individual.gender")
    local_nonpersistent_flags+=("--individual.gender=")
    flags+=("--individual.id-number=")
    two_word_flags+=("--individual.id-number")
    local_nonpersistent_flags+=("--individual.id-number")
    local_nonpersistent_flags+=("--individual.id-number=")
    flags+=("--individual.id-number-secondary=")
    two_word_flags+=("--individual.id-number-secondary")
    local_nonpersistent_flags+=("--individual.id-number-secondary")
    local_nonpersistent_flags+=("--individual.id-number-secondary=")
    flags+=("--individual.last-name=")
    two_word_flags+=("--individual.last-name")
    local_nonpersistent_flags+=("--individual.last-name")
    local_nonpersistent_flags+=("--individual.last-name=")
    flags+=("--individual.last-name-kana=")
    two_word_flags+=("--individual.last-name-kana")
    local_nonpersistent_flags+=("--individual.last-name-kana")
    local_nonpersistent_flags+=("--individual.last-name-kana=")
    flags+=("--individual.last-name-kanji=")
    two_word_flags+=("--individual.last-name-kanji")
    local_nonpersistent_flags+=("--individual.last-name-kanji")
    local_nonpersistent_flags+=("--individual.last-name-kanji=")
    flags+=("--individual.maiden-name=")
    two_word_flags+=("--individual.maiden-name")
    local_nonpersistent_flags+=("--individual.maiden-name")
    local_nonpersistent_flags+=("--individual.maiden-name=")
    flags+=("--individual.phone=")
    two_word_flags+=("--individual.phone")
    local_nonpersistent_flags+=("--individual.phone")
    local_nonpersistent_flags+=("--individual.phone=")
    flags+=("--individual.political-exposure=")
    two_word_flags+=("--individual.political-exposure")
    local_nonpersistent_flags+=("--individual.political-exposure")
    local_nonpersistent_flags+=("--individual.political-exposure=")
    flags+=("--individual.registered-address.city=")
    two_word_flags+=("--individual.registered-address.city")
    local_nonpersistent_flags+=("--individual.registered-address.city")
    local_nonpersistent_flags+=("--individual.registered-address.city=")
    flags+=("--individual.registered-address.country=")
    two_word_flags+=("--individual.registered-address.country")
    local_nonpersistent_flags+=("--individual.registered-address.country")
    local_nonpersistent_flags+=("--individual.registered-address.country=")
    flags+=("--individual.registered-address.line1=")
    two_word_flags+=("--individual.registered-address.line1")
    local_nonpersistent_flags+=("--individual.registered-address.line1")
    local_nonpersistent_flags+=("--individual.registered-address.line1=")
    flags+=("--individual.registered-address.line2=")
    two_word_flags+=("--individual.registered-address.line2")
    local_nonpersistent_flags+=("--individual.registered-address.line2")
    local_nonpersistent_flags+=("--individual.registered-address.line2=")
    flags+=("--individual.registered-address.postal-code=")
    two_word_flags+=("--individual.registered-address.postal-code")
    local_nonpersistent_flags+=("--individual.registered-address.postal-code")
    local_nonpersistent_flags+=("--individual.registered-address.postal-code=")
    flags+=("--individual.registered-address.state=")
    two_word_flags+=("--individual.registered-address.state")
    local_nonpersistent_flags+=("--individual.registered-address.state")
    local_nonpersistent_flags+=("--individual.registered-address.state=")
    flags+=("--individual.relationship.director=")
    two_word_flags+=("--individual.relationship.director")
    local_nonpersistent_flags+=("--individual.relationship.director")
    local_nonpersistent_flags+=("--individual.relationship.director=")
    flags+=("--individual.relationship.executive=")
    two_word_flags+=("--individual.relationship.executive")
    local_nonpersistent_flags+=("--individual.relationship.executive")
    local_nonpersistent_flags+=("--individual.relationship.executive=")
    flags+=("--individual.relationship.owner=")
    two_word_flags+=("--individual.relationship.owner")
    local_nonpersistent_flags+=("--individual.relationship.owner")
    local_nonpersistent_flags+=("--individual.relationship.owner=")
    flags+=("--individual.relationship.percent-ownership=")
    two_word_flags+=("--individual.relationship.percent-ownership")
    local_nonpersistent_flags+=("--individual.relationship.percent-ownership")
    local_nonpersistent_flags+=("--individual.relationship.percent-ownership=")
    flags+=("--individual.relationship.title=")
    two_word_flags+=("--individual.relationship.title")
    local_nonpersistent_flags+=("--individual.relationship.title")
    local_nonpersistent_flags+=("--individual.relationship.title=")
    flags+=("--individual.ssn-last-4=")
    two_word_flags+=("--individual.ssn-last-4")
    local_nonpersistent_flags+=("--individual.ssn-last-4")
    local_nonpersistent_flags+=("--individual.ssn-last-4=")
    flags+=("--individual.verification.additional-document.back=")
    two_word_flags+=("--individual.verification.additional-document.back")
    local_nonpersistent_flags+=("--individual.verification.additional-document.back")
    local_nonpersistent_flags+=("--individual.verification.additional-document.back=")
    flags+=("--individual.verification.additional-document.front=")
    two_word_flags+=("--individual.verification.additional-document.front")
    local_nonpersistent_flags+=("--individual.verification.additional-document.front")
    local_nonpersistent_flags+=("--individual.verification.additional-document.front=")
    flags+=("--individual.verification.document.back=")
    two_word_flags+=("--individual.verification.document.back")
    local_nonpersistent_flags+=("--individual.verification.document.back")
    local_nonpersistent_flags+=("--individual.verification.document.back=")
    flags+=("--individual.verification.document.front=")
    two_word_flags+=("--individual.verification.document.front")
    local_nonpersistent_flags+=("--individual.verification.document.front")
    local_nonpersistent_flags+=("--individual.verification.document.front=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--settings.bacs-debit-payments.display-name=")
    two_word_flags+=("--settings.bacs-debit-payments.display-name")
    local_nonpersistent_flags+=("--settings.bacs-debit-payments.display-name")
    local_nonpersistent_flags+=("--settings.bacs-debit-payments.display-name=")
    flags+=("--settings.branding.icon=")
    two_word_flags+=("--settings.branding.icon")
    local_nonpersistent_flags+=("--settings.branding.icon")
    local_nonpersistent_flags+=("--settings.branding.icon=")
    flags+=("--settings.branding.logo=")
    two_word_flags+=("--settings.branding.logo")
    local_nonpersistent_flags+=("--settings.branding.logo")
    local_nonpersistent_flags+=("--settings.branding.logo=")
    flags+=("--settings.branding.primary-color=")
    two_word_flags+=("--settings.branding.primary-color")
    local_nonpersistent_flags+=("--settings.branding.primary-color")
    local_nonpersistent_flags+=("--settings.branding.primary-color=")
    flags+=("--settings.branding.secondary-color=")
    two_word_flags+=("--settings.branding.secondary-color")
    local_nonpersistent_flags+=("--settings.branding.secondary-color")
    local_nonpersistent_flags+=("--settings.branding.secondary-color=")
    flags+=("--settings.card-issuing.tos-acceptance.date=")
    two_word_flags+=("--settings.card-issuing.tos-acceptance.date")
    local_nonpersistent_flags+=("--settings.card-issuing.tos-acceptance.date")
    local_nonpersistent_flags+=("--settings.card-issuing.tos-acceptance.date=")
    flags+=("--settings.card-issuing.tos-acceptance.ip=")
    two_word_flags+=("--settings.card-issuing.tos-acceptance.ip")
    local_nonpersistent_flags+=("--settings.card-issuing.tos-acceptance.ip")
    local_nonpersistent_flags+=("--settings.card-issuing.tos-acceptance.ip=")
    flags+=("--settings.card-issuing.tos-acceptance.user-agent=")
    two_word_flags+=("--settings.card-issuing.tos-acceptance.user-agent")
    local_nonpersistent_flags+=("--settings.card-issuing.tos-acceptance.user-agent")
    local_nonpersistent_flags+=("--settings.card-issuing.tos-acceptance.user-agent=")
    flags+=("--settings.card-payments.decline-on.avs-failure=")
    two_word_flags+=("--settings.card-payments.decline-on.avs-failure")
    local_nonpersistent_flags+=("--settings.card-payments.decline-on.avs-failure")
    local_nonpersistent_flags+=("--settings.card-payments.decline-on.avs-failure=")
    flags+=("--settings.card-payments.decline-on.cvc-failure=")
    two_word_flags+=("--settings.card-payments.decline-on.cvc-failure")
    local_nonpersistent_flags+=("--settings.card-payments.decline-on.cvc-failure")
    local_nonpersistent_flags+=("--settings.card-payments.decline-on.cvc-failure=")
    flags+=("--settings.card-payments.statement-descriptor-prefix=")
    two_word_flags+=("--settings.card-payments.statement-descriptor-prefix")
    local_nonpersistent_flags+=("--settings.card-payments.statement-descriptor-prefix")
    local_nonpersistent_flags+=("--settings.card-payments.statement-descriptor-prefix=")
    flags+=("--settings.card-payments.statement-descriptor-prefix-kana=")
    two_word_flags+=("--settings.card-payments.statement-descriptor-prefix-kana")
    local_nonpersistent_flags+=("--settings.card-payments.statement-descriptor-prefix-kana")
    local_nonpersistent_flags+=("--settings.card-payments.statement-descriptor-prefix-kana=")
    flags+=("--settings.card-payments.statement-descriptor-prefix-kanji=")
    two_word_flags+=("--settings.card-payments.statement-descriptor-prefix-kanji")
    local_nonpersistent_flags+=("--settings.card-payments.statement-descriptor-prefix-kanji")
    local_nonpersistent_flags+=("--settings.card-payments.statement-descriptor-prefix-kanji=")
    flags+=("--settings.payments.statement-descriptor=")
    two_word_flags+=("--settings.payments.statement-descriptor")
    local_nonpersistent_flags+=("--settings.payments.statement-descriptor")
    local_nonpersistent_flags+=("--settings.payments.statement-descriptor=")
    flags+=("--settings.payments.statement-descriptor-kana=")
    two_word_flags+=("--settings.payments.statement-descriptor-kana")
    local_nonpersistent_flags+=("--settings.payments.statement-descriptor-kana")
    local_nonpersistent_flags+=("--settings.payments.statement-descriptor-kana=")
    flags+=("--settings.payments.statement-descriptor-kanji=")
    two_word_flags+=("--settings.payments.statement-descriptor-kanji")
    local_nonpersistent_flags+=("--settings.payments.statement-descriptor-kanji")
    local_nonpersistent_flags+=("--settings.payments.statement-descriptor-kanji=")
    flags+=("--settings.payouts.debit-negative-balances=")
    two_word_flags+=("--settings.payouts.debit-negative-balances")
    local_nonpersistent_flags+=("--settings.payouts.debit-negative-balances")
    local_nonpersistent_flags+=("--settings.payouts.debit-negative-balances=")
    flags+=("--settings.payouts.schedule.delay-days=")
    two_word_flags+=("--settings.payouts.schedule.delay-days")
    local_nonpersistent_flags+=("--settings.payouts.schedule.delay-days")
    local_nonpersistent_flags+=("--settings.payouts.schedule.delay-days=")
    flags+=("--settings.payouts.schedule.interval=")
    two_word_flags+=("--settings.payouts.schedule.interval")
    local_nonpersistent_flags+=("--settings.payouts.schedule.interval")
    local_nonpersistent_flags+=("--settings.payouts.schedule.interval=")
    flags+=("--settings.payouts.schedule.monthly-anchor=")
    two_word_flags+=("--settings.payouts.schedule.monthly-anchor")
    local_nonpersistent_flags+=("--settings.payouts.schedule.monthly-anchor")
    local_nonpersistent_flags+=("--settings.payouts.schedule.monthly-anchor=")
    flags+=("--settings.payouts.schedule.weekly-anchor=")
    two_word_flags+=("--settings.payouts.schedule.weekly-anchor")
    local_nonpersistent_flags+=("--settings.payouts.schedule.weekly-anchor")
    local_nonpersistent_flags+=("--settings.payouts.schedule.weekly-anchor=")
    flags+=("--settings.payouts.statement-descriptor=")
    two_word_flags+=("--settings.payouts.statement-descriptor")
    local_nonpersistent_flags+=("--settings.payouts.statement-descriptor")
    local_nonpersistent_flags+=("--settings.payouts.statement-descriptor=")
    flags+=("--settings.treasury.tos-acceptance.date=")
    two_word_flags+=("--settings.treasury.tos-acceptance.date")
    local_nonpersistent_flags+=("--settings.treasury.tos-acceptance.date")
    local_nonpersistent_flags+=("--settings.treasury.tos-acceptance.date=")
    flags+=("--settings.treasury.tos-acceptance.ip=")
    two_word_flags+=("--settings.treasury.tos-acceptance.ip")
    local_nonpersistent_flags+=("--settings.treasury.tos-acceptance.ip")
    local_nonpersistent_flags+=("--settings.treasury.tos-acceptance.ip=")
    flags+=("--settings.treasury.tos-acceptance.user-agent=")
    two_word_flags+=("--settings.treasury.tos-acceptance.user-agent")
    local_nonpersistent_flags+=("--settings.treasury.tos-acceptance.user-agent")
    local_nonpersistent_flags+=("--settings.treasury.tos-acceptance.user-agent=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tos-acceptance.date=")
    two_word_flags+=("--tos-acceptance.date")
    local_nonpersistent_flags+=("--tos-acceptance.date")
    local_nonpersistent_flags+=("--tos-acceptance.date=")
    flags+=("--tos-acceptance.ip=")
    two_word_flags+=("--tos-acceptance.ip")
    local_nonpersistent_flags+=("--tos-acceptance.ip")
    local_nonpersistent_flags+=("--tos-acceptance.ip=")
    flags+=("--tos-acceptance.service-agreement=")
    two_word_flags+=("--tos-acceptance.service-agreement")
    local_nonpersistent_flags+=("--tos-acceptance.service-agreement")
    local_nonpersistent_flags+=("--tos-acceptance.service-agreement=")
    flags+=("--tos-acceptance.user-agent=")
    two_word_flags+=("--tos-acceptance.user-agent")
    local_nonpersistent_flags+=("--tos-acceptance.user-agent")
    local_nonpersistent_flags+=("--tos-acceptance.user-agent=")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_accounts_delete()
{
    last_command="stripe_accounts_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_accounts_list()
{
    last_command="stripe_accounts_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_accounts_persons()
{
    last_command="stripe_accounts_persons"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_accounts_reject()
{
    last_command="stripe_accounts_reject"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--reason=")
    two_word_flags+=("--reason")
    local_nonpersistent_flags+=("--reason")
    local_nonpersistent_flags+=("--reason=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_accounts_retrieve()
{
    last_command="stripe_accounts_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_accounts_update()
{
    last_command="stripe_accounts_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--account-token=")
    two_word_flags+=("--account-token")
    local_nonpersistent_flags+=("--account-token")
    local_nonpersistent_flags+=("--account-token=")
    flags+=("--business-profile.annual-revenue.amount=")
    two_word_flags+=("--business-profile.annual-revenue.amount")
    local_nonpersistent_flags+=("--business-profile.annual-revenue.amount")
    local_nonpersistent_flags+=("--business-profile.annual-revenue.amount=")
    flags+=("--business-profile.annual-revenue.currency=")
    two_word_flags+=("--business-profile.annual-revenue.currency")
    local_nonpersistent_flags+=("--business-profile.annual-revenue.currency")
    local_nonpersistent_flags+=("--business-profile.annual-revenue.currency=")
    flags+=("--business-profile.annual-revenue.fiscal-year-end=")
    two_word_flags+=("--business-profile.annual-revenue.fiscal-year-end")
    local_nonpersistent_flags+=("--business-profile.annual-revenue.fiscal-year-end")
    local_nonpersistent_flags+=("--business-profile.annual-revenue.fiscal-year-end=")
    flags+=("--business-profile.estimated-worker-count=")
    two_word_flags+=("--business-profile.estimated-worker-count")
    local_nonpersistent_flags+=("--business-profile.estimated-worker-count")
    local_nonpersistent_flags+=("--business-profile.estimated-worker-count=")
    flags+=("--business-profile.mcc=")
    two_word_flags+=("--business-profile.mcc")
    local_nonpersistent_flags+=("--business-profile.mcc")
    local_nonpersistent_flags+=("--business-profile.mcc=")
    flags+=("--business-profile.monthly-estimated-revenue.amount=")
    two_word_flags+=("--business-profile.monthly-estimated-revenue.amount")
    local_nonpersistent_flags+=("--business-profile.monthly-estimated-revenue.amount")
    local_nonpersistent_flags+=("--business-profile.monthly-estimated-revenue.amount=")
    flags+=("--business-profile.monthly-estimated-revenue.currency=")
    two_word_flags+=("--business-profile.monthly-estimated-revenue.currency")
    local_nonpersistent_flags+=("--business-profile.monthly-estimated-revenue.currency")
    local_nonpersistent_flags+=("--business-profile.monthly-estimated-revenue.currency=")
    flags+=("--business-profile.name=")
    two_word_flags+=("--business-profile.name")
    local_nonpersistent_flags+=("--business-profile.name")
    local_nonpersistent_flags+=("--business-profile.name=")
    flags+=("--business-profile.product-description=")
    two_word_flags+=("--business-profile.product-description")
    local_nonpersistent_flags+=("--business-profile.product-description")
    local_nonpersistent_flags+=("--business-profile.product-description=")
    flags+=("--business-profile.support-address.city=")
    two_word_flags+=("--business-profile.support-address.city")
    local_nonpersistent_flags+=("--business-profile.support-address.city")
    local_nonpersistent_flags+=("--business-profile.support-address.city=")
    flags+=("--business-profile.support-address.country=")
    two_word_flags+=("--business-profile.support-address.country")
    local_nonpersistent_flags+=("--business-profile.support-address.country")
    local_nonpersistent_flags+=("--business-profile.support-address.country=")
    flags+=("--business-profile.support-address.line1=")
    two_word_flags+=("--business-profile.support-address.line1")
    local_nonpersistent_flags+=("--business-profile.support-address.line1")
    local_nonpersistent_flags+=("--business-profile.support-address.line1=")
    flags+=("--business-profile.support-address.line2=")
    two_word_flags+=("--business-profile.support-address.line2")
    local_nonpersistent_flags+=("--business-profile.support-address.line2")
    local_nonpersistent_flags+=("--business-profile.support-address.line2=")
    flags+=("--business-profile.support-address.postal-code=")
    two_word_flags+=("--business-profile.support-address.postal-code")
    local_nonpersistent_flags+=("--business-profile.support-address.postal-code")
    local_nonpersistent_flags+=("--business-profile.support-address.postal-code=")
    flags+=("--business-profile.support-address.state=")
    two_word_flags+=("--business-profile.support-address.state")
    local_nonpersistent_flags+=("--business-profile.support-address.state")
    local_nonpersistent_flags+=("--business-profile.support-address.state=")
    flags+=("--business-profile.support-email=")
    two_word_flags+=("--business-profile.support-email")
    local_nonpersistent_flags+=("--business-profile.support-email")
    local_nonpersistent_flags+=("--business-profile.support-email=")
    flags+=("--business-profile.support-phone=")
    two_word_flags+=("--business-profile.support-phone")
    local_nonpersistent_flags+=("--business-profile.support-phone")
    local_nonpersistent_flags+=("--business-profile.support-phone=")
    flags+=("--business-profile.support-url=")
    two_word_flags+=("--business-profile.support-url")
    local_nonpersistent_flags+=("--business-profile.support-url")
    local_nonpersistent_flags+=("--business-profile.support-url=")
    flags+=("--business-profile.url=")
    two_word_flags+=("--business-profile.url")
    local_nonpersistent_flags+=("--business-profile.url")
    local_nonpersistent_flags+=("--business-profile.url=")
    flags+=("--business-type=")
    two_word_flags+=("--business-type")
    local_nonpersistent_flags+=("--business-type")
    local_nonpersistent_flags+=("--business-type=")
    flags+=("--capabilities.acss-debit-payments.requested=")
    two_word_flags+=("--capabilities.acss-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.acss-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.acss-debit-payments.requested=")
    flags+=("--capabilities.affirm-payments.requested=")
    two_word_flags+=("--capabilities.affirm-payments.requested")
    local_nonpersistent_flags+=("--capabilities.affirm-payments.requested")
    local_nonpersistent_flags+=("--capabilities.affirm-payments.requested=")
    flags+=("--capabilities.afterpay-clearpay-payments.requested=")
    two_word_flags+=("--capabilities.afterpay-clearpay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.afterpay-clearpay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.afterpay-clearpay-payments.requested=")
    flags+=("--capabilities.alma-payments.requested=")
    two_word_flags+=("--capabilities.alma-payments.requested")
    local_nonpersistent_flags+=("--capabilities.alma-payments.requested")
    local_nonpersistent_flags+=("--capabilities.alma-payments.requested=")
    flags+=("--capabilities.amazon-pay-payments.requested=")
    two_word_flags+=("--capabilities.amazon-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.amazon-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.amazon-pay-payments.requested=")
    flags+=("--capabilities.au-becs-debit-payments.requested=")
    two_word_flags+=("--capabilities.au-becs-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.au-becs-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.au-becs-debit-payments.requested=")
    flags+=("--capabilities.bacs-debit-payments.requested=")
    two_word_flags+=("--capabilities.bacs-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.bacs-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.bacs-debit-payments.requested=")
    flags+=("--capabilities.bancontact-payments.requested=")
    two_word_flags+=("--capabilities.bancontact-payments.requested")
    local_nonpersistent_flags+=("--capabilities.bancontact-payments.requested")
    local_nonpersistent_flags+=("--capabilities.bancontact-payments.requested=")
    flags+=("--capabilities.bank-transfer-payments.requested=")
    two_word_flags+=("--capabilities.bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.bank-transfer-payments.requested=")
    flags+=("--capabilities.blik-payments.requested=")
    two_word_flags+=("--capabilities.blik-payments.requested")
    local_nonpersistent_flags+=("--capabilities.blik-payments.requested")
    local_nonpersistent_flags+=("--capabilities.blik-payments.requested=")
    flags+=("--capabilities.boleto-payments.requested=")
    two_word_flags+=("--capabilities.boleto-payments.requested")
    local_nonpersistent_flags+=("--capabilities.boleto-payments.requested")
    local_nonpersistent_flags+=("--capabilities.boleto-payments.requested=")
    flags+=("--capabilities.card-issuing.requested=")
    two_word_flags+=("--capabilities.card-issuing.requested")
    local_nonpersistent_flags+=("--capabilities.card-issuing.requested")
    local_nonpersistent_flags+=("--capabilities.card-issuing.requested=")
    flags+=("--capabilities.card-payments.requested=")
    two_word_flags+=("--capabilities.card-payments.requested")
    local_nonpersistent_flags+=("--capabilities.card-payments.requested")
    local_nonpersistent_flags+=("--capabilities.card-payments.requested=")
    flags+=("--capabilities.cartes-bancaires-payments.requested=")
    two_word_flags+=("--capabilities.cartes-bancaires-payments.requested")
    local_nonpersistent_flags+=("--capabilities.cartes-bancaires-payments.requested")
    local_nonpersistent_flags+=("--capabilities.cartes-bancaires-payments.requested=")
    flags+=("--capabilities.cashapp-payments.requested=")
    two_word_flags+=("--capabilities.cashapp-payments.requested")
    local_nonpersistent_flags+=("--capabilities.cashapp-payments.requested")
    local_nonpersistent_flags+=("--capabilities.cashapp-payments.requested=")
    flags+=("--capabilities.eps-payments.requested=")
    two_word_flags+=("--capabilities.eps-payments.requested")
    local_nonpersistent_flags+=("--capabilities.eps-payments.requested")
    local_nonpersistent_flags+=("--capabilities.eps-payments.requested=")
    flags+=("--capabilities.fpx-payments.requested=")
    two_word_flags+=("--capabilities.fpx-payments.requested")
    local_nonpersistent_flags+=("--capabilities.fpx-payments.requested")
    local_nonpersistent_flags+=("--capabilities.fpx-payments.requested=")
    flags+=("--capabilities.gb-bank-transfer-payments.requested=")
    two_word_flags+=("--capabilities.gb-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.gb-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.gb-bank-transfer-payments.requested=")
    flags+=("--capabilities.giropay-payments.requested=")
    two_word_flags+=("--capabilities.giropay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.giropay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.giropay-payments.requested=")
    flags+=("--capabilities.grabpay-payments.requested=")
    two_word_flags+=("--capabilities.grabpay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.grabpay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.grabpay-payments.requested=")
    flags+=("--capabilities.ideal-payments.requested=")
    two_word_flags+=("--capabilities.ideal-payments.requested")
    local_nonpersistent_flags+=("--capabilities.ideal-payments.requested")
    local_nonpersistent_flags+=("--capabilities.ideal-payments.requested=")
    flags+=("--capabilities.india-international-payments.requested=")
    two_word_flags+=("--capabilities.india-international-payments.requested")
    local_nonpersistent_flags+=("--capabilities.india-international-payments.requested")
    local_nonpersistent_flags+=("--capabilities.india-international-payments.requested=")
    flags+=("--capabilities.jcb-payments.requested=")
    two_word_flags+=("--capabilities.jcb-payments.requested")
    local_nonpersistent_flags+=("--capabilities.jcb-payments.requested")
    local_nonpersistent_flags+=("--capabilities.jcb-payments.requested=")
    flags+=("--capabilities.jp-bank-transfer-payments.requested=")
    two_word_flags+=("--capabilities.jp-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.jp-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.jp-bank-transfer-payments.requested=")
    flags+=("--capabilities.kakao-pay-payments.requested=")
    two_word_flags+=("--capabilities.kakao-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.kakao-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.kakao-pay-payments.requested=")
    flags+=("--capabilities.klarna-payments.requested=")
    two_word_flags+=("--capabilities.klarna-payments.requested")
    local_nonpersistent_flags+=("--capabilities.klarna-payments.requested")
    local_nonpersistent_flags+=("--capabilities.klarna-payments.requested=")
    flags+=("--capabilities.konbini-payments.requested=")
    two_word_flags+=("--capabilities.konbini-payments.requested")
    local_nonpersistent_flags+=("--capabilities.konbini-payments.requested")
    local_nonpersistent_flags+=("--capabilities.konbini-payments.requested=")
    flags+=("--capabilities.kr-card-payments.requested=")
    two_word_flags+=("--capabilities.kr-card-payments.requested")
    local_nonpersistent_flags+=("--capabilities.kr-card-payments.requested")
    local_nonpersistent_flags+=("--capabilities.kr-card-payments.requested=")
    flags+=("--capabilities.legacy-payments.requested=")
    two_word_flags+=("--capabilities.legacy-payments.requested")
    local_nonpersistent_flags+=("--capabilities.legacy-payments.requested")
    local_nonpersistent_flags+=("--capabilities.legacy-payments.requested=")
    flags+=("--capabilities.link-payments.requested=")
    two_word_flags+=("--capabilities.link-payments.requested")
    local_nonpersistent_flags+=("--capabilities.link-payments.requested")
    local_nonpersistent_flags+=("--capabilities.link-payments.requested=")
    flags+=("--capabilities.mobilepay-payments.requested=")
    two_word_flags+=("--capabilities.mobilepay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.mobilepay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.mobilepay-payments.requested=")
    flags+=("--capabilities.multibanco-payments.requested=")
    two_word_flags+=("--capabilities.multibanco-payments.requested")
    local_nonpersistent_flags+=("--capabilities.multibanco-payments.requested")
    local_nonpersistent_flags+=("--capabilities.multibanco-payments.requested=")
    flags+=("--capabilities.mx-bank-transfer-payments.requested=")
    two_word_flags+=("--capabilities.mx-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.mx-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.mx-bank-transfer-payments.requested=")
    flags+=("--capabilities.naver-pay-payments.requested=")
    two_word_flags+=("--capabilities.naver-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.naver-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.naver-pay-payments.requested=")
    flags+=("--capabilities.oxxo-payments.requested=")
    two_word_flags+=("--capabilities.oxxo-payments.requested")
    local_nonpersistent_flags+=("--capabilities.oxxo-payments.requested")
    local_nonpersistent_flags+=("--capabilities.oxxo-payments.requested=")
    flags+=("--capabilities.p24-payments.requested=")
    two_word_flags+=("--capabilities.p24-payments.requested")
    local_nonpersistent_flags+=("--capabilities.p24-payments.requested")
    local_nonpersistent_flags+=("--capabilities.p24-payments.requested=")
    flags+=("--capabilities.payco-payments.requested=")
    two_word_flags+=("--capabilities.payco-payments.requested")
    local_nonpersistent_flags+=("--capabilities.payco-payments.requested")
    local_nonpersistent_flags+=("--capabilities.payco-payments.requested=")
    flags+=("--capabilities.paynow-payments.requested=")
    two_word_flags+=("--capabilities.paynow-payments.requested")
    local_nonpersistent_flags+=("--capabilities.paynow-payments.requested")
    local_nonpersistent_flags+=("--capabilities.paynow-payments.requested=")
    flags+=("--capabilities.promptpay-payments.requested=")
    two_word_flags+=("--capabilities.promptpay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.promptpay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.promptpay-payments.requested=")
    flags+=("--capabilities.revolut-pay-payments.requested=")
    two_word_flags+=("--capabilities.revolut-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.revolut-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.revolut-pay-payments.requested=")
    flags+=("--capabilities.samsung-pay-payments.requested=")
    two_word_flags+=("--capabilities.samsung-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.samsung-pay-payments.requested")
    local_nonpersistent_flags+=("--capabilities.samsung-pay-payments.requested=")
    flags+=("--capabilities.sepa-bank-transfer-payments.requested=")
    two_word_flags+=("--capabilities.sepa-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.sepa-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.sepa-bank-transfer-payments.requested=")
    flags+=("--capabilities.sepa-debit-payments.requested=")
    two_word_flags+=("--capabilities.sepa-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.sepa-debit-payments.requested")
    local_nonpersistent_flags+=("--capabilities.sepa-debit-payments.requested=")
    flags+=("--capabilities.sofort-payments.requested=")
    two_word_flags+=("--capabilities.sofort-payments.requested")
    local_nonpersistent_flags+=("--capabilities.sofort-payments.requested")
    local_nonpersistent_flags+=("--capabilities.sofort-payments.requested=")
    flags+=("--capabilities.swish-payments.requested=")
    two_word_flags+=("--capabilities.swish-payments.requested")
    local_nonpersistent_flags+=("--capabilities.swish-payments.requested")
    local_nonpersistent_flags+=("--capabilities.swish-payments.requested=")
    flags+=("--capabilities.tax-reporting-us-1099-k.requested=")
    two_word_flags+=("--capabilities.tax-reporting-us-1099-k.requested")
    local_nonpersistent_flags+=("--capabilities.tax-reporting-us-1099-k.requested")
    local_nonpersistent_flags+=("--capabilities.tax-reporting-us-1099-k.requested=")
    flags+=("--capabilities.tax-reporting-us-1099-misc.requested=")
    two_word_flags+=("--capabilities.tax-reporting-us-1099-misc.requested")
    local_nonpersistent_flags+=("--capabilities.tax-reporting-us-1099-misc.requested")
    local_nonpersistent_flags+=("--capabilities.tax-reporting-us-1099-misc.requested=")
    flags+=("--capabilities.transfers.requested=")
    two_word_flags+=("--capabilities.transfers.requested")
    local_nonpersistent_flags+=("--capabilities.transfers.requested")
    local_nonpersistent_flags+=("--capabilities.transfers.requested=")
    flags+=("--capabilities.treasury.requested=")
    two_word_flags+=("--capabilities.treasury.requested")
    local_nonpersistent_flags+=("--capabilities.treasury.requested")
    local_nonpersistent_flags+=("--capabilities.treasury.requested=")
    flags+=("--capabilities.twint-payments.requested=")
    two_word_flags+=("--capabilities.twint-payments.requested")
    local_nonpersistent_flags+=("--capabilities.twint-payments.requested")
    local_nonpersistent_flags+=("--capabilities.twint-payments.requested=")
    flags+=("--capabilities.us-bank-account-ach-payments.requested=")
    two_word_flags+=("--capabilities.us-bank-account-ach-payments.requested")
    local_nonpersistent_flags+=("--capabilities.us-bank-account-ach-payments.requested")
    local_nonpersistent_flags+=("--capabilities.us-bank-account-ach-payments.requested=")
    flags+=("--capabilities.us-bank-transfer-payments.requested=")
    two_word_flags+=("--capabilities.us-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.us-bank-transfer-payments.requested")
    local_nonpersistent_flags+=("--capabilities.us-bank-transfer-payments.requested=")
    flags+=("--capabilities.zip-payments.requested=")
    two_word_flags+=("--capabilities.zip-payments.requested")
    local_nonpersistent_flags+=("--capabilities.zip-payments.requested")
    local_nonpersistent_flags+=("--capabilities.zip-payments.requested=")
    flags+=("--company.address-kana.city=")
    two_word_flags+=("--company.address-kana.city")
    local_nonpersistent_flags+=("--company.address-kana.city")
    local_nonpersistent_flags+=("--company.address-kana.city=")
    flags+=("--company.address-kana.country=")
    two_word_flags+=("--company.address-kana.country")
    local_nonpersistent_flags+=("--company.address-kana.country")
    local_nonpersistent_flags+=("--company.address-kana.country=")
    flags+=("--company.address-kana.line1=")
    two_word_flags+=("--company.address-kana.line1")
    local_nonpersistent_flags+=("--company.address-kana.line1")
    local_nonpersistent_flags+=("--company.address-kana.line1=")
    flags+=("--company.address-kana.line2=")
    two_word_flags+=("--company.address-kana.line2")
    local_nonpersistent_flags+=("--company.address-kana.line2")
    local_nonpersistent_flags+=("--company.address-kana.line2=")
    flags+=("--company.address-kana.postal-code=")
    two_word_flags+=("--company.address-kana.postal-code")
    local_nonpersistent_flags+=("--company.address-kana.postal-code")
    local_nonpersistent_flags+=("--company.address-kana.postal-code=")
    flags+=("--company.address-kana.state=")
    two_word_flags+=("--company.address-kana.state")
    local_nonpersistent_flags+=("--company.address-kana.state")
    local_nonpersistent_flags+=("--company.address-kana.state=")
    flags+=("--company.address-kana.town=")
    two_word_flags+=("--company.address-kana.town")
    local_nonpersistent_flags+=("--company.address-kana.town")
    local_nonpersistent_flags+=("--company.address-kana.town=")
    flags+=("--company.address-kanji.city=")
    two_word_flags+=("--company.address-kanji.city")
    local_nonpersistent_flags+=("--company.address-kanji.city")
    local_nonpersistent_flags+=("--company.address-kanji.city=")
    flags+=("--company.address-kanji.country=")
    two_word_flags+=("--company.address-kanji.country")
    local_nonpersistent_flags+=("--company.address-kanji.country")
    local_nonpersistent_flags+=("--company.address-kanji.country=")
    flags+=("--company.address-kanji.line1=")
    two_word_flags+=("--company.address-kanji.line1")
    local_nonpersistent_flags+=("--company.address-kanji.line1")
    local_nonpersistent_flags+=("--company.address-kanji.line1=")
    flags+=("--company.address-kanji.line2=")
    two_word_flags+=("--company.address-kanji.line2")
    local_nonpersistent_flags+=("--company.address-kanji.line2")
    local_nonpersistent_flags+=("--company.address-kanji.line2=")
    flags+=("--company.address-kanji.postal-code=")
    two_word_flags+=("--company.address-kanji.postal-code")
    local_nonpersistent_flags+=("--company.address-kanji.postal-code")
    local_nonpersistent_flags+=("--company.address-kanji.postal-code=")
    flags+=("--company.address-kanji.state=")
    two_word_flags+=("--company.address-kanji.state")
    local_nonpersistent_flags+=("--company.address-kanji.state")
    local_nonpersistent_flags+=("--company.address-kanji.state=")
    flags+=("--company.address-kanji.town=")
    two_word_flags+=("--company.address-kanji.town")
    local_nonpersistent_flags+=("--company.address-kanji.town")
    local_nonpersistent_flags+=("--company.address-kanji.town=")
    flags+=("--company.address.city=")
    two_word_flags+=("--company.address.city")
    local_nonpersistent_flags+=("--company.address.city")
    local_nonpersistent_flags+=("--company.address.city=")
    flags+=("--company.address.country=")
    two_word_flags+=("--company.address.country")
    local_nonpersistent_flags+=("--company.address.country")
    local_nonpersistent_flags+=("--company.address.country=")
    flags+=("--company.address.line1=")
    two_word_flags+=("--company.address.line1")
    local_nonpersistent_flags+=("--company.address.line1")
    local_nonpersistent_flags+=("--company.address.line1=")
    flags+=("--company.address.line2=")
    two_word_flags+=("--company.address.line2")
    local_nonpersistent_flags+=("--company.address.line2")
    local_nonpersistent_flags+=("--company.address.line2=")
    flags+=("--company.address.postal-code=")
    two_word_flags+=("--company.address.postal-code")
    local_nonpersistent_flags+=("--company.address.postal-code")
    local_nonpersistent_flags+=("--company.address.postal-code=")
    flags+=("--company.address.state=")
    two_word_flags+=("--company.address.state")
    local_nonpersistent_flags+=("--company.address.state")
    local_nonpersistent_flags+=("--company.address.state=")
    flags+=("--company.directors-provided=")
    two_word_flags+=("--company.directors-provided")
    local_nonpersistent_flags+=("--company.directors-provided")
    local_nonpersistent_flags+=("--company.directors-provided=")
    flags+=("--company.executives-provided=")
    two_word_flags+=("--company.executives-provided")
    local_nonpersistent_flags+=("--company.executives-provided")
    local_nonpersistent_flags+=("--company.executives-provided=")
    flags+=("--company.export-license-id=")
    two_word_flags+=("--company.export-license-id")
    local_nonpersistent_flags+=("--company.export-license-id")
    local_nonpersistent_flags+=("--company.export-license-id=")
    flags+=("--company.export-purpose-code=")
    two_word_flags+=("--company.export-purpose-code")
    local_nonpersistent_flags+=("--company.export-purpose-code")
    local_nonpersistent_flags+=("--company.export-purpose-code=")
    flags+=("--company.name=")
    two_word_flags+=("--company.name")
    local_nonpersistent_flags+=("--company.name")
    local_nonpersistent_flags+=("--company.name=")
    flags+=("--company.name-kana=")
    two_word_flags+=("--company.name-kana")
    local_nonpersistent_flags+=("--company.name-kana")
    local_nonpersistent_flags+=("--company.name-kana=")
    flags+=("--company.name-kanji=")
    two_word_flags+=("--company.name-kanji")
    local_nonpersistent_flags+=("--company.name-kanji")
    local_nonpersistent_flags+=("--company.name-kanji=")
    flags+=("--company.owners-provided=")
    two_word_flags+=("--company.owners-provided")
    local_nonpersistent_flags+=("--company.owners-provided")
    local_nonpersistent_flags+=("--company.owners-provided=")
    flags+=("--company.ownership-declaration.date=")
    two_word_flags+=("--company.ownership-declaration.date")
    local_nonpersistent_flags+=("--company.ownership-declaration.date")
    local_nonpersistent_flags+=("--company.ownership-declaration.date=")
    flags+=("--company.ownership-declaration.ip=")
    two_word_flags+=("--company.ownership-declaration.ip")
    local_nonpersistent_flags+=("--company.ownership-declaration.ip")
    local_nonpersistent_flags+=("--company.ownership-declaration.ip=")
    flags+=("--company.ownership-declaration.user-agent=")
    two_word_flags+=("--company.ownership-declaration.user-agent")
    local_nonpersistent_flags+=("--company.ownership-declaration.user-agent")
    local_nonpersistent_flags+=("--company.ownership-declaration.user-agent=")
    flags+=("--company.phone=")
    two_word_flags+=("--company.phone")
    local_nonpersistent_flags+=("--company.phone")
    local_nonpersistent_flags+=("--company.phone=")
    flags+=("--company.registration-number=")
    two_word_flags+=("--company.registration-number")
    local_nonpersistent_flags+=("--company.registration-number")
    local_nonpersistent_flags+=("--company.registration-number=")
    flags+=("--company.structure=")
    two_word_flags+=("--company.structure")
    local_nonpersistent_flags+=("--company.structure")
    local_nonpersistent_flags+=("--company.structure=")
    flags+=("--company.tax-id=")
    two_word_flags+=("--company.tax-id")
    local_nonpersistent_flags+=("--company.tax-id")
    local_nonpersistent_flags+=("--company.tax-id=")
    flags+=("--company.tax-id-registrar=")
    two_word_flags+=("--company.tax-id-registrar")
    local_nonpersistent_flags+=("--company.tax-id-registrar")
    local_nonpersistent_flags+=("--company.tax-id-registrar=")
    flags+=("--company.vat-id=")
    two_word_flags+=("--company.vat-id")
    local_nonpersistent_flags+=("--company.vat-id")
    local_nonpersistent_flags+=("--company.vat-id=")
    flags+=("--company.verification.document.back=")
    two_word_flags+=("--company.verification.document.back")
    local_nonpersistent_flags+=("--company.verification.document.back")
    local_nonpersistent_flags+=("--company.verification.document.back=")
    flags+=("--company.verification.document.front=")
    two_word_flags+=("--company.verification.document.front")
    local_nonpersistent_flags+=("--company.verification.document.front")
    local_nonpersistent_flags+=("--company.verification.document.front=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-currency=")
    two_word_flags+=("--default-currency")
    local_nonpersistent_flags+=("--default-currency")
    local_nonpersistent_flags+=("--default-currency=")
    flags+=("--documents.bank-account-ownership-verification.files=")
    two_word_flags+=("--documents.bank-account-ownership-verification.files")
    local_nonpersistent_flags+=("--documents.bank-account-ownership-verification.files")
    local_nonpersistent_flags+=("--documents.bank-account-ownership-verification.files=")
    flags+=("--documents.company-license.files=")
    two_word_flags+=("--documents.company-license.files")
    local_nonpersistent_flags+=("--documents.company-license.files")
    local_nonpersistent_flags+=("--documents.company-license.files=")
    flags+=("--documents.company-memorandum-of-association.files=")
    two_word_flags+=("--documents.company-memorandum-of-association.files")
    local_nonpersistent_flags+=("--documents.company-memorandum-of-association.files")
    local_nonpersistent_flags+=("--documents.company-memorandum-of-association.files=")
    flags+=("--documents.company-ministerial-decree.files=")
    two_word_flags+=("--documents.company-ministerial-decree.files")
    local_nonpersistent_flags+=("--documents.company-ministerial-decree.files")
    local_nonpersistent_flags+=("--documents.company-ministerial-decree.files=")
    flags+=("--documents.company-registration-verification.files=")
    two_word_flags+=("--documents.company-registration-verification.files")
    local_nonpersistent_flags+=("--documents.company-registration-verification.files")
    local_nonpersistent_flags+=("--documents.company-registration-verification.files=")
    flags+=("--documents.company-tax-id-verification.files=")
    two_word_flags+=("--documents.company-tax-id-verification.files")
    local_nonpersistent_flags+=("--documents.company-tax-id-verification.files")
    local_nonpersistent_flags+=("--documents.company-tax-id-verification.files=")
    flags+=("--documents.proof-of-registration.files=")
    two_word_flags+=("--documents.proof-of-registration.files")
    local_nonpersistent_flags+=("--documents.proof-of-registration.files")
    local_nonpersistent_flags+=("--documents.proof-of-registration.files=")
    flags+=("--email=")
    two_word_flags+=("--email")
    local_nonpersistent_flags+=("--email")
    local_nonpersistent_flags+=("--email=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--external-account=")
    two_word_flags+=("--external-account")
    local_nonpersistent_flags+=("--external-account")
    local_nonpersistent_flags+=("--external-account=")
    flags+=("--groups.payments-pricing=")
    two_word_flags+=("--groups.payments-pricing")
    local_nonpersistent_flags+=("--groups.payments-pricing")
    local_nonpersistent_flags+=("--groups.payments-pricing=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--individual.address-kana.city=")
    two_word_flags+=("--individual.address-kana.city")
    local_nonpersistent_flags+=("--individual.address-kana.city")
    local_nonpersistent_flags+=("--individual.address-kana.city=")
    flags+=("--individual.address-kana.country=")
    two_word_flags+=("--individual.address-kana.country")
    local_nonpersistent_flags+=("--individual.address-kana.country")
    local_nonpersistent_flags+=("--individual.address-kana.country=")
    flags+=("--individual.address-kana.line1=")
    two_word_flags+=("--individual.address-kana.line1")
    local_nonpersistent_flags+=("--individual.address-kana.line1")
    local_nonpersistent_flags+=("--individual.address-kana.line1=")
    flags+=("--individual.address-kana.line2=")
    two_word_flags+=("--individual.address-kana.line2")
    local_nonpersistent_flags+=("--individual.address-kana.line2")
    local_nonpersistent_flags+=("--individual.address-kana.line2=")
    flags+=("--individual.address-kana.postal-code=")
    two_word_flags+=("--individual.address-kana.postal-code")
    local_nonpersistent_flags+=("--individual.address-kana.postal-code")
    local_nonpersistent_flags+=("--individual.address-kana.postal-code=")
    flags+=("--individual.address-kana.state=")
    two_word_flags+=("--individual.address-kana.state")
    local_nonpersistent_flags+=("--individual.address-kana.state")
    local_nonpersistent_flags+=("--individual.address-kana.state=")
    flags+=("--individual.address-kana.town=")
    two_word_flags+=("--individual.address-kana.town")
    local_nonpersistent_flags+=("--individual.address-kana.town")
    local_nonpersistent_flags+=("--individual.address-kana.town=")
    flags+=("--individual.address-kanji.city=")
    two_word_flags+=("--individual.address-kanji.city")
    local_nonpersistent_flags+=("--individual.address-kanji.city")
    local_nonpersistent_flags+=("--individual.address-kanji.city=")
    flags+=("--individual.address-kanji.country=")
    two_word_flags+=("--individual.address-kanji.country")
    local_nonpersistent_flags+=("--individual.address-kanji.country")
    local_nonpersistent_flags+=("--individual.address-kanji.country=")
    flags+=("--individual.address-kanji.line1=")
    two_word_flags+=("--individual.address-kanji.line1")
    local_nonpersistent_flags+=("--individual.address-kanji.line1")
    local_nonpersistent_flags+=("--individual.address-kanji.line1=")
    flags+=("--individual.address-kanji.line2=")
    two_word_flags+=("--individual.address-kanji.line2")
    local_nonpersistent_flags+=("--individual.address-kanji.line2")
    local_nonpersistent_flags+=("--individual.address-kanji.line2=")
    flags+=("--individual.address-kanji.postal-code=")
    two_word_flags+=("--individual.address-kanji.postal-code")
    local_nonpersistent_flags+=("--individual.address-kanji.postal-code")
    local_nonpersistent_flags+=("--individual.address-kanji.postal-code=")
    flags+=("--individual.address-kanji.state=")
    two_word_flags+=("--individual.address-kanji.state")
    local_nonpersistent_flags+=("--individual.address-kanji.state")
    local_nonpersistent_flags+=("--individual.address-kanji.state=")
    flags+=("--individual.address-kanji.town=")
    two_word_flags+=("--individual.address-kanji.town")
    local_nonpersistent_flags+=("--individual.address-kanji.town")
    local_nonpersistent_flags+=("--individual.address-kanji.town=")
    flags+=("--individual.address.city=")
    two_word_flags+=("--individual.address.city")
    local_nonpersistent_flags+=("--individual.address.city")
    local_nonpersistent_flags+=("--individual.address.city=")
    flags+=("--individual.address.country=")
    two_word_flags+=("--individual.address.country")
    local_nonpersistent_flags+=("--individual.address.country")
    local_nonpersistent_flags+=("--individual.address.country=")
    flags+=("--individual.address.line1=")
    two_word_flags+=("--individual.address.line1")
    local_nonpersistent_flags+=("--individual.address.line1")
    local_nonpersistent_flags+=("--individual.address.line1=")
    flags+=("--individual.address.line2=")
    two_word_flags+=("--individual.address.line2")
    local_nonpersistent_flags+=("--individual.address.line2")
    local_nonpersistent_flags+=("--individual.address.line2=")
    flags+=("--individual.address.postal-code=")
    two_word_flags+=("--individual.address.postal-code")
    local_nonpersistent_flags+=("--individual.address.postal-code")
    local_nonpersistent_flags+=("--individual.address.postal-code=")
    flags+=("--individual.address.state=")
    two_word_flags+=("--individual.address.state")
    local_nonpersistent_flags+=("--individual.address.state")
    local_nonpersistent_flags+=("--individual.address.state=")
    flags+=("--individual.email=")
    two_word_flags+=("--individual.email")
    local_nonpersistent_flags+=("--individual.email")
    local_nonpersistent_flags+=("--individual.email=")
    flags+=("--individual.first-name=")
    two_word_flags+=("--individual.first-name")
    local_nonpersistent_flags+=("--individual.first-name")
    local_nonpersistent_flags+=("--individual.first-name=")
    flags+=("--individual.first-name-kana=")
    two_word_flags+=("--individual.first-name-kana")
    local_nonpersistent_flags+=("--individual.first-name-kana")
    local_nonpersistent_flags+=("--individual.first-name-kana=")
    flags+=("--individual.first-name-kanji=")
    two_word_flags+=("--individual.first-name-kanji")
    local_nonpersistent_flags+=("--individual.first-name-kanji")
    local_nonpersistent_flags+=("--individual.first-name-kanji=")
    flags+=("--individual.full-name-aliases=")
    two_word_flags+=("--individual.full-name-aliases")
    local_nonpersistent_flags+=("--individual.full-name-aliases")
    local_nonpersistent_flags+=("--individual.full-name-aliases=")
    flags+=("--individual.gender=")
    two_word_flags+=("--individual.gender")
    local_nonpersistent_flags+=("--individual.gender")
    local_nonpersistent_flags+=("--individual.gender=")
    flags+=("--individual.id-number=")
    two_word_flags+=("--individual.id-number")
    local_nonpersistent_flags+=("--individual.id-number")
    local_nonpersistent_flags+=("--individual.id-number=")
    flags+=("--individual.id-number-secondary=")
    two_word_flags+=("--individual.id-number-secondary")
    local_nonpersistent_flags+=("--individual.id-number-secondary")
    local_nonpersistent_flags+=("--individual.id-number-secondary=")
    flags+=("--individual.last-name=")
    two_word_flags+=("--individual.last-name")
    local_nonpersistent_flags+=("--individual.last-name")
    local_nonpersistent_flags+=("--individual.last-name=")
    flags+=("--individual.last-name-kana=")
    two_word_flags+=("--individual.last-name-kana")
    local_nonpersistent_flags+=("--individual.last-name-kana")
    local_nonpersistent_flags+=("--individual.last-name-kana=")
    flags+=("--individual.last-name-kanji=")
    two_word_flags+=("--individual.last-name-kanji")
    local_nonpersistent_flags+=("--individual.last-name-kanji")
    local_nonpersistent_flags+=("--individual.last-name-kanji=")
    flags+=("--individual.maiden-name=")
    two_word_flags+=("--individual.maiden-name")
    local_nonpersistent_flags+=("--individual.maiden-name")
    local_nonpersistent_flags+=("--individual.maiden-name=")
    flags+=("--individual.phone=")
    two_word_flags+=("--individual.phone")
    local_nonpersistent_flags+=("--individual.phone")
    local_nonpersistent_flags+=("--individual.phone=")
    flags+=("--individual.political-exposure=")
    two_word_flags+=("--individual.political-exposure")
    local_nonpersistent_flags+=("--individual.political-exposure")
    local_nonpersistent_flags+=("--individual.political-exposure=")
    flags+=("--individual.registered-address.city=")
    two_word_flags+=("--individual.registered-address.city")
    local_nonpersistent_flags+=("--individual.registered-address.city")
    local_nonpersistent_flags+=("--individual.registered-address.city=")
    flags+=("--individual.registered-address.country=")
    two_word_flags+=("--individual.registered-address.country")
    local_nonpersistent_flags+=("--individual.registered-address.country")
    local_nonpersistent_flags+=("--individual.registered-address.country=")
    flags+=("--individual.registered-address.line1=")
    two_word_flags+=("--individual.registered-address.line1")
    local_nonpersistent_flags+=("--individual.registered-address.line1")
    local_nonpersistent_flags+=("--individual.registered-address.line1=")
    flags+=("--individual.registered-address.line2=")
    two_word_flags+=("--individual.registered-address.line2")
    local_nonpersistent_flags+=("--individual.registered-address.line2")
    local_nonpersistent_flags+=("--individual.registered-address.line2=")
    flags+=("--individual.registered-address.postal-code=")
    two_word_flags+=("--individual.registered-address.postal-code")
    local_nonpersistent_flags+=("--individual.registered-address.postal-code")
    local_nonpersistent_flags+=("--individual.registered-address.postal-code=")
    flags+=("--individual.registered-address.state=")
    two_word_flags+=("--individual.registered-address.state")
    local_nonpersistent_flags+=("--individual.registered-address.state")
    local_nonpersistent_flags+=("--individual.registered-address.state=")
    flags+=("--individual.relationship.director=")
    two_word_flags+=("--individual.relationship.director")
    local_nonpersistent_flags+=("--individual.relationship.director")
    local_nonpersistent_flags+=("--individual.relationship.director=")
    flags+=("--individual.relationship.executive=")
    two_word_flags+=("--individual.relationship.executive")
    local_nonpersistent_flags+=("--individual.relationship.executive")
    local_nonpersistent_flags+=("--individual.relationship.executive=")
    flags+=("--individual.relationship.owner=")
    two_word_flags+=("--individual.relationship.owner")
    local_nonpersistent_flags+=("--individual.relationship.owner")
    local_nonpersistent_flags+=("--individual.relationship.owner=")
    flags+=("--individual.relationship.percent-ownership=")
    two_word_flags+=("--individual.relationship.percent-ownership")
    local_nonpersistent_flags+=("--individual.relationship.percent-ownership")
    local_nonpersistent_flags+=("--individual.relationship.percent-ownership=")
    flags+=("--individual.relationship.title=")
    two_word_flags+=("--individual.relationship.title")
    local_nonpersistent_flags+=("--individual.relationship.title")
    local_nonpersistent_flags+=("--individual.relationship.title=")
    flags+=("--individual.ssn-last-4=")
    two_word_flags+=("--individual.ssn-last-4")
    local_nonpersistent_flags+=("--individual.ssn-last-4")
    local_nonpersistent_flags+=("--individual.ssn-last-4=")
    flags+=("--individual.verification.additional-document.back=")
    two_word_flags+=("--individual.verification.additional-document.back")
    local_nonpersistent_flags+=("--individual.verification.additional-document.back")
    local_nonpersistent_flags+=("--individual.verification.additional-document.back=")
    flags+=("--individual.verification.additional-document.front=")
    two_word_flags+=("--individual.verification.additional-document.front")
    local_nonpersistent_flags+=("--individual.verification.additional-document.front")
    local_nonpersistent_flags+=("--individual.verification.additional-document.front=")
    flags+=("--individual.verification.document.back=")
    two_word_flags+=("--individual.verification.document.back")
    local_nonpersistent_flags+=("--individual.verification.document.back")
    local_nonpersistent_flags+=("--individual.verification.document.back=")
    flags+=("--individual.verification.document.front=")
    two_word_flags+=("--individual.verification.document.front")
    local_nonpersistent_flags+=("--individual.verification.document.front")
    local_nonpersistent_flags+=("--individual.verification.document.front=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--settings.bacs-debit-payments.display-name=")
    two_word_flags+=("--settings.bacs-debit-payments.display-name")
    local_nonpersistent_flags+=("--settings.bacs-debit-payments.display-name")
    local_nonpersistent_flags+=("--settings.bacs-debit-payments.display-name=")
    flags+=("--settings.branding.icon=")
    two_word_flags+=("--settings.branding.icon")
    local_nonpersistent_flags+=("--settings.branding.icon")
    local_nonpersistent_flags+=("--settings.branding.icon=")
    flags+=("--settings.branding.logo=")
    two_word_flags+=("--settings.branding.logo")
    local_nonpersistent_flags+=("--settings.branding.logo")
    local_nonpersistent_flags+=("--settings.branding.logo=")
    flags+=("--settings.branding.primary-color=")
    two_word_flags+=("--settings.branding.primary-color")
    local_nonpersistent_flags+=("--settings.branding.primary-color")
    local_nonpersistent_flags+=("--settings.branding.primary-color=")
    flags+=("--settings.branding.secondary-color=")
    two_word_flags+=("--settings.branding.secondary-color")
    local_nonpersistent_flags+=("--settings.branding.secondary-color")
    local_nonpersistent_flags+=("--settings.branding.secondary-color=")
    flags+=("--settings.card-issuing.tos-acceptance.date=")
    two_word_flags+=("--settings.card-issuing.tos-acceptance.date")
    local_nonpersistent_flags+=("--settings.card-issuing.tos-acceptance.date")
    local_nonpersistent_flags+=("--settings.card-issuing.tos-acceptance.date=")
    flags+=("--settings.card-issuing.tos-acceptance.ip=")
    two_word_flags+=("--settings.card-issuing.tos-acceptance.ip")
    local_nonpersistent_flags+=("--settings.card-issuing.tos-acceptance.ip")
    local_nonpersistent_flags+=("--settings.card-issuing.tos-acceptance.ip=")
    flags+=("--settings.card-issuing.tos-acceptance.user-agent=")
    two_word_flags+=("--settings.card-issuing.tos-acceptance.user-agent")
    local_nonpersistent_flags+=("--settings.card-issuing.tos-acceptance.user-agent")
    local_nonpersistent_flags+=("--settings.card-issuing.tos-acceptance.user-agent=")
    flags+=("--settings.card-payments.decline-on.avs-failure=")
    two_word_flags+=("--settings.card-payments.decline-on.avs-failure")
    local_nonpersistent_flags+=("--settings.card-payments.decline-on.avs-failure")
    local_nonpersistent_flags+=("--settings.card-payments.decline-on.avs-failure=")
    flags+=("--settings.card-payments.decline-on.cvc-failure=")
    two_word_flags+=("--settings.card-payments.decline-on.cvc-failure")
    local_nonpersistent_flags+=("--settings.card-payments.decline-on.cvc-failure")
    local_nonpersistent_flags+=("--settings.card-payments.decline-on.cvc-failure=")
    flags+=("--settings.card-payments.statement-descriptor-prefix=")
    two_word_flags+=("--settings.card-payments.statement-descriptor-prefix")
    local_nonpersistent_flags+=("--settings.card-payments.statement-descriptor-prefix")
    local_nonpersistent_flags+=("--settings.card-payments.statement-descriptor-prefix=")
    flags+=("--settings.card-payments.statement-descriptor-prefix-kana=")
    two_word_flags+=("--settings.card-payments.statement-descriptor-prefix-kana")
    local_nonpersistent_flags+=("--settings.card-payments.statement-descriptor-prefix-kana")
    local_nonpersistent_flags+=("--settings.card-payments.statement-descriptor-prefix-kana=")
    flags+=("--settings.card-payments.statement-descriptor-prefix-kanji=")
    two_word_flags+=("--settings.card-payments.statement-descriptor-prefix-kanji")
    local_nonpersistent_flags+=("--settings.card-payments.statement-descriptor-prefix-kanji")
    local_nonpersistent_flags+=("--settings.card-payments.statement-descriptor-prefix-kanji=")
    flags+=("--settings.invoices.default-account-tax-ids=")
    two_word_flags+=("--settings.invoices.default-account-tax-ids")
    local_nonpersistent_flags+=("--settings.invoices.default-account-tax-ids")
    local_nonpersistent_flags+=("--settings.invoices.default-account-tax-ids=")
    flags+=("--settings.payments.statement-descriptor=")
    two_word_flags+=("--settings.payments.statement-descriptor")
    local_nonpersistent_flags+=("--settings.payments.statement-descriptor")
    local_nonpersistent_flags+=("--settings.payments.statement-descriptor=")
    flags+=("--settings.payments.statement-descriptor-kana=")
    two_word_flags+=("--settings.payments.statement-descriptor-kana")
    local_nonpersistent_flags+=("--settings.payments.statement-descriptor-kana")
    local_nonpersistent_flags+=("--settings.payments.statement-descriptor-kana=")
    flags+=("--settings.payments.statement-descriptor-kanji=")
    two_word_flags+=("--settings.payments.statement-descriptor-kanji")
    local_nonpersistent_flags+=("--settings.payments.statement-descriptor-kanji")
    local_nonpersistent_flags+=("--settings.payments.statement-descriptor-kanji=")
    flags+=("--settings.payouts.debit-negative-balances=")
    two_word_flags+=("--settings.payouts.debit-negative-balances")
    local_nonpersistent_flags+=("--settings.payouts.debit-negative-balances")
    local_nonpersistent_flags+=("--settings.payouts.debit-negative-balances=")
    flags+=("--settings.payouts.schedule.delay-days=")
    two_word_flags+=("--settings.payouts.schedule.delay-days")
    local_nonpersistent_flags+=("--settings.payouts.schedule.delay-days")
    local_nonpersistent_flags+=("--settings.payouts.schedule.delay-days=")
    flags+=("--settings.payouts.schedule.interval=")
    two_word_flags+=("--settings.payouts.schedule.interval")
    local_nonpersistent_flags+=("--settings.payouts.schedule.interval")
    local_nonpersistent_flags+=("--settings.payouts.schedule.interval=")
    flags+=("--settings.payouts.schedule.monthly-anchor=")
    two_word_flags+=("--settings.payouts.schedule.monthly-anchor")
    local_nonpersistent_flags+=("--settings.payouts.schedule.monthly-anchor")
    local_nonpersistent_flags+=("--settings.payouts.schedule.monthly-anchor=")
    flags+=("--settings.payouts.schedule.weekly-anchor=")
    two_word_flags+=("--settings.payouts.schedule.weekly-anchor")
    local_nonpersistent_flags+=("--settings.payouts.schedule.weekly-anchor")
    local_nonpersistent_flags+=("--settings.payouts.schedule.weekly-anchor=")
    flags+=("--settings.payouts.statement-descriptor=")
    two_word_flags+=("--settings.payouts.statement-descriptor")
    local_nonpersistent_flags+=("--settings.payouts.statement-descriptor")
    local_nonpersistent_flags+=("--settings.payouts.statement-descriptor=")
    flags+=("--settings.treasury.tos-acceptance.date=")
    two_word_flags+=("--settings.treasury.tos-acceptance.date")
    local_nonpersistent_flags+=("--settings.treasury.tos-acceptance.date")
    local_nonpersistent_flags+=("--settings.treasury.tos-acceptance.date=")
    flags+=("--settings.treasury.tos-acceptance.ip=")
    two_word_flags+=("--settings.treasury.tos-acceptance.ip")
    local_nonpersistent_flags+=("--settings.treasury.tos-acceptance.ip")
    local_nonpersistent_flags+=("--settings.treasury.tos-acceptance.ip=")
    flags+=("--settings.treasury.tos-acceptance.user-agent=")
    two_word_flags+=("--settings.treasury.tos-acceptance.user-agent")
    local_nonpersistent_flags+=("--settings.treasury.tos-acceptance.user-agent")
    local_nonpersistent_flags+=("--settings.treasury.tos-acceptance.user-agent=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tos-acceptance.date=")
    two_word_flags+=("--tos-acceptance.date")
    local_nonpersistent_flags+=("--tos-acceptance.date")
    local_nonpersistent_flags+=("--tos-acceptance.date=")
    flags+=("--tos-acceptance.ip=")
    two_word_flags+=("--tos-acceptance.ip")
    local_nonpersistent_flags+=("--tos-acceptance.ip")
    local_nonpersistent_flags+=("--tos-acceptance.ip=")
    flags+=("--tos-acceptance.service-agreement=")
    two_word_flags+=("--tos-acceptance.service-agreement")
    local_nonpersistent_flags+=("--tos-acceptance.service-agreement")
    local_nonpersistent_flags+=("--tos-acceptance.service-agreement=")
    flags+=("--tos-acceptance.user-agent=")
    two_word_flags+=("--tos-acceptance.user-agent")
    local_nonpersistent_flags+=("--tos-acceptance.user-agent")
    local_nonpersistent_flags+=("--tos-acceptance.user-agent=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_accounts()
{
    last_command="stripe_accounts"

    command_aliases=()

    commands=()
    commands+=("capabilities")
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("persons")
    commands+=("reject")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_apple_pay_domains_create()
{
    last_command="stripe_apple_pay_domains_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--domain-name=")
    two_word_flags+=("--domain-name")
    local_nonpersistent_flags+=("--domain-name")
    local_nonpersistent_flags+=("--domain-name=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_apple_pay_domains_delete()
{
    last_command="stripe_apple_pay_domains_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_apple_pay_domains_list()
{
    last_command="stripe_apple_pay_domains_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--domain-name=")
    two_word_flags+=("--domain-name")
    local_nonpersistent_flags+=("--domain-name")
    local_nonpersistent_flags+=("--domain-name=")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_apple_pay_domains_retrieve()
{
    last_command="stripe_apple_pay_domains_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_apple_pay_domains()
{
    last_command="stripe_apple_pay_domains"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_application_fees_list()
{
    last_command="stripe_application_fees_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--charge=")
    two_word_flags+=("--charge")
    local_nonpersistent_flags+=("--charge")
    local_nonpersistent_flags+=("--charge=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_application_fees_retrieve()
{
    last_command="stripe_application_fees_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_application_fees()
{
    last_command="stripe_application_fees"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_balance_retrieve()
{
    last_command="stripe_balance_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_balance()
{
    last_command="stripe_balance"

    command_aliases=()

    commands=()
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_balance_transactions_list()
{
    last_command="stripe_balance_transactions_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payout=")
    two_word_flags+=("--payout")
    local_nonpersistent_flags+=("--payout")
    local_nonpersistent_flags+=("--payout=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--source=")
    two_word_flags+=("--source")
    local_nonpersistent_flags+=("--source")
    local_nonpersistent_flags+=("--source=")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_balance_transactions_retrieve()
{
    last_command="stripe_balance_transactions_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_balance_transactions()
{
    last_command="stripe_balance_transactions"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_bank_accounts_delete()
{
    last_command="stripe_bank_accounts_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_bank_accounts_update()
{
    last_command="stripe_bank_accounts_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--account-holder-name=")
    two_word_flags+=("--account-holder-name")
    local_nonpersistent_flags+=("--account-holder-name")
    local_nonpersistent_flags+=("--account-holder-name=")
    flags+=("--account-holder-type=")
    two_word_flags+=("--account-holder-type")
    local_nonpersistent_flags+=("--account-holder-type")
    local_nonpersistent_flags+=("--account-holder-type=")
    flags+=("--account-type=")
    two_word_flags+=("--account-type")
    local_nonpersistent_flags+=("--account-type")
    local_nonpersistent_flags+=("--account-type=")
    flags+=("--address-city=")
    two_word_flags+=("--address-city")
    local_nonpersistent_flags+=("--address-city")
    local_nonpersistent_flags+=("--address-city=")
    flags+=("--address-country=")
    two_word_flags+=("--address-country")
    local_nonpersistent_flags+=("--address-country")
    local_nonpersistent_flags+=("--address-country=")
    flags+=("--address-line1=")
    two_word_flags+=("--address-line1")
    local_nonpersistent_flags+=("--address-line1")
    local_nonpersistent_flags+=("--address-line1=")
    flags+=("--address-line2=")
    two_word_flags+=("--address-line2")
    local_nonpersistent_flags+=("--address-line2")
    local_nonpersistent_flags+=("--address-line2=")
    flags+=("--address-state=")
    two_word_flags+=("--address-state")
    local_nonpersistent_flags+=("--address-state")
    local_nonpersistent_flags+=("--address-state=")
    flags+=("--address-zip=")
    two_word_flags+=("--address-zip")
    local_nonpersistent_flags+=("--address-zip")
    local_nonpersistent_flags+=("--address-zip=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-for-currency=")
    two_word_flags+=("--default-for-currency")
    local_nonpersistent_flags+=("--default-for-currency")
    local_nonpersistent_flags+=("--default-for-currency=")
    flags+=("--documents.bank-account-ownership-verification.files=")
    two_word_flags+=("--documents.bank-account-ownership-verification.files")
    local_nonpersistent_flags+=("--documents.bank-account-ownership-verification.files")
    local_nonpersistent_flags+=("--documents.bank-account-ownership-verification.files=")
    flags+=("--exp-month=")
    two_word_flags+=("--exp-month")
    local_nonpersistent_flags+=("--exp-month")
    local_nonpersistent_flags+=("--exp-month=")
    flags+=("--exp-year=")
    two_word_flags+=("--exp-year")
    local_nonpersistent_flags+=("--exp-year")
    local_nonpersistent_flags+=("--exp-year=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_bank_accounts_verify()
{
    last_command="stripe_bank_accounts_verify"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amounts=")
    two_word_flags+=("--amounts")
    local_nonpersistent_flags+=("--amounts")
    local_nonpersistent_flags+=("--amounts=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_bank_accounts()
{
    last_command="stripe_bank_accounts"

    command_aliases=()

    commands=()
    commands+=("delete")
    commands+=("update")
    commands+=("verify")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_alerts_activate()
{
    last_command="stripe_billing_alerts_activate"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_alerts_archive()
{
    last_command="stripe_billing_alerts_archive"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_alerts_create()
{
    last_command="stripe_billing_alerts_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--alert-type=")
    two_word_flags+=("--alert-type")
    local_nonpersistent_flags+=("--alert-type")
    local_nonpersistent_flags+=("--alert-type=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--title=")
    two_word_flags+=("--title")
    local_nonpersistent_flags+=("--title")
    local_nonpersistent_flags+=("--title=")
    flags+=("--usage-threshold.gte=")
    two_word_flags+=("--usage-threshold.gte")
    local_nonpersistent_flags+=("--usage-threshold.gte")
    local_nonpersistent_flags+=("--usage-threshold.gte=")
    flags+=("--usage-threshold.meter=")
    two_word_flags+=("--usage-threshold.meter")
    local_nonpersistent_flags+=("--usage-threshold.meter")
    local_nonpersistent_flags+=("--usage-threshold.meter=")
    flags+=("--usage-threshold.recurrence=")
    two_word_flags+=("--usage-threshold.recurrence")
    local_nonpersistent_flags+=("--usage-threshold.recurrence")
    local_nonpersistent_flags+=("--usage-threshold.recurrence=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_alerts_deactivate()
{
    last_command="stripe_billing_alerts_deactivate"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_alerts_list()
{
    last_command="stripe_billing_alerts_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--alert-type=")
    two_word_flags+=("--alert-type")
    local_nonpersistent_flags+=("--alert-type")
    local_nonpersistent_flags+=("--alert-type=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--meter=")
    two_word_flags+=("--meter")
    local_nonpersistent_flags+=("--meter")
    local_nonpersistent_flags+=("--meter=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_alerts_retrieve()
{
    last_command="stripe_billing_alerts_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_alerts()
{
    last_command="stripe_billing_alerts"

    command_aliases=()

    commands=()
    commands+=("activate")
    commands+=("archive")
    commands+=("create")
    commands+=("deactivate")
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_credit_balance_summarys_retrieve()
{
    last_command="stripe_billing_credit_balance_summarys_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_credit_balance_summarys()
{
    last_command="stripe_billing_credit_balance_summarys"

    command_aliases=()

    commands=()
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_credit_balance_transactions_list()
{
    last_command="stripe_billing_credit_balance_transactions_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--credit-grant=")
    two_word_flags+=("--credit-grant")
    local_nonpersistent_flags+=("--credit-grant")
    local_nonpersistent_flags+=("--credit-grant=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_credit_balance_transactions_retrieve()
{
    last_command="stripe_billing_credit_balance_transactions_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_credit_balance_transactions()
{
    last_command="stripe_billing_credit_balance_transactions"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_credit_grants_create()
{
    last_command="stripe_billing_credit_grants_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount.monetary.currency=")
    two_word_flags+=("--amount.monetary.currency")
    local_nonpersistent_flags+=("--amount.monetary.currency")
    local_nonpersistent_flags+=("--amount.monetary.currency=")
    flags+=("--amount.monetary.value=")
    two_word_flags+=("--amount.monetary.value")
    local_nonpersistent_flags+=("--amount.monetary.value")
    local_nonpersistent_flags+=("--amount.monetary.value=")
    flags+=("--amount.type=")
    two_word_flags+=("--amount.type")
    local_nonpersistent_flags+=("--amount.type")
    local_nonpersistent_flags+=("--amount.type=")
    flags+=("--applicability-config.scope.price-type=")
    two_word_flags+=("--applicability-config.scope.price-type")
    local_nonpersistent_flags+=("--applicability-config.scope.price-type")
    local_nonpersistent_flags+=("--applicability-config.scope.price-type=")
    flags+=("--category=")
    two_word_flags+=("--category")
    local_nonpersistent_flags+=("--category")
    local_nonpersistent_flags+=("--category=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--effective-at=")
    two_word_flags+=("--effective-at")
    local_nonpersistent_flags+=("--effective-at")
    local_nonpersistent_flags+=("--effective-at=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--expires-at=")
    two_word_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_credit_grants_expire()
{
    last_command="stripe_billing_credit_grants_expire"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_credit_grants_list()
{
    last_command="stripe_billing_credit_grants_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_credit_grants_retrieve()
{
    last_command="stripe_billing_credit_grants_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_credit_grants_update()
{
    last_command="stripe_billing_credit_grants_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--expires-at=")
    two_word_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_credit_grants_void_grant()
{
    last_command="stripe_billing_credit_grants_void_grant"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_credit_grants()
{
    last_command="stripe_billing_credit_grants"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("expire")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")
    commands+=("void_grant")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meter_event_adjustments_create()
{
    last_command="stripe_billing_meter_event_adjustments_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--cancel.identifier=")
    two_word_flags+=("--cancel.identifier")
    local_nonpersistent_flags+=("--cancel.identifier")
    local_nonpersistent_flags+=("--cancel.identifier=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--event-name=")
    two_word_flags+=("--event-name")
    local_nonpersistent_flags+=("--event-name")
    local_nonpersistent_flags+=("--event-name=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meter_event_adjustments()
{
    last_command="stripe_billing_meter_event_adjustments"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meter_event_session_create()
{
    last_command="stripe_billing_meter_event_session_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meter_event_session()
{
    last_command="stripe_billing_meter_event_session"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meter_event_stream_create()
{
    last_command="stripe_billing_meter_event_stream_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meter_event_stream()
{
    last_command="stripe_billing_meter_event_stream"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meter_event_summarys_list()
{
    last_command="stripe_billing_meter_event_summarys_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--end-time=")
    two_word_flags+=("--end-time")
    local_nonpersistent_flags+=("--end-time")
    local_nonpersistent_flags+=("--end-time=")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--start-time=")
    two_word_flags+=("--start-time")
    local_nonpersistent_flags+=("--start-time")
    local_nonpersistent_flags+=("--start-time=")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--value-grouping-window=")
    two_word_flags+=("--value-grouping-window")
    local_nonpersistent_flags+=("--value-grouping-window")
    local_nonpersistent_flags+=("--value-grouping-window=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meter_event_summarys()
{
    last_command="stripe_billing_meter_event_summarys"

    command_aliases=()

    commands=()
    commands+=("list")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meter_events_create()
{
    last_command="stripe_billing_meter_events_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--event-name=")
    two_word_flags+=("--event-name")
    local_nonpersistent_flags+=("--event-name")
    local_nonpersistent_flags+=("--event-name=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--identifier=")
    two_word_flags+=("--identifier")
    local_nonpersistent_flags+=("--identifier")
    local_nonpersistent_flags+=("--identifier=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--timestamp=")
    two_word_flags+=("--timestamp")
    local_nonpersistent_flags+=("--timestamp")
    local_nonpersistent_flags+=("--timestamp=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meter_events()
{
    last_command="stripe_billing_meter_events"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meters_create()
{
    last_command="stripe_billing_meters_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer-mapping.event-payload-key=")
    two_word_flags+=("--customer-mapping.event-payload-key")
    local_nonpersistent_flags+=("--customer-mapping.event-payload-key")
    local_nonpersistent_flags+=("--customer-mapping.event-payload-key=")
    flags+=("--customer-mapping.type=")
    two_word_flags+=("--customer-mapping.type")
    local_nonpersistent_flags+=("--customer-mapping.type")
    local_nonpersistent_flags+=("--customer-mapping.type=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-aggregation.formula=")
    two_word_flags+=("--default-aggregation.formula")
    local_nonpersistent_flags+=("--default-aggregation.formula")
    local_nonpersistent_flags+=("--default-aggregation.formula=")
    flags+=("--display-name=")
    two_word_flags+=("--display-name")
    local_nonpersistent_flags+=("--display-name")
    local_nonpersistent_flags+=("--display-name=")
    flags+=("--event-name=")
    two_word_flags+=("--event-name")
    local_nonpersistent_flags+=("--event-name")
    local_nonpersistent_flags+=("--event-name=")
    flags+=("--event-time-window=")
    two_word_flags+=("--event-time-window")
    local_nonpersistent_flags+=("--event-time-window")
    local_nonpersistent_flags+=("--event-time-window=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--value-settings.event-payload-key=")
    two_word_flags+=("--value-settings.event-payload-key")
    local_nonpersistent_flags+=("--value-settings.event-payload-key")
    local_nonpersistent_flags+=("--value-settings.event-payload-key=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meters_deactivate()
{
    last_command="stripe_billing_meters_deactivate"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meters_list()
{
    last_command="stripe_billing_meters_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meters_reactivate()
{
    last_command="stripe_billing_meters_reactivate"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meters_retrieve()
{
    last_command="stripe_billing_meters_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meters_update()
{
    last_command="stripe_billing_meters_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--display-name=")
    two_word_flags+=("--display-name")
    local_nonpersistent_flags+=("--display-name")
    local_nonpersistent_flags+=("--display-name=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_meters()
{
    last_command="stripe_billing_meters"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("deactivate")
    commands+=("list")
    commands+=("reactivate")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing()
{
    last_command="stripe_billing"

    command_aliases=()

    commands=()
    commands+=("alerts")
    commands+=("credit_balance_summarys")
    commands+=("credit_balance_transactions")
    commands+=("credit_grants")
    commands+=("meter_event_adjustments")
    commands+=("meter_event_session")
    commands+=("meter_event_stream")
    commands+=("meter_event_summarys")
    commands+=("meter_events")
    commands+=("meters")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_portal_configurations_create()
{
    last_command="stripe_billing_portal_configurations_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--business-profile.headline=")
    two_word_flags+=("--business-profile.headline")
    local_nonpersistent_flags+=("--business-profile.headline")
    local_nonpersistent_flags+=("--business-profile.headline=")
    flags+=("--business-profile.privacy-policy-url=")
    two_word_flags+=("--business-profile.privacy-policy-url")
    local_nonpersistent_flags+=("--business-profile.privacy-policy-url")
    local_nonpersistent_flags+=("--business-profile.privacy-policy-url=")
    flags+=("--business-profile.terms-of-service-url=")
    two_word_flags+=("--business-profile.terms-of-service-url")
    local_nonpersistent_flags+=("--business-profile.terms-of-service-url")
    local_nonpersistent_flags+=("--business-profile.terms-of-service-url=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-return-url=")
    two_word_flags+=("--default-return-url")
    local_nonpersistent_flags+=("--default-return-url")
    local_nonpersistent_flags+=("--default-return-url=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--features.customer-update.allowed-updates=")
    two_word_flags+=("--features.customer-update.allowed-updates")
    local_nonpersistent_flags+=("--features.customer-update.allowed-updates")
    local_nonpersistent_flags+=("--features.customer-update.allowed-updates=")
    flags+=("--features.customer-update.enabled=")
    two_word_flags+=("--features.customer-update.enabled")
    local_nonpersistent_flags+=("--features.customer-update.enabled")
    local_nonpersistent_flags+=("--features.customer-update.enabled=")
    flags+=("--features.invoice-history.enabled=")
    two_word_flags+=("--features.invoice-history.enabled")
    local_nonpersistent_flags+=("--features.invoice-history.enabled")
    local_nonpersistent_flags+=("--features.invoice-history.enabled=")
    flags+=("--features.payment-method-update.enabled=")
    two_word_flags+=("--features.payment-method-update.enabled")
    local_nonpersistent_flags+=("--features.payment-method-update.enabled")
    local_nonpersistent_flags+=("--features.payment-method-update.enabled=")
    flags+=("--features.subscription-cancel.cancellation-reason.enabled=")
    two_word_flags+=("--features.subscription-cancel.cancellation-reason.enabled")
    local_nonpersistent_flags+=("--features.subscription-cancel.cancellation-reason.enabled")
    local_nonpersistent_flags+=("--features.subscription-cancel.cancellation-reason.enabled=")
    flags+=("--features.subscription-cancel.cancellation-reason.options=")
    two_word_flags+=("--features.subscription-cancel.cancellation-reason.options")
    local_nonpersistent_flags+=("--features.subscription-cancel.cancellation-reason.options")
    local_nonpersistent_flags+=("--features.subscription-cancel.cancellation-reason.options=")
    flags+=("--features.subscription-cancel.enabled=")
    two_word_flags+=("--features.subscription-cancel.enabled")
    local_nonpersistent_flags+=("--features.subscription-cancel.enabled")
    local_nonpersistent_flags+=("--features.subscription-cancel.enabled=")
    flags+=("--features.subscription-cancel.mode=")
    two_word_flags+=("--features.subscription-cancel.mode")
    local_nonpersistent_flags+=("--features.subscription-cancel.mode")
    local_nonpersistent_flags+=("--features.subscription-cancel.mode=")
    flags+=("--features.subscription-cancel.proration-behavior=")
    two_word_flags+=("--features.subscription-cancel.proration-behavior")
    local_nonpersistent_flags+=("--features.subscription-cancel.proration-behavior")
    local_nonpersistent_flags+=("--features.subscription-cancel.proration-behavior=")
    flags+=("--features.subscription-update.default-allowed-updates=")
    two_word_flags+=("--features.subscription-update.default-allowed-updates")
    local_nonpersistent_flags+=("--features.subscription-update.default-allowed-updates")
    local_nonpersistent_flags+=("--features.subscription-update.default-allowed-updates=")
    flags+=("--features.subscription-update.enabled=")
    two_word_flags+=("--features.subscription-update.enabled")
    local_nonpersistent_flags+=("--features.subscription-update.enabled")
    local_nonpersistent_flags+=("--features.subscription-update.enabled=")
    flags+=("--features.subscription-update.proration-behavior=")
    two_word_flags+=("--features.subscription-update.proration-behavior")
    local_nonpersistent_flags+=("--features.subscription-update.proration-behavior")
    local_nonpersistent_flags+=("--features.subscription-update.proration-behavior=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--login-page.enabled=")
    two_word_flags+=("--login-page.enabled")
    local_nonpersistent_flags+=("--login-page.enabled")
    local_nonpersistent_flags+=("--login-page.enabled=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_portal_configurations_list()
{
    last_command="stripe_billing_portal_configurations_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--is-default=")
    two_word_flags+=("--is-default")
    local_nonpersistent_flags+=("--is-default")
    local_nonpersistent_flags+=("--is-default=")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_portal_configurations_retrieve()
{
    last_command="stripe_billing_portal_configurations_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_portal_configurations_update()
{
    last_command="stripe_billing_portal_configurations_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--business-profile.headline=")
    two_word_flags+=("--business-profile.headline")
    local_nonpersistent_flags+=("--business-profile.headline")
    local_nonpersistent_flags+=("--business-profile.headline=")
    flags+=("--business-profile.privacy-policy-url=")
    two_word_flags+=("--business-profile.privacy-policy-url")
    local_nonpersistent_flags+=("--business-profile.privacy-policy-url")
    local_nonpersistent_flags+=("--business-profile.privacy-policy-url=")
    flags+=("--business-profile.terms-of-service-url=")
    two_word_flags+=("--business-profile.terms-of-service-url")
    local_nonpersistent_flags+=("--business-profile.terms-of-service-url")
    local_nonpersistent_flags+=("--business-profile.terms-of-service-url=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-return-url=")
    two_word_flags+=("--default-return-url")
    local_nonpersistent_flags+=("--default-return-url")
    local_nonpersistent_flags+=("--default-return-url=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--features.customer-update.allowed-updates=")
    two_word_flags+=("--features.customer-update.allowed-updates")
    local_nonpersistent_flags+=("--features.customer-update.allowed-updates")
    local_nonpersistent_flags+=("--features.customer-update.allowed-updates=")
    flags+=("--features.customer-update.enabled=")
    two_word_flags+=("--features.customer-update.enabled")
    local_nonpersistent_flags+=("--features.customer-update.enabled")
    local_nonpersistent_flags+=("--features.customer-update.enabled=")
    flags+=("--features.invoice-history.enabled=")
    two_word_flags+=("--features.invoice-history.enabled")
    local_nonpersistent_flags+=("--features.invoice-history.enabled")
    local_nonpersistent_flags+=("--features.invoice-history.enabled=")
    flags+=("--features.payment-method-update.enabled=")
    two_word_flags+=("--features.payment-method-update.enabled")
    local_nonpersistent_flags+=("--features.payment-method-update.enabled")
    local_nonpersistent_flags+=("--features.payment-method-update.enabled=")
    flags+=("--features.subscription-cancel.cancellation-reason.enabled=")
    two_word_flags+=("--features.subscription-cancel.cancellation-reason.enabled")
    local_nonpersistent_flags+=("--features.subscription-cancel.cancellation-reason.enabled")
    local_nonpersistent_flags+=("--features.subscription-cancel.cancellation-reason.enabled=")
    flags+=("--features.subscription-cancel.cancellation-reason.options=")
    two_word_flags+=("--features.subscription-cancel.cancellation-reason.options")
    local_nonpersistent_flags+=("--features.subscription-cancel.cancellation-reason.options")
    local_nonpersistent_flags+=("--features.subscription-cancel.cancellation-reason.options=")
    flags+=("--features.subscription-cancel.enabled=")
    two_word_flags+=("--features.subscription-cancel.enabled")
    local_nonpersistent_flags+=("--features.subscription-cancel.enabled")
    local_nonpersistent_flags+=("--features.subscription-cancel.enabled=")
    flags+=("--features.subscription-cancel.mode=")
    two_word_flags+=("--features.subscription-cancel.mode")
    local_nonpersistent_flags+=("--features.subscription-cancel.mode")
    local_nonpersistent_flags+=("--features.subscription-cancel.mode=")
    flags+=("--features.subscription-cancel.proration-behavior=")
    two_word_flags+=("--features.subscription-cancel.proration-behavior")
    local_nonpersistent_flags+=("--features.subscription-cancel.proration-behavior")
    local_nonpersistent_flags+=("--features.subscription-cancel.proration-behavior=")
    flags+=("--features.subscription-update.default-allowed-updates=")
    two_word_flags+=("--features.subscription-update.default-allowed-updates")
    local_nonpersistent_flags+=("--features.subscription-update.default-allowed-updates")
    local_nonpersistent_flags+=("--features.subscription-update.default-allowed-updates=")
    flags+=("--features.subscription-update.enabled=")
    two_word_flags+=("--features.subscription-update.enabled")
    local_nonpersistent_flags+=("--features.subscription-update.enabled")
    local_nonpersistent_flags+=("--features.subscription-update.enabled=")
    flags+=("--features.subscription-update.proration-behavior=")
    two_word_flags+=("--features.subscription-update.proration-behavior")
    local_nonpersistent_flags+=("--features.subscription-update.proration-behavior")
    local_nonpersistent_flags+=("--features.subscription-update.proration-behavior=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--login-page.enabled=")
    two_word_flags+=("--login-page.enabled")
    local_nonpersistent_flags+=("--login-page.enabled")
    local_nonpersistent_flags+=("--login-page.enabled=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_portal_configurations()
{
    last_command="stripe_billing_portal_configurations"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_portal_sessions_create()
{
    last_command="stripe_billing_portal_sessions_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--configuration=")
    two_word_flags+=("--configuration")
    local_nonpersistent_flags+=("--configuration")
    local_nonpersistent_flags+=("--configuration=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--flow-data.after-completion.hosted-confirmation.custom-message=")
    two_word_flags+=("--flow-data.after-completion.hosted-confirmation.custom-message")
    local_nonpersistent_flags+=("--flow-data.after-completion.hosted-confirmation.custom-message")
    local_nonpersistent_flags+=("--flow-data.after-completion.hosted-confirmation.custom-message=")
    flags+=("--flow-data.after-completion.redirect.return-url=")
    two_word_flags+=("--flow-data.after-completion.redirect.return-url")
    local_nonpersistent_flags+=("--flow-data.after-completion.redirect.return-url")
    local_nonpersistent_flags+=("--flow-data.after-completion.redirect.return-url=")
    flags+=("--flow-data.after-completion.type=")
    two_word_flags+=("--flow-data.after-completion.type")
    local_nonpersistent_flags+=("--flow-data.after-completion.type")
    local_nonpersistent_flags+=("--flow-data.after-completion.type=")
    flags+=("--flow-data.subscription-cancel.retention.coupon-offer.coupon=")
    two_word_flags+=("--flow-data.subscription-cancel.retention.coupon-offer.coupon")
    local_nonpersistent_flags+=("--flow-data.subscription-cancel.retention.coupon-offer.coupon")
    local_nonpersistent_flags+=("--flow-data.subscription-cancel.retention.coupon-offer.coupon=")
    flags+=("--flow-data.subscription-cancel.retention.type=")
    two_word_flags+=("--flow-data.subscription-cancel.retention.type")
    local_nonpersistent_flags+=("--flow-data.subscription-cancel.retention.type")
    local_nonpersistent_flags+=("--flow-data.subscription-cancel.retention.type=")
    flags+=("--flow-data.subscription-cancel.subscription=")
    two_word_flags+=("--flow-data.subscription-cancel.subscription")
    local_nonpersistent_flags+=("--flow-data.subscription-cancel.subscription")
    local_nonpersistent_flags+=("--flow-data.subscription-cancel.subscription=")
    flags+=("--flow-data.subscription-update-confirm.subscription=")
    two_word_flags+=("--flow-data.subscription-update-confirm.subscription")
    local_nonpersistent_flags+=("--flow-data.subscription-update-confirm.subscription")
    local_nonpersistent_flags+=("--flow-data.subscription-update-confirm.subscription=")
    flags+=("--flow-data.subscription-update.subscription=")
    two_word_flags+=("--flow-data.subscription-update.subscription")
    local_nonpersistent_flags+=("--flow-data.subscription-update.subscription")
    local_nonpersistent_flags+=("--flow-data.subscription-update.subscription=")
    flags+=("--flow-data.type=")
    two_word_flags+=("--flow-data.type")
    local_nonpersistent_flags+=("--flow-data.type")
    local_nonpersistent_flags+=("--flow-data.type=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--locale=")
    two_word_flags+=("--locale")
    local_nonpersistent_flags+=("--locale")
    local_nonpersistent_flags+=("--locale=")
    flags+=("--on-behalf-of=")
    two_word_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of=")
    flags+=("--return-url=")
    two_word_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_portal_sessions()
{
    last_command="stripe_billing_portal_sessions"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_billing_portal()
{
    last_command="stripe_billing_portal"

    command_aliases=()

    commands=()
    commands+=("configurations")
    commands+=("sessions")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_capabilities_list()
{
    last_command="stripe_capabilities_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_capabilities_retrieve()
{
    last_command="stripe_capabilities_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_capabilities_update()
{
    last_command="stripe_capabilities_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--requested=")
    two_word_flags+=("--requested")
    local_nonpersistent_flags+=("--requested")
    local_nonpersistent_flags+=("--requested=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_capabilities()
{
    last_command="stripe_capabilities"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_cards_delete()
{
    last_command="stripe_cards_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_cards_update()
{
    last_command="stripe_cards_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--account-holder-name=")
    two_word_flags+=("--account-holder-name")
    local_nonpersistent_flags+=("--account-holder-name")
    local_nonpersistent_flags+=("--account-holder-name=")
    flags+=("--account-holder-type=")
    two_word_flags+=("--account-holder-type")
    local_nonpersistent_flags+=("--account-holder-type")
    local_nonpersistent_flags+=("--account-holder-type=")
    flags+=("--account-type=")
    two_word_flags+=("--account-type")
    local_nonpersistent_flags+=("--account-type")
    local_nonpersistent_flags+=("--account-type=")
    flags+=("--address-city=")
    two_word_flags+=("--address-city")
    local_nonpersistent_flags+=("--address-city")
    local_nonpersistent_flags+=("--address-city=")
    flags+=("--address-country=")
    two_word_flags+=("--address-country")
    local_nonpersistent_flags+=("--address-country")
    local_nonpersistent_flags+=("--address-country=")
    flags+=("--address-line1=")
    two_word_flags+=("--address-line1")
    local_nonpersistent_flags+=("--address-line1")
    local_nonpersistent_flags+=("--address-line1=")
    flags+=("--address-line2=")
    two_word_flags+=("--address-line2")
    local_nonpersistent_flags+=("--address-line2")
    local_nonpersistent_flags+=("--address-line2=")
    flags+=("--address-state=")
    two_word_flags+=("--address-state")
    local_nonpersistent_flags+=("--address-state")
    local_nonpersistent_flags+=("--address-state=")
    flags+=("--address-zip=")
    two_word_flags+=("--address-zip")
    local_nonpersistent_flags+=("--address-zip")
    local_nonpersistent_flags+=("--address-zip=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-for-currency=")
    two_word_flags+=("--default-for-currency")
    local_nonpersistent_flags+=("--default-for-currency")
    local_nonpersistent_flags+=("--default-for-currency=")
    flags+=("--documents.bank-account-ownership-verification.files=")
    two_word_flags+=("--documents.bank-account-ownership-verification.files")
    local_nonpersistent_flags+=("--documents.bank-account-ownership-verification.files")
    local_nonpersistent_flags+=("--documents.bank-account-ownership-verification.files=")
    flags+=("--exp-month=")
    two_word_flags+=("--exp-month")
    local_nonpersistent_flags+=("--exp-month")
    local_nonpersistent_flags+=("--exp-month=")
    flags+=("--exp-year=")
    two_word_flags+=("--exp-year")
    local_nonpersistent_flags+=("--exp-year")
    local_nonpersistent_flags+=("--exp-year=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_cards()
{
    last_command="stripe_cards"

    command_aliases=()

    commands=()
    commands+=("delete")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_cash_balances_retrieve()
{
    last_command="stripe_cash_balances_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_cash_balances_update()
{
    last_command="stripe_cash_balances_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--settings.reconciliation-mode=")
    two_word_flags+=("--settings.reconciliation-mode")
    local_nonpersistent_flags+=("--settings.reconciliation-mode")
    local_nonpersistent_flags+=("--settings.reconciliation-mode=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_cash_balances()
{
    last_command="stripe_cash_balances"

    command_aliases=()

    commands=()
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_charges_capture()
{
    last_command="stripe_charges_capture"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--application-fee=")
    two_word_flags+=("--application-fee")
    local_nonpersistent_flags+=("--application-fee")
    local_nonpersistent_flags+=("--application-fee=")
    flags+=("--application-fee-amount=")
    two_word_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--receipt-email=")
    two_word_flags+=("--receipt-email")
    local_nonpersistent_flags+=("--receipt-email")
    local_nonpersistent_flags+=("--receipt-email=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--statement-descriptor-suffix=")
    two_word_flags+=("--statement-descriptor-suffix")
    local_nonpersistent_flags+=("--statement-descriptor-suffix")
    local_nonpersistent_flags+=("--statement-descriptor-suffix=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transfer-data.amount=")
    two_word_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount=")
    flags+=("--transfer-group=")
    two_word_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_charges_create()
{
    last_command="stripe_charges_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--application-fee=")
    two_word_flags+=("--application-fee")
    local_nonpersistent_flags+=("--application-fee")
    local_nonpersistent_flags+=("--application-fee=")
    flags+=("--application-fee-amount=")
    two_word_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount=")
    flags+=("--capture=")
    two_word_flags+=("--capture")
    local_nonpersistent_flags+=("--capture")
    local_nonpersistent_flags+=("--capture=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--destination.account=")
    two_word_flags+=("--destination.account")
    local_nonpersistent_flags+=("--destination.account")
    local_nonpersistent_flags+=("--destination.account=")
    flags+=("--destination.amount=")
    two_word_flags+=("--destination.amount")
    local_nonpersistent_flags+=("--destination.amount")
    local_nonpersistent_flags+=("--destination.amount=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--on-behalf-of=")
    two_word_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of=")
    flags+=("--radar-options.session=")
    two_word_flags+=("--radar-options.session")
    local_nonpersistent_flags+=("--radar-options.session")
    local_nonpersistent_flags+=("--radar-options.session=")
    flags+=("--receipt-email=")
    two_word_flags+=("--receipt-email")
    local_nonpersistent_flags+=("--receipt-email")
    local_nonpersistent_flags+=("--receipt-email=")
    flags+=("--shipping.address.city=")
    two_word_flags+=("--shipping.address.city")
    local_nonpersistent_flags+=("--shipping.address.city")
    local_nonpersistent_flags+=("--shipping.address.city=")
    flags+=("--shipping.address.country=")
    two_word_flags+=("--shipping.address.country")
    local_nonpersistent_flags+=("--shipping.address.country")
    local_nonpersistent_flags+=("--shipping.address.country=")
    flags+=("--shipping.address.line1=")
    two_word_flags+=("--shipping.address.line1")
    local_nonpersistent_flags+=("--shipping.address.line1")
    local_nonpersistent_flags+=("--shipping.address.line1=")
    flags+=("--shipping.address.line2=")
    two_word_flags+=("--shipping.address.line2")
    local_nonpersistent_flags+=("--shipping.address.line2")
    local_nonpersistent_flags+=("--shipping.address.line2=")
    flags+=("--shipping.address.postal-code=")
    two_word_flags+=("--shipping.address.postal-code")
    local_nonpersistent_flags+=("--shipping.address.postal-code")
    local_nonpersistent_flags+=("--shipping.address.postal-code=")
    flags+=("--shipping.address.state=")
    two_word_flags+=("--shipping.address.state")
    local_nonpersistent_flags+=("--shipping.address.state")
    local_nonpersistent_flags+=("--shipping.address.state=")
    flags+=("--shipping.carrier=")
    two_word_flags+=("--shipping.carrier")
    local_nonpersistent_flags+=("--shipping.carrier")
    local_nonpersistent_flags+=("--shipping.carrier=")
    flags+=("--shipping.name=")
    two_word_flags+=("--shipping.name")
    local_nonpersistent_flags+=("--shipping.name")
    local_nonpersistent_flags+=("--shipping.name=")
    flags+=("--shipping.phone=")
    two_word_flags+=("--shipping.phone")
    local_nonpersistent_flags+=("--shipping.phone")
    local_nonpersistent_flags+=("--shipping.phone=")
    flags+=("--shipping.tracking-number=")
    two_word_flags+=("--shipping.tracking-number")
    local_nonpersistent_flags+=("--shipping.tracking-number")
    local_nonpersistent_flags+=("--shipping.tracking-number=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--source=")
    two_word_flags+=("--source")
    local_nonpersistent_flags+=("--source")
    local_nonpersistent_flags+=("--source=")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--statement-descriptor-suffix=")
    two_word_flags+=("--statement-descriptor-suffix")
    local_nonpersistent_flags+=("--statement-descriptor-suffix")
    local_nonpersistent_flags+=("--statement-descriptor-suffix=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transfer-data.amount=")
    two_word_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount=")
    flags+=("--transfer-data.destination=")
    two_word_flags+=("--transfer-data.destination")
    local_nonpersistent_flags+=("--transfer-data.destination")
    local_nonpersistent_flags+=("--transfer-data.destination=")
    flags+=("--transfer-group=")
    two_word_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_charges_list()
{
    last_command="stripe_charges_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-intent=")
    two_word_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transfer-group=")
    two_word_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_charges_retrieve()
{
    last_command="stripe_charges_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_charges_search()
{
    last_command="stripe_charges_search"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--page=")
    two_word_flags+=("--page")
    local_nonpersistent_flags+=("--page")
    local_nonpersistent_flags+=("--page=")
    flags+=("--query=")
    two_word_flags+=("--query")
    local_nonpersistent_flags+=("--query")
    local_nonpersistent_flags+=("--query=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_charges_update()
{
    last_command="stripe_charges_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--fraud-details.user-report=")
    two_word_flags+=("--fraud-details.user-report")
    local_nonpersistent_flags+=("--fraud-details.user-report")
    local_nonpersistent_flags+=("--fraud-details.user-report=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--receipt-email=")
    two_word_flags+=("--receipt-email")
    local_nonpersistent_flags+=("--receipt-email")
    local_nonpersistent_flags+=("--receipt-email=")
    flags+=("--shipping.address.city=")
    two_word_flags+=("--shipping.address.city")
    local_nonpersistent_flags+=("--shipping.address.city")
    local_nonpersistent_flags+=("--shipping.address.city=")
    flags+=("--shipping.address.country=")
    two_word_flags+=("--shipping.address.country")
    local_nonpersistent_flags+=("--shipping.address.country")
    local_nonpersistent_flags+=("--shipping.address.country=")
    flags+=("--shipping.address.line1=")
    two_word_flags+=("--shipping.address.line1")
    local_nonpersistent_flags+=("--shipping.address.line1")
    local_nonpersistent_flags+=("--shipping.address.line1=")
    flags+=("--shipping.address.line2=")
    two_word_flags+=("--shipping.address.line2")
    local_nonpersistent_flags+=("--shipping.address.line2")
    local_nonpersistent_flags+=("--shipping.address.line2=")
    flags+=("--shipping.address.postal-code=")
    two_word_flags+=("--shipping.address.postal-code")
    local_nonpersistent_flags+=("--shipping.address.postal-code")
    local_nonpersistent_flags+=("--shipping.address.postal-code=")
    flags+=("--shipping.address.state=")
    two_word_flags+=("--shipping.address.state")
    local_nonpersistent_flags+=("--shipping.address.state")
    local_nonpersistent_flags+=("--shipping.address.state=")
    flags+=("--shipping.carrier=")
    two_word_flags+=("--shipping.carrier")
    local_nonpersistent_flags+=("--shipping.carrier")
    local_nonpersistent_flags+=("--shipping.carrier=")
    flags+=("--shipping.name=")
    two_word_flags+=("--shipping.name")
    local_nonpersistent_flags+=("--shipping.name")
    local_nonpersistent_flags+=("--shipping.name=")
    flags+=("--shipping.phone=")
    two_word_flags+=("--shipping.phone")
    local_nonpersistent_flags+=("--shipping.phone")
    local_nonpersistent_flags+=("--shipping.phone=")
    flags+=("--shipping.tracking-number=")
    two_word_flags+=("--shipping.tracking-number")
    local_nonpersistent_flags+=("--shipping.tracking-number")
    local_nonpersistent_flags+=("--shipping.tracking-number=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transfer-group=")
    two_word_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_charges()
{
    last_command="stripe_charges"

    command_aliases=()

    commands=()
    commands+=("capture")
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("search")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_checkout_sessions_create()
{
    last_command="stripe_checkout_sessions_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--after-expiration.recovery.allow-promotion-codes=")
    two_word_flags+=("--after-expiration.recovery.allow-promotion-codes")
    local_nonpersistent_flags+=("--after-expiration.recovery.allow-promotion-codes")
    local_nonpersistent_flags+=("--after-expiration.recovery.allow-promotion-codes=")
    flags+=("--after-expiration.recovery.enabled=")
    two_word_flags+=("--after-expiration.recovery.enabled")
    local_nonpersistent_flags+=("--after-expiration.recovery.enabled")
    local_nonpersistent_flags+=("--after-expiration.recovery.enabled=")
    flags+=("--allow-promotion-codes=")
    two_word_flags+=("--allow-promotion-codes")
    local_nonpersistent_flags+=("--allow-promotion-codes")
    local_nonpersistent_flags+=("--allow-promotion-codes=")
    flags+=("--automatic-tax.enabled=")
    two_word_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled=")
    flags+=("--automatic-tax.liability.account=")
    two_word_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account=")
    flags+=("--automatic-tax.liability.type=")
    two_word_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type=")
    flags+=("--billing-address-collection=")
    two_word_flags+=("--billing-address-collection")
    local_nonpersistent_flags+=("--billing-address-collection")
    local_nonpersistent_flags+=("--billing-address-collection=")
    flags+=("--cancel-url=")
    two_word_flags+=("--cancel-url")
    local_nonpersistent_flags+=("--cancel-url")
    local_nonpersistent_flags+=("--cancel-url=")
    flags+=("--client-reference-id=")
    two_word_flags+=("--client-reference-id")
    local_nonpersistent_flags+=("--client-reference-id")
    local_nonpersistent_flags+=("--client-reference-id=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--consent-collection.payment-method-reuse-agreement.position=")
    two_word_flags+=("--consent-collection.payment-method-reuse-agreement.position")
    local_nonpersistent_flags+=("--consent-collection.payment-method-reuse-agreement.position")
    local_nonpersistent_flags+=("--consent-collection.payment-method-reuse-agreement.position=")
    flags+=("--consent-collection.promotions=")
    two_word_flags+=("--consent-collection.promotions")
    local_nonpersistent_flags+=("--consent-collection.promotions")
    local_nonpersistent_flags+=("--consent-collection.promotions=")
    flags+=("--consent-collection.terms-of-service=")
    two_word_flags+=("--consent-collection.terms-of-service")
    local_nonpersistent_flags+=("--consent-collection.terms-of-service")
    local_nonpersistent_flags+=("--consent-collection.terms-of-service=")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--customer-creation=")
    two_word_flags+=("--customer-creation")
    local_nonpersistent_flags+=("--customer-creation")
    local_nonpersistent_flags+=("--customer-creation=")
    flags+=("--customer-email=")
    two_word_flags+=("--customer-email")
    local_nonpersistent_flags+=("--customer-email")
    local_nonpersistent_flags+=("--customer-email=")
    flags+=("--customer-update.address=")
    two_word_flags+=("--customer-update.address")
    local_nonpersistent_flags+=("--customer-update.address")
    local_nonpersistent_flags+=("--customer-update.address=")
    flags+=("--customer-update.name=")
    two_word_flags+=("--customer-update.name")
    local_nonpersistent_flags+=("--customer-update.name")
    local_nonpersistent_flags+=("--customer-update.name=")
    flags+=("--customer-update.shipping=")
    two_word_flags+=("--customer-update.shipping")
    local_nonpersistent_flags+=("--customer-update.shipping")
    local_nonpersistent_flags+=("--customer-update.shipping=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--expires-at=")
    two_word_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--invoice-creation.enabled=")
    two_word_flags+=("--invoice-creation.enabled")
    local_nonpersistent_flags+=("--invoice-creation.enabled")
    local_nonpersistent_flags+=("--invoice-creation.enabled=")
    flags+=("--invoice-creation.invoice-data.account-tax-ids=")
    two_word_flags+=("--invoice-creation.invoice-data.account-tax-ids")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.account-tax-ids")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.account-tax-ids=")
    flags+=("--invoice-creation.invoice-data.description=")
    two_word_flags+=("--invoice-creation.invoice-data.description")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.description")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.description=")
    flags+=("--invoice-creation.invoice-data.footer=")
    two_word_flags+=("--invoice-creation.invoice-data.footer")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.footer")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.footer=")
    flags+=("--invoice-creation.invoice-data.issuer.account=")
    two_word_flags+=("--invoice-creation.invoice-data.issuer.account")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.issuer.account")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.issuer.account=")
    flags+=("--invoice-creation.invoice-data.issuer.type=")
    two_word_flags+=("--invoice-creation.invoice-data.issuer.type")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.issuer.type")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.issuer.type=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--locale=")
    two_word_flags+=("--locale")
    local_nonpersistent_flags+=("--locale")
    local_nonpersistent_flags+=("--locale=")
    flags+=("--mode=")
    two_word_flags+=("--mode")
    local_nonpersistent_flags+=("--mode")
    local_nonpersistent_flags+=("--mode=")
    flags+=("--payment-intent-data.application-fee-amount=")
    two_word_flags+=("--payment-intent-data.application-fee-amount")
    local_nonpersistent_flags+=("--payment-intent-data.application-fee-amount")
    local_nonpersistent_flags+=("--payment-intent-data.application-fee-amount=")
    flags+=("--payment-intent-data.capture-method=")
    two_word_flags+=("--payment-intent-data.capture-method")
    local_nonpersistent_flags+=("--payment-intent-data.capture-method")
    local_nonpersistent_flags+=("--payment-intent-data.capture-method=")
    flags+=("--payment-intent-data.description=")
    two_word_flags+=("--payment-intent-data.description")
    local_nonpersistent_flags+=("--payment-intent-data.description")
    local_nonpersistent_flags+=("--payment-intent-data.description=")
    flags+=("--payment-intent-data.on-behalf-of=")
    two_word_flags+=("--payment-intent-data.on-behalf-of")
    local_nonpersistent_flags+=("--payment-intent-data.on-behalf-of")
    local_nonpersistent_flags+=("--payment-intent-data.on-behalf-of=")
    flags+=("--payment-intent-data.receipt-email=")
    two_word_flags+=("--payment-intent-data.receipt-email")
    local_nonpersistent_flags+=("--payment-intent-data.receipt-email")
    local_nonpersistent_flags+=("--payment-intent-data.receipt-email=")
    flags+=("--payment-intent-data.setup-future-usage=")
    two_word_flags+=("--payment-intent-data.setup-future-usage")
    local_nonpersistent_flags+=("--payment-intent-data.setup-future-usage")
    local_nonpersistent_flags+=("--payment-intent-data.setup-future-usage=")
    flags+=("--payment-intent-data.shipping.address.city=")
    two_word_flags+=("--payment-intent-data.shipping.address.city")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.address.city")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.address.city=")
    flags+=("--payment-intent-data.shipping.address.country=")
    two_word_flags+=("--payment-intent-data.shipping.address.country")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.address.country")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.address.country=")
    flags+=("--payment-intent-data.shipping.address.line1=")
    two_word_flags+=("--payment-intent-data.shipping.address.line1")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.address.line1")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.address.line1=")
    flags+=("--payment-intent-data.shipping.address.line2=")
    two_word_flags+=("--payment-intent-data.shipping.address.line2")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.address.line2")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.address.line2=")
    flags+=("--payment-intent-data.shipping.address.postal-code=")
    two_word_flags+=("--payment-intent-data.shipping.address.postal-code")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.address.postal-code")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.address.postal-code=")
    flags+=("--payment-intent-data.shipping.address.state=")
    two_word_flags+=("--payment-intent-data.shipping.address.state")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.address.state")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.address.state=")
    flags+=("--payment-intent-data.shipping.carrier=")
    two_word_flags+=("--payment-intent-data.shipping.carrier")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.carrier")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.carrier=")
    flags+=("--payment-intent-data.shipping.name=")
    two_word_flags+=("--payment-intent-data.shipping.name")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.name")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.name=")
    flags+=("--payment-intent-data.shipping.phone=")
    two_word_flags+=("--payment-intent-data.shipping.phone")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.phone")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.phone=")
    flags+=("--payment-intent-data.shipping.tracking-number=")
    two_word_flags+=("--payment-intent-data.shipping.tracking-number")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.tracking-number")
    local_nonpersistent_flags+=("--payment-intent-data.shipping.tracking-number=")
    flags+=("--payment-intent-data.statement-descriptor=")
    two_word_flags+=("--payment-intent-data.statement-descriptor")
    local_nonpersistent_flags+=("--payment-intent-data.statement-descriptor")
    local_nonpersistent_flags+=("--payment-intent-data.statement-descriptor=")
    flags+=("--payment-intent-data.statement-descriptor-suffix=")
    two_word_flags+=("--payment-intent-data.statement-descriptor-suffix")
    local_nonpersistent_flags+=("--payment-intent-data.statement-descriptor-suffix")
    local_nonpersistent_flags+=("--payment-intent-data.statement-descriptor-suffix=")
    flags+=("--payment-intent-data.transfer-data.amount=")
    two_word_flags+=("--payment-intent-data.transfer-data.amount")
    local_nonpersistent_flags+=("--payment-intent-data.transfer-data.amount")
    local_nonpersistent_flags+=("--payment-intent-data.transfer-data.amount=")
    flags+=("--payment-intent-data.transfer-data.destination=")
    two_word_flags+=("--payment-intent-data.transfer-data.destination")
    local_nonpersistent_flags+=("--payment-intent-data.transfer-data.destination")
    local_nonpersistent_flags+=("--payment-intent-data.transfer-data.destination=")
    flags+=("--payment-intent-data.transfer-group=")
    two_word_flags+=("--payment-intent-data.transfer-group")
    local_nonpersistent_flags+=("--payment-intent-data.transfer-group")
    local_nonpersistent_flags+=("--payment-intent-data.transfer-group=")
    flags+=("--payment-method-collection=")
    two_word_flags+=("--payment-method-collection")
    local_nonpersistent_flags+=("--payment-method-collection")
    local_nonpersistent_flags+=("--payment-method-collection=")
    flags+=("--payment-method-configuration=")
    two_word_flags+=("--payment-method-configuration")
    local_nonpersistent_flags+=("--payment-method-configuration")
    local_nonpersistent_flags+=("--payment-method-configuration=")
    flags+=("--payment-method-data.allow-redisplay=")
    two_word_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay=")
    flags+=("--payment-method-options.acss-debit.currency=")
    two_word_flags+=("--payment-method-options.acss-debit.currency")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.currency")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.currency=")
    flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url=")
    flags+=("--payment-method-options.acss-debit.mandate-options.default-for=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.default-for")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.default-for")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.default-for=")
    flags+=("--payment-method-options.acss-debit.mandate-options.interval-description=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.interval-description")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.interval-description")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.interval-description=")
    flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule=")
    flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type=")
    flags+=("--payment-method-options.acss-debit.setup-future-usage=")
    two_word_flags+=("--payment-method-options.acss-debit.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.setup-future-usage=")
    flags+=("--payment-method-options.acss-debit.verification-method=")
    two_word_flags+=("--payment-method-options.acss-debit.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.verification-method=")
    flags+=("--payment-method-options.affirm.setup-future-usage=")
    two_word_flags+=("--payment-method-options.affirm.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.affirm.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.affirm.setup-future-usage=")
    flags+=("--payment-method-options.afterpay-clearpay.setup-future-usage=")
    two_word_flags+=("--payment-method-options.afterpay-clearpay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.afterpay-clearpay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.afterpay-clearpay.setup-future-usage=")
    flags+=("--payment-method-options.alipay.setup-future-usage=")
    two_word_flags+=("--payment-method-options.alipay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.alipay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.alipay.setup-future-usage=")
    flags+=("--payment-method-options.amazon-pay.setup-future-usage=")
    two_word_flags+=("--payment-method-options.amazon-pay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.amazon-pay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.amazon-pay.setup-future-usage=")
    flags+=("--payment-method-options.au-becs-debit.setup-future-usage=")
    two_word_flags+=("--payment-method-options.au-becs-debit.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.au-becs-debit.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.au-becs-debit.setup-future-usage=")
    flags+=("--payment-method-options.bacs-debit.setup-future-usage=")
    two_word_flags+=("--payment-method-options.bacs-debit.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.bacs-debit.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.bacs-debit.setup-future-usage=")
    flags+=("--payment-method-options.bancontact.setup-future-usage=")
    two_word_flags+=("--payment-method-options.bancontact.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.bancontact.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.bancontact.setup-future-usage=")
    flags+=("--payment-method-options.boleto.expires-after-days=")
    two_word_flags+=("--payment-method-options.boleto.expires-after-days")
    local_nonpersistent_flags+=("--payment-method-options.boleto.expires-after-days")
    local_nonpersistent_flags+=("--payment-method-options.boleto.expires-after-days=")
    flags+=("--payment-method-options.boleto.setup-future-usage=")
    two_word_flags+=("--payment-method-options.boleto.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.boleto.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.boleto.setup-future-usage=")
    flags+=("--payment-method-options.card.installments.enabled=")
    two_word_flags+=("--payment-method-options.card.installments.enabled")
    local_nonpersistent_flags+=("--payment-method-options.card.installments.enabled")
    local_nonpersistent_flags+=("--payment-method-options.card.installments.enabled=")
    flags+=("--payment-method-options.card.request-three-d-secure=")
    two_word_flags+=("--payment-method-options.card.request-three-d-secure")
    local_nonpersistent_flags+=("--payment-method-options.card.request-three-d-secure")
    local_nonpersistent_flags+=("--payment-method-options.card.request-three-d-secure=")
    flags+=("--payment-method-options.card.setup-future-usage=")
    two_word_flags+=("--payment-method-options.card.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.card.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.card.setup-future-usage=")
    flags+=("--payment-method-options.card.statement-descriptor-suffix-kana=")
    two_word_flags+=("--payment-method-options.card.statement-descriptor-suffix-kana")
    local_nonpersistent_flags+=("--payment-method-options.card.statement-descriptor-suffix-kana")
    local_nonpersistent_flags+=("--payment-method-options.card.statement-descriptor-suffix-kana=")
    flags+=("--payment-method-options.card.statement-descriptor-suffix-kanji=")
    two_word_flags+=("--payment-method-options.card.statement-descriptor-suffix-kanji")
    local_nonpersistent_flags+=("--payment-method-options.card.statement-descriptor-suffix-kanji")
    local_nonpersistent_flags+=("--payment-method-options.card.statement-descriptor-suffix-kanji=")
    flags+=("--payment-method-options.cashapp.setup-future-usage=")
    two_word_flags+=("--payment-method-options.cashapp.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.cashapp.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.cashapp.setup-future-usage=")
    flags+=("--payment-method-options.customer-balance.bank-transfer.eu-bank-transfer.country=")
    two_word_flags+=("--payment-method-options.customer-balance.bank-transfer.eu-bank-transfer.country")
    local_nonpersistent_flags+=("--payment-method-options.customer-balance.bank-transfer.eu-bank-transfer.country")
    local_nonpersistent_flags+=("--payment-method-options.customer-balance.bank-transfer.eu-bank-transfer.country=")
    flags+=("--payment-method-options.customer-balance.bank-transfer.requested-address-types=")
    two_word_flags+=("--payment-method-options.customer-balance.bank-transfer.requested-address-types")
    local_nonpersistent_flags+=("--payment-method-options.customer-balance.bank-transfer.requested-address-types")
    local_nonpersistent_flags+=("--payment-method-options.customer-balance.bank-transfer.requested-address-types=")
    flags+=("--payment-method-options.customer-balance.bank-transfer.type=")
    two_word_flags+=("--payment-method-options.customer-balance.bank-transfer.type")
    local_nonpersistent_flags+=("--payment-method-options.customer-balance.bank-transfer.type")
    local_nonpersistent_flags+=("--payment-method-options.customer-balance.bank-transfer.type=")
    flags+=("--payment-method-options.customer-balance.funding-type=")
    two_word_flags+=("--payment-method-options.customer-balance.funding-type")
    local_nonpersistent_flags+=("--payment-method-options.customer-balance.funding-type")
    local_nonpersistent_flags+=("--payment-method-options.customer-balance.funding-type=")
    flags+=("--payment-method-options.customer-balance.setup-future-usage=")
    two_word_flags+=("--payment-method-options.customer-balance.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.customer-balance.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.customer-balance.setup-future-usage=")
    flags+=("--payment-method-options.eps.setup-future-usage=")
    two_word_flags+=("--payment-method-options.eps.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.eps.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.eps.setup-future-usage=")
    flags+=("--payment-method-options.fpx.setup-future-usage=")
    two_word_flags+=("--payment-method-options.fpx.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.fpx.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.fpx.setup-future-usage=")
    flags+=("--payment-method-options.giropay.setup-future-usage=")
    two_word_flags+=("--payment-method-options.giropay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.giropay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.giropay.setup-future-usage=")
    flags+=("--payment-method-options.grabpay.setup-future-usage=")
    two_word_flags+=("--payment-method-options.grabpay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.grabpay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.grabpay.setup-future-usage=")
    flags+=("--payment-method-options.ideal.setup-future-usage=")
    two_word_flags+=("--payment-method-options.ideal.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.ideal.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.ideal.setup-future-usage=")
    flags+=("--payment-method-options.kakao-pay.setup-future-usage=")
    two_word_flags+=("--payment-method-options.kakao-pay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.kakao-pay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.kakao-pay.setup-future-usage=")
    flags+=("--payment-method-options.klarna.setup-future-usage=")
    two_word_flags+=("--payment-method-options.klarna.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.klarna.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.klarna.setup-future-usage=")
    flags+=("--payment-method-options.konbini.expires-after-days=")
    two_word_flags+=("--payment-method-options.konbini.expires-after-days")
    local_nonpersistent_flags+=("--payment-method-options.konbini.expires-after-days")
    local_nonpersistent_flags+=("--payment-method-options.konbini.expires-after-days=")
    flags+=("--payment-method-options.konbini.setup-future-usage=")
    two_word_flags+=("--payment-method-options.konbini.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.konbini.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.konbini.setup-future-usage=")
    flags+=("--payment-method-options.kr-card.setup-future-usage=")
    two_word_flags+=("--payment-method-options.kr-card.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.kr-card.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.kr-card.setup-future-usage=")
    flags+=("--payment-method-options.link.setup-future-usage=")
    two_word_flags+=("--payment-method-options.link.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.link.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.link.setup-future-usage=")
    flags+=("--payment-method-options.mobilepay.setup-future-usage=")
    two_word_flags+=("--payment-method-options.mobilepay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.mobilepay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.mobilepay.setup-future-usage=")
    flags+=("--payment-method-options.multibanco.setup-future-usage=")
    two_word_flags+=("--payment-method-options.multibanco.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.multibanco.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.multibanco.setup-future-usage=")
    flags+=("--payment-method-options.naver-pay.setup-future-usage=")
    two_word_flags+=("--payment-method-options.naver-pay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.naver-pay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.naver-pay.setup-future-usage=")
    flags+=("--payment-method-options.oxxo.expires-after-days=")
    two_word_flags+=("--payment-method-options.oxxo.expires-after-days")
    local_nonpersistent_flags+=("--payment-method-options.oxxo.expires-after-days")
    local_nonpersistent_flags+=("--payment-method-options.oxxo.expires-after-days=")
    flags+=("--payment-method-options.oxxo.setup-future-usage=")
    two_word_flags+=("--payment-method-options.oxxo.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.oxxo.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.oxxo.setup-future-usage=")
    flags+=("--payment-method-options.p24.setup-future-usage=")
    two_word_flags+=("--payment-method-options.p24.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.p24.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.p24.setup-future-usage=")
    flags+=("--payment-method-options.p24.tos-shown-and-accepted=")
    two_word_flags+=("--payment-method-options.p24.tos-shown-and-accepted")
    local_nonpersistent_flags+=("--payment-method-options.p24.tos-shown-and-accepted")
    local_nonpersistent_flags+=("--payment-method-options.p24.tos-shown-and-accepted=")
    flags+=("--payment-method-options.paynow.setup-future-usage=")
    two_word_flags+=("--payment-method-options.paynow.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.paynow.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.paynow.setup-future-usage=")
    flags+=("--payment-method-options.paypal.capture-method=")
    two_word_flags+=("--payment-method-options.paypal.capture-method")
    local_nonpersistent_flags+=("--payment-method-options.paypal.capture-method")
    local_nonpersistent_flags+=("--payment-method-options.paypal.capture-method=")
    flags+=("--payment-method-options.paypal.preferred-locale=")
    two_word_flags+=("--payment-method-options.paypal.preferred-locale")
    local_nonpersistent_flags+=("--payment-method-options.paypal.preferred-locale")
    local_nonpersistent_flags+=("--payment-method-options.paypal.preferred-locale=")
    flags+=("--payment-method-options.paypal.reference=")
    two_word_flags+=("--payment-method-options.paypal.reference")
    local_nonpersistent_flags+=("--payment-method-options.paypal.reference")
    local_nonpersistent_flags+=("--payment-method-options.paypal.reference=")
    flags+=("--payment-method-options.paypal.risk-correlation-id=")
    two_word_flags+=("--payment-method-options.paypal.risk-correlation-id")
    local_nonpersistent_flags+=("--payment-method-options.paypal.risk-correlation-id")
    local_nonpersistent_flags+=("--payment-method-options.paypal.risk-correlation-id=")
    flags+=("--payment-method-options.paypal.setup-future-usage=")
    two_word_flags+=("--payment-method-options.paypal.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.paypal.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.paypal.setup-future-usage=")
    flags+=("--payment-method-options.pix.expires-after-seconds=")
    two_word_flags+=("--payment-method-options.pix.expires-after-seconds")
    local_nonpersistent_flags+=("--payment-method-options.pix.expires-after-seconds")
    local_nonpersistent_flags+=("--payment-method-options.pix.expires-after-seconds=")
    flags+=("--payment-method-options.revolut-pay.setup-future-usage=")
    two_word_flags+=("--payment-method-options.revolut-pay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.revolut-pay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.revolut-pay.setup-future-usage=")
    flags+=("--payment-method-options.sepa-debit.setup-future-usage=")
    two_word_flags+=("--payment-method-options.sepa-debit.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.sepa-debit.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.sepa-debit.setup-future-usage=")
    flags+=("--payment-method-options.sofort.setup-future-usage=")
    two_word_flags+=("--payment-method-options.sofort.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.sofort.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.sofort.setup-future-usage=")
    flags+=("--payment-method-options.swish.reference=")
    two_word_flags+=("--payment-method-options.swish.reference")
    local_nonpersistent_flags+=("--payment-method-options.swish.reference")
    local_nonpersistent_flags+=("--payment-method-options.swish.reference=")
    flags+=("--payment-method-options.us-bank-account.financial-connections.permissions=")
    two_word_flags+=("--payment-method-options.us-bank-account.financial-connections.permissions")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.permissions")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.permissions=")
    flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch=")
    two_word_flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch=")
    flags+=("--payment-method-options.us-bank-account.setup-future-usage=")
    two_word_flags+=("--payment-method-options.us-bank-account.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.setup-future-usage=")
    flags+=("--payment-method-options.us-bank-account.verification-method=")
    two_word_flags+=("--payment-method-options.us-bank-account.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.verification-method=")
    flags+=("--payment-method-options.wechat-pay.app-id=")
    two_word_flags+=("--payment-method-options.wechat-pay.app-id")
    local_nonpersistent_flags+=("--payment-method-options.wechat-pay.app-id")
    local_nonpersistent_flags+=("--payment-method-options.wechat-pay.app-id=")
    flags+=("--payment-method-options.wechat-pay.client=")
    two_word_flags+=("--payment-method-options.wechat-pay.client")
    local_nonpersistent_flags+=("--payment-method-options.wechat-pay.client")
    local_nonpersistent_flags+=("--payment-method-options.wechat-pay.client=")
    flags+=("--payment-method-options.wechat-pay.setup-future-usage=")
    two_word_flags+=("--payment-method-options.wechat-pay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.wechat-pay.setup-future-usage")
    local_nonpersistent_flags+=("--payment-method-options.wechat-pay.setup-future-usage=")
    flags+=("--payment-method-types=")
    two_word_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types=")
    flags+=("--phone-number-collection.enabled=")
    two_word_flags+=("--phone-number-collection.enabled")
    local_nonpersistent_flags+=("--phone-number-collection.enabled")
    local_nonpersistent_flags+=("--phone-number-collection.enabled=")
    flags+=("--redirect-on-completion=")
    two_word_flags+=("--redirect-on-completion")
    local_nonpersistent_flags+=("--redirect-on-completion")
    local_nonpersistent_flags+=("--redirect-on-completion=")
    flags+=("--return-url=")
    two_word_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url=")
    flags+=("--saved-payment-method-options.allow-redisplay-filters=")
    two_word_flags+=("--saved-payment-method-options.allow-redisplay-filters")
    local_nonpersistent_flags+=("--saved-payment-method-options.allow-redisplay-filters")
    local_nonpersistent_flags+=("--saved-payment-method-options.allow-redisplay-filters=")
    flags+=("--saved-payment-method-options.payment-method-save=")
    two_word_flags+=("--saved-payment-method-options.payment-method-save")
    local_nonpersistent_flags+=("--saved-payment-method-options.payment-method-save")
    local_nonpersistent_flags+=("--saved-payment-method-options.payment-method-save=")
    flags+=("--setup-intent-data.description=")
    two_word_flags+=("--setup-intent-data.description")
    local_nonpersistent_flags+=("--setup-intent-data.description")
    local_nonpersistent_flags+=("--setup-intent-data.description=")
    flags+=("--setup-intent-data.on-behalf-of=")
    two_word_flags+=("--setup-intent-data.on-behalf-of")
    local_nonpersistent_flags+=("--setup-intent-data.on-behalf-of")
    local_nonpersistent_flags+=("--setup-intent-data.on-behalf-of=")
    flags+=("--shipping-address-collection.allowed-countries=")
    two_word_flags+=("--shipping-address-collection.allowed-countries")
    local_nonpersistent_flags+=("--shipping-address-collection.allowed-countries")
    local_nonpersistent_flags+=("--shipping-address-collection.allowed-countries=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--submit-type=")
    two_word_flags+=("--submit-type")
    local_nonpersistent_flags+=("--submit-type")
    local_nonpersistent_flags+=("--submit-type=")
    flags+=("--subscription-data.application-fee-percent=")
    two_word_flags+=("--subscription-data.application-fee-percent")
    local_nonpersistent_flags+=("--subscription-data.application-fee-percent")
    local_nonpersistent_flags+=("--subscription-data.application-fee-percent=")
    flags+=("--subscription-data.billing-cycle-anchor=")
    two_word_flags+=("--subscription-data.billing-cycle-anchor")
    local_nonpersistent_flags+=("--subscription-data.billing-cycle-anchor")
    local_nonpersistent_flags+=("--subscription-data.billing-cycle-anchor=")
    flags+=("--subscription-data.default-tax-rates=")
    two_word_flags+=("--subscription-data.default-tax-rates")
    local_nonpersistent_flags+=("--subscription-data.default-tax-rates")
    local_nonpersistent_flags+=("--subscription-data.default-tax-rates=")
    flags+=("--subscription-data.description=")
    two_word_flags+=("--subscription-data.description")
    local_nonpersistent_flags+=("--subscription-data.description")
    local_nonpersistent_flags+=("--subscription-data.description=")
    flags+=("--subscription-data.invoice-settings.issuer.account=")
    two_word_flags+=("--subscription-data.invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--subscription-data.invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--subscription-data.invoice-settings.issuer.account=")
    flags+=("--subscription-data.invoice-settings.issuer.type=")
    two_word_flags+=("--subscription-data.invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--subscription-data.invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--subscription-data.invoice-settings.issuer.type=")
    flags+=("--subscription-data.on-behalf-of=")
    two_word_flags+=("--subscription-data.on-behalf-of")
    local_nonpersistent_flags+=("--subscription-data.on-behalf-of")
    local_nonpersistent_flags+=("--subscription-data.on-behalf-of=")
    flags+=("--subscription-data.proration-behavior=")
    two_word_flags+=("--subscription-data.proration-behavior")
    local_nonpersistent_flags+=("--subscription-data.proration-behavior")
    local_nonpersistent_flags+=("--subscription-data.proration-behavior=")
    flags+=("--subscription-data.transfer-data.amount-percent=")
    two_word_flags+=("--subscription-data.transfer-data.amount-percent")
    local_nonpersistent_flags+=("--subscription-data.transfer-data.amount-percent")
    local_nonpersistent_flags+=("--subscription-data.transfer-data.amount-percent=")
    flags+=("--subscription-data.transfer-data.destination=")
    two_word_flags+=("--subscription-data.transfer-data.destination")
    local_nonpersistent_flags+=("--subscription-data.transfer-data.destination")
    local_nonpersistent_flags+=("--subscription-data.transfer-data.destination=")
    flags+=("--subscription-data.trial-end=")
    two_word_flags+=("--subscription-data.trial-end")
    local_nonpersistent_flags+=("--subscription-data.trial-end")
    local_nonpersistent_flags+=("--subscription-data.trial-end=")
    flags+=("--subscription-data.trial-period-days=")
    two_word_flags+=("--subscription-data.trial-period-days")
    local_nonpersistent_flags+=("--subscription-data.trial-period-days")
    local_nonpersistent_flags+=("--subscription-data.trial-period-days=")
    flags+=("--subscription-data.trial-settings.end-behavior.missing-payment-method=")
    two_word_flags+=("--subscription-data.trial-settings.end-behavior.missing-payment-method")
    local_nonpersistent_flags+=("--subscription-data.trial-settings.end-behavior.missing-payment-method")
    local_nonpersistent_flags+=("--subscription-data.trial-settings.end-behavior.missing-payment-method=")
    flags+=("--success-url=")
    two_word_flags+=("--success-url")
    local_nonpersistent_flags+=("--success-url")
    local_nonpersistent_flags+=("--success-url=")
    flags+=("--tax-id-collection.enabled=")
    two_word_flags+=("--tax-id-collection.enabled")
    local_nonpersistent_flags+=("--tax-id-collection.enabled")
    local_nonpersistent_flags+=("--tax-id-collection.enabled=")
    flags+=("--tax-id-collection.required=")
    two_word_flags+=("--tax-id-collection.required")
    local_nonpersistent_flags+=("--tax-id-collection.required")
    local_nonpersistent_flags+=("--tax-id-collection.required=")
    flags+=("--ui-mode=")
    two_word_flags+=("--ui-mode")
    local_nonpersistent_flags+=("--ui-mode")
    local_nonpersistent_flags+=("--ui-mode=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_checkout_sessions_expire()
{
    last_command="stripe_checkout_sessions_expire"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_checkout_sessions_list()
{
    last_command="stripe_checkout_sessions_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-intent=")
    two_word_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent=")
    flags+=("--payment-link=")
    two_word_flags+=("--payment-link")
    local_nonpersistent_flags+=("--payment-link")
    local_nonpersistent_flags+=("--payment-link=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--subscription=")
    two_word_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_checkout_sessions_list_line_items()
{
    last_command="stripe_checkout_sessions_list_line_items"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_checkout_sessions_retrieve()
{
    last_command="stripe_checkout_sessions_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_checkout_sessions_update()
{
    last_command="stripe_checkout_sessions_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_checkout_sessions()
{
    last_command="stripe_checkout_sessions"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("expire")
    commands+=("list")
    commands+=("list_line_items")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_checkout()
{
    last_command="stripe_checkout"

    command_aliases=()

    commands=()
    commands+=("sessions")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_climate_orders_cancel()
{
    last_command="stripe_climate_orders_cancel"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_climate_orders_create()
{
    last_command="stripe_climate_orders_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--beneficiary.public-name=")
    two_word_flags+=("--beneficiary.public-name")
    local_nonpersistent_flags+=("--beneficiary.public-name")
    local_nonpersistent_flags+=("--beneficiary.public-name=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--metric-tons=")
    two_word_flags+=("--metric-tons")
    local_nonpersistent_flags+=("--metric-tons")
    local_nonpersistent_flags+=("--metric-tons=")
    flags+=("--product=")
    two_word_flags+=("--product")
    local_nonpersistent_flags+=("--product")
    local_nonpersistent_flags+=("--product=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_climate_orders_list()
{
    last_command="stripe_climate_orders_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_climate_orders_retrieve()
{
    last_command="stripe_climate_orders_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_climate_orders_update()
{
    last_command="stripe_climate_orders_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_climate_orders()
{
    last_command="stripe_climate_orders"

    command_aliases=()

    commands=()
    commands+=("cancel")
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_climate_products_list()
{
    last_command="stripe_climate_products_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_climate_products_retrieve()
{
    last_command="stripe_climate_products_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_climate_products()
{
    last_command="stripe_climate_products"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_climate_suppliers_list()
{
    last_command="stripe_climate_suppliers_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_climate_suppliers_retrieve()
{
    last_command="stripe_climate_suppliers_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_climate_suppliers()
{
    last_command="stripe_climate_suppliers"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_climate()
{
    last_command="stripe_climate"

    command_aliases=()

    commands=()
    commands+=("orders")
    commands+=("products")
    commands+=("suppliers")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_community()
{
    last_command="stripe_community"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_completion()
{
    last_command="stripe_completion"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--help")
    flags+=("-h")
    local_nonpersistent_flags+=("--help")
    local_nonpersistent_flags+=("-h")
    flags+=("--shell=")
    two_word_flags+=("--shell")
    local_nonpersistent_flags+=("--shell")
    local_nonpersistent_flags+=("--shell=")
    flags+=("--write-to-stdout")
    local_nonpersistent_flags+=("--write-to-stdout")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_config()
{
    last_command="stripe_config"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--edit")
    flags+=("-e")
    local_nonpersistent_flags+=("--edit")
    local_nonpersistent_flags+=("-e")
    flags+=("--list")
    local_nonpersistent_flags+=("--list")
    flags+=("--set")
    local_nonpersistent_flags+=("--set")
    flags+=("--unset=")
    two_word_flags+=("--unset")
    local_nonpersistent_flags+=("--unset")
    local_nonpersistent_flags+=("--unset=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_confirmation_tokens_retrieve()
{
    last_command="stripe_confirmation_tokens_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_confirmation_tokens_test_helpers_create()
{
    last_command="stripe_confirmation_tokens_test_helpers_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-method=")
    two_word_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method=")
    flags+=("--payment-method-data.acss-debit.account-number=")
    two_word_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number=")
    flags+=("--payment-method-data.acss-debit.institution-number=")
    two_word_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number=")
    flags+=("--payment-method-data.acss-debit.transit-number=")
    two_word_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number=")
    flags+=("--payment-method-data.allow-redisplay=")
    two_word_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay=")
    flags+=("--payment-method-data.au-becs-debit.account-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number=")
    flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    flags+=("--payment-method-data.bacs-debit.account-number=")
    two_word_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number=")
    flags+=("--payment-method-data.bacs-debit.sort-code=")
    two_word_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code=")
    flags+=("--payment-method-data.billing-details.email=")
    two_word_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email=")
    flags+=("--payment-method-data.billing-details.name=")
    two_word_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name=")
    flags+=("--payment-method-data.billing-details.phone=")
    two_word_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone=")
    flags+=("--payment-method-data.boleto.tax-id=")
    two_word_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id=")
    flags+=("--payment-method-data.eps.bank=")
    two_word_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank=")
    flags+=("--payment-method-data.fpx.account-holder-type=")
    two_word_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type=")
    flags+=("--payment-method-data.fpx.bank=")
    two_word_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank=")
    flags+=("--payment-method-data.ideal.bank=")
    two_word_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank=")
    flags+=("--payment-method-data.klarna.dob.day=")
    two_word_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day=")
    flags+=("--payment-method-data.klarna.dob.month=")
    two_word_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month=")
    flags+=("--payment-method-data.klarna.dob.year=")
    two_word_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year=")
    flags+=("--payment-method-data.naver-pay.funding=")
    two_word_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding=")
    flags+=("--payment-method-data.p24.bank=")
    two_word_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank=")
    flags+=("--payment-method-data.radar-options.session=")
    two_word_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session=")
    flags+=("--payment-method-data.sepa-debit.iban=")
    two_word_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban=")
    flags+=("--payment-method-data.sofort.country=")
    two_word_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country=")
    flags+=("--payment-method-data.type=")
    two_word_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type=")
    flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    flags+=("--payment-method-data.us-bank-account.account-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number=")
    flags+=("--payment-method-data.us-bank-account.account-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type=")
    flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    two_word_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    flags+=("--payment-method-data.us-bank-account.routing-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number=")
    flags+=("--return-url=")
    two_word_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url=")
    flags+=("--setup-future-usage=")
    two_word_flags+=("--setup-future-usage")
    local_nonpersistent_flags+=("--setup-future-usage")
    local_nonpersistent_flags+=("--setup-future-usage=")
    flags+=("--shipping.address.city=")
    two_word_flags+=("--shipping.address.city")
    local_nonpersistent_flags+=("--shipping.address.city")
    local_nonpersistent_flags+=("--shipping.address.city=")
    flags+=("--shipping.address.country=")
    two_word_flags+=("--shipping.address.country")
    local_nonpersistent_flags+=("--shipping.address.country")
    local_nonpersistent_flags+=("--shipping.address.country=")
    flags+=("--shipping.address.line1=")
    two_word_flags+=("--shipping.address.line1")
    local_nonpersistent_flags+=("--shipping.address.line1")
    local_nonpersistent_flags+=("--shipping.address.line1=")
    flags+=("--shipping.address.line2=")
    two_word_flags+=("--shipping.address.line2")
    local_nonpersistent_flags+=("--shipping.address.line2")
    local_nonpersistent_flags+=("--shipping.address.line2=")
    flags+=("--shipping.address.postal-code=")
    two_word_flags+=("--shipping.address.postal-code")
    local_nonpersistent_flags+=("--shipping.address.postal-code")
    local_nonpersistent_flags+=("--shipping.address.postal-code=")
    flags+=("--shipping.address.state=")
    two_word_flags+=("--shipping.address.state")
    local_nonpersistent_flags+=("--shipping.address.state")
    local_nonpersistent_flags+=("--shipping.address.state=")
    flags+=("--shipping.name=")
    two_word_flags+=("--shipping.name")
    local_nonpersistent_flags+=("--shipping.name")
    local_nonpersistent_flags+=("--shipping.name=")
    flags+=("--shipping.phone=")
    two_word_flags+=("--shipping.phone")
    local_nonpersistent_flags+=("--shipping.phone")
    local_nonpersistent_flags+=("--shipping.phone=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_confirmation_tokens_test_helpers()
{
    last_command="stripe_confirmation_tokens_test_helpers"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_confirmation_tokens()
{
    last_command="stripe_confirmation_tokens"

    command_aliases=()

    commands=()
    commands+=("retrieve")
    commands+=("test_helpers")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_country_specs_list()
{
    last_command="stripe_country_specs_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_country_specs_retrieve()
{
    last_command="stripe_country_specs_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_country_specs()
{
    last_command="stripe_country_specs"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_coupons_create()
{
    last_command="stripe_coupons_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount-off=")
    two_word_flags+=("--amount-off")
    local_nonpersistent_flags+=("--amount-off")
    local_nonpersistent_flags+=("--amount-off=")
    flags+=("--applies-to.products=")
    two_word_flags+=("--applies-to.products")
    local_nonpersistent_flags+=("--applies-to.products")
    local_nonpersistent_flags+=("--applies-to.products=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--duration=")
    two_word_flags+=("--duration")
    local_nonpersistent_flags+=("--duration")
    local_nonpersistent_flags+=("--duration=")
    flags+=("--duration-in-months=")
    two_word_flags+=("--duration-in-months")
    local_nonpersistent_flags+=("--duration-in-months")
    local_nonpersistent_flags+=("--duration-in-months=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--id=")
    two_word_flags+=("--id")
    local_nonpersistent_flags+=("--id")
    local_nonpersistent_flags+=("--id=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--max-redemptions=")
    two_word_flags+=("--max-redemptions")
    local_nonpersistent_flags+=("--max-redemptions")
    local_nonpersistent_flags+=("--max-redemptions=")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--percent-off=")
    two_word_flags+=("--percent-off")
    local_nonpersistent_flags+=("--percent-off")
    local_nonpersistent_flags+=("--percent-off=")
    flags+=("--redeem-by=")
    two_word_flags+=("--redeem-by")
    local_nonpersistent_flags+=("--redeem-by")
    local_nonpersistent_flags+=("--redeem-by=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_coupons_delete()
{
    last_command="stripe_coupons_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_coupons_list()
{
    last_command="stripe_coupons_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_coupons_retrieve()
{
    last_command="stripe_coupons_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_coupons_update()
{
    last_command="stripe_coupons_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_coupons()
{
    last_command="stripe_coupons"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_credit_note_line_items_list()
{
    last_command="stripe_credit_note_line_items_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_credit_note_line_items()
{
    last_command="stripe_credit_note_line_items"

    command_aliases=()

    commands=()
    commands+=("list")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_credit_notes_create()
{
    last_command="stripe_credit_notes_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--credit-amount=")
    two_word_flags+=("--credit-amount")
    local_nonpersistent_flags+=("--credit-amount")
    local_nonpersistent_flags+=("--credit-amount=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--effective-at=")
    two_word_flags+=("--effective-at")
    local_nonpersistent_flags+=("--effective-at")
    local_nonpersistent_flags+=("--effective-at=")
    flags+=("--email-type=")
    two_word_flags+=("--email-type")
    local_nonpersistent_flags+=("--email-type")
    local_nonpersistent_flags+=("--email-type=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--invoice=")
    two_word_flags+=("--invoice")
    local_nonpersistent_flags+=("--invoice")
    local_nonpersistent_flags+=("--invoice=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--memo=")
    two_word_flags+=("--memo")
    local_nonpersistent_flags+=("--memo")
    local_nonpersistent_flags+=("--memo=")
    flags+=("--out-of-band-amount=")
    two_word_flags+=("--out-of-band-amount")
    local_nonpersistent_flags+=("--out-of-band-amount")
    local_nonpersistent_flags+=("--out-of-band-amount=")
    flags+=("--reason=")
    two_word_flags+=("--reason")
    local_nonpersistent_flags+=("--reason")
    local_nonpersistent_flags+=("--reason=")
    flags+=("--refund=")
    two_word_flags+=("--refund")
    local_nonpersistent_flags+=("--refund")
    local_nonpersistent_flags+=("--refund=")
    flags+=("--refund-amount=")
    two_word_flags+=("--refund-amount")
    local_nonpersistent_flags+=("--refund-amount")
    local_nonpersistent_flags+=("--refund-amount=")
    flags+=("--shipping-cost.shipping-rate=")
    two_word_flags+=("--shipping-cost.shipping-rate")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_credit_notes_list()
{
    last_command="stripe_credit_notes_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--invoice=")
    two_word_flags+=("--invoice")
    local_nonpersistent_flags+=("--invoice")
    local_nonpersistent_flags+=("--invoice=")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_credit_notes_preview()
{
    last_command="stripe_credit_notes_preview"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--credit-amount=")
    two_word_flags+=("--credit-amount")
    local_nonpersistent_flags+=("--credit-amount")
    local_nonpersistent_flags+=("--credit-amount=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--effective-at=")
    two_word_flags+=("--effective-at")
    local_nonpersistent_flags+=("--effective-at")
    local_nonpersistent_flags+=("--effective-at=")
    flags+=("--email-type=")
    two_word_flags+=("--email-type")
    local_nonpersistent_flags+=("--email-type")
    local_nonpersistent_flags+=("--email-type=")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--invoice=")
    two_word_flags+=("--invoice")
    local_nonpersistent_flags+=("--invoice")
    local_nonpersistent_flags+=("--invoice=")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--memo=")
    two_word_flags+=("--memo")
    local_nonpersistent_flags+=("--memo")
    local_nonpersistent_flags+=("--memo=")
    flags+=("--out-of-band-amount=")
    two_word_flags+=("--out-of-band-amount")
    local_nonpersistent_flags+=("--out-of-band-amount")
    local_nonpersistent_flags+=("--out-of-band-amount=")
    flags+=("--reason=")
    two_word_flags+=("--reason")
    local_nonpersistent_flags+=("--reason")
    local_nonpersistent_flags+=("--reason=")
    flags+=("--refund=")
    two_word_flags+=("--refund")
    local_nonpersistent_flags+=("--refund")
    local_nonpersistent_flags+=("--refund=")
    flags+=("--refund-amount=")
    two_word_flags+=("--refund-amount")
    local_nonpersistent_flags+=("--refund-amount")
    local_nonpersistent_flags+=("--refund-amount=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_credit_notes_preview_lines()
{
    last_command="stripe_credit_notes_preview_lines"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--credit-amount=")
    two_word_flags+=("--credit-amount")
    local_nonpersistent_flags+=("--credit-amount")
    local_nonpersistent_flags+=("--credit-amount=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--effective-at=")
    two_word_flags+=("--effective-at")
    local_nonpersistent_flags+=("--effective-at")
    local_nonpersistent_flags+=("--effective-at=")
    flags+=("--email-type=")
    two_word_flags+=("--email-type")
    local_nonpersistent_flags+=("--email-type")
    local_nonpersistent_flags+=("--email-type=")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--invoice=")
    two_word_flags+=("--invoice")
    local_nonpersistent_flags+=("--invoice")
    local_nonpersistent_flags+=("--invoice=")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--memo=")
    two_word_flags+=("--memo")
    local_nonpersistent_flags+=("--memo")
    local_nonpersistent_flags+=("--memo=")
    flags+=("--out-of-band-amount=")
    two_word_flags+=("--out-of-band-amount")
    local_nonpersistent_flags+=("--out-of-band-amount")
    local_nonpersistent_flags+=("--out-of-band-amount=")
    flags+=("--reason=")
    two_word_flags+=("--reason")
    local_nonpersistent_flags+=("--reason")
    local_nonpersistent_flags+=("--reason=")
    flags+=("--refund=")
    two_word_flags+=("--refund")
    local_nonpersistent_flags+=("--refund")
    local_nonpersistent_flags+=("--refund=")
    flags+=("--refund-amount=")
    two_word_flags+=("--refund-amount")
    local_nonpersistent_flags+=("--refund-amount")
    local_nonpersistent_flags+=("--refund-amount=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_credit_notes_retrieve()
{
    last_command="stripe_credit_notes_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_credit_notes_update()
{
    last_command="stripe_credit_notes_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--memo=")
    two_word_flags+=("--memo")
    local_nonpersistent_flags+=("--memo")
    local_nonpersistent_flags+=("--memo=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_credit_notes_void_credit_note()
{
    last_command="stripe_credit_notes_void_credit_note"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_credit_notes()
{
    last_command="stripe_credit_notes"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("preview")
    commands+=("preview_lines")
    commands+=("retrieve")
    commands+=("update")
    commands+=("void_credit_note")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customer_balance_transactions_create()
{
    last_command="stripe_customer_balance_transactions_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customer_balance_transactions_list()
{
    last_command="stripe_customer_balance_transactions_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customer_balance_transactions_retrieve()
{
    last_command="stripe_customer_balance_transactions_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customer_balance_transactions_update()
{
    last_command="stripe_customer_balance_transactions_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customer_balance_transactions()
{
    last_command="stripe_customer_balance_transactions"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customer_cash_balance_transactions_list()
{
    last_command="stripe_customer_cash_balance_transactions_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customer_cash_balance_transactions_retrieve()
{
    last_command="stripe_customer_cash_balance_transactions_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customer_cash_balance_transactions()
{
    last_command="stripe_customer_cash_balance_transactions"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customer_sessions_create()
{
    last_command="stripe_customer_sessions_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--components.buy-button.enabled=")
    two_word_flags+=("--components.buy-button.enabled")
    local_nonpersistent_flags+=("--components.buy-button.enabled")
    local_nonpersistent_flags+=("--components.buy-button.enabled=")
    flags+=("--components.payment-element.enabled=")
    two_word_flags+=("--components.payment-element.enabled")
    local_nonpersistent_flags+=("--components.payment-element.enabled")
    local_nonpersistent_flags+=("--components.payment-element.enabled=")
    flags+=("--components.payment-element.features.payment-method-allow-redisplay-filters=")
    two_word_flags+=("--components.payment-element.features.payment-method-allow-redisplay-filters")
    local_nonpersistent_flags+=("--components.payment-element.features.payment-method-allow-redisplay-filters")
    local_nonpersistent_flags+=("--components.payment-element.features.payment-method-allow-redisplay-filters=")
    flags+=("--components.payment-element.features.payment-method-redisplay=")
    two_word_flags+=("--components.payment-element.features.payment-method-redisplay")
    local_nonpersistent_flags+=("--components.payment-element.features.payment-method-redisplay")
    local_nonpersistent_flags+=("--components.payment-element.features.payment-method-redisplay=")
    flags+=("--components.payment-element.features.payment-method-redisplay-limit=")
    two_word_flags+=("--components.payment-element.features.payment-method-redisplay-limit")
    local_nonpersistent_flags+=("--components.payment-element.features.payment-method-redisplay-limit")
    local_nonpersistent_flags+=("--components.payment-element.features.payment-method-redisplay-limit=")
    flags+=("--components.payment-element.features.payment-method-remove=")
    two_word_flags+=("--components.payment-element.features.payment-method-remove")
    local_nonpersistent_flags+=("--components.payment-element.features.payment-method-remove")
    local_nonpersistent_flags+=("--components.payment-element.features.payment-method-remove=")
    flags+=("--components.payment-element.features.payment-method-save=")
    two_word_flags+=("--components.payment-element.features.payment-method-save")
    local_nonpersistent_flags+=("--components.payment-element.features.payment-method-save")
    local_nonpersistent_flags+=("--components.payment-element.features.payment-method-save=")
    flags+=("--components.payment-element.features.payment-method-save-usage=")
    two_word_flags+=("--components.payment-element.features.payment-method-save-usage")
    local_nonpersistent_flags+=("--components.payment-element.features.payment-method-save-usage")
    local_nonpersistent_flags+=("--components.payment-element.features.payment-method-save-usage=")
    flags+=("--components.pricing-table.enabled=")
    two_word_flags+=("--components.pricing-table.enabled")
    local_nonpersistent_flags+=("--components.pricing-table.enabled")
    local_nonpersistent_flags+=("--components.pricing-table.enabled=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customer_sessions()
{
    last_command="stripe_customer_sessions"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customers_balance_transactions()
{
    last_command="stripe_customers_balance_transactions"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customers_create()
{
    last_command="stripe_customers_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--balance=")
    two_word_flags+=("--balance")
    local_nonpersistent_flags+=("--balance")
    local_nonpersistent_flags+=("--balance=")
    flags+=("--cash-balance.settings.reconciliation-mode=")
    two_word_flags+=("--cash-balance.settings.reconciliation-mode")
    local_nonpersistent_flags+=("--cash-balance.settings.reconciliation-mode")
    local_nonpersistent_flags+=("--cash-balance.settings.reconciliation-mode=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--coupon=")
    two_word_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--email=")
    two_word_flags+=("--email")
    local_nonpersistent_flags+=("--email")
    local_nonpersistent_flags+=("--email=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--invoice-prefix=")
    two_word_flags+=("--invoice-prefix")
    local_nonpersistent_flags+=("--invoice-prefix")
    local_nonpersistent_flags+=("--invoice-prefix=")
    flags+=("--invoice-settings.default-payment-method=")
    two_word_flags+=("--invoice-settings.default-payment-method")
    local_nonpersistent_flags+=("--invoice-settings.default-payment-method")
    local_nonpersistent_flags+=("--invoice-settings.default-payment-method=")
    flags+=("--invoice-settings.footer=")
    two_word_flags+=("--invoice-settings.footer")
    local_nonpersistent_flags+=("--invoice-settings.footer")
    local_nonpersistent_flags+=("--invoice-settings.footer=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--next-invoice-sequence=")
    two_word_flags+=("--next-invoice-sequence")
    local_nonpersistent_flags+=("--next-invoice-sequence")
    local_nonpersistent_flags+=("--next-invoice-sequence=")
    flags+=("--payment-method=")
    two_word_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method=")
    flags+=("--phone=")
    two_word_flags+=("--phone")
    local_nonpersistent_flags+=("--phone")
    local_nonpersistent_flags+=("--phone=")
    flags+=("--preferred-locales=")
    two_word_flags+=("--preferred-locales")
    local_nonpersistent_flags+=("--preferred-locales")
    local_nonpersistent_flags+=("--preferred-locales=")
    flags+=("--promotion-code=")
    two_word_flags+=("--promotion-code")
    local_nonpersistent_flags+=("--promotion-code")
    local_nonpersistent_flags+=("--promotion-code=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--source=")
    two_word_flags+=("--source")
    local_nonpersistent_flags+=("--source")
    local_nonpersistent_flags+=("--source=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tax-exempt=")
    two_word_flags+=("--tax-exempt")
    local_nonpersistent_flags+=("--tax-exempt")
    local_nonpersistent_flags+=("--tax-exempt=")
    flags+=("--tax.ip-address=")
    two_word_flags+=("--tax.ip-address")
    local_nonpersistent_flags+=("--tax.ip-address")
    local_nonpersistent_flags+=("--tax.ip-address=")
    flags+=("--tax.validate-location=")
    two_word_flags+=("--tax.validate-location")
    local_nonpersistent_flags+=("--tax.validate-location")
    local_nonpersistent_flags+=("--tax.validate-location=")
    flags+=("--test-clock=")
    two_word_flags+=("--test-clock")
    local_nonpersistent_flags+=("--test-clock")
    local_nonpersistent_flags+=("--test-clock=")
    flags+=("--validate=")
    two_word_flags+=("--validate")
    local_nonpersistent_flags+=("--validate")
    local_nonpersistent_flags+=("--validate=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customers_create_funding_instructions()
{
    last_command="stripe_customers_create_funding_instructions"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--bank-transfer.eu-bank-transfer.country=")
    two_word_flags+=("--bank-transfer.eu-bank-transfer.country")
    local_nonpersistent_flags+=("--bank-transfer.eu-bank-transfer.country")
    local_nonpersistent_flags+=("--bank-transfer.eu-bank-transfer.country=")
    flags+=("--bank-transfer.requested-address-types=")
    two_word_flags+=("--bank-transfer.requested-address-types")
    local_nonpersistent_flags+=("--bank-transfer.requested-address-types")
    local_nonpersistent_flags+=("--bank-transfer.requested-address-types=")
    flags+=("--bank-transfer.type=")
    two_word_flags+=("--bank-transfer.type")
    local_nonpersistent_flags+=("--bank-transfer.type")
    local_nonpersistent_flags+=("--bank-transfer.type=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--funding-type=")
    two_word_flags+=("--funding-type")
    local_nonpersistent_flags+=("--funding-type")
    local_nonpersistent_flags+=("--funding-type=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customers_delete()
{
    last_command="stripe_customers_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customers_delete_discount()
{
    last_command="stripe_customers_delete_discount"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customers_list()
{
    last_command="stripe_customers_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--email=")
    two_word_flags+=("--email")
    local_nonpersistent_flags+=("--email")
    local_nonpersistent_flags+=("--email=")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--test-clock=")
    two_word_flags+=("--test-clock")
    local_nonpersistent_flags+=("--test-clock")
    local_nonpersistent_flags+=("--test-clock=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customers_list_payment_methods()
{
    last_command="stripe_customers_list_payment_methods"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--allow-redisplay=")
    two_word_flags+=("--allow-redisplay")
    local_nonpersistent_flags+=("--allow-redisplay")
    local_nonpersistent_flags+=("--allow-redisplay=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customers_retrieve()
{
    last_command="stripe_customers_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customers_retrieve_payment_method()
{
    last_command="stripe_customers_retrieve_payment_method"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customers_search()
{
    last_command="stripe_customers_search"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--page=")
    two_word_flags+=("--page")
    local_nonpersistent_flags+=("--page")
    local_nonpersistent_flags+=("--page=")
    flags+=("--query=")
    two_word_flags+=("--query")
    local_nonpersistent_flags+=("--query")
    local_nonpersistent_flags+=("--query=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customers_test_helpers_fund_cash_balance()
{
    last_command="stripe_customers_test_helpers_fund_cash_balance"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--reference=")
    two_word_flags+=("--reference")
    local_nonpersistent_flags+=("--reference")
    local_nonpersistent_flags+=("--reference=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customers_test_helpers()
{
    last_command="stripe_customers_test_helpers"

    command_aliases=()

    commands=()
    commands+=("fund_cash_balance")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customers_update()
{
    last_command="stripe_customers_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--balance=")
    two_word_flags+=("--balance")
    local_nonpersistent_flags+=("--balance")
    local_nonpersistent_flags+=("--balance=")
    flags+=("--cash-balance.settings.reconciliation-mode=")
    two_word_flags+=("--cash-balance.settings.reconciliation-mode")
    local_nonpersistent_flags+=("--cash-balance.settings.reconciliation-mode")
    local_nonpersistent_flags+=("--cash-balance.settings.reconciliation-mode=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--coupon=")
    two_word_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-source=")
    two_word_flags+=("--default-source")
    local_nonpersistent_flags+=("--default-source")
    local_nonpersistent_flags+=("--default-source=")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--email=")
    two_word_flags+=("--email")
    local_nonpersistent_flags+=("--email")
    local_nonpersistent_flags+=("--email=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--invoice-prefix=")
    two_word_flags+=("--invoice-prefix")
    local_nonpersistent_flags+=("--invoice-prefix")
    local_nonpersistent_flags+=("--invoice-prefix=")
    flags+=("--invoice-settings.default-payment-method=")
    two_word_flags+=("--invoice-settings.default-payment-method")
    local_nonpersistent_flags+=("--invoice-settings.default-payment-method")
    local_nonpersistent_flags+=("--invoice-settings.default-payment-method=")
    flags+=("--invoice-settings.footer=")
    two_word_flags+=("--invoice-settings.footer")
    local_nonpersistent_flags+=("--invoice-settings.footer")
    local_nonpersistent_flags+=("--invoice-settings.footer=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--next-invoice-sequence=")
    two_word_flags+=("--next-invoice-sequence")
    local_nonpersistent_flags+=("--next-invoice-sequence")
    local_nonpersistent_flags+=("--next-invoice-sequence=")
    flags+=("--phone=")
    two_word_flags+=("--phone")
    local_nonpersistent_flags+=("--phone")
    local_nonpersistent_flags+=("--phone=")
    flags+=("--preferred-locales=")
    two_word_flags+=("--preferred-locales")
    local_nonpersistent_flags+=("--preferred-locales")
    local_nonpersistent_flags+=("--preferred-locales=")
    flags+=("--promotion-code=")
    two_word_flags+=("--promotion-code")
    local_nonpersistent_flags+=("--promotion-code")
    local_nonpersistent_flags+=("--promotion-code=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--source=")
    two_word_flags+=("--source")
    local_nonpersistent_flags+=("--source")
    local_nonpersistent_flags+=("--source=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tax-exempt=")
    two_word_flags+=("--tax-exempt")
    local_nonpersistent_flags+=("--tax-exempt")
    local_nonpersistent_flags+=("--tax-exempt=")
    flags+=("--tax.ip-address=")
    two_word_flags+=("--tax.ip-address")
    local_nonpersistent_flags+=("--tax.ip-address")
    local_nonpersistent_flags+=("--tax.ip-address=")
    flags+=("--tax.validate-location=")
    two_word_flags+=("--tax.validate-location")
    local_nonpersistent_flags+=("--tax.validate-location")
    local_nonpersistent_flags+=("--tax.validate-location=")
    flags+=("--validate=")
    two_word_flags+=("--validate")
    local_nonpersistent_flags+=("--validate")
    local_nonpersistent_flags+=("--validate=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_customers()
{
    last_command="stripe_customers"

    command_aliases=()

    commands=()
    commands+=("balance_transactions")
    commands+=("create")
    commands+=("create_funding_instructions")
    commands+=("delete")
    commands+=("delete_discount")
    commands+=("list")
    commands+=("list_payment_methods")
    commands+=("retrieve")
    commands+=("retrieve_payment_method")
    commands+=("search")
    commands+=("test_helpers")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_delete()
{
    last_command="stripe_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_disputes_close()
{
    last_command="stripe_disputes_close"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_disputes_list()
{
    last_command="stripe_disputes_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--charge=")
    two_word_flags+=("--charge")
    local_nonpersistent_flags+=("--charge")
    local_nonpersistent_flags+=("--charge=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-intent=")
    two_word_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_disputes_retrieve()
{
    last_command="stripe_disputes_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_disputes_update()
{
    last_command="stripe_disputes_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--evidence.access-activity-log=")
    two_word_flags+=("--evidence.access-activity-log")
    local_nonpersistent_flags+=("--evidence.access-activity-log")
    local_nonpersistent_flags+=("--evidence.access-activity-log=")
    flags+=("--evidence.billing-address=")
    two_word_flags+=("--evidence.billing-address")
    local_nonpersistent_flags+=("--evidence.billing-address")
    local_nonpersistent_flags+=("--evidence.billing-address=")
    flags+=("--evidence.cancellation-policy=")
    two_word_flags+=("--evidence.cancellation-policy")
    local_nonpersistent_flags+=("--evidence.cancellation-policy")
    local_nonpersistent_flags+=("--evidence.cancellation-policy=")
    flags+=("--evidence.cancellation-policy-disclosure=")
    two_word_flags+=("--evidence.cancellation-policy-disclosure")
    local_nonpersistent_flags+=("--evidence.cancellation-policy-disclosure")
    local_nonpersistent_flags+=("--evidence.cancellation-policy-disclosure=")
    flags+=("--evidence.cancellation-rebuttal=")
    two_word_flags+=("--evidence.cancellation-rebuttal")
    local_nonpersistent_flags+=("--evidence.cancellation-rebuttal")
    local_nonpersistent_flags+=("--evidence.cancellation-rebuttal=")
    flags+=("--evidence.customer-communication=")
    two_word_flags+=("--evidence.customer-communication")
    local_nonpersistent_flags+=("--evidence.customer-communication")
    local_nonpersistent_flags+=("--evidence.customer-communication=")
    flags+=("--evidence.customer-email-address=")
    two_word_flags+=("--evidence.customer-email-address")
    local_nonpersistent_flags+=("--evidence.customer-email-address")
    local_nonpersistent_flags+=("--evidence.customer-email-address=")
    flags+=("--evidence.customer-name=")
    two_word_flags+=("--evidence.customer-name")
    local_nonpersistent_flags+=("--evidence.customer-name")
    local_nonpersistent_flags+=("--evidence.customer-name=")
    flags+=("--evidence.customer-purchase-ip=")
    two_word_flags+=("--evidence.customer-purchase-ip")
    local_nonpersistent_flags+=("--evidence.customer-purchase-ip")
    local_nonpersistent_flags+=("--evidence.customer-purchase-ip=")
    flags+=("--evidence.customer-signature=")
    two_word_flags+=("--evidence.customer-signature")
    local_nonpersistent_flags+=("--evidence.customer-signature")
    local_nonpersistent_flags+=("--evidence.customer-signature=")
    flags+=("--evidence.duplicate-charge-documentation=")
    two_word_flags+=("--evidence.duplicate-charge-documentation")
    local_nonpersistent_flags+=("--evidence.duplicate-charge-documentation")
    local_nonpersistent_flags+=("--evidence.duplicate-charge-documentation=")
    flags+=("--evidence.duplicate-charge-explanation=")
    two_word_flags+=("--evidence.duplicate-charge-explanation")
    local_nonpersistent_flags+=("--evidence.duplicate-charge-explanation")
    local_nonpersistent_flags+=("--evidence.duplicate-charge-explanation=")
    flags+=("--evidence.duplicate-charge-id=")
    two_word_flags+=("--evidence.duplicate-charge-id")
    local_nonpersistent_flags+=("--evidence.duplicate-charge-id")
    local_nonpersistent_flags+=("--evidence.duplicate-charge-id=")
    flags+=("--evidence.product-description=")
    two_word_flags+=("--evidence.product-description")
    local_nonpersistent_flags+=("--evidence.product-description")
    local_nonpersistent_flags+=("--evidence.product-description=")
    flags+=("--evidence.receipt=")
    two_word_flags+=("--evidence.receipt")
    local_nonpersistent_flags+=("--evidence.receipt")
    local_nonpersistent_flags+=("--evidence.receipt=")
    flags+=("--evidence.refund-policy=")
    two_word_flags+=("--evidence.refund-policy")
    local_nonpersistent_flags+=("--evidence.refund-policy")
    local_nonpersistent_flags+=("--evidence.refund-policy=")
    flags+=("--evidence.refund-policy-disclosure=")
    two_word_flags+=("--evidence.refund-policy-disclosure")
    local_nonpersistent_flags+=("--evidence.refund-policy-disclosure")
    local_nonpersistent_flags+=("--evidence.refund-policy-disclosure=")
    flags+=("--evidence.refund-refusal-explanation=")
    two_word_flags+=("--evidence.refund-refusal-explanation")
    local_nonpersistent_flags+=("--evidence.refund-refusal-explanation")
    local_nonpersistent_flags+=("--evidence.refund-refusal-explanation=")
    flags+=("--evidence.service-date=")
    two_word_flags+=("--evidence.service-date")
    local_nonpersistent_flags+=("--evidence.service-date")
    local_nonpersistent_flags+=("--evidence.service-date=")
    flags+=("--evidence.service-documentation=")
    two_word_flags+=("--evidence.service-documentation")
    local_nonpersistent_flags+=("--evidence.service-documentation")
    local_nonpersistent_flags+=("--evidence.service-documentation=")
    flags+=("--evidence.shipping-address=")
    two_word_flags+=("--evidence.shipping-address")
    local_nonpersistent_flags+=("--evidence.shipping-address")
    local_nonpersistent_flags+=("--evidence.shipping-address=")
    flags+=("--evidence.shipping-carrier=")
    two_word_flags+=("--evidence.shipping-carrier")
    local_nonpersistent_flags+=("--evidence.shipping-carrier")
    local_nonpersistent_flags+=("--evidence.shipping-carrier=")
    flags+=("--evidence.shipping-date=")
    two_word_flags+=("--evidence.shipping-date")
    local_nonpersistent_flags+=("--evidence.shipping-date")
    local_nonpersistent_flags+=("--evidence.shipping-date=")
    flags+=("--evidence.shipping-documentation=")
    two_word_flags+=("--evidence.shipping-documentation")
    local_nonpersistent_flags+=("--evidence.shipping-documentation")
    local_nonpersistent_flags+=("--evidence.shipping-documentation=")
    flags+=("--evidence.shipping-tracking-number=")
    two_word_flags+=("--evidence.shipping-tracking-number")
    local_nonpersistent_flags+=("--evidence.shipping-tracking-number")
    local_nonpersistent_flags+=("--evidence.shipping-tracking-number=")
    flags+=("--evidence.uncategorized-file=")
    two_word_flags+=("--evidence.uncategorized-file")
    local_nonpersistent_flags+=("--evidence.uncategorized-file")
    local_nonpersistent_flags+=("--evidence.uncategorized-file=")
    flags+=("--evidence.uncategorized-text=")
    two_word_flags+=("--evidence.uncategorized-text")
    local_nonpersistent_flags+=("--evidence.uncategorized-text")
    local_nonpersistent_flags+=("--evidence.uncategorized-text=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--submit=")
    two_word_flags+=("--submit")
    local_nonpersistent_flags+=("--submit")
    local_nonpersistent_flags+=("--submit=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_disputes()
{
    last_command="stripe_disputes"

    command_aliases=()

    commands=()
    commands+=("close")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_entitlements_active_entitlements_list()
{
    last_command="stripe_entitlements_active_entitlements_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_entitlements_active_entitlements_retrieve()
{
    last_command="stripe_entitlements_active_entitlements_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_entitlements_active_entitlements()
{
    last_command="stripe_entitlements_active_entitlements"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_entitlements_features_create()
{
    last_command="stripe_entitlements_features_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--lookup-key=")
    two_word_flags+=("--lookup-key")
    local_nonpersistent_flags+=("--lookup-key")
    local_nonpersistent_flags+=("--lookup-key=")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_entitlements_features_list()
{
    last_command="stripe_entitlements_features_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--archived=")
    two_word_flags+=("--archived")
    local_nonpersistent_flags+=("--archived")
    local_nonpersistent_flags+=("--archived=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--lookup-key=")
    two_word_flags+=("--lookup-key")
    local_nonpersistent_flags+=("--lookup-key")
    local_nonpersistent_flags+=("--lookup-key=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_entitlements_features_retrieve()
{
    last_command="stripe_entitlements_features_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_entitlements_features_update()
{
    last_command="stripe_entitlements_features_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_entitlements_features()
{
    last_command="stripe_entitlements_features"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_entitlements()
{
    last_command="stripe_entitlements"

    command_aliases=()

    commands=()
    commands+=("active_entitlements")
    commands+=("features")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_ephemeral_keys_create()
{
    last_command="stripe_ephemeral_keys_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--issuing-card=")
    two_word_flags+=("--issuing-card")
    local_nonpersistent_flags+=("--issuing-card")
    local_nonpersistent_flags+=("--issuing-card=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--nonce=")
    two_word_flags+=("--nonce")
    local_nonpersistent_flags+=("--nonce")
    local_nonpersistent_flags+=("--nonce=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--verification-session=")
    two_word_flags+=("--verification-session")
    local_nonpersistent_flags+=("--verification-session")
    local_nonpersistent_flags+=("--verification-session=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_ephemeral_keys_delete()
{
    last_command="stripe_ephemeral_keys_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_ephemeral_keys()
{
    last_command="stripe_ephemeral_keys"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_events_list()
{
    last_command="stripe_events_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--delivery-success=")
    two_word_flags+=("--delivery-success")
    local_nonpersistent_flags+=("--delivery-success")
    local_nonpersistent_flags+=("--delivery-success=")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--types=")
    two_word_flags+=("--types")
    local_nonpersistent_flags+=("--types")
    local_nonpersistent_flags+=("--types=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_events_resend()
{
    last_command="stripe_events_resend"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--account=")
    two_word_flags+=("--account")
    local_nonpersistent_flags+=("--account")
    local_nonpersistent_flags+=("--account=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--webhook-endpoint=")
    two_word_flags+=("--webhook-endpoint")
    local_nonpersistent_flags+=("--webhook-endpoint")
    local_nonpersistent_flags+=("--webhook-endpoint=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_events_retrieve()
{
    last_command="stripe_events_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_events()
{
    last_command="stripe_events"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("resend")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_exchange_rates_list()
{
    last_command="stripe_exchange_rates_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_exchange_rates_retrieve()
{
    last_command="stripe_exchange_rates_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_exchange_rates()
{
    last_command="stripe_exchange_rates"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_external_accounts_create()
{
    last_command="stripe_external_accounts_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-for-currency=")
    two_word_flags+=("--default-for-currency")
    local_nonpersistent_flags+=("--default-for-currency")
    local_nonpersistent_flags+=("--default-for-currency=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--external-account=")
    two_word_flags+=("--external-account")
    local_nonpersistent_flags+=("--external-account")
    local_nonpersistent_flags+=("--external-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_external_accounts_delete()
{
    last_command="stripe_external_accounts_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_external_accounts_list()
{
    last_command="stripe_external_accounts_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--object=")
    two_word_flags+=("--object")
    local_nonpersistent_flags+=("--object")
    local_nonpersistent_flags+=("--object=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_external_accounts_retrieve()
{
    last_command="stripe_external_accounts_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_external_accounts_update()
{
    last_command="stripe_external_accounts_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--account-holder-name=")
    two_word_flags+=("--account-holder-name")
    local_nonpersistent_flags+=("--account-holder-name")
    local_nonpersistent_flags+=("--account-holder-name=")
    flags+=("--account-holder-type=")
    two_word_flags+=("--account-holder-type")
    local_nonpersistent_flags+=("--account-holder-type")
    local_nonpersistent_flags+=("--account-holder-type=")
    flags+=("--account-type=")
    two_word_flags+=("--account-type")
    local_nonpersistent_flags+=("--account-type")
    local_nonpersistent_flags+=("--account-type=")
    flags+=("--address-city=")
    two_word_flags+=("--address-city")
    local_nonpersistent_flags+=("--address-city")
    local_nonpersistent_flags+=("--address-city=")
    flags+=("--address-country=")
    two_word_flags+=("--address-country")
    local_nonpersistent_flags+=("--address-country")
    local_nonpersistent_flags+=("--address-country=")
    flags+=("--address-line1=")
    two_word_flags+=("--address-line1")
    local_nonpersistent_flags+=("--address-line1")
    local_nonpersistent_flags+=("--address-line1=")
    flags+=("--address-line2=")
    two_word_flags+=("--address-line2")
    local_nonpersistent_flags+=("--address-line2")
    local_nonpersistent_flags+=("--address-line2=")
    flags+=("--address-state=")
    two_word_flags+=("--address-state")
    local_nonpersistent_flags+=("--address-state")
    local_nonpersistent_flags+=("--address-state=")
    flags+=("--address-zip=")
    two_word_flags+=("--address-zip")
    local_nonpersistent_flags+=("--address-zip")
    local_nonpersistent_flags+=("--address-zip=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-for-currency=")
    two_word_flags+=("--default-for-currency")
    local_nonpersistent_flags+=("--default-for-currency")
    local_nonpersistent_flags+=("--default-for-currency=")
    flags+=("--documents.bank-account-ownership-verification.files=")
    two_word_flags+=("--documents.bank-account-ownership-verification.files")
    local_nonpersistent_flags+=("--documents.bank-account-ownership-verification.files")
    local_nonpersistent_flags+=("--documents.bank-account-ownership-verification.files=")
    flags+=("--exp-month=")
    two_word_flags+=("--exp-month")
    local_nonpersistent_flags+=("--exp-month")
    local_nonpersistent_flags+=("--exp-month=")
    flags+=("--exp-year=")
    two_word_flags+=("--exp-year")
    local_nonpersistent_flags+=("--exp-year")
    local_nonpersistent_flags+=("--exp-year=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_external_accounts()
{
    last_command="stripe_external_accounts"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_fee_refunds_create()
{
    last_command="stripe_fee_refunds_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_fee_refunds_list()
{
    last_command="stripe_fee_refunds_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_fee_refunds_retrieve()
{
    last_command="stripe_fee_refunds_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_fee_refunds_update()
{
    last_command="stripe_fee_refunds_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_fee_refunds()
{
    last_command="stripe_fee_refunds"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_feedback()
{
    last_command="stripe_feedback"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_file_links_create()
{
    last_command="stripe_file_links_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--expires-at=")
    two_word_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at=")
    flags+=("--file=")
    two_word_flags+=("--file")
    local_nonpersistent_flags+=("--file")
    local_nonpersistent_flags+=("--file=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_file_links_list()
{
    last_command="stripe_file_links_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--expired=")
    two_word_flags+=("--expired")
    local_nonpersistent_flags+=("--expired")
    local_nonpersistent_flags+=("--expired=")
    flags+=("--file=")
    two_word_flags+=("--file")
    local_nonpersistent_flags+=("--file")
    local_nonpersistent_flags+=("--file=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_file_links_retrieve()
{
    last_command="stripe_file_links_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_file_links_update()
{
    last_command="stripe_file_links_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--expires-at=")
    two_word_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_file_links()
{
    last_command="stripe_file_links"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_files_create()
{
    last_command="stripe_files_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_files_list()
{
    last_command="stripe_files_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--purpose=")
    two_word_flags+=("--purpose")
    local_nonpersistent_flags+=("--purpose")
    local_nonpersistent_flags+=("--purpose=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_files_retrieve()
{
    last_command="stripe_files_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_files()
{
    last_command="stripe_files"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_financial_connections_accounts_disconnect()
{
    last_command="stripe_financial_connections_accounts_disconnect"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_financial_connections_accounts_list()
{
    last_command="stripe_financial_connections_accounts_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--session=")
    two_word_flags+=("--session")
    local_nonpersistent_flags+=("--session")
    local_nonpersistent_flags+=("--session=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_financial_connections_accounts_list_owners()
{
    last_command="stripe_financial_connections_accounts_list_owners"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--ownership=")
    two_word_flags+=("--ownership")
    local_nonpersistent_flags+=("--ownership")
    local_nonpersistent_flags+=("--ownership=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_financial_connections_accounts_refresh()
{
    last_command="stripe_financial_connections_accounts_refresh"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--features=")
    two_word_flags+=("--features")
    local_nonpersistent_flags+=("--features")
    local_nonpersistent_flags+=("--features=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_financial_connections_accounts_retrieve()
{
    last_command="stripe_financial_connections_accounts_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_financial_connections_accounts_subscribe()
{
    last_command="stripe_financial_connections_accounts_subscribe"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--features=")
    two_word_flags+=("--features")
    local_nonpersistent_flags+=("--features")
    local_nonpersistent_flags+=("--features=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_financial_connections_accounts_unsubscribe()
{
    last_command="stripe_financial_connections_accounts_unsubscribe"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--features=")
    two_word_flags+=("--features")
    local_nonpersistent_flags+=("--features")
    local_nonpersistent_flags+=("--features=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_financial_connections_accounts()
{
    last_command="stripe_financial_connections_accounts"

    command_aliases=()

    commands=()
    commands+=("disconnect")
    commands+=("list")
    commands+=("list_owners")
    commands+=("refresh")
    commands+=("retrieve")
    commands+=("subscribe")
    commands+=("unsubscribe")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_financial_connections_sessions_create()
{
    last_command="stripe_financial_connections_sessions_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--account-holder.account=")
    two_word_flags+=("--account-holder.account")
    local_nonpersistent_flags+=("--account-holder.account")
    local_nonpersistent_flags+=("--account-holder.account=")
    flags+=("--account-holder.customer=")
    two_word_flags+=("--account-holder.customer")
    local_nonpersistent_flags+=("--account-holder.customer")
    local_nonpersistent_flags+=("--account-holder.customer=")
    flags+=("--account-holder.type=")
    two_word_flags+=("--account-holder.type")
    local_nonpersistent_flags+=("--account-holder.type")
    local_nonpersistent_flags+=("--account-holder.type=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--filters.account-subcategories=")
    two_word_flags+=("--filters.account-subcategories")
    local_nonpersistent_flags+=("--filters.account-subcategories")
    local_nonpersistent_flags+=("--filters.account-subcategories=")
    flags+=("--filters.countries=")
    two_word_flags+=("--filters.countries")
    local_nonpersistent_flags+=("--filters.countries")
    local_nonpersistent_flags+=("--filters.countries=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--permissions=")
    two_word_flags+=("--permissions")
    local_nonpersistent_flags+=("--permissions")
    local_nonpersistent_flags+=("--permissions=")
    flags+=("--prefetch=")
    two_word_flags+=("--prefetch")
    local_nonpersistent_flags+=("--prefetch")
    local_nonpersistent_flags+=("--prefetch=")
    flags+=("--return-url=")
    two_word_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_financial_connections_sessions_retrieve()
{
    last_command="stripe_financial_connections_sessions_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_financial_connections_sessions()
{
    last_command="stripe_financial_connections_sessions"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_financial_connections_transactions_list()
{
    last_command="stripe_financial_connections_transactions_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--account=")
    two_word_flags+=("--account")
    local_nonpersistent_flags+=("--account")
    local_nonpersistent_flags+=("--account=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transacted-at=")
    two_word_flags+=("--transacted-at")
    local_nonpersistent_flags+=("--transacted-at")
    local_nonpersistent_flags+=("--transacted-at=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_financial_connections_transactions_retrieve()
{
    last_command="stripe_financial_connections_transactions_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_financial_connections_transactions()
{
    last_command="stripe_financial_connections_transactions"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_financial_connections()
{
    last_command="stripe_financial_connections"

    command_aliases=()

    commands=()
    commands+=("accounts")
    commands+=("sessions")
    commands+=("transactions")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_fixtures()
{
    last_command="stripe_fixtures"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--add=")
    two_word_flags+=("--add")
    local_nonpersistent_flags+=("--add")
    local_nonpersistent_flags+=("--add=")
    flags+=("--api-version=")
    two_word_flags+=("--api-version")
    local_nonpersistent_flags+=("--api-version")
    local_nonpersistent_flags+=("--api-version=")
    flags+=("--edit")
    local_nonpersistent_flags+=("--edit")
    flags+=("--override=")
    two_word_flags+=("--override")
    local_nonpersistent_flags+=("--override")
    local_nonpersistent_flags+=("--override=")
    flags+=("--remove=")
    two_word_flags+=("--remove")
    local_nonpersistent_flags+=("--remove")
    local_nonpersistent_flags+=("--remove=")
    flags+=("--skip=")
    two_word_flags+=("--skip")
    local_nonpersistent_flags+=("--skip")
    local_nonpersistent_flags+=("--skip=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_forwarding_requests_create()
{
    last_command="stripe_forwarding_requests_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-method=")
    two_word_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method=")
    flags+=("--replacements=")
    two_word_flags+=("--replacements")
    local_nonpersistent_flags+=("--replacements")
    local_nonpersistent_flags+=("--replacements=")
    flags+=("--request.body=")
    two_word_flags+=("--request.body")
    local_nonpersistent_flags+=("--request.body")
    local_nonpersistent_flags+=("--request.body=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--url=")
    two_word_flags+=("--url")
    local_nonpersistent_flags+=("--url")
    local_nonpersistent_flags+=("--url=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_forwarding_requests_list()
{
    last_command="stripe_forwarding_requests_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_forwarding_requests_retrieve()
{
    last_command="stripe_forwarding_requests_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_forwarding_requests()
{
    last_command="stripe_forwarding_requests"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_forwarding()
{
    last_command="stripe_forwarding"

    command_aliases=()

    commands=()
    commands+=("requests")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_get()
{
    last_command="stripe_get"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_help()
{
    last_command="stripe_help"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    has_completion_function=1
    noun_aliases=()
}

_stripe_identity_verification_reports_list()
{
    last_command="stripe_identity_verification_reports_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--client-reference-id=")
    two_word_flags+=("--client-reference-id")
    local_nonpersistent_flags+=("--client-reference-id")
    local_nonpersistent_flags+=("--client-reference-id=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--verification-session=")
    two_word_flags+=("--verification-session")
    local_nonpersistent_flags+=("--verification-session")
    local_nonpersistent_flags+=("--verification-session=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_identity_verification_reports_retrieve()
{
    last_command="stripe_identity_verification_reports_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_identity_verification_reports()
{
    last_command="stripe_identity_verification_reports"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_identity_verification_sessions_cancel()
{
    last_command="stripe_identity_verification_sessions_cancel"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_identity_verification_sessions_create()
{
    last_command="stripe_identity_verification_sessions_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--client-reference-id=")
    two_word_flags+=("--client-reference-id")
    local_nonpersistent_flags+=("--client-reference-id")
    local_nonpersistent_flags+=("--client-reference-id=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--provided-details.email=")
    two_word_flags+=("--provided-details.email")
    local_nonpersistent_flags+=("--provided-details.email")
    local_nonpersistent_flags+=("--provided-details.email=")
    flags+=("--provided-details.phone=")
    two_word_flags+=("--provided-details.phone")
    local_nonpersistent_flags+=("--provided-details.phone")
    local_nonpersistent_flags+=("--provided-details.phone=")
    flags+=("--related-customer=")
    two_word_flags+=("--related-customer")
    local_nonpersistent_flags+=("--related-customer")
    local_nonpersistent_flags+=("--related-customer=")
    flags+=("--return-url=")
    two_word_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--verification-flow=")
    two_word_flags+=("--verification-flow")
    local_nonpersistent_flags+=("--verification-flow")
    local_nonpersistent_flags+=("--verification-flow=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_identity_verification_sessions_list()
{
    last_command="stripe_identity_verification_sessions_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--client-reference-id=")
    two_word_flags+=("--client-reference-id")
    local_nonpersistent_flags+=("--client-reference-id")
    local_nonpersistent_flags+=("--client-reference-id=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--related-customer=")
    two_word_flags+=("--related-customer")
    local_nonpersistent_flags+=("--related-customer")
    local_nonpersistent_flags+=("--related-customer=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_identity_verification_sessions_redact()
{
    last_command="stripe_identity_verification_sessions_redact"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_identity_verification_sessions_retrieve()
{
    last_command="stripe_identity_verification_sessions_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_identity_verification_sessions_update()
{
    last_command="stripe_identity_verification_sessions_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--provided-details.email=")
    two_word_flags+=("--provided-details.email")
    local_nonpersistent_flags+=("--provided-details.email")
    local_nonpersistent_flags+=("--provided-details.email=")
    flags+=("--provided-details.phone=")
    two_word_flags+=("--provided-details.phone")
    local_nonpersistent_flags+=("--provided-details.phone")
    local_nonpersistent_flags+=("--provided-details.phone=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_identity_verification_sessions()
{
    last_command="stripe_identity_verification_sessions"

    command_aliases=()

    commands=()
    commands+=("cancel")
    commands+=("create")
    commands+=("list")
    commands+=("redact")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_identity()
{
    last_command="stripe_identity"

    command_aliases=()

    commands=()
    commands+=("verification_reports")
    commands+=("verification_sessions")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoice_rendering_templates_archive()
{
    last_command="stripe_invoice_rendering_templates_archive"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoice_rendering_templates_list()
{
    last_command="stripe_invoice_rendering_templates_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoice_rendering_templates_retrieve()
{
    last_command="stripe_invoice_rendering_templates_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--version=")
    two_word_flags+=("--version")
    local_nonpersistent_flags+=("--version")
    local_nonpersistent_flags+=("--version=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoice_rendering_templates_unarchive()
{
    last_command="stripe_invoice_rendering_templates_unarchive"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoice_rendering_templates()
{
    last_command="stripe_invoice_rendering_templates"

    command_aliases=()

    commands=()
    commands+=("archive")
    commands+=("list")
    commands+=("retrieve")
    commands+=("unarchive")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoiceitems_create()
{
    last_command="stripe_invoiceitems_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--discountable=")
    two_word_flags+=("--discountable")
    local_nonpersistent_flags+=("--discountable")
    local_nonpersistent_flags+=("--discountable=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--invoice=")
    two_word_flags+=("--invoice")
    local_nonpersistent_flags+=("--invoice")
    local_nonpersistent_flags+=("--invoice=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--period.end=")
    two_word_flags+=("--period.end")
    local_nonpersistent_flags+=("--period.end")
    local_nonpersistent_flags+=("--period.end=")
    flags+=("--period.start=")
    two_word_flags+=("--period.start")
    local_nonpersistent_flags+=("--period.start")
    local_nonpersistent_flags+=("--period.start=")
    flags+=("--price=")
    two_word_flags+=("--price")
    local_nonpersistent_flags+=("--price")
    local_nonpersistent_flags+=("--price=")
    flags+=("--price-data.currency=")
    two_word_flags+=("--price-data.currency")
    local_nonpersistent_flags+=("--price-data.currency")
    local_nonpersistent_flags+=("--price-data.currency=")
    flags+=("--price-data.product=")
    two_word_flags+=("--price-data.product")
    local_nonpersistent_flags+=("--price-data.product")
    local_nonpersistent_flags+=("--price-data.product=")
    flags+=("--price-data.tax-behavior=")
    two_word_flags+=("--price-data.tax-behavior")
    local_nonpersistent_flags+=("--price-data.tax-behavior")
    local_nonpersistent_flags+=("--price-data.tax-behavior=")
    flags+=("--price-data.unit-amount=")
    two_word_flags+=("--price-data.unit-amount")
    local_nonpersistent_flags+=("--price-data.unit-amount")
    local_nonpersistent_flags+=("--price-data.unit-amount=")
    flags+=("--price-data.unit-amount-decimal=")
    two_word_flags+=("--price-data.unit-amount-decimal")
    local_nonpersistent_flags+=("--price-data.unit-amount-decimal")
    local_nonpersistent_flags+=("--price-data.unit-amount-decimal=")
    flags+=("--quantity=")
    two_word_flags+=("--quantity")
    local_nonpersistent_flags+=("--quantity")
    local_nonpersistent_flags+=("--quantity=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--subscription=")
    two_word_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription=")
    flags+=("--tax-behavior=")
    two_word_flags+=("--tax-behavior")
    local_nonpersistent_flags+=("--tax-behavior")
    local_nonpersistent_flags+=("--tax-behavior=")
    flags+=("--tax-code=")
    two_word_flags+=("--tax-code")
    local_nonpersistent_flags+=("--tax-code")
    local_nonpersistent_flags+=("--tax-code=")
    flags+=("--tax-rates=")
    two_word_flags+=("--tax-rates")
    local_nonpersistent_flags+=("--tax-rates")
    local_nonpersistent_flags+=("--tax-rates=")
    flags+=("--unit-amount=")
    two_word_flags+=("--unit-amount")
    local_nonpersistent_flags+=("--unit-amount")
    local_nonpersistent_flags+=("--unit-amount=")
    flags+=("--unit-amount-decimal=")
    two_word_flags+=("--unit-amount-decimal")
    local_nonpersistent_flags+=("--unit-amount-decimal")
    local_nonpersistent_flags+=("--unit-amount-decimal=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoiceitems_delete()
{
    last_command="stripe_invoiceitems_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoiceitems_list()
{
    last_command="stripe_invoiceitems_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--invoice=")
    two_word_flags+=("--invoice")
    local_nonpersistent_flags+=("--invoice")
    local_nonpersistent_flags+=("--invoice=")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--pending=")
    two_word_flags+=("--pending")
    local_nonpersistent_flags+=("--pending")
    local_nonpersistent_flags+=("--pending=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoiceitems_retrieve()
{
    last_command="stripe_invoiceitems_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoiceitems_update()
{
    last_command="stripe_invoiceitems_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--discountable=")
    two_word_flags+=("--discountable")
    local_nonpersistent_flags+=("--discountable")
    local_nonpersistent_flags+=("--discountable=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--period.end=")
    two_word_flags+=("--period.end")
    local_nonpersistent_flags+=("--period.end")
    local_nonpersistent_flags+=("--period.end=")
    flags+=("--period.start=")
    two_word_flags+=("--period.start")
    local_nonpersistent_flags+=("--period.start")
    local_nonpersistent_flags+=("--period.start=")
    flags+=("--price=")
    two_word_flags+=("--price")
    local_nonpersistent_flags+=("--price")
    local_nonpersistent_flags+=("--price=")
    flags+=("--price-data.currency=")
    two_word_flags+=("--price-data.currency")
    local_nonpersistent_flags+=("--price-data.currency")
    local_nonpersistent_flags+=("--price-data.currency=")
    flags+=("--price-data.product=")
    two_word_flags+=("--price-data.product")
    local_nonpersistent_flags+=("--price-data.product")
    local_nonpersistent_flags+=("--price-data.product=")
    flags+=("--price-data.tax-behavior=")
    two_word_flags+=("--price-data.tax-behavior")
    local_nonpersistent_flags+=("--price-data.tax-behavior")
    local_nonpersistent_flags+=("--price-data.tax-behavior=")
    flags+=("--price-data.unit-amount=")
    two_word_flags+=("--price-data.unit-amount")
    local_nonpersistent_flags+=("--price-data.unit-amount")
    local_nonpersistent_flags+=("--price-data.unit-amount=")
    flags+=("--price-data.unit-amount-decimal=")
    two_word_flags+=("--price-data.unit-amount-decimal")
    local_nonpersistent_flags+=("--price-data.unit-amount-decimal")
    local_nonpersistent_flags+=("--price-data.unit-amount-decimal=")
    flags+=("--quantity=")
    two_word_flags+=("--quantity")
    local_nonpersistent_flags+=("--quantity")
    local_nonpersistent_flags+=("--quantity=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tax-behavior=")
    two_word_flags+=("--tax-behavior")
    local_nonpersistent_flags+=("--tax-behavior")
    local_nonpersistent_flags+=("--tax-behavior=")
    flags+=("--tax-code=")
    two_word_flags+=("--tax-code")
    local_nonpersistent_flags+=("--tax-code")
    local_nonpersistent_flags+=("--tax-code=")
    flags+=("--tax-rates=")
    two_word_flags+=("--tax-rates")
    local_nonpersistent_flags+=("--tax-rates")
    local_nonpersistent_flags+=("--tax-rates=")
    flags+=("--unit-amount=")
    two_word_flags+=("--unit-amount")
    local_nonpersistent_flags+=("--unit-amount")
    local_nonpersistent_flags+=("--unit-amount=")
    flags+=("--unit-amount-decimal=")
    two_word_flags+=("--unit-amount-decimal")
    local_nonpersistent_flags+=("--unit-amount-decimal")
    local_nonpersistent_flags+=("--unit-amount-decimal=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoiceitems()
{
    last_command="stripe_invoiceitems"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_add_lines()
{
    last_command="stripe_invoices_add_lines"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_create()
{
    last_command="stripe_invoices_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--account-tax-ids=")
    two_word_flags+=("--account-tax-ids")
    local_nonpersistent_flags+=("--account-tax-ids")
    local_nonpersistent_flags+=("--account-tax-ids=")
    flags+=("--application-fee-amount=")
    two_word_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount=")
    flags+=("--auto-advance=")
    two_word_flags+=("--auto-advance")
    local_nonpersistent_flags+=("--auto-advance")
    local_nonpersistent_flags+=("--auto-advance=")
    flags+=("--automatic-tax.enabled=")
    two_word_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled=")
    flags+=("--automatic-tax.liability.account=")
    two_word_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account=")
    flags+=("--automatic-tax.liability.type=")
    two_word_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type=")
    flags+=("--automatically-finalizes-at=")
    two_word_flags+=("--automatically-finalizes-at")
    local_nonpersistent_flags+=("--automatically-finalizes-at")
    local_nonpersistent_flags+=("--automatically-finalizes-at=")
    flags+=("--collection-method=")
    two_word_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--days-until-due=")
    two_word_flags+=("--days-until-due")
    local_nonpersistent_flags+=("--days-until-due")
    local_nonpersistent_flags+=("--days-until-due=")
    flags+=("--default-payment-method=")
    two_word_flags+=("--default-payment-method")
    local_nonpersistent_flags+=("--default-payment-method")
    local_nonpersistent_flags+=("--default-payment-method=")
    flags+=("--default-source=")
    two_word_flags+=("--default-source")
    local_nonpersistent_flags+=("--default-source")
    local_nonpersistent_flags+=("--default-source=")
    flags+=("--default-tax-rates=")
    two_word_flags+=("--default-tax-rates")
    local_nonpersistent_flags+=("--default-tax-rates")
    local_nonpersistent_flags+=("--default-tax-rates=")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--due-date=")
    two_word_flags+=("--due-date")
    local_nonpersistent_flags+=("--due-date")
    local_nonpersistent_flags+=("--due-date=")
    flags+=("--effective-at=")
    two_word_flags+=("--effective-at")
    local_nonpersistent_flags+=("--effective-at")
    local_nonpersistent_flags+=("--effective-at=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--footer=")
    two_word_flags+=("--footer")
    local_nonpersistent_flags+=("--footer")
    local_nonpersistent_flags+=("--footer=")
    flags+=("--from-invoice.action=")
    two_word_flags+=("--from-invoice.action")
    local_nonpersistent_flags+=("--from-invoice.action")
    local_nonpersistent_flags+=("--from-invoice.action=")
    flags+=("--from-invoice.invoice=")
    two_word_flags+=("--from-invoice.invoice")
    local_nonpersistent_flags+=("--from-invoice.invoice")
    local_nonpersistent_flags+=("--from-invoice.invoice=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--issuer.account=")
    two_word_flags+=("--issuer.account")
    local_nonpersistent_flags+=("--issuer.account")
    local_nonpersistent_flags+=("--issuer.account=")
    flags+=("--issuer.type=")
    two_word_flags+=("--issuer.type")
    local_nonpersistent_flags+=("--issuer.type")
    local_nonpersistent_flags+=("--issuer.type=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--number=")
    two_word_flags+=("--number")
    local_nonpersistent_flags+=("--number")
    local_nonpersistent_flags+=("--number=")
    flags+=("--on-behalf-of=")
    two_word_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of=")
    flags+=("--payment-settings.default-mandate=")
    two_word_flags+=("--payment-settings.default-mandate")
    local_nonpersistent_flags+=("--payment-settings.default-mandate")
    local_nonpersistent_flags+=("--payment-settings.default-mandate=")
    flags+=("--payment-settings.payment-method-types=")
    two_word_flags+=("--payment-settings.payment-method-types")
    local_nonpersistent_flags+=("--payment-settings.payment-method-types")
    local_nonpersistent_flags+=("--payment-settings.payment-method-types=")
    flags+=("--pending-invoice-items-behavior=")
    two_word_flags+=("--pending-invoice-items-behavior")
    local_nonpersistent_flags+=("--pending-invoice-items-behavior")
    local_nonpersistent_flags+=("--pending-invoice-items-behavior=")
    flags+=("--rendering.amount-tax-display=")
    two_word_flags+=("--rendering.amount-tax-display")
    local_nonpersistent_flags+=("--rendering.amount-tax-display")
    local_nonpersistent_flags+=("--rendering.amount-tax-display=")
    flags+=("--rendering.pdf.page-size=")
    two_word_flags+=("--rendering.pdf.page-size")
    local_nonpersistent_flags+=("--rendering.pdf.page-size")
    local_nonpersistent_flags+=("--rendering.pdf.page-size=")
    flags+=("--rendering.template=")
    two_word_flags+=("--rendering.template")
    local_nonpersistent_flags+=("--rendering.template")
    local_nonpersistent_flags+=("--rendering.template=")
    flags+=("--rendering.template-version=")
    two_word_flags+=("--rendering.template-version")
    local_nonpersistent_flags+=("--rendering.template-version")
    local_nonpersistent_flags+=("--rendering.template-version=")
    flags+=("--shipping-cost.shipping-rate=")
    two_word_flags+=("--shipping-cost.shipping-rate")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate=")
    flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.maximum.unit=")
    two_word_flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.maximum.unit")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.maximum.unit")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.maximum.unit=")
    flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.maximum.value=")
    two_word_flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.maximum.value")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.maximum.value")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.maximum.value=")
    flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.minimum.unit=")
    two_word_flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.minimum.unit")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.minimum.unit")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.minimum.unit=")
    flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.minimum.value=")
    two_word_flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.minimum.value")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.minimum.value")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.delivery-estimate.minimum.value=")
    flags+=("--shipping-cost.shipping-rate-data.display-name=")
    two_word_flags+=("--shipping-cost.shipping-rate-data.display-name")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.display-name")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.display-name=")
    flags+=("--shipping-cost.shipping-rate-data.fixed-amount.amount=")
    two_word_flags+=("--shipping-cost.shipping-rate-data.fixed-amount.amount")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.fixed-amount.amount")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.fixed-amount.amount=")
    flags+=("--shipping-cost.shipping-rate-data.fixed-amount.currency=")
    two_word_flags+=("--shipping-cost.shipping-rate-data.fixed-amount.currency")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.fixed-amount.currency")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.fixed-amount.currency=")
    flags+=("--shipping-cost.shipping-rate-data.tax-behavior=")
    two_word_flags+=("--shipping-cost.shipping-rate-data.tax-behavior")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.tax-behavior")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.tax-behavior=")
    flags+=("--shipping-cost.shipping-rate-data.tax-code=")
    two_word_flags+=("--shipping-cost.shipping-rate-data.tax-code")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.tax-code")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.tax-code=")
    flags+=("--shipping-cost.shipping-rate-data.type=")
    two_word_flags+=("--shipping-cost.shipping-rate-data.type")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.type")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate-data.type=")
    flags+=("--shipping-details.address.city=")
    two_word_flags+=("--shipping-details.address.city")
    local_nonpersistent_flags+=("--shipping-details.address.city")
    local_nonpersistent_flags+=("--shipping-details.address.city=")
    flags+=("--shipping-details.address.country=")
    two_word_flags+=("--shipping-details.address.country")
    local_nonpersistent_flags+=("--shipping-details.address.country")
    local_nonpersistent_flags+=("--shipping-details.address.country=")
    flags+=("--shipping-details.address.line1=")
    two_word_flags+=("--shipping-details.address.line1")
    local_nonpersistent_flags+=("--shipping-details.address.line1")
    local_nonpersistent_flags+=("--shipping-details.address.line1=")
    flags+=("--shipping-details.address.line2=")
    two_word_flags+=("--shipping-details.address.line2")
    local_nonpersistent_flags+=("--shipping-details.address.line2")
    local_nonpersistent_flags+=("--shipping-details.address.line2=")
    flags+=("--shipping-details.address.postal-code=")
    two_word_flags+=("--shipping-details.address.postal-code")
    local_nonpersistent_flags+=("--shipping-details.address.postal-code")
    local_nonpersistent_flags+=("--shipping-details.address.postal-code=")
    flags+=("--shipping-details.address.state=")
    two_word_flags+=("--shipping-details.address.state")
    local_nonpersistent_flags+=("--shipping-details.address.state")
    local_nonpersistent_flags+=("--shipping-details.address.state=")
    flags+=("--shipping-details.name=")
    two_word_flags+=("--shipping-details.name")
    local_nonpersistent_flags+=("--shipping-details.name")
    local_nonpersistent_flags+=("--shipping-details.name=")
    flags+=("--shipping-details.phone=")
    two_word_flags+=("--shipping-details.phone")
    local_nonpersistent_flags+=("--shipping-details.phone")
    local_nonpersistent_flags+=("--shipping-details.phone=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--subscription=")
    two_word_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription=")
    flags+=("--transfer-data.amount=")
    two_word_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount=")
    flags+=("--transfer-data.destination=")
    two_word_flags+=("--transfer-data.destination")
    local_nonpersistent_flags+=("--transfer-data.destination")
    local_nonpersistent_flags+=("--transfer-data.destination=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_create_preview()
{
    last_command="stripe_invoices_create_preview"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--automatic-tax.enabled=")
    two_word_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled=")
    flags+=("--automatic-tax.liability.account=")
    two_word_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account=")
    flags+=("--automatic-tax.liability.type=")
    two_word_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--coupon=")
    two_word_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon=")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--customer-details.tax-exempt=")
    two_word_flags+=("--customer-details.tax-exempt")
    local_nonpersistent_flags+=("--customer-details.tax-exempt")
    local_nonpersistent_flags+=("--customer-details.tax-exempt=")
    flags+=("--customer-details.tax.ip-address=")
    two_word_flags+=("--customer-details.tax.ip-address")
    local_nonpersistent_flags+=("--customer-details.tax.ip-address")
    local_nonpersistent_flags+=("--customer-details.tax.ip-address=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--issuer.account=")
    two_word_flags+=("--issuer.account")
    local_nonpersistent_flags+=("--issuer.account")
    local_nonpersistent_flags+=("--issuer.account=")
    flags+=("--issuer.type=")
    two_word_flags+=("--issuer.type")
    local_nonpersistent_flags+=("--issuer.type")
    local_nonpersistent_flags+=("--issuer.type=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--on-behalf-of=")
    two_word_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of=")
    flags+=("--preview-mode=")
    two_word_flags+=("--preview-mode")
    local_nonpersistent_flags+=("--preview-mode")
    local_nonpersistent_flags+=("--preview-mode=")
    flags+=("--schedule=")
    two_word_flags+=("--schedule")
    local_nonpersistent_flags+=("--schedule")
    local_nonpersistent_flags+=("--schedule=")
    flags+=("--schedule-details.end-behavior=")
    two_word_flags+=("--schedule-details.end-behavior")
    local_nonpersistent_flags+=("--schedule-details.end-behavior")
    local_nonpersistent_flags+=("--schedule-details.end-behavior=")
    flags+=("--schedule-details.proration-behavior=")
    two_word_flags+=("--schedule-details.proration-behavior")
    local_nonpersistent_flags+=("--schedule-details.proration-behavior")
    local_nonpersistent_flags+=("--schedule-details.proration-behavior=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--subscription=")
    two_word_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription=")
    flags+=("--subscription-details.billing-cycle-anchor=")
    two_word_flags+=("--subscription-details.billing-cycle-anchor")
    local_nonpersistent_flags+=("--subscription-details.billing-cycle-anchor")
    local_nonpersistent_flags+=("--subscription-details.billing-cycle-anchor=")
    flags+=("--subscription-details.cancel-at=")
    two_word_flags+=("--subscription-details.cancel-at")
    local_nonpersistent_flags+=("--subscription-details.cancel-at")
    local_nonpersistent_flags+=("--subscription-details.cancel-at=")
    flags+=("--subscription-details.cancel-at-period-end=")
    two_word_flags+=("--subscription-details.cancel-at-period-end")
    local_nonpersistent_flags+=("--subscription-details.cancel-at-period-end")
    local_nonpersistent_flags+=("--subscription-details.cancel-at-period-end=")
    flags+=("--subscription-details.cancel-now=")
    two_word_flags+=("--subscription-details.cancel-now")
    local_nonpersistent_flags+=("--subscription-details.cancel-now")
    local_nonpersistent_flags+=("--subscription-details.cancel-now=")
    flags+=("--subscription-details.default-tax-rates=")
    two_word_flags+=("--subscription-details.default-tax-rates")
    local_nonpersistent_flags+=("--subscription-details.default-tax-rates")
    local_nonpersistent_flags+=("--subscription-details.default-tax-rates=")
    flags+=("--subscription-details.proration-behavior=")
    two_word_flags+=("--subscription-details.proration-behavior")
    local_nonpersistent_flags+=("--subscription-details.proration-behavior")
    local_nonpersistent_flags+=("--subscription-details.proration-behavior=")
    flags+=("--subscription-details.proration-date=")
    two_word_flags+=("--subscription-details.proration-date")
    local_nonpersistent_flags+=("--subscription-details.proration-date")
    local_nonpersistent_flags+=("--subscription-details.proration-date=")
    flags+=("--subscription-details.resume-at=")
    two_word_flags+=("--subscription-details.resume-at")
    local_nonpersistent_flags+=("--subscription-details.resume-at")
    local_nonpersistent_flags+=("--subscription-details.resume-at=")
    flags+=("--subscription-details.start-date=")
    two_word_flags+=("--subscription-details.start-date")
    local_nonpersistent_flags+=("--subscription-details.start-date")
    local_nonpersistent_flags+=("--subscription-details.start-date=")
    flags+=("--subscription-details.trial-end=")
    two_word_flags+=("--subscription-details.trial-end")
    local_nonpersistent_flags+=("--subscription-details.trial-end")
    local_nonpersistent_flags+=("--subscription-details.trial-end=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_delete()
{
    last_command="stripe_invoices_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_finalize_invoice()
{
    last_command="stripe_invoices_finalize_invoice"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--auto-advance=")
    two_word_flags+=("--auto-advance")
    local_nonpersistent_flags+=("--auto-advance")
    local_nonpersistent_flags+=("--auto-advance=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_list()
{
    last_command="stripe_invoices_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--collection-method=")
    two_word_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--due-date=")
    two_word_flags+=("--due-date")
    local_nonpersistent_flags+=("--due-date")
    local_nonpersistent_flags+=("--due-date=")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--subscription=")
    two_word_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_mark_uncollectible()
{
    last_command="stripe_invoices_mark_uncollectible"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_pay()
{
    last_command="stripe_invoices_pay"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--forgive=")
    two_word_flags+=("--forgive")
    local_nonpersistent_flags+=("--forgive")
    local_nonpersistent_flags+=("--forgive=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--mandate=")
    two_word_flags+=("--mandate")
    local_nonpersistent_flags+=("--mandate")
    local_nonpersistent_flags+=("--mandate=")
    flags+=("--off-session=")
    two_word_flags+=("--off-session")
    local_nonpersistent_flags+=("--off-session")
    local_nonpersistent_flags+=("--off-session=")
    flags+=("--paid-out-of-band=")
    two_word_flags+=("--paid-out-of-band")
    local_nonpersistent_flags+=("--paid-out-of-band")
    local_nonpersistent_flags+=("--paid-out-of-band=")
    flags+=("--payment-method=")
    two_word_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--source=")
    two_word_flags+=("--source")
    local_nonpersistent_flags+=("--source")
    local_nonpersistent_flags+=("--source=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_remove_lines()
{
    last_command="stripe_invoices_remove_lines"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_retrieve()
{
    last_command="stripe_invoices_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_search()
{
    last_command="stripe_invoices_search"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--page=")
    two_word_flags+=("--page")
    local_nonpersistent_flags+=("--page")
    local_nonpersistent_flags+=("--page=")
    flags+=("--query=")
    two_word_flags+=("--query")
    local_nonpersistent_flags+=("--query")
    local_nonpersistent_flags+=("--query=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_send_invoice()
{
    last_command="stripe_invoices_send_invoice"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_upcoming()
{
    last_command="stripe_invoices_upcoming"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--coupon=")
    two_word_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon=")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--on-behalf-of=")
    two_word_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of=")
    flags+=("--preview-mode=")
    two_word_flags+=("--preview-mode")
    local_nonpersistent_flags+=("--preview-mode")
    local_nonpersistent_flags+=("--preview-mode=")
    flags+=("--schedule=")
    two_word_flags+=("--schedule")
    local_nonpersistent_flags+=("--schedule")
    local_nonpersistent_flags+=("--schedule=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--subscription=")
    two_word_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription=")
    flags+=("--subscription-billing-cycle-anchor=")
    two_word_flags+=("--subscription-billing-cycle-anchor")
    local_nonpersistent_flags+=("--subscription-billing-cycle-anchor")
    local_nonpersistent_flags+=("--subscription-billing-cycle-anchor=")
    flags+=("--subscription-cancel-at=")
    two_word_flags+=("--subscription-cancel-at")
    local_nonpersistent_flags+=("--subscription-cancel-at")
    local_nonpersistent_flags+=("--subscription-cancel-at=")
    flags+=("--subscription-cancel-at-period-end=")
    two_word_flags+=("--subscription-cancel-at-period-end")
    local_nonpersistent_flags+=("--subscription-cancel-at-period-end")
    local_nonpersistent_flags+=("--subscription-cancel-at-period-end=")
    flags+=("--subscription-cancel-now=")
    two_word_flags+=("--subscription-cancel-now")
    local_nonpersistent_flags+=("--subscription-cancel-now")
    local_nonpersistent_flags+=("--subscription-cancel-now=")
    flags+=("--subscription-default-tax-rates=")
    two_word_flags+=("--subscription-default-tax-rates")
    local_nonpersistent_flags+=("--subscription-default-tax-rates")
    local_nonpersistent_flags+=("--subscription-default-tax-rates=")
    flags+=("--subscription-proration-behavior=")
    two_word_flags+=("--subscription-proration-behavior")
    local_nonpersistent_flags+=("--subscription-proration-behavior")
    local_nonpersistent_flags+=("--subscription-proration-behavior=")
    flags+=("--subscription-proration-date=")
    two_word_flags+=("--subscription-proration-date")
    local_nonpersistent_flags+=("--subscription-proration-date")
    local_nonpersistent_flags+=("--subscription-proration-date=")
    flags+=("--subscription-resume-at=")
    two_word_flags+=("--subscription-resume-at")
    local_nonpersistent_flags+=("--subscription-resume-at")
    local_nonpersistent_flags+=("--subscription-resume-at=")
    flags+=("--subscription-start-date=")
    two_word_flags+=("--subscription-start-date")
    local_nonpersistent_flags+=("--subscription-start-date")
    local_nonpersistent_flags+=("--subscription-start-date=")
    flags+=("--subscription-trial-end=")
    two_word_flags+=("--subscription-trial-end")
    local_nonpersistent_flags+=("--subscription-trial-end")
    local_nonpersistent_flags+=("--subscription-trial-end=")
    flags+=("--subscription-trial-from-plan=")
    two_word_flags+=("--subscription-trial-from-plan")
    local_nonpersistent_flags+=("--subscription-trial-from-plan")
    local_nonpersistent_flags+=("--subscription-trial-from-plan=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_upcomingLines()
{
    last_command="stripe_invoices_upcomingLines"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--coupon=")
    two_word_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon=")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--on-behalf-of=")
    two_word_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of=")
    flags+=("--preview-mode=")
    two_word_flags+=("--preview-mode")
    local_nonpersistent_flags+=("--preview-mode")
    local_nonpersistent_flags+=("--preview-mode=")
    flags+=("--schedule=")
    two_word_flags+=("--schedule")
    local_nonpersistent_flags+=("--schedule")
    local_nonpersistent_flags+=("--schedule=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--subscription=")
    two_word_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription=")
    flags+=("--subscription-billing-cycle-anchor=")
    two_word_flags+=("--subscription-billing-cycle-anchor")
    local_nonpersistent_flags+=("--subscription-billing-cycle-anchor")
    local_nonpersistent_flags+=("--subscription-billing-cycle-anchor=")
    flags+=("--subscription-cancel-at=")
    two_word_flags+=("--subscription-cancel-at")
    local_nonpersistent_flags+=("--subscription-cancel-at")
    local_nonpersistent_flags+=("--subscription-cancel-at=")
    flags+=("--subscription-cancel-at-period-end=")
    two_word_flags+=("--subscription-cancel-at-period-end")
    local_nonpersistent_flags+=("--subscription-cancel-at-period-end")
    local_nonpersistent_flags+=("--subscription-cancel-at-period-end=")
    flags+=("--subscription-cancel-now=")
    two_word_flags+=("--subscription-cancel-now")
    local_nonpersistent_flags+=("--subscription-cancel-now")
    local_nonpersistent_flags+=("--subscription-cancel-now=")
    flags+=("--subscription-default-tax-rates=")
    two_word_flags+=("--subscription-default-tax-rates")
    local_nonpersistent_flags+=("--subscription-default-tax-rates")
    local_nonpersistent_flags+=("--subscription-default-tax-rates=")
    flags+=("--subscription-proration-behavior=")
    two_word_flags+=("--subscription-proration-behavior")
    local_nonpersistent_flags+=("--subscription-proration-behavior")
    local_nonpersistent_flags+=("--subscription-proration-behavior=")
    flags+=("--subscription-proration-date=")
    two_word_flags+=("--subscription-proration-date")
    local_nonpersistent_flags+=("--subscription-proration-date")
    local_nonpersistent_flags+=("--subscription-proration-date=")
    flags+=("--subscription-resume-at=")
    two_word_flags+=("--subscription-resume-at")
    local_nonpersistent_flags+=("--subscription-resume-at")
    local_nonpersistent_flags+=("--subscription-resume-at=")
    flags+=("--subscription-start-date=")
    two_word_flags+=("--subscription-start-date")
    local_nonpersistent_flags+=("--subscription-start-date")
    local_nonpersistent_flags+=("--subscription-start-date=")
    flags+=("--subscription-trial-end=")
    two_word_flags+=("--subscription-trial-end")
    local_nonpersistent_flags+=("--subscription-trial-end")
    local_nonpersistent_flags+=("--subscription-trial-end=")
    flags+=("--subscription-trial-from-plan=")
    two_word_flags+=("--subscription-trial-from-plan")
    local_nonpersistent_flags+=("--subscription-trial-from-plan")
    local_nonpersistent_flags+=("--subscription-trial-from-plan=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_update()
{
    last_command="stripe_invoices_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--account-tax-ids=")
    two_word_flags+=("--account-tax-ids")
    local_nonpersistent_flags+=("--account-tax-ids")
    local_nonpersistent_flags+=("--account-tax-ids=")
    flags+=("--application-fee-amount=")
    two_word_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount=")
    flags+=("--auto-advance=")
    two_word_flags+=("--auto-advance")
    local_nonpersistent_flags+=("--auto-advance")
    local_nonpersistent_flags+=("--auto-advance=")
    flags+=("--automatic-tax.enabled=")
    two_word_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled=")
    flags+=("--automatic-tax.liability.account=")
    two_word_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account=")
    flags+=("--automatic-tax.liability.type=")
    two_word_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type=")
    flags+=("--automatically-finalizes-at=")
    two_word_flags+=("--automatically-finalizes-at")
    local_nonpersistent_flags+=("--automatically-finalizes-at")
    local_nonpersistent_flags+=("--automatically-finalizes-at=")
    flags+=("--collection-method=")
    two_word_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--days-until-due=")
    two_word_flags+=("--days-until-due")
    local_nonpersistent_flags+=("--days-until-due")
    local_nonpersistent_flags+=("--days-until-due=")
    flags+=("--default-payment-method=")
    two_word_flags+=("--default-payment-method")
    local_nonpersistent_flags+=("--default-payment-method")
    local_nonpersistent_flags+=("--default-payment-method=")
    flags+=("--default-source=")
    two_word_flags+=("--default-source")
    local_nonpersistent_flags+=("--default-source")
    local_nonpersistent_flags+=("--default-source=")
    flags+=("--default-tax-rates=")
    two_word_flags+=("--default-tax-rates")
    local_nonpersistent_flags+=("--default-tax-rates")
    local_nonpersistent_flags+=("--default-tax-rates=")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--due-date=")
    two_word_flags+=("--due-date")
    local_nonpersistent_flags+=("--due-date")
    local_nonpersistent_flags+=("--due-date=")
    flags+=("--effective-at=")
    two_word_flags+=("--effective-at")
    local_nonpersistent_flags+=("--effective-at")
    local_nonpersistent_flags+=("--effective-at=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--footer=")
    two_word_flags+=("--footer")
    local_nonpersistent_flags+=("--footer")
    local_nonpersistent_flags+=("--footer=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--issuer.account=")
    two_word_flags+=("--issuer.account")
    local_nonpersistent_flags+=("--issuer.account")
    local_nonpersistent_flags+=("--issuer.account=")
    flags+=("--issuer.type=")
    two_word_flags+=("--issuer.type")
    local_nonpersistent_flags+=("--issuer.type")
    local_nonpersistent_flags+=("--issuer.type=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--number=")
    two_word_flags+=("--number")
    local_nonpersistent_flags+=("--number")
    local_nonpersistent_flags+=("--number=")
    flags+=("--on-behalf-of=")
    two_word_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of=")
    flags+=("--payment-settings.default-mandate=")
    two_word_flags+=("--payment-settings.default-mandate")
    local_nonpersistent_flags+=("--payment-settings.default-mandate")
    local_nonpersistent_flags+=("--payment-settings.default-mandate=")
    flags+=("--payment-settings.payment-method-types=")
    two_word_flags+=("--payment-settings.payment-method-types")
    local_nonpersistent_flags+=("--payment-settings.payment-method-types")
    local_nonpersistent_flags+=("--payment-settings.payment-method-types=")
    flags+=("--rendering.amount-tax-display=")
    two_word_flags+=("--rendering.amount-tax-display")
    local_nonpersistent_flags+=("--rendering.amount-tax-display")
    local_nonpersistent_flags+=("--rendering.amount-tax-display=")
    flags+=("--rendering.pdf.page-size=")
    two_word_flags+=("--rendering.pdf.page-size")
    local_nonpersistent_flags+=("--rendering.pdf.page-size")
    local_nonpersistent_flags+=("--rendering.pdf.page-size=")
    flags+=("--rendering.template=")
    two_word_flags+=("--rendering.template")
    local_nonpersistent_flags+=("--rendering.template")
    local_nonpersistent_flags+=("--rendering.template=")
    flags+=("--rendering.template-version=")
    two_word_flags+=("--rendering.template-version")
    local_nonpersistent_flags+=("--rendering.template-version")
    local_nonpersistent_flags+=("--rendering.template-version=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_update_lines()
{
    last_command="stripe_invoices_update_lines"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices_void_invoice()
{
    last_command="stripe_invoices_void_invoice"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_invoices()
{
    last_command="stripe_invoices"

    command_aliases=()

    commands=()
    commands+=("add_lines")
    commands+=("create")
    commands+=("create_preview")
    commands+=("delete")
    commands+=("finalize_invoice")
    commands+=("list")
    commands+=("mark_uncollectible")
    commands+=("pay")
    commands+=("remove_lines")
    commands+=("retrieve")
    commands+=("search")
    commands+=("send_invoice")
    commands+=("upcoming")
    commands+=("upcomingLines")
    commands+=("update")
    commands+=("update_lines")
    commands+=("void_invoice")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_authorizations_list()
{
    last_command="stripe_issuing_authorizations_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--card=")
    two_word_flags+=("--card")
    local_nonpersistent_flags+=("--card")
    local_nonpersistent_flags+=("--card=")
    flags+=("--cardholder=")
    two_word_flags+=("--cardholder")
    local_nonpersistent_flags+=("--cardholder")
    local_nonpersistent_flags+=("--cardholder=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_authorizations_retrieve()
{
    last_command="stripe_issuing_authorizations_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_authorizations_test_helpers_capture()
{
    last_command="stripe_issuing_authorizations_test_helpers_capture"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--capture-amount=")
    two_word_flags+=("--capture-amount")
    local_nonpersistent_flags+=("--capture-amount")
    local_nonpersistent_flags+=("--capture-amount=")
    flags+=("--close-authorization=")
    two_word_flags+=("--close-authorization")
    local_nonpersistent_flags+=("--close-authorization")
    local_nonpersistent_flags+=("--close-authorization=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number=")
    flags+=("--purchase-details.fleet.purchase-type=")
    two_word_flags+=("--purchase-details.fleet.purchase-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.purchase-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.purchase-type=")
    flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal=")
    flags+=("--purchase-details.fleet.service-type=")
    two_word_flags+=("--purchase-details.fleet.service-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.service-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.service-type=")
    flags+=("--purchase-details.flight.departure-at=")
    two_word_flags+=("--purchase-details.flight.departure-at")
    local_nonpersistent_flags+=("--purchase-details.flight.departure-at")
    local_nonpersistent_flags+=("--purchase-details.flight.departure-at=")
    flags+=("--purchase-details.flight.passenger-name=")
    two_word_flags+=("--purchase-details.flight.passenger-name")
    local_nonpersistent_flags+=("--purchase-details.flight.passenger-name")
    local_nonpersistent_flags+=("--purchase-details.flight.passenger-name=")
    flags+=("--purchase-details.flight.refundable=")
    two_word_flags+=("--purchase-details.flight.refundable")
    local_nonpersistent_flags+=("--purchase-details.flight.refundable")
    local_nonpersistent_flags+=("--purchase-details.flight.refundable=")
    flags+=("--purchase-details.flight.travel-agency=")
    two_word_flags+=("--purchase-details.flight.travel-agency")
    local_nonpersistent_flags+=("--purchase-details.flight.travel-agency")
    local_nonpersistent_flags+=("--purchase-details.flight.travel-agency=")
    flags+=("--purchase-details.fuel.industry-product-code=")
    two_word_flags+=("--purchase-details.fuel.industry-product-code")
    local_nonpersistent_flags+=("--purchase-details.fuel.industry-product-code")
    local_nonpersistent_flags+=("--purchase-details.fuel.industry-product-code=")
    flags+=("--purchase-details.fuel.quantity-decimal=")
    two_word_flags+=("--purchase-details.fuel.quantity-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.quantity-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.quantity-decimal=")
    flags+=("--purchase-details.fuel.type=")
    two_word_flags+=("--purchase-details.fuel.type")
    local_nonpersistent_flags+=("--purchase-details.fuel.type")
    local_nonpersistent_flags+=("--purchase-details.fuel.type=")
    flags+=("--purchase-details.fuel.unit=")
    two_word_flags+=("--purchase-details.fuel.unit")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit=")
    flags+=("--purchase-details.fuel.unit-cost-decimal=")
    two_word_flags+=("--purchase-details.fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit-cost-decimal=")
    flags+=("--purchase-details.lodging.check-in-at=")
    two_word_flags+=("--purchase-details.lodging.check-in-at")
    local_nonpersistent_flags+=("--purchase-details.lodging.check-in-at")
    local_nonpersistent_flags+=("--purchase-details.lodging.check-in-at=")
    flags+=("--purchase-details.lodging.nights=")
    two_word_flags+=("--purchase-details.lodging.nights")
    local_nonpersistent_flags+=("--purchase-details.lodging.nights")
    local_nonpersistent_flags+=("--purchase-details.lodging.nights=")
    flags+=("--purchase-details.reference=")
    two_word_flags+=("--purchase-details.reference")
    local_nonpersistent_flags+=("--purchase-details.reference")
    local_nonpersistent_flags+=("--purchase-details.reference=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_authorizations_test_helpers_create()
{
    last_command="stripe_issuing_authorizations_test_helpers_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--amount-details.atm-fee=")
    two_word_flags+=("--amount-details.atm-fee")
    local_nonpersistent_flags+=("--amount-details.atm-fee")
    local_nonpersistent_flags+=("--amount-details.atm-fee=")
    flags+=("--amount-details.cashback-amount=")
    two_word_flags+=("--amount-details.cashback-amount")
    local_nonpersistent_flags+=("--amount-details.cashback-amount")
    local_nonpersistent_flags+=("--amount-details.cashback-amount=")
    flags+=("--authorization-method=")
    two_word_flags+=("--authorization-method")
    local_nonpersistent_flags+=("--authorization-method")
    local_nonpersistent_flags+=("--authorization-method=")
    flags+=("--card=")
    two_word_flags+=("--card")
    local_nonpersistent_flags+=("--card")
    local_nonpersistent_flags+=("--card=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--fleet.cardholder-prompt-data.driver-id=")
    two_word_flags+=("--fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.driver-id=")
    flags+=("--fleet.cardholder-prompt-data.odometer=")
    two_word_flags+=("--fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.odometer=")
    flags+=("--fleet.cardholder-prompt-data.unspecified-id=")
    two_word_flags+=("--fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.unspecified-id=")
    flags+=("--fleet.cardholder-prompt-data.user-id=")
    two_word_flags+=("--fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.user-id=")
    flags+=("--fleet.cardholder-prompt-data.vehicle-number=")
    two_word_flags+=("--fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.vehicle-number=")
    flags+=("--fleet.purchase-type=")
    two_word_flags+=("--fleet.purchase-type")
    local_nonpersistent_flags+=("--fleet.purchase-type")
    local_nonpersistent_flags+=("--fleet.purchase-type=")
    flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal=")
    flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    flags+=("--fleet.reported-breakdown.tax.local-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.local-amount-decimal=")
    flags+=("--fleet.reported-breakdown.tax.national-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.national-amount-decimal=")
    flags+=("--fleet.service-type=")
    two_word_flags+=("--fleet.service-type")
    local_nonpersistent_flags+=("--fleet.service-type")
    local_nonpersistent_flags+=("--fleet.service-type=")
    flags+=("--fuel.industry-product-code=")
    two_word_flags+=("--fuel.industry-product-code")
    local_nonpersistent_flags+=("--fuel.industry-product-code")
    local_nonpersistent_flags+=("--fuel.industry-product-code=")
    flags+=("--fuel.quantity-decimal=")
    two_word_flags+=("--fuel.quantity-decimal")
    local_nonpersistent_flags+=("--fuel.quantity-decimal")
    local_nonpersistent_flags+=("--fuel.quantity-decimal=")
    flags+=("--fuel.type=")
    two_word_flags+=("--fuel.type")
    local_nonpersistent_flags+=("--fuel.type")
    local_nonpersistent_flags+=("--fuel.type=")
    flags+=("--fuel.unit=")
    two_word_flags+=("--fuel.unit")
    local_nonpersistent_flags+=("--fuel.unit")
    local_nonpersistent_flags+=("--fuel.unit=")
    flags+=("--fuel.unit-cost-decimal=")
    two_word_flags+=("--fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--fuel.unit-cost-decimal=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--is-amount-controllable=")
    two_word_flags+=("--is-amount-controllable")
    local_nonpersistent_flags+=("--is-amount-controllable")
    local_nonpersistent_flags+=("--is-amount-controllable=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--merchant-data.category=")
    two_word_flags+=("--merchant-data.category")
    local_nonpersistent_flags+=("--merchant-data.category")
    local_nonpersistent_flags+=("--merchant-data.category=")
    flags+=("--merchant-data.city=")
    two_word_flags+=("--merchant-data.city")
    local_nonpersistent_flags+=("--merchant-data.city")
    local_nonpersistent_flags+=("--merchant-data.city=")
    flags+=("--merchant-data.country=")
    two_word_flags+=("--merchant-data.country")
    local_nonpersistent_flags+=("--merchant-data.country")
    local_nonpersistent_flags+=("--merchant-data.country=")
    flags+=("--merchant-data.name=")
    two_word_flags+=("--merchant-data.name")
    local_nonpersistent_flags+=("--merchant-data.name")
    local_nonpersistent_flags+=("--merchant-data.name=")
    flags+=("--merchant-data.network-id=")
    two_word_flags+=("--merchant-data.network-id")
    local_nonpersistent_flags+=("--merchant-data.network-id")
    local_nonpersistent_flags+=("--merchant-data.network-id=")
    flags+=("--merchant-data.postal-code=")
    two_word_flags+=("--merchant-data.postal-code")
    local_nonpersistent_flags+=("--merchant-data.postal-code")
    local_nonpersistent_flags+=("--merchant-data.postal-code=")
    flags+=("--merchant-data.state=")
    two_word_flags+=("--merchant-data.state")
    local_nonpersistent_flags+=("--merchant-data.state")
    local_nonpersistent_flags+=("--merchant-data.state=")
    flags+=("--merchant-data.terminal-id=")
    two_word_flags+=("--merchant-data.terminal-id")
    local_nonpersistent_flags+=("--merchant-data.terminal-id")
    local_nonpersistent_flags+=("--merchant-data.terminal-id=")
    flags+=("--merchant-data.url=")
    two_word_flags+=("--merchant-data.url")
    local_nonpersistent_flags+=("--merchant-data.url")
    local_nonpersistent_flags+=("--merchant-data.url=")
    flags+=("--network-data.acquiring-institution-id=")
    two_word_flags+=("--network-data.acquiring-institution-id")
    local_nonpersistent_flags+=("--network-data.acquiring-institution-id")
    local_nonpersistent_flags+=("--network-data.acquiring-institution-id=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--verification-data.address-line1-check=")
    two_word_flags+=("--verification-data.address-line1-check")
    local_nonpersistent_flags+=("--verification-data.address-line1-check")
    local_nonpersistent_flags+=("--verification-data.address-line1-check=")
    flags+=("--verification-data.address-postal-code-check=")
    two_word_flags+=("--verification-data.address-postal-code-check")
    local_nonpersistent_flags+=("--verification-data.address-postal-code-check")
    local_nonpersistent_flags+=("--verification-data.address-postal-code-check=")
    flags+=("--verification-data.authentication-exemption.claimed-by=")
    two_word_flags+=("--verification-data.authentication-exemption.claimed-by")
    local_nonpersistent_flags+=("--verification-data.authentication-exemption.claimed-by")
    local_nonpersistent_flags+=("--verification-data.authentication-exemption.claimed-by=")
    flags+=("--verification-data.authentication-exemption.type=")
    two_word_flags+=("--verification-data.authentication-exemption.type")
    local_nonpersistent_flags+=("--verification-data.authentication-exemption.type")
    local_nonpersistent_flags+=("--verification-data.authentication-exemption.type=")
    flags+=("--verification-data.cvc-check=")
    two_word_flags+=("--verification-data.cvc-check")
    local_nonpersistent_flags+=("--verification-data.cvc-check")
    local_nonpersistent_flags+=("--verification-data.cvc-check=")
    flags+=("--verification-data.expiry-check=")
    two_word_flags+=("--verification-data.expiry-check")
    local_nonpersistent_flags+=("--verification-data.expiry-check")
    local_nonpersistent_flags+=("--verification-data.expiry-check=")
    flags+=("--verification-data.three-d-secure.result=")
    two_word_flags+=("--verification-data.three-d-secure.result")
    local_nonpersistent_flags+=("--verification-data.three-d-secure.result")
    local_nonpersistent_flags+=("--verification-data.three-d-secure.result=")
    flags+=("--wallet=")
    two_word_flags+=("--wallet")
    local_nonpersistent_flags+=("--wallet")
    local_nonpersistent_flags+=("--wallet=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_authorizations_test_helpers_expire()
{
    last_command="stripe_issuing_authorizations_test_helpers_expire"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_authorizations_test_helpers_finalize_amount()
{
    last_command="stripe_issuing_authorizations_test_helpers_finalize_amount"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--final-amount=")
    two_word_flags+=("--final-amount")
    local_nonpersistent_flags+=("--final-amount")
    local_nonpersistent_flags+=("--final-amount=")
    flags+=("--fleet.cardholder-prompt-data.driver-id=")
    two_word_flags+=("--fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.driver-id=")
    flags+=("--fleet.cardholder-prompt-data.odometer=")
    two_word_flags+=("--fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.odometer=")
    flags+=("--fleet.cardholder-prompt-data.unspecified-id=")
    two_word_flags+=("--fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.unspecified-id=")
    flags+=("--fleet.cardholder-prompt-data.user-id=")
    two_word_flags+=("--fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.user-id=")
    flags+=("--fleet.cardholder-prompt-data.vehicle-number=")
    two_word_flags+=("--fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.vehicle-number=")
    flags+=("--fleet.purchase-type=")
    two_word_flags+=("--fleet.purchase-type")
    local_nonpersistent_flags+=("--fleet.purchase-type")
    local_nonpersistent_flags+=("--fleet.purchase-type=")
    flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal=")
    flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    flags+=("--fleet.reported-breakdown.tax.local-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.local-amount-decimal=")
    flags+=("--fleet.reported-breakdown.tax.national-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.national-amount-decimal=")
    flags+=("--fleet.service-type=")
    two_word_flags+=("--fleet.service-type")
    local_nonpersistent_flags+=("--fleet.service-type")
    local_nonpersistent_flags+=("--fleet.service-type=")
    flags+=("--fuel.industry-product-code=")
    two_word_flags+=("--fuel.industry-product-code")
    local_nonpersistent_flags+=("--fuel.industry-product-code")
    local_nonpersistent_flags+=("--fuel.industry-product-code=")
    flags+=("--fuel.quantity-decimal=")
    two_word_flags+=("--fuel.quantity-decimal")
    local_nonpersistent_flags+=("--fuel.quantity-decimal")
    local_nonpersistent_flags+=("--fuel.quantity-decimal=")
    flags+=("--fuel.type=")
    two_word_flags+=("--fuel.type")
    local_nonpersistent_flags+=("--fuel.type")
    local_nonpersistent_flags+=("--fuel.type=")
    flags+=("--fuel.unit=")
    two_word_flags+=("--fuel.unit")
    local_nonpersistent_flags+=("--fuel.unit")
    local_nonpersistent_flags+=("--fuel.unit=")
    flags+=("--fuel.unit-cost-decimal=")
    two_word_flags+=("--fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--fuel.unit-cost-decimal=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_authorizations_test_helpers_increment()
{
    last_command="stripe_issuing_authorizations_test_helpers_increment"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--increment-amount=")
    two_word_flags+=("--increment-amount")
    local_nonpersistent_flags+=("--increment-amount")
    local_nonpersistent_flags+=("--increment-amount=")
    flags+=("--is-amount-controllable=")
    two_word_flags+=("--is-amount-controllable")
    local_nonpersistent_flags+=("--is-amount-controllable")
    local_nonpersistent_flags+=("--is-amount-controllable=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_authorizations_test_helpers_reverse()
{
    last_command="stripe_issuing_authorizations_test_helpers_reverse"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--reverse-amount=")
    two_word_flags+=("--reverse-amount")
    local_nonpersistent_flags+=("--reverse-amount")
    local_nonpersistent_flags+=("--reverse-amount=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_authorizations_test_helpers()
{
    last_command="stripe_issuing_authorizations_test_helpers"

    command_aliases=()

    commands=()
    commands+=("capture")
    commands+=("create")
    commands+=("expire")
    commands+=("finalize_amount")
    commands+=("increment")
    commands+=("reverse")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_authorizations_update()
{
    last_command="stripe_issuing_authorizations_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_authorizations()
{
    last_command="stripe_issuing_authorizations"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")
    commands+=("test_helpers")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cardholders_create()
{
    last_command="stripe_issuing_cardholders_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--billing.address.city=")
    two_word_flags+=("--billing.address.city")
    local_nonpersistent_flags+=("--billing.address.city")
    local_nonpersistent_flags+=("--billing.address.city=")
    flags+=("--billing.address.country=")
    two_word_flags+=("--billing.address.country")
    local_nonpersistent_flags+=("--billing.address.country")
    local_nonpersistent_flags+=("--billing.address.country=")
    flags+=("--billing.address.line1=")
    two_word_flags+=("--billing.address.line1")
    local_nonpersistent_flags+=("--billing.address.line1")
    local_nonpersistent_flags+=("--billing.address.line1=")
    flags+=("--billing.address.line2=")
    two_word_flags+=("--billing.address.line2")
    local_nonpersistent_flags+=("--billing.address.line2")
    local_nonpersistent_flags+=("--billing.address.line2=")
    flags+=("--billing.address.postal-code=")
    two_word_flags+=("--billing.address.postal-code")
    local_nonpersistent_flags+=("--billing.address.postal-code")
    local_nonpersistent_flags+=("--billing.address.postal-code=")
    flags+=("--billing.address.state=")
    two_word_flags+=("--billing.address.state")
    local_nonpersistent_flags+=("--billing.address.state")
    local_nonpersistent_flags+=("--billing.address.state=")
    flags+=("--company.tax-id=")
    two_word_flags+=("--company.tax-id")
    local_nonpersistent_flags+=("--company.tax-id")
    local_nonpersistent_flags+=("--company.tax-id=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--email=")
    two_word_flags+=("--email")
    local_nonpersistent_flags+=("--email")
    local_nonpersistent_flags+=("--email=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--individual.card-issuing.user-terms-acceptance.date=")
    two_word_flags+=("--individual.card-issuing.user-terms-acceptance.date")
    local_nonpersistent_flags+=("--individual.card-issuing.user-terms-acceptance.date")
    local_nonpersistent_flags+=("--individual.card-issuing.user-terms-acceptance.date=")
    flags+=("--individual.card-issuing.user-terms-acceptance.ip=")
    two_word_flags+=("--individual.card-issuing.user-terms-acceptance.ip")
    local_nonpersistent_flags+=("--individual.card-issuing.user-terms-acceptance.ip")
    local_nonpersistent_flags+=("--individual.card-issuing.user-terms-acceptance.ip=")
    flags+=("--individual.card-issuing.user-terms-acceptance.user-agent=")
    two_word_flags+=("--individual.card-issuing.user-terms-acceptance.user-agent")
    local_nonpersistent_flags+=("--individual.card-issuing.user-terms-acceptance.user-agent")
    local_nonpersistent_flags+=("--individual.card-issuing.user-terms-acceptance.user-agent=")
    flags+=("--individual.dob.day=")
    two_word_flags+=("--individual.dob.day")
    local_nonpersistent_flags+=("--individual.dob.day")
    local_nonpersistent_flags+=("--individual.dob.day=")
    flags+=("--individual.dob.month=")
    two_word_flags+=("--individual.dob.month")
    local_nonpersistent_flags+=("--individual.dob.month")
    local_nonpersistent_flags+=("--individual.dob.month=")
    flags+=("--individual.dob.year=")
    two_word_flags+=("--individual.dob.year")
    local_nonpersistent_flags+=("--individual.dob.year")
    local_nonpersistent_flags+=("--individual.dob.year=")
    flags+=("--individual.first-name=")
    two_word_flags+=("--individual.first-name")
    local_nonpersistent_flags+=("--individual.first-name")
    local_nonpersistent_flags+=("--individual.first-name=")
    flags+=("--individual.last-name=")
    two_word_flags+=("--individual.last-name")
    local_nonpersistent_flags+=("--individual.last-name")
    local_nonpersistent_flags+=("--individual.last-name=")
    flags+=("--individual.verification.document.back=")
    two_word_flags+=("--individual.verification.document.back")
    local_nonpersistent_flags+=("--individual.verification.document.back")
    local_nonpersistent_flags+=("--individual.verification.document.back=")
    flags+=("--individual.verification.document.front=")
    two_word_flags+=("--individual.verification.document.front")
    local_nonpersistent_flags+=("--individual.verification.document.front")
    local_nonpersistent_flags+=("--individual.verification.document.front=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--phone-number=")
    two_word_flags+=("--phone-number")
    local_nonpersistent_flags+=("--phone-number")
    local_nonpersistent_flags+=("--phone-number=")
    flags+=("--preferred-locales=")
    two_word_flags+=("--preferred-locales")
    local_nonpersistent_flags+=("--preferred-locales")
    local_nonpersistent_flags+=("--preferred-locales=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--spending-controls.allowed-categories=")
    two_word_flags+=("--spending-controls.allowed-categories")
    local_nonpersistent_flags+=("--spending-controls.allowed-categories")
    local_nonpersistent_flags+=("--spending-controls.allowed-categories=")
    flags+=("--spending-controls.allowed-merchant-countries=")
    two_word_flags+=("--spending-controls.allowed-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.allowed-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.allowed-merchant-countries=")
    flags+=("--spending-controls.blocked-categories=")
    two_word_flags+=("--spending-controls.blocked-categories")
    local_nonpersistent_flags+=("--spending-controls.blocked-categories")
    local_nonpersistent_flags+=("--spending-controls.blocked-categories=")
    flags+=("--spending-controls.blocked-merchant-countries=")
    two_word_flags+=("--spending-controls.blocked-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.blocked-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.blocked-merchant-countries=")
    flags+=("--spending-controls.spending-limits-currency=")
    two_word_flags+=("--spending-controls.spending-limits-currency")
    local_nonpersistent_flags+=("--spending-controls.spending-limits-currency")
    local_nonpersistent_flags+=("--spending-controls.spending-limits-currency=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cardholders_list()
{
    last_command="stripe_issuing_cardholders_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--email=")
    two_word_flags+=("--email")
    local_nonpersistent_flags+=("--email")
    local_nonpersistent_flags+=("--email=")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--phone-number=")
    two_word_flags+=("--phone-number")
    local_nonpersistent_flags+=("--phone-number")
    local_nonpersistent_flags+=("--phone-number=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cardholders_retrieve()
{
    last_command="stripe_issuing_cardholders_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cardholders_update()
{
    last_command="stripe_issuing_cardholders_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--billing.address.city=")
    two_word_flags+=("--billing.address.city")
    local_nonpersistent_flags+=("--billing.address.city")
    local_nonpersistent_flags+=("--billing.address.city=")
    flags+=("--billing.address.country=")
    two_word_flags+=("--billing.address.country")
    local_nonpersistent_flags+=("--billing.address.country")
    local_nonpersistent_flags+=("--billing.address.country=")
    flags+=("--billing.address.line1=")
    two_word_flags+=("--billing.address.line1")
    local_nonpersistent_flags+=("--billing.address.line1")
    local_nonpersistent_flags+=("--billing.address.line1=")
    flags+=("--billing.address.line2=")
    two_word_flags+=("--billing.address.line2")
    local_nonpersistent_flags+=("--billing.address.line2")
    local_nonpersistent_flags+=("--billing.address.line2=")
    flags+=("--billing.address.postal-code=")
    two_word_flags+=("--billing.address.postal-code")
    local_nonpersistent_flags+=("--billing.address.postal-code")
    local_nonpersistent_flags+=("--billing.address.postal-code=")
    flags+=("--billing.address.state=")
    two_word_flags+=("--billing.address.state")
    local_nonpersistent_flags+=("--billing.address.state")
    local_nonpersistent_flags+=("--billing.address.state=")
    flags+=("--company.tax-id=")
    two_word_flags+=("--company.tax-id")
    local_nonpersistent_flags+=("--company.tax-id")
    local_nonpersistent_flags+=("--company.tax-id=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--email=")
    two_word_flags+=("--email")
    local_nonpersistent_flags+=("--email")
    local_nonpersistent_flags+=("--email=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--individual.card-issuing.user-terms-acceptance.date=")
    two_word_flags+=("--individual.card-issuing.user-terms-acceptance.date")
    local_nonpersistent_flags+=("--individual.card-issuing.user-terms-acceptance.date")
    local_nonpersistent_flags+=("--individual.card-issuing.user-terms-acceptance.date=")
    flags+=("--individual.card-issuing.user-terms-acceptance.ip=")
    two_word_flags+=("--individual.card-issuing.user-terms-acceptance.ip")
    local_nonpersistent_flags+=("--individual.card-issuing.user-terms-acceptance.ip")
    local_nonpersistent_flags+=("--individual.card-issuing.user-terms-acceptance.ip=")
    flags+=("--individual.card-issuing.user-terms-acceptance.user-agent=")
    two_word_flags+=("--individual.card-issuing.user-terms-acceptance.user-agent")
    local_nonpersistent_flags+=("--individual.card-issuing.user-terms-acceptance.user-agent")
    local_nonpersistent_flags+=("--individual.card-issuing.user-terms-acceptance.user-agent=")
    flags+=("--individual.dob.day=")
    two_word_flags+=("--individual.dob.day")
    local_nonpersistent_flags+=("--individual.dob.day")
    local_nonpersistent_flags+=("--individual.dob.day=")
    flags+=("--individual.dob.month=")
    two_word_flags+=("--individual.dob.month")
    local_nonpersistent_flags+=("--individual.dob.month")
    local_nonpersistent_flags+=("--individual.dob.month=")
    flags+=("--individual.dob.year=")
    two_word_flags+=("--individual.dob.year")
    local_nonpersistent_flags+=("--individual.dob.year")
    local_nonpersistent_flags+=("--individual.dob.year=")
    flags+=("--individual.first-name=")
    two_word_flags+=("--individual.first-name")
    local_nonpersistent_flags+=("--individual.first-name")
    local_nonpersistent_flags+=("--individual.first-name=")
    flags+=("--individual.last-name=")
    two_word_flags+=("--individual.last-name")
    local_nonpersistent_flags+=("--individual.last-name")
    local_nonpersistent_flags+=("--individual.last-name=")
    flags+=("--individual.verification.document.back=")
    two_word_flags+=("--individual.verification.document.back")
    local_nonpersistent_flags+=("--individual.verification.document.back")
    local_nonpersistent_flags+=("--individual.verification.document.back=")
    flags+=("--individual.verification.document.front=")
    two_word_flags+=("--individual.verification.document.front")
    local_nonpersistent_flags+=("--individual.verification.document.front")
    local_nonpersistent_flags+=("--individual.verification.document.front=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--phone-number=")
    two_word_flags+=("--phone-number")
    local_nonpersistent_flags+=("--phone-number")
    local_nonpersistent_flags+=("--phone-number=")
    flags+=("--preferred-locales=")
    two_word_flags+=("--preferred-locales")
    local_nonpersistent_flags+=("--preferred-locales")
    local_nonpersistent_flags+=("--preferred-locales=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--spending-controls.allowed-categories=")
    two_word_flags+=("--spending-controls.allowed-categories")
    local_nonpersistent_flags+=("--spending-controls.allowed-categories")
    local_nonpersistent_flags+=("--spending-controls.allowed-categories=")
    flags+=("--spending-controls.allowed-merchant-countries=")
    two_word_flags+=("--spending-controls.allowed-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.allowed-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.allowed-merchant-countries=")
    flags+=("--spending-controls.blocked-categories=")
    two_word_flags+=("--spending-controls.blocked-categories")
    local_nonpersistent_flags+=("--spending-controls.blocked-categories")
    local_nonpersistent_flags+=("--spending-controls.blocked-categories=")
    flags+=("--spending-controls.blocked-merchant-countries=")
    two_word_flags+=("--spending-controls.blocked-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.blocked-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.blocked-merchant-countries=")
    flags+=("--spending-controls.spending-limits-currency=")
    two_word_flags+=("--spending-controls.spending-limits-currency")
    local_nonpersistent_flags+=("--spending-controls.spending-limits-currency")
    local_nonpersistent_flags+=("--spending-controls.spending-limits-currency=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cardholders()
{
    last_command="stripe_issuing_cardholders"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cards_create()
{
    last_command="stripe_issuing_cards_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--cardholder=")
    two_word_flags+=("--cardholder")
    local_nonpersistent_flags+=("--cardholder")
    local_nonpersistent_flags+=("--cardholder=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--personalization-design=")
    two_word_flags+=("--personalization-design")
    local_nonpersistent_flags+=("--personalization-design")
    local_nonpersistent_flags+=("--personalization-design=")
    flags+=("--pin.encrypted-number=")
    two_word_flags+=("--pin.encrypted-number")
    local_nonpersistent_flags+=("--pin.encrypted-number")
    local_nonpersistent_flags+=("--pin.encrypted-number=")
    flags+=("--replacement-for=")
    two_word_flags+=("--replacement-for")
    local_nonpersistent_flags+=("--replacement-for")
    local_nonpersistent_flags+=("--replacement-for=")
    flags+=("--replacement-reason=")
    two_word_flags+=("--replacement-reason")
    local_nonpersistent_flags+=("--replacement-reason")
    local_nonpersistent_flags+=("--replacement-reason=")
    flags+=("--second-line=")
    two_word_flags+=("--second-line")
    local_nonpersistent_flags+=("--second-line")
    local_nonpersistent_flags+=("--second-line=")
    flags+=("--shipping.address-validation.mode=")
    two_word_flags+=("--shipping.address-validation.mode")
    local_nonpersistent_flags+=("--shipping.address-validation.mode")
    local_nonpersistent_flags+=("--shipping.address-validation.mode=")
    flags+=("--shipping.address.city=")
    two_word_flags+=("--shipping.address.city")
    local_nonpersistent_flags+=("--shipping.address.city")
    local_nonpersistent_flags+=("--shipping.address.city=")
    flags+=("--shipping.address.country=")
    two_word_flags+=("--shipping.address.country")
    local_nonpersistent_flags+=("--shipping.address.country")
    local_nonpersistent_flags+=("--shipping.address.country=")
    flags+=("--shipping.address.line1=")
    two_word_flags+=("--shipping.address.line1")
    local_nonpersistent_flags+=("--shipping.address.line1")
    local_nonpersistent_flags+=("--shipping.address.line1=")
    flags+=("--shipping.address.line2=")
    two_word_flags+=("--shipping.address.line2")
    local_nonpersistent_flags+=("--shipping.address.line2")
    local_nonpersistent_flags+=("--shipping.address.line2=")
    flags+=("--shipping.address.postal-code=")
    two_word_flags+=("--shipping.address.postal-code")
    local_nonpersistent_flags+=("--shipping.address.postal-code")
    local_nonpersistent_flags+=("--shipping.address.postal-code=")
    flags+=("--shipping.address.state=")
    two_word_flags+=("--shipping.address.state")
    local_nonpersistent_flags+=("--shipping.address.state")
    local_nonpersistent_flags+=("--shipping.address.state=")
    flags+=("--shipping.customs.eori-number=")
    two_word_flags+=("--shipping.customs.eori-number")
    local_nonpersistent_flags+=("--shipping.customs.eori-number")
    local_nonpersistent_flags+=("--shipping.customs.eori-number=")
    flags+=("--shipping.name=")
    two_word_flags+=("--shipping.name")
    local_nonpersistent_flags+=("--shipping.name")
    local_nonpersistent_flags+=("--shipping.name=")
    flags+=("--shipping.phone-number=")
    two_word_flags+=("--shipping.phone-number")
    local_nonpersistent_flags+=("--shipping.phone-number")
    local_nonpersistent_flags+=("--shipping.phone-number=")
    flags+=("--shipping.require-signature=")
    two_word_flags+=("--shipping.require-signature")
    local_nonpersistent_flags+=("--shipping.require-signature")
    local_nonpersistent_flags+=("--shipping.require-signature=")
    flags+=("--shipping.service=")
    two_word_flags+=("--shipping.service")
    local_nonpersistent_flags+=("--shipping.service")
    local_nonpersistent_flags+=("--shipping.service=")
    flags+=("--shipping.type=")
    two_word_flags+=("--shipping.type")
    local_nonpersistent_flags+=("--shipping.type")
    local_nonpersistent_flags+=("--shipping.type=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--spending-controls.allowed-categories=")
    two_word_flags+=("--spending-controls.allowed-categories")
    local_nonpersistent_flags+=("--spending-controls.allowed-categories")
    local_nonpersistent_flags+=("--spending-controls.allowed-categories=")
    flags+=("--spending-controls.allowed-merchant-countries=")
    two_word_flags+=("--spending-controls.allowed-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.allowed-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.allowed-merchant-countries=")
    flags+=("--spending-controls.blocked-categories=")
    two_word_flags+=("--spending-controls.blocked-categories")
    local_nonpersistent_flags+=("--spending-controls.blocked-categories")
    local_nonpersistent_flags+=("--spending-controls.blocked-categories=")
    flags+=("--spending-controls.blocked-merchant-countries=")
    two_word_flags+=("--spending-controls.blocked-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.blocked-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.blocked-merchant-countries=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cards_list()
{
    last_command="stripe_issuing_cards_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--cardholder=")
    two_word_flags+=("--cardholder")
    local_nonpersistent_flags+=("--cardholder")
    local_nonpersistent_flags+=("--cardholder=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--exp-month=")
    two_word_flags+=("--exp-month")
    local_nonpersistent_flags+=("--exp-month")
    local_nonpersistent_flags+=("--exp-month=")
    flags+=("--exp-year=")
    two_word_flags+=("--exp-year")
    local_nonpersistent_flags+=("--exp-year")
    local_nonpersistent_flags+=("--exp-year=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--last4=")
    two_word_flags+=("--last4")
    local_nonpersistent_flags+=("--last4")
    local_nonpersistent_flags+=("--last4=")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--personalization-design=")
    two_word_flags+=("--personalization-design")
    local_nonpersistent_flags+=("--personalization-design")
    local_nonpersistent_flags+=("--personalization-design=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cards_retrieve()
{
    last_command="stripe_issuing_cards_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cards_test_helpers_deliver_card()
{
    last_command="stripe_issuing_cards_test_helpers_deliver_card"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cards_test_helpers_fail_card()
{
    last_command="stripe_issuing_cards_test_helpers_fail_card"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cards_test_helpers_return_card()
{
    last_command="stripe_issuing_cards_test_helpers_return_card"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cards_test_helpers_ship_card()
{
    last_command="stripe_issuing_cards_test_helpers_ship_card"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cards_test_helpers_submit_card()
{
    last_command="stripe_issuing_cards_test_helpers_submit_card"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cards_test_helpers()
{
    last_command="stripe_issuing_cards_test_helpers"

    command_aliases=()

    commands=()
    commands+=("deliver_card")
    commands+=("fail_card")
    commands+=("return_card")
    commands+=("ship_card")
    commands+=("submit_card")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cards_update()
{
    last_command="stripe_issuing_cards_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--cancellation-reason=")
    two_word_flags+=("--cancellation-reason")
    local_nonpersistent_flags+=("--cancellation-reason")
    local_nonpersistent_flags+=("--cancellation-reason=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--personalization-design=")
    two_word_flags+=("--personalization-design")
    local_nonpersistent_flags+=("--personalization-design")
    local_nonpersistent_flags+=("--personalization-design=")
    flags+=("--pin.encrypted-number=")
    two_word_flags+=("--pin.encrypted-number")
    local_nonpersistent_flags+=("--pin.encrypted-number")
    local_nonpersistent_flags+=("--pin.encrypted-number=")
    flags+=("--shipping.address-validation.mode=")
    two_word_flags+=("--shipping.address-validation.mode")
    local_nonpersistent_flags+=("--shipping.address-validation.mode")
    local_nonpersistent_flags+=("--shipping.address-validation.mode=")
    flags+=("--shipping.address.city=")
    two_word_flags+=("--shipping.address.city")
    local_nonpersistent_flags+=("--shipping.address.city")
    local_nonpersistent_flags+=("--shipping.address.city=")
    flags+=("--shipping.address.country=")
    two_word_flags+=("--shipping.address.country")
    local_nonpersistent_flags+=("--shipping.address.country")
    local_nonpersistent_flags+=("--shipping.address.country=")
    flags+=("--shipping.address.line1=")
    two_word_flags+=("--shipping.address.line1")
    local_nonpersistent_flags+=("--shipping.address.line1")
    local_nonpersistent_flags+=("--shipping.address.line1=")
    flags+=("--shipping.address.line2=")
    two_word_flags+=("--shipping.address.line2")
    local_nonpersistent_flags+=("--shipping.address.line2")
    local_nonpersistent_flags+=("--shipping.address.line2=")
    flags+=("--shipping.address.postal-code=")
    two_word_flags+=("--shipping.address.postal-code")
    local_nonpersistent_flags+=("--shipping.address.postal-code")
    local_nonpersistent_flags+=("--shipping.address.postal-code=")
    flags+=("--shipping.address.state=")
    two_word_flags+=("--shipping.address.state")
    local_nonpersistent_flags+=("--shipping.address.state")
    local_nonpersistent_flags+=("--shipping.address.state=")
    flags+=("--shipping.customs.eori-number=")
    two_word_flags+=("--shipping.customs.eori-number")
    local_nonpersistent_flags+=("--shipping.customs.eori-number")
    local_nonpersistent_flags+=("--shipping.customs.eori-number=")
    flags+=("--shipping.name=")
    two_word_flags+=("--shipping.name")
    local_nonpersistent_flags+=("--shipping.name")
    local_nonpersistent_flags+=("--shipping.name=")
    flags+=("--shipping.phone-number=")
    two_word_flags+=("--shipping.phone-number")
    local_nonpersistent_flags+=("--shipping.phone-number")
    local_nonpersistent_flags+=("--shipping.phone-number=")
    flags+=("--shipping.require-signature=")
    two_word_flags+=("--shipping.require-signature")
    local_nonpersistent_flags+=("--shipping.require-signature")
    local_nonpersistent_flags+=("--shipping.require-signature=")
    flags+=("--shipping.service=")
    two_word_flags+=("--shipping.service")
    local_nonpersistent_flags+=("--shipping.service")
    local_nonpersistent_flags+=("--shipping.service=")
    flags+=("--shipping.type=")
    two_word_flags+=("--shipping.type")
    local_nonpersistent_flags+=("--shipping.type")
    local_nonpersistent_flags+=("--shipping.type=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--spending-controls.allowed-categories=")
    two_word_flags+=("--spending-controls.allowed-categories")
    local_nonpersistent_flags+=("--spending-controls.allowed-categories")
    local_nonpersistent_flags+=("--spending-controls.allowed-categories=")
    flags+=("--spending-controls.allowed-merchant-countries=")
    two_word_flags+=("--spending-controls.allowed-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.allowed-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.allowed-merchant-countries=")
    flags+=("--spending-controls.blocked-categories=")
    two_word_flags+=("--spending-controls.blocked-categories")
    local_nonpersistent_flags+=("--spending-controls.blocked-categories")
    local_nonpersistent_flags+=("--spending-controls.blocked-categories=")
    flags+=("--spending-controls.blocked-merchant-countries=")
    two_word_flags+=("--spending-controls.blocked-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.blocked-merchant-countries")
    local_nonpersistent_flags+=("--spending-controls.blocked-merchant-countries=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_cards()
{
    last_command="stripe_issuing_cards"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("test_helpers")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_disputes_create()
{
    last_command="stripe_issuing_disputes_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--evidence.reason=")
    two_word_flags+=("--evidence.reason")
    local_nonpersistent_flags+=("--evidence.reason")
    local_nonpersistent_flags+=("--evidence.reason=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transaction=")
    two_word_flags+=("--transaction")
    local_nonpersistent_flags+=("--transaction")
    local_nonpersistent_flags+=("--transaction=")
    flags+=("--treasury.received-debit=")
    two_word_flags+=("--treasury.received-debit")
    local_nonpersistent_flags+=("--treasury.received-debit")
    local_nonpersistent_flags+=("--treasury.received-debit=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_disputes_list()
{
    last_command="stripe_issuing_disputes_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transaction=")
    two_word_flags+=("--transaction")
    local_nonpersistent_flags+=("--transaction")
    local_nonpersistent_flags+=("--transaction=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_disputes_retrieve()
{
    last_command="stripe_issuing_disputes_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_disputes_submit()
{
    last_command="stripe_issuing_disputes_submit"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_disputes_update()
{
    last_command="stripe_issuing_disputes_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--evidence.reason=")
    two_word_flags+=("--evidence.reason")
    local_nonpersistent_flags+=("--evidence.reason")
    local_nonpersistent_flags+=("--evidence.reason=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_disputes()
{
    last_command="stripe_issuing_disputes"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("submit")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_personalization_designs_create()
{
    last_command="stripe_issuing_personalization_designs_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--card-logo=")
    two_word_flags+=("--card-logo")
    local_nonpersistent_flags+=("--card-logo")
    local_nonpersistent_flags+=("--card-logo=")
    flags+=("--carrier-text.footer-body=")
    two_word_flags+=("--carrier-text.footer-body")
    local_nonpersistent_flags+=("--carrier-text.footer-body")
    local_nonpersistent_flags+=("--carrier-text.footer-body=")
    flags+=("--carrier-text.footer-title=")
    two_word_flags+=("--carrier-text.footer-title")
    local_nonpersistent_flags+=("--carrier-text.footer-title")
    local_nonpersistent_flags+=("--carrier-text.footer-title=")
    flags+=("--carrier-text.header-body=")
    two_word_flags+=("--carrier-text.header-body")
    local_nonpersistent_flags+=("--carrier-text.header-body")
    local_nonpersistent_flags+=("--carrier-text.header-body=")
    flags+=("--carrier-text.header-title=")
    two_word_flags+=("--carrier-text.header-title")
    local_nonpersistent_flags+=("--carrier-text.header-title")
    local_nonpersistent_flags+=("--carrier-text.header-title=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--lookup-key=")
    two_word_flags+=("--lookup-key")
    local_nonpersistent_flags+=("--lookup-key")
    local_nonpersistent_flags+=("--lookup-key=")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--physical-bundle=")
    two_word_flags+=("--physical-bundle")
    local_nonpersistent_flags+=("--physical-bundle")
    local_nonpersistent_flags+=("--physical-bundle=")
    flags+=("--preferences.is-default=")
    two_word_flags+=("--preferences.is-default")
    local_nonpersistent_flags+=("--preferences.is-default")
    local_nonpersistent_flags+=("--preferences.is-default=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transfer-lookup-key=")
    two_word_flags+=("--transfer-lookup-key")
    local_nonpersistent_flags+=("--transfer-lookup-key")
    local_nonpersistent_flags+=("--transfer-lookup-key=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_personalization_designs_list()
{
    last_command="stripe_issuing_personalization_designs_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--lookup-keys=")
    two_word_flags+=("--lookup-keys")
    local_nonpersistent_flags+=("--lookup-keys")
    local_nonpersistent_flags+=("--lookup-keys=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_personalization_designs_retrieve()
{
    last_command="stripe_issuing_personalization_designs_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_personalization_designs_test_helpers_activate()
{
    last_command="stripe_issuing_personalization_designs_test_helpers_activate"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_personalization_designs_test_helpers_deactivate()
{
    last_command="stripe_issuing_personalization_designs_test_helpers_deactivate"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_personalization_designs_test_helpers_reject()
{
    last_command="stripe_issuing_personalization_designs_test_helpers_reject"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--rejection-reasons.card-logo=")
    two_word_flags+=("--rejection-reasons.card-logo")
    local_nonpersistent_flags+=("--rejection-reasons.card-logo")
    local_nonpersistent_flags+=("--rejection-reasons.card-logo=")
    flags+=("--rejection-reasons.carrier-text=")
    two_word_flags+=("--rejection-reasons.carrier-text")
    local_nonpersistent_flags+=("--rejection-reasons.carrier-text")
    local_nonpersistent_flags+=("--rejection-reasons.carrier-text=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_personalization_designs_test_helpers()
{
    last_command="stripe_issuing_personalization_designs_test_helpers"

    command_aliases=()

    commands=()
    commands+=("activate")
    commands+=("deactivate")
    commands+=("reject")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_personalization_designs_update()
{
    last_command="stripe_issuing_personalization_designs_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--card-logo=")
    two_word_flags+=("--card-logo")
    local_nonpersistent_flags+=("--card-logo")
    local_nonpersistent_flags+=("--card-logo=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--lookup-key=")
    two_word_flags+=("--lookup-key")
    local_nonpersistent_flags+=("--lookup-key")
    local_nonpersistent_flags+=("--lookup-key=")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--physical-bundle=")
    two_word_flags+=("--physical-bundle")
    local_nonpersistent_flags+=("--physical-bundle")
    local_nonpersistent_flags+=("--physical-bundle=")
    flags+=("--preferences.is-default=")
    two_word_flags+=("--preferences.is-default")
    local_nonpersistent_flags+=("--preferences.is-default")
    local_nonpersistent_flags+=("--preferences.is-default=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transfer-lookup-key=")
    two_word_flags+=("--transfer-lookup-key")
    local_nonpersistent_flags+=("--transfer-lookup-key")
    local_nonpersistent_flags+=("--transfer-lookup-key=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_personalization_designs()
{
    last_command="stripe_issuing_personalization_designs"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("test_helpers")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_physical_bundles_list()
{
    last_command="stripe_issuing_physical_bundles_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_physical_bundles_retrieve()
{
    last_command="stripe_issuing_physical_bundles_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_physical_bundles()
{
    last_command="stripe_issuing_physical_bundles"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_tokens_list()
{
    last_command="stripe_issuing_tokens_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--card=")
    two_word_flags+=("--card")
    local_nonpersistent_flags+=("--card")
    local_nonpersistent_flags+=("--card=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_tokens_retrieve()
{
    last_command="stripe_issuing_tokens_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_tokens_update()
{
    last_command="stripe_issuing_tokens_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_tokens()
{
    last_command="stripe_issuing_tokens"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_transactions_list()
{
    last_command="stripe_issuing_transactions_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--card=")
    two_word_flags+=("--card")
    local_nonpersistent_flags+=("--card")
    local_nonpersistent_flags+=("--card=")
    flags+=("--cardholder=")
    two_word_flags+=("--cardholder")
    local_nonpersistent_flags+=("--cardholder")
    local_nonpersistent_flags+=("--cardholder=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_transactions_retrieve()
{
    last_command="stripe_issuing_transactions_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_transactions_test_helpers_create_force_capture()
{
    last_command="stripe_issuing_transactions_test_helpers_create_force_capture"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--card=")
    two_word_flags+=("--card")
    local_nonpersistent_flags+=("--card")
    local_nonpersistent_flags+=("--card=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--merchant-data.category=")
    two_word_flags+=("--merchant-data.category")
    local_nonpersistent_flags+=("--merchant-data.category")
    local_nonpersistent_flags+=("--merchant-data.category=")
    flags+=("--merchant-data.city=")
    two_word_flags+=("--merchant-data.city")
    local_nonpersistent_flags+=("--merchant-data.city")
    local_nonpersistent_flags+=("--merchant-data.city=")
    flags+=("--merchant-data.country=")
    two_word_flags+=("--merchant-data.country")
    local_nonpersistent_flags+=("--merchant-data.country")
    local_nonpersistent_flags+=("--merchant-data.country=")
    flags+=("--merchant-data.name=")
    two_word_flags+=("--merchant-data.name")
    local_nonpersistent_flags+=("--merchant-data.name")
    local_nonpersistent_flags+=("--merchant-data.name=")
    flags+=("--merchant-data.network-id=")
    two_word_flags+=("--merchant-data.network-id")
    local_nonpersistent_flags+=("--merchant-data.network-id")
    local_nonpersistent_flags+=("--merchant-data.network-id=")
    flags+=("--merchant-data.postal-code=")
    two_word_flags+=("--merchant-data.postal-code")
    local_nonpersistent_flags+=("--merchant-data.postal-code")
    local_nonpersistent_flags+=("--merchant-data.postal-code=")
    flags+=("--merchant-data.state=")
    two_word_flags+=("--merchant-data.state")
    local_nonpersistent_flags+=("--merchant-data.state")
    local_nonpersistent_flags+=("--merchant-data.state=")
    flags+=("--merchant-data.terminal-id=")
    two_word_flags+=("--merchant-data.terminal-id")
    local_nonpersistent_flags+=("--merchant-data.terminal-id")
    local_nonpersistent_flags+=("--merchant-data.terminal-id=")
    flags+=("--merchant-data.url=")
    two_word_flags+=("--merchant-data.url")
    local_nonpersistent_flags+=("--merchant-data.url")
    local_nonpersistent_flags+=("--merchant-data.url=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number=")
    flags+=("--purchase-details.fleet.purchase-type=")
    two_word_flags+=("--purchase-details.fleet.purchase-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.purchase-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.purchase-type=")
    flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal=")
    flags+=("--purchase-details.fleet.service-type=")
    two_word_flags+=("--purchase-details.fleet.service-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.service-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.service-type=")
    flags+=("--purchase-details.flight.departure-at=")
    two_word_flags+=("--purchase-details.flight.departure-at")
    local_nonpersistent_flags+=("--purchase-details.flight.departure-at")
    local_nonpersistent_flags+=("--purchase-details.flight.departure-at=")
    flags+=("--purchase-details.flight.passenger-name=")
    two_word_flags+=("--purchase-details.flight.passenger-name")
    local_nonpersistent_flags+=("--purchase-details.flight.passenger-name")
    local_nonpersistent_flags+=("--purchase-details.flight.passenger-name=")
    flags+=("--purchase-details.flight.refundable=")
    two_word_flags+=("--purchase-details.flight.refundable")
    local_nonpersistent_flags+=("--purchase-details.flight.refundable")
    local_nonpersistent_flags+=("--purchase-details.flight.refundable=")
    flags+=("--purchase-details.flight.travel-agency=")
    two_word_flags+=("--purchase-details.flight.travel-agency")
    local_nonpersistent_flags+=("--purchase-details.flight.travel-agency")
    local_nonpersistent_flags+=("--purchase-details.flight.travel-agency=")
    flags+=("--purchase-details.fuel.industry-product-code=")
    two_word_flags+=("--purchase-details.fuel.industry-product-code")
    local_nonpersistent_flags+=("--purchase-details.fuel.industry-product-code")
    local_nonpersistent_flags+=("--purchase-details.fuel.industry-product-code=")
    flags+=("--purchase-details.fuel.quantity-decimal=")
    two_word_flags+=("--purchase-details.fuel.quantity-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.quantity-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.quantity-decimal=")
    flags+=("--purchase-details.fuel.type=")
    two_word_flags+=("--purchase-details.fuel.type")
    local_nonpersistent_flags+=("--purchase-details.fuel.type")
    local_nonpersistent_flags+=("--purchase-details.fuel.type=")
    flags+=("--purchase-details.fuel.unit=")
    two_word_flags+=("--purchase-details.fuel.unit")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit=")
    flags+=("--purchase-details.fuel.unit-cost-decimal=")
    two_word_flags+=("--purchase-details.fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit-cost-decimal=")
    flags+=("--purchase-details.lodging.check-in-at=")
    two_word_flags+=("--purchase-details.lodging.check-in-at")
    local_nonpersistent_flags+=("--purchase-details.lodging.check-in-at")
    local_nonpersistent_flags+=("--purchase-details.lodging.check-in-at=")
    flags+=("--purchase-details.lodging.nights=")
    two_word_flags+=("--purchase-details.lodging.nights")
    local_nonpersistent_flags+=("--purchase-details.lodging.nights")
    local_nonpersistent_flags+=("--purchase-details.lodging.nights=")
    flags+=("--purchase-details.reference=")
    two_word_flags+=("--purchase-details.reference")
    local_nonpersistent_flags+=("--purchase-details.reference")
    local_nonpersistent_flags+=("--purchase-details.reference=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_transactions_test_helpers_create_unlinked_refund()
{
    last_command="stripe_issuing_transactions_test_helpers_create_unlinked_refund"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--card=")
    two_word_flags+=("--card")
    local_nonpersistent_flags+=("--card")
    local_nonpersistent_flags+=("--card=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--merchant-data.category=")
    two_word_flags+=("--merchant-data.category")
    local_nonpersistent_flags+=("--merchant-data.category")
    local_nonpersistent_flags+=("--merchant-data.category=")
    flags+=("--merchant-data.city=")
    two_word_flags+=("--merchant-data.city")
    local_nonpersistent_flags+=("--merchant-data.city")
    local_nonpersistent_flags+=("--merchant-data.city=")
    flags+=("--merchant-data.country=")
    two_word_flags+=("--merchant-data.country")
    local_nonpersistent_flags+=("--merchant-data.country")
    local_nonpersistent_flags+=("--merchant-data.country=")
    flags+=("--merchant-data.name=")
    two_word_flags+=("--merchant-data.name")
    local_nonpersistent_flags+=("--merchant-data.name")
    local_nonpersistent_flags+=("--merchant-data.name=")
    flags+=("--merchant-data.network-id=")
    two_word_flags+=("--merchant-data.network-id")
    local_nonpersistent_flags+=("--merchant-data.network-id")
    local_nonpersistent_flags+=("--merchant-data.network-id=")
    flags+=("--merchant-data.postal-code=")
    two_word_flags+=("--merchant-data.postal-code")
    local_nonpersistent_flags+=("--merchant-data.postal-code")
    local_nonpersistent_flags+=("--merchant-data.postal-code=")
    flags+=("--merchant-data.state=")
    two_word_flags+=("--merchant-data.state")
    local_nonpersistent_flags+=("--merchant-data.state")
    local_nonpersistent_flags+=("--merchant-data.state=")
    flags+=("--merchant-data.terminal-id=")
    two_word_flags+=("--merchant-data.terminal-id")
    local_nonpersistent_flags+=("--merchant-data.terminal-id")
    local_nonpersistent_flags+=("--merchant-data.terminal-id=")
    flags+=("--merchant-data.url=")
    two_word_flags+=("--merchant-data.url")
    local_nonpersistent_flags+=("--merchant-data.url")
    local_nonpersistent_flags+=("--merchant-data.url=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number=")
    flags+=("--purchase-details.fleet.purchase-type=")
    two_word_flags+=("--purchase-details.fleet.purchase-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.purchase-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.purchase-type=")
    flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal=")
    flags+=("--purchase-details.fleet.service-type=")
    two_word_flags+=("--purchase-details.fleet.service-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.service-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.service-type=")
    flags+=("--purchase-details.flight.departure-at=")
    two_word_flags+=("--purchase-details.flight.departure-at")
    local_nonpersistent_flags+=("--purchase-details.flight.departure-at")
    local_nonpersistent_flags+=("--purchase-details.flight.departure-at=")
    flags+=("--purchase-details.flight.passenger-name=")
    two_word_flags+=("--purchase-details.flight.passenger-name")
    local_nonpersistent_flags+=("--purchase-details.flight.passenger-name")
    local_nonpersistent_flags+=("--purchase-details.flight.passenger-name=")
    flags+=("--purchase-details.flight.refundable=")
    two_word_flags+=("--purchase-details.flight.refundable")
    local_nonpersistent_flags+=("--purchase-details.flight.refundable")
    local_nonpersistent_flags+=("--purchase-details.flight.refundable=")
    flags+=("--purchase-details.flight.travel-agency=")
    two_word_flags+=("--purchase-details.flight.travel-agency")
    local_nonpersistent_flags+=("--purchase-details.flight.travel-agency")
    local_nonpersistent_flags+=("--purchase-details.flight.travel-agency=")
    flags+=("--purchase-details.fuel.industry-product-code=")
    two_word_flags+=("--purchase-details.fuel.industry-product-code")
    local_nonpersistent_flags+=("--purchase-details.fuel.industry-product-code")
    local_nonpersistent_flags+=("--purchase-details.fuel.industry-product-code=")
    flags+=("--purchase-details.fuel.quantity-decimal=")
    two_word_flags+=("--purchase-details.fuel.quantity-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.quantity-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.quantity-decimal=")
    flags+=("--purchase-details.fuel.type=")
    two_word_flags+=("--purchase-details.fuel.type")
    local_nonpersistent_flags+=("--purchase-details.fuel.type")
    local_nonpersistent_flags+=("--purchase-details.fuel.type=")
    flags+=("--purchase-details.fuel.unit=")
    two_word_flags+=("--purchase-details.fuel.unit")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit=")
    flags+=("--purchase-details.fuel.unit-cost-decimal=")
    two_word_flags+=("--purchase-details.fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit-cost-decimal=")
    flags+=("--purchase-details.lodging.check-in-at=")
    two_word_flags+=("--purchase-details.lodging.check-in-at")
    local_nonpersistent_flags+=("--purchase-details.lodging.check-in-at")
    local_nonpersistent_flags+=("--purchase-details.lodging.check-in-at=")
    flags+=("--purchase-details.lodging.nights=")
    two_word_flags+=("--purchase-details.lodging.nights")
    local_nonpersistent_flags+=("--purchase-details.lodging.nights")
    local_nonpersistent_flags+=("--purchase-details.lodging.nights=")
    flags+=("--purchase-details.reference=")
    two_word_flags+=("--purchase-details.reference")
    local_nonpersistent_flags+=("--purchase-details.reference")
    local_nonpersistent_flags+=("--purchase-details.reference=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_transactions_test_helpers_refund()
{
    last_command="stripe_issuing_transactions_test_helpers_refund"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--refund-amount=")
    two_word_flags+=("--refund-amount")
    local_nonpersistent_flags+=("--refund-amount")
    local_nonpersistent_flags+=("--refund-amount=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_transactions_test_helpers()
{
    last_command="stripe_issuing_transactions_test_helpers"

    command_aliases=()

    commands=()
    commands+=("create_force_capture")
    commands+=("create_unlinked_refund")
    commands+=("refund")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_transactions_update()
{
    last_command="stripe_issuing_transactions_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing_transactions()
{
    last_command="stripe_issuing_transactions"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")
    commands+=("test_helpers")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_issuing()
{
    last_command="stripe_issuing"

    command_aliases=()

    commands=()
    commands+=("authorizations")
    commands+=("cardholders")
    commands+=("cards")
    commands+=("disputes")
    commands+=("personalization_designs")
    commands+=("physical_bundles")
    commands+=("tokens")
    commands+=("transactions")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_line_items_list()
{
    last_command="stripe_line_items_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_line_items_update()
{
    last_command="stripe_line_items_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--discountable=")
    two_word_flags+=("--discountable")
    local_nonpersistent_flags+=("--discountable")
    local_nonpersistent_flags+=("--discountable=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--period.end=")
    two_word_flags+=("--period.end")
    local_nonpersistent_flags+=("--period.end")
    local_nonpersistent_flags+=("--period.end=")
    flags+=("--period.start=")
    two_word_flags+=("--period.start")
    local_nonpersistent_flags+=("--period.start")
    local_nonpersistent_flags+=("--period.start=")
    flags+=("--price=")
    two_word_flags+=("--price")
    local_nonpersistent_flags+=("--price")
    local_nonpersistent_flags+=("--price=")
    flags+=("--price-data.currency=")
    two_word_flags+=("--price-data.currency")
    local_nonpersistent_flags+=("--price-data.currency")
    local_nonpersistent_flags+=("--price-data.currency=")
    flags+=("--price-data.product=")
    two_word_flags+=("--price-data.product")
    local_nonpersistent_flags+=("--price-data.product")
    local_nonpersistent_flags+=("--price-data.product=")
    flags+=("--price-data.product-data.description=")
    two_word_flags+=("--price-data.product-data.description")
    local_nonpersistent_flags+=("--price-data.product-data.description")
    local_nonpersistent_flags+=("--price-data.product-data.description=")
    flags+=("--price-data.product-data.images=")
    two_word_flags+=("--price-data.product-data.images")
    local_nonpersistent_flags+=("--price-data.product-data.images")
    local_nonpersistent_flags+=("--price-data.product-data.images=")
    flags+=("--price-data.product-data.name=")
    two_word_flags+=("--price-data.product-data.name")
    local_nonpersistent_flags+=("--price-data.product-data.name")
    local_nonpersistent_flags+=("--price-data.product-data.name=")
    flags+=("--price-data.product-data.tax-code=")
    two_word_flags+=("--price-data.product-data.tax-code")
    local_nonpersistent_flags+=("--price-data.product-data.tax-code")
    local_nonpersistent_flags+=("--price-data.product-data.tax-code=")
    flags+=("--price-data.tax-behavior=")
    two_word_flags+=("--price-data.tax-behavior")
    local_nonpersistent_flags+=("--price-data.tax-behavior")
    local_nonpersistent_flags+=("--price-data.tax-behavior=")
    flags+=("--price-data.unit-amount=")
    two_word_flags+=("--price-data.unit-amount")
    local_nonpersistent_flags+=("--price-data.unit-amount")
    local_nonpersistent_flags+=("--price-data.unit-amount=")
    flags+=("--price-data.unit-amount-decimal=")
    two_word_flags+=("--price-data.unit-amount-decimal")
    local_nonpersistent_flags+=("--price-data.unit-amount-decimal")
    local_nonpersistent_flags+=("--price-data.unit-amount-decimal=")
    flags+=("--quantity=")
    two_word_flags+=("--quantity")
    local_nonpersistent_flags+=("--quantity")
    local_nonpersistent_flags+=("--quantity=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tax-rates=")
    two_word_flags+=("--tax-rates")
    local_nonpersistent_flags+=("--tax-rates")
    local_nonpersistent_flags+=("--tax-rates=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_line_items()
{
    last_command="stripe_line_items"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_listen()
{
    last_command="stripe_listen"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--connect-headers=")
    two_word_flags+=("--connect-headers")
    local_nonpersistent_flags+=("--connect-headers")
    local_nonpersistent_flags+=("--connect-headers=")
    flags+=("--events=")
    two_word_flags+=("--events")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--events")
    local_nonpersistent_flags+=("--events=")
    local_nonpersistent_flags+=("-e")
    flags+=("--format=")
    two_word_flags+=("--format")
    local_nonpersistent_flags+=("--format")
    local_nonpersistent_flags+=("--format=")
    flags+=("--forward-connect-to=")
    two_word_flags+=("--forward-connect-to")
    two_word_flags+=("-c")
    local_nonpersistent_flags+=("--forward-connect-to")
    local_nonpersistent_flags+=("--forward-connect-to=")
    local_nonpersistent_flags+=("-c")
    flags+=("--forward-thin-connect-to=")
    two_word_flags+=("--forward-thin-connect-to")
    local_nonpersistent_flags+=("--forward-thin-connect-to")
    local_nonpersistent_flags+=("--forward-thin-connect-to=")
    flags+=("--forward-thin-to=")
    two_word_flags+=("--forward-thin-to")
    local_nonpersistent_flags+=("--forward-thin-to")
    local_nonpersistent_flags+=("--forward-thin-to=")
    flags+=("--forward-to=")
    two_word_flags+=("--forward-to")
    two_word_flags+=("-f")
    local_nonpersistent_flags+=("--forward-to")
    local_nonpersistent_flags+=("--forward-to=")
    local_nonpersistent_flags+=("-f")
    flags+=("--headers=")
    two_word_flags+=("--headers")
    two_word_flags+=("-H")
    local_nonpersistent_flags+=("--headers")
    local_nonpersistent_flags+=("--headers=")
    local_nonpersistent_flags+=("-H")
    flags+=("--latest")
    flags+=("-l")
    local_nonpersistent_flags+=("--latest")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--print-secret")
    local_nonpersistent_flags+=("--print-secret")
    flags+=("--skip-update")
    flags+=("-s")
    local_nonpersistent_flags+=("--skip-update")
    local_nonpersistent_flags+=("-s")
    flags+=("--skip-verify")
    local_nonpersistent_flags+=("--skip-verify")
    flags+=("--thin-events=")
    two_word_flags+=("--thin-events")
    local_nonpersistent_flags+=("--thin-events")
    local_nonpersistent_flags+=("--thin-events=")
    flags+=("--use-configured-webhooks")
    flags+=("-a")
    local_nonpersistent_flags+=("--use-configured-webhooks")
    local_nonpersistent_flags+=("-a")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_login()
{
    last_command="stripe_login"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--interactive")
    flags+=("-i")
    local_nonpersistent_flags+=("--interactive")
    local_nonpersistent_flags+=("-i")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_login_links_create()
{
    last_command="stripe_login_links_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_login_links()
{
    last_command="stripe_login_links"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_logout()
{
    last_command="stripe_logout"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--all")
    flags+=("-a")
    local_nonpersistent_flags+=("--all")
    local_nonpersistent_flags+=("-a")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_logs_tail()
{
    last_command="stripe_logs_tail"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--filter-account=")
    two_word_flags+=("--filter-account")
    local_nonpersistent_flags+=("--filter-account")
    local_nonpersistent_flags+=("--filter-account=")
    flags+=("--filter-http-method=")
    two_word_flags+=("--filter-http-method")
    local_nonpersistent_flags+=("--filter-http-method")
    local_nonpersistent_flags+=("--filter-http-method=")
    flags+=("--filter-ip-address=")
    two_word_flags+=("--filter-ip-address")
    local_nonpersistent_flags+=("--filter-ip-address")
    local_nonpersistent_flags+=("--filter-ip-address=")
    flags+=("--filter-request-path=")
    two_word_flags+=("--filter-request-path")
    local_nonpersistent_flags+=("--filter-request-path")
    local_nonpersistent_flags+=("--filter-request-path=")
    flags+=("--filter-request-status=")
    two_word_flags+=("--filter-request-status")
    local_nonpersistent_flags+=("--filter-request-status")
    local_nonpersistent_flags+=("--filter-request-status=")
    flags+=("--filter-source=")
    two_word_flags+=("--filter-source")
    local_nonpersistent_flags+=("--filter-source")
    local_nonpersistent_flags+=("--filter-source=")
    flags+=("--filter-status-code=")
    two_word_flags+=("--filter-status-code")
    local_nonpersistent_flags+=("--filter-status-code")
    local_nonpersistent_flags+=("--filter-status-code=")
    flags+=("--filter-status-code-type=")
    two_word_flags+=("--filter-status-code-type")
    local_nonpersistent_flags+=("--filter-status-code-type")
    local_nonpersistent_flags+=("--filter-status-code-type=")
    flags+=("--format=")
    two_word_flags+=("--format")
    local_nonpersistent_flags+=("--format")
    local_nonpersistent_flags+=("--format=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_logs()
{
    last_command="stripe_logs"

    command_aliases=()

    commands=()
    commands+=("tail")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_mandates_retrieve()
{
    last_command="stripe_mandates_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_mandates()
{
    last_command="stripe_mandates"

    command_aliases=()

    commands=()
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_open()
{
    last_command="stripe_open"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--list")
    local_nonpersistent_flags+=("--list")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    must_have_one_noun+=("api")
    must_have_one_noun+=("apiref")
    must_have_one_noun+=("cliref")
    must_have_one_noun+=("dashboard")
    must_have_one_noun+=("dashboard/apikeys")
    must_have_one_noun+=("dashboard/atlas")
    must_have_one_noun+=("dashboard/balance")
    must_have_one_noun+=("dashboard/billing")
    must_have_one_noun+=("dashboard/connect")
    must_have_one_noun+=("dashboard/connect/accounts")
    must_have_one_noun+=("dashboard/connect/collected-fees")
    must_have_one_noun+=("dashboard/connect/transfers")
    must_have_one_noun+=("dashboard/coupons")
    must_have_one_noun+=("dashboard/customers")
    must_have_one_noun+=("dashboard/developers")
    must_have_one_noun+=("dashboard/disputes")
    must_have_one_noun+=("dashboard/events")
    must_have_one_noun+=("dashboard/invoices")
    must_have_one_noun+=("dashboard/logs")
    must_have_one_noun+=("dashboard/orders")
    must_have_one_noun+=("dashboard/orders/products")
    must_have_one_noun+=("dashboard/payments")
    must_have_one_noun+=("dashboard/payouts")
    must_have_one_noun+=("dashboard/radar")
    must_have_one_noun+=("dashboard/radar/list")
    must_have_one_noun+=("dashboard/radar/reviews")
    must_have_one_noun+=("dashboard/radar/rules")
    must_have_one_noun+=("dashboard/settings")
    must_have_one_noun+=("dashboard/subscriptions")
    must_have_one_noun+=("dashboard/subscriptions/products")
    must_have_one_noun+=("dashboard/tax-rates")
    must_have_one_noun+=("dashboard/terminal")
    must_have_one_noun+=("dashboard/terminal/hardware_orders")
    must_have_one_noun+=("dashboard/terminal/locations")
    must_have_one_noun+=("dashboard/topups")
    must_have_one_noun+=("dashboard/transactions")
    must_have_one_noun+=("dashboard/webhooks")
    must_have_one_noun+=("docs")
    noun_aliases=()
}

_stripe_payment_intents_apply_customer_balance()
{
    last_command="stripe_payment_intents_apply_customer_balance"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_intents_cancel()
{
    last_command="stripe_payment_intents_cancel"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--cancellation-reason=")
    two_word_flags+=("--cancellation-reason")
    local_nonpersistent_flags+=("--cancellation-reason")
    local_nonpersistent_flags+=("--cancellation-reason=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_intents_capture()
{
    last_command="stripe_payment_intents_capture"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount-to-capture=")
    two_word_flags+=("--amount-to-capture")
    local_nonpersistent_flags+=("--amount-to-capture")
    local_nonpersistent_flags+=("--amount-to-capture=")
    flags+=("--application-fee-amount=")
    two_word_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--final-capture=")
    two_word_flags+=("--final-capture")
    local_nonpersistent_flags+=("--final-capture")
    local_nonpersistent_flags+=("--final-capture=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--statement-descriptor-suffix=")
    two_word_flags+=("--statement-descriptor-suffix")
    local_nonpersistent_flags+=("--statement-descriptor-suffix")
    local_nonpersistent_flags+=("--statement-descriptor-suffix=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transfer-data.amount=")
    two_word_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_intents_confirm()
{
    last_command="stripe_payment_intents_confirm"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--capture-method=")
    two_word_flags+=("--capture-method")
    local_nonpersistent_flags+=("--capture-method")
    local_nonpersistent_flags+=("--capture-method=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--confirmation-token=")
    two_word_flags+=("--confirmation-token")
    local_nonpersistent_flags+=("--confirmation-token")
    local_nonpersistent_flags+=("--confirmation-token=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--error-on-requires-action=")
    two_word_flags+=("--error-on-requires-action")
    local_nonpersistent_flags+=("--error-on-requires-action")
    local_nonpersistent_flags+=("--error-on-requires-action=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--mandate=")
    two_word_flags+=("--mandate")
    local_nonpersistent_flags+=("--mandate")
    local_nonpersistent_flags+=("--mandate=")
    flags+=("--off-session=")
    two_word_flags+=("--off-session")
    local_nonpersistent_flags+=("--off-session")
    local_nonpersistent_flags+=("--off-session=")
    flags+=("--payment-method=")
    two_word_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method=")
    flags+=("--payment-method-data.acss-debit.account-number=")
    two_word_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number=")
    flags+=("--payment-method-data.acss-debit.institution-number=")
    two_word_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number=")
    flags+=("--payment-method-data.acss-debit.transit-number=")
    two_word_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number=")
    flags+=("--payment-method-data.allow-redisplay=")
    two_word_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay=")
    flags+=("--payment-method-data.au-becs-debit.account-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number=")
    flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    flags+=("--payment-method-data.bacs-debit.account-number=")
    two_word_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number=")
    flags+=("--payment-method-data.bacs-debit.sort-code=")
    two_word_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code=")
    flags+=("--payment-method-data.billing-details.email=")
    two_word_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email=")
    flags+=("--payment-method-data.billing-details.name=")
    two_word_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name=")
    flags+=("--payment-method-data.billing-details.phone=")
    two_word_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone=")
    flags+=("--payment-method-data.boleto.tax-id=")
    two_word_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id=")
    flags+=("--payment-method-data.eps.bank=")
    two_word_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank=")
    flags+=("--payment-method-data.fpx.account-holder-type=")
    two_word_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type=")
    flags+=("--payment-method-data.fpx.bank=")
    two_word_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank=")
    flags+=("--payment-method-data.ideal.bank=")
    two_word_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank=")
    flags+=("--payment-method-data.klarna.dob.day=")
    two_word_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day=")
    flags+=("--payment-method-data.klarna.dob.month=")
    two_word_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month=")
    flags+=("--payment-method-data.klarna.dob.year=")
    two_word_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year=")
    flags+=("--payment-method-data.naver-pay.funding=")
    two_word_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding=")
    flags+=("--payment-method-data.p24.bank=")
    two_word_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank=")
    flags+=("--payment-method-data.radar-options.session=")
    two_word_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session=")
    flags+=("--payment-method-data.sepa-debit.iban=")
    two_word_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban=")
    flags+=("--payment-method-data.sofort.country=")
    two_word_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country=")
    flags+=("--payment-method-data.type=")
    two_word_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type=")
    flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    flags+=("--payment-method-data.us-bank-account.account-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number=")
    flags+=("--payment-method-data.us-bank-account.account-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type=")
    flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    two_word_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    flags+=("--payment-method-data.us-bank-account.routing-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number=")
    flags+=("--payment-method-types=")
    two_word_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types=")
    flags+=("--radar-options.session=")
    two_word_flags+=("--radar-options.session")
    local_nonpersistent_flags+=("--radar-options.session")
    local_nonpersistent_flags+=("--radar-options.session=")
    flags+=("--receipt-email=")
    two_word_flags+=("--receipt-email")
    local_nonpersistent_flags+=("--receipt-email")
    local_nonpersistent_flags+=("--receipt-email=")
    flags+=("--return-url=")
    two_word_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url=")
    flags+=("--setup-future-usage=")
    two_word_flags+=("--setup-future-usage")
    local_nonpersistent_flags+=("--setup-future-usage")
    local_nonpersistent_flags+=("--setup-future-usage=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--use-stripe-sdk=")
    two_word_flags+=("--use-stripe-sdk")
    local_nonpersistent_flags+=("--use-stripe-sdk")
    local_nonpersistent_flags+=("--use-stripe-sdk=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_intents_create()
{
    last_command="stripe_payment_intents_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--application-fee-amount=")
    two_word_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount=")
    flags+=("--automatic-payment-methods.allow-redirects=")
    two_word_flags+=("--automatic-payment-methods.allow-redirects")
    local_nonpersistent_flags+=("--automatic-payment-methods.allow-redirects")
    local_nonpersistent_flags+=("--automatic-payment-methods.allow-redirects=")
    flags+=("--automatic-payment-methods.enabled=")
    two_word_flags+=("--automatic-payment-methods.enabled")
    local_nonpersistent_flags+=("--automatic-payment-methods.enabled")
    local_nonpersistent_flags+=("--automatic-payment-methods.enabled=")
    flags+=("--capture-method=")
    two_word_flags+=("--capture-method")
    local_nonpersistent_flags+=("--capture-method")
    local_nonpersistent_flags+=("--capture-method=")
    flags+=("--confirm=")
    two_word_flags+=("--confirm")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("--confirm=")
    flags+=("--confirmation-method=")
    two_word_flags+=("--confirmation-method")
    local_nonpersistent_flags+=("--confirmation-method")
    local_nonpersistent_flags+=("--confirmation-method=")
    flags+=("--confirmation-token=")
    two_word_flags+=("--confirmation-token")
    local_nonpersistent_flags+=("--confirmation-token")
    local_nonpersistent_flags+=("--confirmation-token=")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--error-on-requires-action=")
    two_word_flags+=("--error-on-requires-action")
    local_nonpersistent_flags+=("--error-on-requires-action")
    local_nonpersistent_flags+=("--error-on-requires-action=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--mandate=")
    two_word_flags+=("--mandate")
    local_nonpersistent_flags+=("--mandate")
    local_nonpersistent_flags+=("--mandate=")
    flags+=("--off-session=")
    two_word_flags+=("--off-session")
    local_nonpersistent_flags+=("--off-session")
    local_nonpersistent_flags+=("--off-session=")
    flags+=("--on-behalf-of=")
    two_word_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of=")
    flags+=("--payment-method=")
    two_word_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method=")
    flags+=("--payment-method-configuration=")
    two_word_flags+=("--payment-method-configuration")
    local_nonpersistent_flags+=("--payment-method-configuration")
    local_nonpersistent_flags+=("--payment-method-configuration=")
    flags+=("--payment-method-data.acss-debit.account-number=")
    two_word_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number=")
    flags+=("--payment-method-data.acss-debit.institution-number=")
    two_word_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number=")
    flags+=("--payment-method-data.acss-debit.transit-number=")
    two_word_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number=")
    flags+=("--payment-method-data.allow-redisplay=")
    two_word_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay=")
    flags+=("--payment-method-data.au-becs-debit.account-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number=")
    flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    flags+=("--payment-method-data.bacs-debit.account-number=")
    two_word_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number=")
    flags+=("--payment-method-data.bacs-debit.sort-code=")
    two_word_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code=")
    flags+=("--payment-method-data.billing-details.email=")
    two_word_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email=")
    flags+=("--payment-method-data.billing-details.name=")
    two_word_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name=")
    flags+=("--payment-method-data.billing-details.phone=")
    two_word_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone=")
    flags+=("--payment-method-data.boleto.tax-id=")
    two_word_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id=")
    flags+=("--payment-method-data.eps.bank=")
    two_word_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank=")
    flags+=("--payment-method-data.fpx.account-holder-type=")
    two_word_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type=")
    flags+=("--payment-method-data.fpx.bank=")
    two_word_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank=")
    flags+=("--payment-method-data.ideal.bank=")
    two_word_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank=")
    flags+=("--payment-method-data.klarna.dob.day=")
    two_word_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day=")
    flags+=("--payment-method-data.klarna.dob.month=")
    two_word_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month=")
    flags+=("--payment-method-data.klarna.dob.year=")
    two_word_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year=")
    flags+=("--payment-method-data.naver-pay.funding=")
    two_word_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding=")
    flags+=("--payment-method-data.p24.bank=")
    two_word_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank=")
    flags+=("--payment-method-data.radar-options.session=")
    two_word_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session=")
    flags+=("--payment-method-data.sepa-debit.iban=")
    two_word_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban=")
    flags+=("--payment-method-data.sofort.country=")
    two_word_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country=")
    flags+=("--payment-method-data.type=")
    two_word_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type=")
    flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    flags+=("--payment-method-data.us-bank-account.account-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number=")
    flags+=("--payment-method-data.us-bank-account.account-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type=")
    flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    two_word_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    flags+=("--payment-method-data.us-bank-account.routing-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number=")
    flags+=("--payment-method-types=")
    two_word_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types=")
    flags+=("--radar-options.session=")
    two_word_flags+=("--radar-options.session")
    local_nonpersistent_flags+=("--radar-options.session")
    local_nonpersistent_flags+=("--radar-options.session=")
    flags+=("--receipt-email=")
    two_word_flags+=("--receipt-email")
    local_nonpersistent_flags+=("--receipt-email")
    local_nonpersistent_flags+=("--receipt-email=")
    flags+=("--return-url=")
    two_word_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url=")
    flags+=("--setup-future-usage=")
    two_word_flags+=("--setup-future-usage")
    local_nonpersistent_flags+=("--setup-future-usage")
    local_nonpersistent_flags+=("--setup-future-usage=")
    flags+=("--shipping.address.city=")
    two_word_flags+=("--shipping.address.city")
    local_nonpersistent_flags+=("--shipping.address.city")
    local_nonpersistent_flags+=("--shipping.address.city=")
    flags+=("--shipping.address.country=")
    two_word_flags+=("--shipping.address.country")
    local_nonpersistent_flags+=("--shipping.address.country")
    local_nonpersistent_flags+=("--shipping.address.country=")
    flags+=("--shipping.address.line1=")
    two_word_flags+=("--shipping.address.line1")
    local_nonpersistent_flags+=("--shipping.address.line1")
    local_nonpersistent_flags+=("--shipping.address.line1=")
    flags+=("--shipping.address.line2=")
    two_word_flags+=("--shipping.address.line2")
    local_nonpersistent_flags+=("--shipping.address.line2")
    local_nonpersistent_flags+=("--shipping.address.line2=")
    flags+=("--shipping.address.postal-code=")
    two_word_flags+=("--shipping.address.postal-code")
    local_nonpersistent_flags+=("--shipping.address.postal-code")
    local_nonpersistent_flags+=("--shipping.address.postal-code=")
    flags+=("--shipping.address.state=")
    two_word_flags+=("--shipping.address.state")
    local_nonpersistent_flags+=("--shipping.address.state")
    local_nonpersistent_flags+=("--shipping.address.state=")
    flags+=("--shipping.carrier=")
    two_word_flags+=("--shipping.carrier")
    local_nonpersistent_flags+=("--shipping.carrier")
    local_nonpersistent_flags+=("--shipping.carrier=")
    flags+=("--shipping.name=")
    two_word_flags+=("--shipping.name")
    local_nonpersistent_flags+=("--shipping.name")
    local_nonpersistent_flags+=("--shipping.name=")
    flags+=("--shipping.phone=")
    two_word_flags+=("--shipping.phone")
    local_nonpersistent_flags+=("--shipping.phone")
    local_nonpersistent_flags+=("--shipping.phone=")
    flags+=("--shipping.tracking-number=")
    two_word_flags+=("--shipping.tracking-number")
    local_nonpersistent_flags+=("--shipping.tracking-number")
    local_nonpersistent_flags+=("--shipping.tracking-number=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--statement-descriptor-suffix=")
    two_word_flags+=("--statement-descriptor-suffix")
    local_nonpersistent_flags+=("--statement-descriptor-suffix")
    local_nonpersistent_flags+=("--statement-descriptor-suffix=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transfer-data.amount=")
    two_word_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount=")
    flags+=("--transfer-data.destination=")
    two_word_flags+=("--transfer-data.destination")
    local_nonpersistent_flags+=("--transfer-data.destination")
    local_nonpersistent_flags+=("--transfer-data.destination=")
    flags+=("--transfer-group=")
    two_word_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group=")
    flags+=("--use-stripe-sdk=")
    two_word_flags+=("--use-stripe-sdk")
    local_nonpersistent_flags+=("--use-stripe-sdk")
    local_nonpersistent_flags+=("--use-stripe-sdk=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_intents_increment_authorization()
{
    last_command="stripe_payment_intents_increment_authorization"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--application-fee-amount=")
    two_word_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transfer-data.amount=")
    two_word_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_intents_list()
{
    last_command="stripe_payment_intents_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_intents_retrieve()
{
    last_command="stripe_payment_intents_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--client-secret=")
    two_word_flags+=("--client-secret")
    local_nonpersistent_flags+=("--client-secret")
    local_nonpersistent_flags+=("--client-secret=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_intents_search()
{
    last_command="stripe_payment_intents_search"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--page=")
    two_word_flags+=("--page")
    local_nonpersistent_flags+=("--page")
    local_nonpersistent_flags+=("--page=")
    flags+=("--query=")
    two_word_flags+=("--query")
    local_nonpersistent_flags+=("--query")
    local_nonpersistent_flags+=("--query=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_intents_update()
{
    last_command="stripe_payment_intents_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--application-fee-amount=")
    two_word_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount=")
    flags+=("--capture-method=")
    two_word_flags+=("--capture-method")
    local_nonpersistent_flags+=("--capture-method")
    local_nonpersistent_flags+=("--capture-method=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-method=")
    two_word_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method=")
    flags+=("--payment-method-configuration=")
    two_word_flags+=("--payment-method-configuration")
    local_nonpersistent_flags+=("--payment-method-configuration")
    local_nonpersistent_flags+=("--payment-method-configuration=")
    flags+=("--payment-method-data.acss-debit.account-number=")
    two_word_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number=")
    flags+=("--payment-method-data.acss-debit.institution-number=")
    two_word_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number=")
    flags+=("--payment-method-data.acss-debit.transit-number=")
    two_word_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number=")
    flags+=("--payment-method-data.allow-redisplay=")
    two_word_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay=")
    flags+=("--payment-method-data.au-becs-debit.account-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number=")
    flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    flags+=("--payment-method-data.bacs-debit.account-number=")
    two_word_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number=")
    flags+=("--payment-method-data.bacs-debit.sort-code=")
    two_word_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code=")
    flags+=("--payment-method-data.billing-details.email=")
    two_word_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email=")
    flags+=("--payment-method-data.billing-details.name=")
    two_word_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name=")
    flags+=("--payment-method-data.billing-details.phone=")
    two_word_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone=")
    flags+=("--payment-method-data.boleto.tax-id=")
    two_word_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id=")
    flags+=("--payment-method-data.eps.bank=")
    two_word_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank=")
    flags+=("--payment-method-data.fpx.account-holder-type=")
    two_word_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type=")
    flags+=("--payment-method-data.fpx.bank=")
    two_word_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank=")
    flags+=("--payment-method-data.ideal.bank=")
    two_word_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank=")
    flags+=("--payment-method-data.klarna.dob.day=")
    two_word_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day=")
    flags+=("--payment-method-data.klarna.dob.month=")
    two_word_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month=")
    flags+=("--payment-method-data.klarna.dob.year=")
    two_word_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year=")
    flags+=("--payment-method-data.naver-pay.funding=")
    two_word_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding=")
    flags+=("--payment-method-data.p24.bank=")
    two_word_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank=")
    flags+=("--payment-method-data.radar-options.session=")
    two_word_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session=")
    flags+=("--payment-method-data.sepa-debit.iban=")
    two_word_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban=")
    flags+=("--payment-method-data.sofort.country=")
    two_word_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country=")
    flags+=("--payment-method-data.type=")
    two_word_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type=")
    flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    flags+=("--payment-method-data.us-bank-account.account-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number=")
    flags+=("--payment-method-data.us-bank-account.account-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type=")
    flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    two_word_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    flags+=("--payment-method-data.us-bank-account.routing-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number=")
    flags+=("--payment-method-types=")
    two_word_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types=")
    flags+=("--receipt-email=")
    two_word_flags+=("--receipt-email")
    local_nonpersistent_flags+=("--receipt-email")
    local_nonpersistent_flags+=("--receipt-email=")
    flags+=("--setup-future-usage=")
    two_word_flags+=("--setup-future-usage")
    local_nonpersistent_flags+=("--setup-future-usage")
    local_nonpersistent_flags+=("--setup-future-usage=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--statement-descriptor-suffix=")
    two_word_flags+=("--statement-descriptor-suffix")
    local_nonpersistent_flags+=("--statement-descriptor-suffix")
    local_nonpersistent_flags+=("--statement-descriptor-suffix=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transfer-data.amount=")
    two_word_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount=")
    flags+=("--transfer-group=")
    two_word_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_intents_verify_microdeposits()
{
    last_command="stripe_payment_intents_verify_microdeposits"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amounts=")
    two_word_flags+=("--amounts")
    local_nonpersistent_flags+=("--amounts")
    local_nonpersistent_flags+=("--amounts=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--descriptor-code=")
    two_word_flags+=("--descriptor-code")
    local_nonpersistent_flags+=("--descriptor-code")
    local_nonpersistent_flags+=("--descriptor-code=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_intents()
{
    last_command="stripe_payment_intents"

    command_aliases=()

    commands=()
    commands+=("apply_customer_balance")
    commands+=("cancel")
    commands+=("capture")
    commands+=("confirm")
    commands+=("create")
    commands+=("increment_authorization")
    commands+=("list")
    commands+=("retrieve")
    commands+=("search")
    commands+=("update")
    commands+=("verify_microdeposits")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_links_create()
{
    last_command="stripe_payment_links_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--after-completion.hosted-confirmation.custom-message=")
    two_word_flags+=("--after-completion.hosted-confirmation.custom-message")
    local_nonpersistent_flags+=("--after-completion.hosted-confirmation.custom-message")
    local_nonpersistent_flags+=("--after-completion.hosted-confirmation.custom-message=")
    flags+=("--after-completion.redirect.url=")
    two_word_flags+=("--after-completion.redirect.url")
    local_nonpersistent_flags+=("--after-completion.redirect.url")
    local_nonpersistent_flags+=("--after-completion.redirect.url=")
    flags+=("--after-completion.type=")
    two_word_flags+=("--after-completion.type")
    local_nonpersistent_flags+=("--after-completion.type")
    local_nonpersistent_flags+=("--after-completion.type=")
    flags+=("--allow-promotion-codes=")
    two_word_flags+=("--allow-promotion-codes")
    local_nonpersistent_flags+=("--allow-promotion-codes")
    local_nonpersistent_flags+=("--allow-promotion-codes=")
    flags+=("--application-fee-amount=")
    two_word_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount=")
    flags+=("--application-fee-percent=")
    two_word_flags+=("--application-fee-percent")
    local_nonpersistent_flags+=("--application-fee-percent")
    local_nonpersistent_flags+=("--application-fee-percent=")
    flags+=("--automatic-tax.enabled=")
    two_word_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled=")
    flags+=("--automatic-tax.liability.account=")
    two_word_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account=")
    flags+=("--automatic-tax.liability.type=")
    two_word_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type=")
    flags+=("--billing-address-collection=")
    two_word_flags+=("--billing-address-collection")
    local_nonpersistent_flags+=("--billing-address-collection")
    local_nonpersistent_flags+=("--billing-address-collection=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--consent-collection.payment-method-reuse-agreement.position=")
    two_word_flags+=("--consent-collection.payment-method-reuse-agreement.position")
    local_nonpersistent_flags+=("--consent-collection.payment-method-reuse-agreement.position")
    local_nonpersistent_flags+=("--consent-collection.payment-method-reuse-agreement.position=")
    flags+=("--consent-collection.promotions=")
    two_word_flags+=("--consent-collection.promotions")
    local_nonpersistent_flags+=("--consent-collection.promotions")
    local_nonpersistent_flags+=("--consent-collection.promotions=")
    flags+=("--consent-collection.terms-of-service=")
    two_word_flags+=("--consent-collection.terms-of-service")
    local_nonpersistent_flags+=("--consent-collection.terms-of-service")
    local_nonpersistent_flags+=("--consent-collection.terms-of-service=")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--customer-creation=")
    two_word_flags+=("--customer-creation")
    local_nonpersistent_flags+=("--customer-creation")
    local_nonpersistent_flags+=("--customer-creation=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--inactive-message=")
    two_word_flags+=("--inactive-message")
    local_nonpersistent_flags+=("--inactive-message")
    local_nonpersistent_flags+=("--inactive-message=")
    flags+=("--invoice-creation.enabled=")
    two_word_flags+=("--invoice-creation.enabled")
    local_nonpersistent_flags+=("--invoice-creation.enabled")
    local_nonpersistent_flags+=("--invoice-creation.enabled=")
    flags+=("--invoice-creation.invoice-data.account-tax-ids=")
    two_word_flags+=("--invoice-creation.invoice-data.account-tax-ids")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.account-tax-ids")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.account-tax-ids=")
    flags+=("--invoice-creation.invoice-data.description=")
    two_word_flags+=("--invoice-creation.invoice-data.description")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.description")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.description=")
    flags+=("--invoice-creation.invoice-data.footer=")
    two_word_flags+=("--invoice-creation.invoice-data.footer")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.footer")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.footer=")
    flags+=("--invoice-creation.invoice-data.issuer.account=")
    two_word_flags+=("--invoice-creation.invoice-data.issuer.account")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.issuer.account")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.issuer.account=")
    flags+=("--invoice-creation.invoice-data.issuer.type=")
    two_word_flags+=("--invoice-creation.invoice-data.issuer.type")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.issuer.type")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.issuer.type=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--on-behalf-of=")
    two_word_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of=")
    flags+=("--payment-intent-data.capture-method=")
    two_word_flags+=("--payment-intent-data.capture-method")
    local_nonpersistent_flags+=("--payment-intent-data.capture-method")
    local_nonpersistent_flags+=("--payment-intent-data.capture-method=")
    flags+=("--payment-intent-data.description=")
    two_word_flags+=("--payment-intent-data.description")
    local_nonpersistent_flags+=("--payment-intent-data.description")
    local_nonpersistent_flags+=("--payment-intent-data.description=")
    flags+=("--payment-intent-data.setup-future-usage=")
    two_word_flags+=("--payment-intent-data.setup-future-usage")
    local_nonpersistent_flags+=("--payment-intent-data.setup-future-usage")
    local_nonpersistent_flags+=("--payment-intent-data.setup-future-usage=")
    flags+=("--payment-intent-data.statement-descriptor=")
    two_word_flags+=("--payment-intent-data.statement-descriptor")
    local_nonpersistent_flags+=("--payment-intent-data.statement-descriptor")
    local_nonpersistent_flags+=("--payment-intent-data.statement-descriptor=")
    flags+=("--payment-intent-data.statement-descriptor-suffix=")
    two_word_flags+=("--payment-intent-data.statement-descriptor-suffix")
    local_nonpersistent_flags+=("--payment-intent-data.statement-descriptor-suffix")
    local_nonpersistent_flags+=("--payment-intent-data.statement-descriptor-suffix=")
    flags+=("--payment-intent-data.transfer-group=")
    two_word_flags+=("--payment-intent-data.transfer-group")
    local_nonpersistent_flags+=("--payment-intent-data.transfer-group")
    local_nonpersistent_flags+=("--payment-intent-data.transfer-group=")
    flags+=("--payment-method-collection=")
    two_word_flags+=("--payment-method-collection")
    local_nonpersistent_flags+=("--payment-method-collection")
    local_nonpersistent_flags+=("--payment-method-collection=")
    flags+=("--payment-method-types=")
    two_word_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types=")
    flags+=("--phone-number-collection.enabled=")
    two_word_flags+=("--phone-number-collection.enabled")
    local_nonpersistent_flags+=("--phone-number-collection.enabled")
    local_nonpersistent_flags+=("--phone-number-collection.enabled=")
    flags+=("--restrictions.completed-sessions.limit=")
    two_word_flags+=("--restrictions.completed-sessions.limit")
    local_nonpersistent_flags+=("--restrictions.completed-sessions.limit")
    local_nonpersistent_flags+=("--restrictions.completed-sessions.limit=")
    flags+=("--shipping-address-collection.allowed-countries=")
    two_word_flags+=("--shipping-address-collection.allowed-countries")
    local_nonpersistent_flags+=("--shipping-address-collection.allowed-countries")
    local_nonpersistent_flags+=("--shipping-address-collection.allowed-countries=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--submit-type=")
    two_word_flags+=("--submit-type")
    local_nonpersistent_flags+=("--submit-type")
    local_nonpersistent_flags+=("--submit-type=")
    flags+=("--subscription-data.description=")
    two_word_flags+=("--subscription-data.description")
    local_nonpersistent_flags+=("--subscription-data.description")
    local_nonpersistent_flags+=("--subscription-data.description=")
    flags+=("--subscription-data.invoice-settings.issuer.account=")
    two_word_flags+=("--subscription-data.invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--subscription-data.invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--subscription-data.invoice-settings.issuer.account=")
    flags+=("--subscription-data.invoice-settings.issuer.type=")
    two_word_flags+=("--subscription-data.invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--subscription-data.invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--subscription-data.invoice-settings.issuer.type=")
    flags+=("--subscription-data.trial-period-days=")
    two_word_flags+=("--subscription-data.trial-period-days")
    local_nonpersistent_flags+=("--subscription-data.trial-period-days")
    local_nonpersistent_flags+=("--subscription-data.trial-period-days=")
    flags+=("--subscription-data.trial-settings.end-behavior.missing-payment-method=")
    two_word_flags+=("--subscription-data.trial-settings.end-behavior.missing-payment-method")
    local_nonpersistent_flags+=("--subscription-data.trial-settings.end-behavior.missing-payment-method")
    local_nonpersistent_flags+=("--subscription-data.trial-settings.end-behavior.missing-payment-method=")
    flags+=("--tax-id-collection.enabled=")
    two_word_flags+=("--tax-id-collection.enabled")
    local_nonpersistent_flags+=("--tax-id-collection.enabled")
    local_nonpersistent_flags+=("--tax-id-collection.enabled=")
    flags+=("--tax-id-collection.required=")
    two_word_flags+=("--tax-id-collection.required")
    local_nonpersistent_flags+=("--tax-id-collection.required")
    local_nonpersistent_flags+=("--tax-id-collection.required=")
    flags+=("--transfer-data.amount=")
    two_word_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount")
    local_nonpersistent_flags+=("--transfer-data.amount=")
    flags+=("--transfer-data.destination=")
    two_word_flags+=("--transfer-data.destination")
    local_nonpersistent_flags+=("--transfer-data.destination")
    local_nonpersistent_flags+=("--transfer-data.destination=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_links_list()
{
    last_command="stripe_payment_links_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_links_list_line_items()
{
    last_command="stripe_payment_links_list_line_items"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_links_retrieve()
{
    last_command="stripe_payment_links_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_links_update()
{
    last_command="stripe_payment_links_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--after-completion.hosted-confirmation.custom-message=")
    two_word_flags+=("--after-completion.hosted-confirmation.custom-message")
    local_nonpersistent_flags+=("--after-completion.hosted-confirmation.custom-message")
    local_nonpersistent_flags+=("--after-completion.hosted-confirmation.custom-message=")
    flags+=("--after-completion.redirect.url=")
    two_word_flags+=("--after-completion.redirect.url")
    local_nonpersistent_flags+=("--after-completion.redirect.url")
    local_nonpersistent_flags+=("--after-completion.redirect.url=")
    flags+=("--after-completion.type=")
    two_word_flags+=("--after-completion.type")
    local_nonpersistent_flags+=("--after-completion.type")
    local_nonpersistent_flags+=("--after-completion.type=")
    flags+=("--allow-promotion-codes=")
    two_word_flags+=("--allow-promotion-codes")
    local_nonpersistent_flags+=("--allow-promotion-codes")
    local_nonpersistent_flags+=("--allow-promotion-codes=")
    flags+=("--automatic-tax.enabled=")
    two_word_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled=")
    flags+=("--automatic-tax.liability.account=")
    two_word_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account=")
    flags+=("--automatic-tax.liability.type=")
    two_word_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type=")
    flags+=("--billing-address-collection=")
    two_word_flags+=("--billing-address-collection")
    local_nonpersistent_flags+=("--billing-address-collection")
    local_nonpersistent_flags+=("--billing-address-collection=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer-creation=")
    two_word_flags+=("--customer-creation")
    local_nonpersistent_flags+=("--customer-creation")
    local_nonpersistent_flags+=("--customer-creation=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--inactive-message=")
    two_word_flags+=("--inactive-message")
    local_nonpersistent_flags+=("--inactive-message")
    local_nonpersistent_flags+=("--inactive-message=")
    flags+=("--invoice-creation.enabled=")
    two_word_flags+=("--invoice-creation.enabled")
    local_nonpersistent_flags+=("--invoice-creation.enabled")
    local_nonpersistent_flags+=("--invoice-creation.enabled=")
    flags+=("--invoice-creation.invoice-data.account-tax-ids=")
    two_word_flags+=("--invoice-creation.invoice-data.account-tax-ids")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.account-tax-ids")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.account-tax-ids=")
    flags+=("--invoice-creation.invoice-data.description=")
    two_word_flags+=("--invoice-creation.invoice-data.description")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.description")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.description=")
    flags+=("--invoice-creation.invoice-data.footer=")
    two_word_flags+=("--invoice-creation.invoice-data.footer")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.footer")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.footer=")
    flags+=("--invoice-creation.invoice-data.issuer.account=")
    two_word_flags+=("--invoice-creation.invoice-data.issuer.account")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.issuer.account")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.issuer.account=")
    flags+=("--invoice-creation.invoice-data.issuer.type=")
    two_word_flags+=("--invoice-creation.invoice-data.issuer.type")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.issuer.type")
    local_nonpersistent_flags+=("--invoice-creation.invoice-data.issuer.type=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-intent-data.description=")
    two_word_flags+=("--payment-intent-data.description")
    local_nonpersistent_flags+=("--payment-intent-data.description")
    local_nonpersistent_flags+=("--payment-intent-data.description=")
    flags+=("--payment-intent-data.statement-descriptor=")
    two_word_flags+=("--payment-intent-data.statement-descriptor")
    local_nonpersistent_flags+=("--payment-intent-data.statement-descriptor")
    local_nonpersistent_flags+=("--payment-intent-data.statement-descriptor=")
    flags+=("--payment-intent-data.statement-descriptor-suffix=")
    two_word_flags+=("--payment-intent-data.statement-descriptor-suffix")
    local_nonpersistent_flags+=("--payment-intent-data.statement-descriptor-suffix")
    local_nonpersistent_flags+=("--payment-intent-data.statement-descriptor-suffix=")
    flags+=("--payment-intent-data.transfer-group=")
    two_word_flags+=("--payment-intent-data.transfer-group")
    local_nonpersistent_flags+=("--payment-intent-data.transfer-group")
    local_nonpersistent_flags+=("--payment-intent-data.transfer-group=")
    flags+=("--payment-method-collection=")
    two_word_flags+=("--payment-method-collection")
    local_nonpersistent_flags+=("--payment-method-collection")
    local_nonpersistent_flags+=("--payment-method-collection=")
    flags+=("--payment-method-types=")
    two_word_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--subscription-data.invoice-settings.issuer.account=")
    two_word_flags+=("--subscription-data.invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--subscription-data.invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--subscription-data.invoice-settings.issuer.account=")
    flags+=("--subscription-data.invoice-settings.issuer.type=")
    two_word_flags+=("--subscription-data.invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--subscription-data.invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--subscription-data.invoice-settings.issuer.type=")
    flags+=("--tax-id-collection.enabled=")
    two_word_flags+=("--tax-id-collection.enabled")
    local_nonpersistent_flags+=("--tax-id-collection.enabled")
    local_nonpersistent_flags+=("--tax-id-collection.enabled=")
    flags+=("--tax-id-collection.required=")
    two_word_flags+=("--tax-id-collection.required")
    local_nonpersistent_flags+=("--tax-id-collection.required")
    local_nonpersistent_flags+=("--tax-id-collection.required=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_links()
{
    last_command="stripe_payment_links"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("list_line_items")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_method_configurations_create()
{
    last_command="stripe_payment_method_configurations_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--acss-debit.display-preference.preference=")
    two_word_flags+=("--acss-debit.display-preference.preference")
    local_nonpersistent_flags+=("--acss-debit.display-preference.preference")
    local_nonpersistent_flags+=("--acss-debit.display-preference.preference=")
    flags+=("--affirm.display-preference.preference=")
    two_word_flags+=("--affirm.display-preference.preference")
    local_nonpersistent_flags+=("--affirm.display-preference.preference")
    local_nonpersistent_flags+=("--affirm.display-preference.preference=")
    flags+=("--afterpay-clearpay.display-preference.preference=")
    two_word_flags+=("--afterpay-clearpay.display-preference.preference")
    local_nonpersistent_flags+=("--afterpay-clearpay.display-preference.preference")
    local_nonpersistent_flags+=("--afterpay-clearpay.display-preference.preference=")
    flags+=("--alipay.display-preference.preference=")
    two_word_flags+=("--alipay.display-preference.preference")
    local_nonpersistent_flags+=("--alipay.display-preference.preference")
    local_nonpersistent_flags+=("--alipay.display-preference.preference=")
    flags+=("--alma.display-preference.preference=")
    two_word_flags+=("--alma.display-preference.preference")
    local_nonpersistent_flags+=("--alma.display-preference.preference")
    local_nonpersistent_flags+=("--alma.display-preference.preference=")
    flags+=("--amazon-pay.display-preference.preference=")
    two_word_flags+=("--amazon-pay.display-preference.preference")
    local_nonpersistent_flags+=("--amazon-pay.display-preference.preference")
    local_nonpersistent_flags+=("--amazon-pay.display-preference.preference=")
    flags+=("--apple-pay-later.display-preference.preference=")
    two_word_flags+=("--apple-pay-later.display-preference.preference")
    local_nonpersistent_flags+=("--apple-pay-later.display-preference.preference")
    local_nonpersistent_flags+=("--apple-pay-later.display-preference.preference=")
    flags+=("--apple-pay.display-preference.preference=")
    two_word_flags+=("--apple-pay.display-preference.preference")
    local_nonpersistent_flags+=("--apple-pay.display-preference.preference")
    local_nonpersistent_flags+=("--apple-pay.display-preference.preference=")
    flags+=("--au-becs-debit.display-preference.preference=")
    two_word_flags+=("--au-becs-debit.display-preference.preference")
    local_nonpersistent_flags+=("--au-becs-debit.display-preference.preference")
    local_nonpersistent_flags+=("--au-becs-debit.display-preference.preference=")
    flags+=("--bacs-debit.display-preference.preference=")
    two_word_flags+=("--bacs-debit.display-preference.preference")
    local_nonpersistent_flags+=("--bacs-debit.display-preference.preference")
    local_nonpersistent_flags+=("--bacs-debit.display-preference.preference=")
    flags+=("--bancontact.display-preference.preference=")
    two_word_flags+=("--bancontact.display-preference.preference")
    local_nonpersistent_flags+=("--bancontact.display-preference.preference")
    local_nonpersistent_flags+=("--bancontact.display-preference.preference=")
    flags+=("--blik.display-preference.preference=")
    two_word_flags+=("--blik.display-preference.preference")
    local_nonpersistent_flags+=("--blik.display-preference.preference")
    local_nonpersistent_flags+=("--blik.display-preference.preference=")
    flags+=("--boleto.display-preference.preference=")
    two_word_flags+=("--boleto.display-preference.preference")
    local_nonpersistent_flags+=("--boleto.display-preference.preference")
    local_nonpersistent_flags+=("--boleto.display-preference.preference=")
    flags+=("--card.display-preference.preference=")
    two_word_flags+=("--card.display-preference.preference")
    local_nonpersistent_flags+=("--card.display-preference.preference")
    local_nonpersistent_flags+=("--card.display-preference.preference=")
    flags+=("--cartes-bancaires.display-preference.preference=")
    two_word_flags+=("--cartes-bancaires.display-preference.preference")
    local_nonpersistent_flags+=("--cartes-bancaires.display-preference.preference")
    local_nonpersistent_flags+=("--cartes-bancaires.display-preference.preference=")
    flags+=("--cashapp.display-preference.preference=")
    two_word_flags+=("--cashapp.display-preference.preference")
    local_nonpersistent_flags+=("--cashapp.display-preference.preference")
    local_nonpersistent_flags+=("--cashapp.display-preference.preference=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer-balance.display-preference.preference=")
    two_word_flags+=("--customer-balance.display-preference.preference")
    local_nonpersistent_flags+=("--customer-balance.display-preference.preference")
    local_nonpersistent_flags+=("--customer-balance.display-preference.preference=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--eps.display-preference.preference=")
    two_word_flags+=("--eps.display-preference.preference")
    local_nonpersistent_flags+=("--eps.display-preference.preference")
    local_nonpersistent_flags+=("--eps.display-preference.preference=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--fpx.display-preference.preference=")
    two_word_flags+=("--fpx.display-preference.preference")
    local_nonpersistent_flags+=("--fpx.display-preference.preference")
    local_nonpersistent_flags+=("--fpx.display-preference.preference=")
    flags+=("--giropay.display-preference.preference=")
    two_word_flags+=("--giropay.display-preference.preference")
    local_nonpersistent_flags+=("--giropay.display-preference.preference")
    local_nonpersistent_flags+=("--giropay.display-preference.preference=")
    flags+=("--google-pay.display-preference.preference=")
    two_word_flags+=("--google-pay.display-preference.preference")
    local_nonpersistent_flags+=("--google-pay.display-preference.preference")
    local_nonpersistent_flags+=("--google-pay.display-preference.preference=")
    flags+=("--grabpay.display-preference.preference=")
    two_word_flags+=("--grabpay.display-preference.preference")
    local_nonpersistent_flags+=("--grabpay.display-preference.preference")
    local_nonpersistent_flags+=("--grabpay.display-preference.preference=")
    flags+=("--ideal.display-preference.preference=")
    two_word_flags+=("--ideal.display-preference.preference")
    local_nonpersistent_flags+=("--ideal.display-preference.preference")
    local_nonpersistent_flags+=("--ideal.display-preference.preference=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--jcb.display-preference.preference=")
    two_word_flags+=("--jcb.display-preference.preference")
    local_nonpersistent_flags+=("--jcb.display-preference.preference")
    local_nonpersistent_flags+=("--jcb.display-preference.preference=")
    flags+=("--klarna.display-preference.preference=")
    two_word_flags+=("--klarna.display-preference.preference")
    local_nonpersistent_flags+=("--klarna.display-preference.preference")
    local_nonpersistent_flags+=("--klarna.display-preference.preference=")
    flags+=("--konbini.display-preference.preference=")
    two_word_flags+=("--konbini.display-preference.preference")
    local_nonpersistent_flags+=("--konbini.display-preference.preference")
    local_nonpersistent_flags+=("--konbini.display-preference.preference=")
    flags+=("--link.display-preference.preference=")
    two_word_flags+=("--link.display-preference.preference")
    local_nonpersistent_flags+=("--link.display-preference.preference")
    local_nonpersistent_flags+=("--link.display-preference.preference=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--mobilepay.display-preference.preference=")
    two_word_flags+=("--mobilepay.display-preference.preference")
    local_nonpersistent_flags+=("--mobilepay.display-preference.preference")
    local_nonpersistent_flags+=("--mobilepay.display-preference.preference=")
    flags+=("--multibanco.display-preference.preference=")
    two_word_flags+=("--multibanco.display-preference.preference")
    local_nonpersistent_flags+=("--multibanco.display-preference.preference")
    local_nonpersistent_flags+=("--multibanco.display-preference.preference=")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--oxxo.display-preference.preference=")
    two_word_flags+=("--oxxo.display-preference.preference")
    local_nonpersistent_flags+=("--oxxo.display-preference.preference")
    local_nonpersistent_flags+=("--oxxo.display-preference.preference=")
    flags+=("--p24.display-preference.preference=")
    two_word_flags+=("--p24.display-preference.preference")
    local_nonpersistent_flags+=("--p24.display-preference.preference")
    local_nonpersistent_flags+=("--p24.display-preference.preference=")
    flags+=("--parent=")
    two_word_flags+=("--parent")
    local_nonpersistent_flags+=("--parent")
    local_nonpersistent_flags+=("--parent=")
    flags+=("--paynow.display-preference.preference=")
    two_word_flags+=("--paynow.display-preference.preference")
    local_nonpersistent_flags+=("--paynow.display-preference.preference")
    local_nonpersistent_flags+=("--paynow.display-preference.preference=")
    flags+=("--paypal.display-preference.preference=")
    two_word_flags+=("--paypal.display-preference.preference")
    local_nonpersistent_flags+=("--paypal.display-preference.preference")
    local_nonpersistent_flags+=("--paypal.display-preference.preference=")
    flags+=("--promptpay.display-preference.preference=")
    two_word_flags+=("--promptpay.display-preference.preference")
    local_nonpersistent_flags+=("--promptpay.display-preference.preference")
    local_nonpersistent_flags+=("--promptpay.display-preference.preference=")
    flags+=("--revolut-pay.display-preference.preference=")
    two_word_flags+=("--revolut-pay.display-preference.preference")
    local_nonpersistent_flags+=("--revolut-pay.display-preference.preference")
    local_nonpersistent_flags+=("--revolut-pay.display-preference.preference=")
    flags+=("--sepa-debit.display-preference.preference=")
    two_word_flags+=("--sepa-debit.display-preference.preference")
    local_nonpersistent_flags+=("--sepa-debit.display-preference.preference")
    local_nonpersistent_flags+=("--sepa-debit.display-preference.preference=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--sofort.display-preference.preference=")
    two_word_flags+=("--sofort.display-preference.preference")
    local_nonpersistent_flags+=("--sofort.display-preference.preference")
    local_nonpersistent_flags+=("--sofort.display-preference.preference=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--swish.display-preference.preference=")
    two_word_flags+=("--swish.display-preference.preference")
    local_nonpersistent_flags+=("--swish.display-preference.preference")
    local_nonpersistent_flags+=("--swish.display-preference.preference=")
    flags+=("--twint.display-preference.preference=")
    two_word_flags+=("--twint.display-preference.preference")
    local_nonpersistent_flags+=("--twint.display-preference.preference")
    local_nonpersistent_flags+=("--twint.display-preference.preference=")
    flags+=("--us-bank-account.display-preference.preference=")
    two_word_flags+=("--us-bank-account.display-preference.preference")
    local_nonpersistent_flags+=("--us-bank-account.display-preference.preference")
    local_nonpersistent_flags+=("--us-bank-account.display-preference.preference=")
    flags+=("--wechat-pay.display-preference.preference=")
    two_word_flags+=("--wechat-pay.display-preference.preference")
    local_nonpersistent_flags+=("--wechat-pay.display-preference.preference")
    local_nonpersistent_flags+=("--wechat-pay.display-preference.preference=")
    flags+=("--zip.display-preference.preference=")
    two_word_flags+=("--zip.display-preference.preference")
    local_nonpersistent_flags+=("--zip.display-preference.preference")
    local_nonpersistent_flags+=("--zip.display-preference.preference=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_method_configurations_list()
{
    last_command="stripe_payment_method_configurations_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--application=")
    two_word_flags+=("--application")
    local_nonpersistent_flags+=("--application")
    local_nonpersistent_flags+=("--application=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_method_configurations_retrieve()
{
    last_command="stripe_payment_method_configurations_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_method_configurations_update()
{
    last_command="stripe_payment_method_configurations_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--acss-debit.display-preference.preference=")
    two_word_flags+=("--acss-debit.display-preference.preference")
    local_nonpersistent_flags+=("--acss-debit.display-preference.preference")
    local_nonpersistent_flags+=("--acss-debit.display-preference.preference=")
    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--affirm.display-preference.preference=")
    two_word_flags+=("--affirm.display-preference.preference")
    local_nonpersistent_flags+=("--affirm.display-preference.preference")
    local_nonpersistent_flags+=("--affirm.display-preference.preference=")
    flags+=("--afterpay-clearpay.display-preference.preference=")
    two_word_flags+=("--afterpay-clearpay.display-preference.preference")
    local_nonpersistent_flags+=("--afterpay-clearpay.display-preference.preference")
    local_nonpersistent_flags+=("--afterpay-clearpay.display-preference.preference=")
    flags+=("--alipay.display-preference.preference=")
    two_word_flags+=("--alipay.display-preference.preference")
    local_nonpersistent_flags+=("--alipay.display-preference.preference")
    local_nonpersistent_flags+=("--alipay.display-preference.preference=")
    flags+=("--alma.display-preference.preference=")
    two_word_flags+=("--alma.display-preference.preference")
    local_nonpersistent_flags+=("--alma.display-preference.preference")
    local_nonpersistent_flags+=("--alma.display-preference.preference=")
    flags+=("--amazon-pay.display-preference.preference=")
    two_word_flags+=("--amazon-pay.display-preference.preference")
    local_nonpersistent_flags+=("--amazon-pay.display-preference.preference")
    local_nonpersistent_flags+=("--amazon-pay.display-preference.preference=")
    flags+=("--apple-pay-later.display-preference.preference=")
    two_word_flags+=("--apple-pay-later.display-preference.preference")
    local_nonpersistent_flags+=("--apple-pay-later.display-preference.preference")
    local_nonpersistent_flags+=("--apple-pay-later.display-preference.preference=")
    flags+=("--apple-pay.display-preference.preference=")
    two_word_flags+=("--apple-pay.display-preference.preference")
    local_nonpersistent_flags+=("--apple-pay.display-preference.preference")
    local_nonpersistent_flags+=("--apple-pay.display-preference.preference=")
    flags+=("--au-becs-debit.display-preference.preference=")
    two_word_flags+=("--au-becs-debit.display-preference.preference")
    local_nonpersistent_flags+=("--au-becs-debit.display-preference.preference")
    local_nonpersistent_flags+=("--au-becs-debit.display-preference.preference=")
    flags+=("--bacs-debit.display-preference.preference=")
    two_word_flags+=("--bacs-debit.display-preference.preference")
    local_nonpersistent_flags+=("--bacs-debit.display-preference.preference")
    local_nonpersistent_flags+=("--bacs-debit.display-preference.preference=")
    flags+=("--bancontact.display-preference.preference=")
    two_word_flags+=("--bancontact.display-preference.preference")
    local_nonpersistent_flags+=("--bancontact.display-preference.preference")
    local_nonpersistent_flags+=("--bancontact.display-preference.preference=")
    flags+=("--blik.display-preference.preference=")
    two_word_flags+=("--blik.display-preference.preference")
    local_nonpersistent_flags+=("--blik.display-preference.preference")
    local_nonpersistent_flags+=("--blik.display-preference.preference=")
    flags+=("--boleto.display-preference.preference=")
    two_word_flags+=("--boleto.display-preference.preference")
    local_nonpersistent_flags+=("--boleto.display-preference.preference")
    local_nonpersistent_flags+=("--boleto.display-preference.preference=")
    flags+=("--card.display-preference.preference=")
    two_word_flags+=("--card.display-preference.preference")
    local_nonpersistent_flags+=("--card.display-preference.preference")
    local_nonpersistent_flags+=("--card.display-preference.preference=")
    flags+=("--cartes-bancaires.display-preference.preference=")
    two_word_flags+=("--cartes-bancaires.display-preference.preference")
    local_nonpersistent_flags+=("--cartes-bancaires.display-preference.preference")
    local_nonpersistent_flags+=("--cartes-bancaires.display-preference.preference=")
    flags+=("--cashapp.display-preference.preference=")
    two_word_flags+=("--cashapp.display-preference.preference")
    local_nonpersistent_flags+=("--cashapp.display-preference.preference")
    local_nonpersistent_flags+=("--cashapp.display-preference.preference=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer-balance.display-preference.preference=")
    two_word_flags+=("--customer-balance.display-preference.preference")
    local_nonpersistent_flags+=("--customer-balance.display-preference.preference")
    local_nonpersistent_flags+=("--customer-balance.display-preference.preference=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--eps.display-preference.preference=")
    two_word_flags+=("--eps.display-preference.preference")
    local_nonpersistent_flags+=("--eps.display-preference.preference")
    local_nonpersistent_flags+=("--eps.display-preference.preference=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--fpx.display-preference.preference=")
    two_word_flags+=("--fpx.display-preference.preference")
    local_nonpersistent_flags+=("--fpx.display-preference.preference")
    local_nonpersistent_flags+=("--fpx.display-preference.preference=")
    flags+=("--giropay.display-preference.preference=")
    two_word_flags+=("--giropay.display-preference.preference")
    local_nonpersistent_flags+=("--giropay.display-preference.preference")
    local_nonpersistent_flags+=("--giropay.display-preference.preference=")
    flags+=("--google-pay.display-preference.preference=")
    two_word_flags+=("--google-pay.display-preference.preference")
    local_nonpersistent_flags+=("--google-pay.display-preference.preference")
    local_nonpersistent_flags+=("--google-pay.display-preference.preference=")
    flags+=("--grabpay.display-preference.preference=")
    two_word_flags+=("--grabpay.display-preference.preference")
    local_nonpersistent_flags+=("--grabpay.display-preference.preference")
    local_nonpersistent_flags+=("--grabpay.display-preference.preference=")
    flags+=("--ideal.display-preference.preference=")
    two_word_flags+=("--ideal.display-preference.preference")
    local_nonpersistent_flags+=("--ideal.display-preference.preference")
    local_nonpersistent_flags+=("--ideal.display-preference.preference=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--jcb.display-preference.preference=")
    two_word_flags+=("--jcb.display-preference.preference")
    local_nonpersistent_flags+=("--jcb.display-preference.preference")
    local_nonpersistent_flags+=("--jcb.display-preference.preference=")
    flags+=("--klarna.display-preference.preference=")
    two_word_flags+=("--klarna.display-preference.preference")
    local_nonpersistent_flags+=("--klarna.display-preference.preference")
    local_nonpersistent_flags+=("--klarna.display-preference.preference=")
    flags+=("--konbini.display-preference.preference=")
    two_word_flags+=("--konbini.display-preference.preference")
    local_nonpersistent_flags+=("--konbini.display-preference.preference")
    local_nonpersistent_flags+=("--konbini.display-preference.preference=")
    flags+=("--link.display-preference.preference=")
    two_word_flags+=("--link.display-preference.preference")
    local_nonpersistent_flags+=("--link.display-preference.preference")
    local_nonpersistent_flags+=("--link.display-preference.preference=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--mobilepay.display-preference.preference=")
    two_word_flags+=("--mobilepay.display-preference.preference")
    local_nonpersistent_flags+=("--mobilepay.display-preference.preference")
    local_nonpersistent_flags+=("--mobilepay.display-preference.preference=")
    flags+=("--multibanco.display-preference.preference=")
    two_word_flags+=("--multibanco.display-preference.preference")
    local_nonpersistent_flags+=("--multibanco.display-preference.preference")
    local_nonpersistent_flags+=("--multibanco.display-preference.preference=")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--oxxo.display-preference.preference=")
    two_word_flags+=("--oxxo.display-preference.preference")
    local_nonpersistent_flags+=("--oxxo.display-preference.preference")
    local_nonpersistent_flags+=("--oxxo.display-preference.preference=")
    flags+=("--p24.display-preference.preference=")
    two_word_flags+=("--p24.display-preference.preference")
    local_nonpersistent_flags+=("--p24.display-preference.preference")
    local_nonpersistent_flags+=("--p24.display-preference.preference=")
    flags+=("--paynow.display-preference.preference=")
    two_word_flags+=("--paynow.display-preference.preference")
    local_nonpersistent_flags+=("--paynow.display-preference.preference")
    local_nonpersistent_flags+=("--paynow.display-preference.preference=")
    flags+=("--paypal.display-preference.preference=")
    two_word_flags+=("--paypal.display-preference.preference")
    local_nonpersistent_flags+=("--paypal.display-preference.preference")
    local_nonpersistent_flags+=("--paypal.display-preference.preference=")
    flags+=("--promptpay.display-preference.preference=")
    two_word_flags+=("--promptpay.display-preference.preference")
    local_nonpersistent_flags+=("--promptpay.display-preference.preference")
    local_nonpersistent_flags+=("--promptpay.display-preference.preference=")
    flags+=("--revolut-pay.display-preference.preference=")
    two_word_flags+=("--revolut-pay.display-preference.preference")
    local_nonpersistent_flags+=("--revolut-pay.display-preference.preference")
    local_nonpersistent_flags+=("--revolut-pay.display-preference.preference=")
    flags+=("--sepa-debit.display-preference.preference=")
    two_word_flags+=("--sepa-debit.display-preference.preference")
    local_nonpersistent_flags+=("--sepa-debit.display-preference.preference")
    local_nonpersistent_flags+=("--sepa-debit.display-preference.preference=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--sofort.display-preference.preference=")
    two_word_flags+=("--sofort.display-preference.preference")
    local_nonpersistent_flags+=("--sofort.display-preference.preference")
    local_nonpersistent_flags+=("--sofort.display-preference.preference=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--swish.display-preference.preference=")
    two_word_flags+=("--swish.display-preference.preference")
    local_nonpersistent_flags+=("--swish.display-preference.preference")
    local_nonpersistent_flags+=("--swish.display-preference.preference=")
    flags+=("--twint.display-preference.preference=")
    two_word_flags+=("--twint.display-preference.preference")
    local_nonpersistent_flags+=("--twint.display-preference.preference")
    local_nonpersistent_flags+=("--twint.display-preference.preference=")
    flags+=("--us-bank-account.display-preference.preference=")
    two_word_flags+=("--us-bank-account.display-preference.preference")
    local_nonpersistent_flags+=("--us-bank-account.display-preference.preference")
    local_nonpersistent_flags+=("--us-bank-account.display-preference.preference=")
    flags+=("--wechat-pay.display-preference.preference=")
    two_word_flags+=("--wechat-pay.display-preference.preference")
    local_nonpersistent_flags+=("--wechat-pay.display-preference.preference")
    local_nonpersistent_flags+=("--wechat-pay.display-preference.preference=")
    flags+=("--zip.display-preference.preference=")
    two_word_flags+=("--zip.display-preference.preference")
    local_nonpersistent_flags+=("--zip.display-preference.preference")
    local_nonpersistent_flags+=("--zip.display-preference.preference=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_method_configurations()
{
    last_command="stripe_payment_method_configurations"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_method_domains_create()
{
    last_command="stripe_payment_method_domains_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--domain-name=")
    two_word_flags+=("--domain-name")
    local_nonpersistent_flags+=("--domain-name")
    local_nonpersistent_flags+=("--domain-name=")
    flags+=("--enabled=")
    two_word_flags+=("--enabled")
    local_nonpersistent_flags+=("--enabled")
    local_nonpersistent_flags+=("--enabled=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_method_domains_list()
{
    last_command="stripe_payment_method_domains_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--domain-name=")
    two_word_flags+=("--domain-name")
    local_nonpersistent_flags+=("--domain-name")
    local_nonpersistent_flags+=("--domain-name=")
    flags+=("--enabled=")
    two_word_flags+=("--enabled")
    local_nonpersistent_flags+=("--enabled")
    local_nonpersistent_flags+=("--enabled=")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_method_domains_retrieve()
{
    last_command="stripe_payment_method_domains_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_method_domains_update()
{
    last_command="stripe_payment_method_domains_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--enabled=")
    two_word_flags+=("--enabled")
    local_nonpersistent_flags+=("--enabled")
    local_nonpersistent_flags+=("--enabled=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_method_domains_validate()
{
    last_command="stripe_payment_method_domains_validate"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_method_domains()
{
    last_command="stripe_payment_method_domains"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")
    commands+=("validate")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_methods_attach()
{
    last_command="stripe_payment_methods_attach"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_methods_create()
{
    last_command="stripe_payment_methods_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--acss-debit.account-number=")
    two_word_flags+=("--acss-debit.account-number")
    local_nonpersistent_flags+=("--acss-debit.account-number")
    local_nonpersistent_flags+=("--acss-debit.account-number=")
    flags+=("--acss-debit.institution-number=")
    two_word_flags+=("--acss-debit.institution-number")
    local_nonpersistent_flags+=("--acss-debit.institution-number")
    local_nonpersistent_flags+=("--acss-debit.institution-number=")
    flags+=("--acss-debit.transit-number=")
    two_word_flags+=("--acss-debit.transit-number")
    local_nonpersistent_flags+=("--acss-debit.transit-number")
    local_nonpersistent_flags+=("--acss-debit.transit-number=")
    flags+=("--allow-redisplay=")
    two_word_flags+=("--allow-redisplay")
    local_nonpersistent_flags+=("--allow-redisplay")
    local_nonpersistent_flags+=("--allow-redisplay=")
    flags+=("--au-becs-debit.account-number=")
    two_word_flags+=("--au-becs-debit.account-number")
    local_nonpersistent_flags+=("--au-becs-debit.account-number")
    local_nonpersistent_flags+=("--au-becs-debit.account-number=")
    flags+=("--au-becs-debit.bsb-number=")
    two_word_flags+=("--au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--au-becs-debit.bsb-number=")
    flags+=("--bacs-debit.account-number=")
    two_word_flags+=("--bacs-debit.account-number")
    local_nonpersistent_flags+=("--bacs-debit.account-number")
    local_nonpersistent_flags+=("--bacs-debit.account-number=")
    flags+=("--bacs-debit.sort-code=")
    two_word_flags+=("--bacs-debit.sort-code")
    local_nonpersistent_flags+=("--bacs-debit.sort-code")
    local_nonpersistent_flags+=("--bacs-debit.sort-code=")
    flags+=("--billing-details.email=")
    two_word_flags+=("--billing-details.email")
    local_nonpersistent_flags+=("--billing-details.email")
    local_nonpersistent_flags+=("--billing-details.email=")
    flags+=("--billing-details.name=")
    two_word_flags+=("--billing-details.name")
    local_nonpersistent_flags+=("--billing-details.name")
    local_nonpersistent_flags+=("--billing-details.name=")
    flags+=("--billing-details.phone=")
    two_word_flags+=("--billing-details.phone")
    local_nonpersistent_flags+=("--billing-details.phone")
    local_nonpersistent_flags+=("--billing-details.phone=")
    flags+=("--boleto.tax-id=")
    two_word_flags+=("--boleto.tax-id")
    local_nonpersistent_flags+=("--boleto.tax-id")
    local_nonpersistent_flags+=("--boleto.tax-id=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--eps.bank=")
    two_word_flags+=("--eps.bank")
    local_nonpersistent_flags+=("--eps.bank")
    local_nonpersistent_flags+=("--eps.bank=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--fpx.account-holder-type=")
    two_word_flags+=("--fpx.account-holder-type")
    local_nonpersistent_flags+=("--fpx.account-holder-type")
    local_nonpersistent_flags+=("--fpx.account-holder-type=")
    flags+=("--fpx.bank=")
    two_word_flags+=("--fpx.bank")
    local_nonpersistent_flags+=("--fpx.bank")
    local_nonpersistent_flags+=("--fpx.bank=")
    flags+=("--ideal.bank=")
    two_word_flags+=("--ideal.bank")
    local_nonpersistent_flags+=("--ideal.bank")
    local_nonpersistent_flags+=("--ideal.bank=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--klarna.dob.day=")
    two_word_flags+=("--klarna.dob.day")
    local_nonpersistent_flags+=("--klarna.dob.day")
    local_nonpersistent_flags+=("--klarna.dob.day=")
    flags+=("--klarna.dob.month=")
    two_word_flags+=("--klarna.dob.month")
    local_nonpersistent_flags+=("--klarna.dob.month")
    local_nonpersistent_flags+=("--klarna.dob.month=")
    flags+=("--klarna.dob.year=")
    two_word_flags+=("--klarna.dob.year")
    local_nonpersistent_flags+=("--klarna.dob.year")
    local_nonpersistent_flags+=("--klarna.dob.year=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--naver-pay.funding=")
    two_word_flags+=("--naver-pay.funding")
    local_nonpersistent_flags+=("--naver-pay.funding")
    local_nonpersistent_flags+=("--naver-pay.funding=")
    flags+=("--p24.bank=")
    two_word_flags+=("--p24.bank")
    local_nonpersistent_flags+=("--p24.bank")
    local_nonpersistent_flags+=("--p24.bank=")
    flags+=("--payment-method=")
    two_word_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method=")
    flags+=("--radar-options.session=")
    two_word_flags+=("--radar-options.session")
    local_nonpersistent_flags+=("--radar-options.session")
    local_nonpersistent_flags+=("--radar-options.session=")
    flags+=("--sepa-debit.iban=")
    two_word_flags+=("--sepa-debit.iban")
    local_nonpersistent_flags+=("--sepa-debit.iban")
    local_nonpersistent_flags+=("--sepa-debit.iban=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--sofort.country=")
    two_word_flags+=("--sofort.country")
    local_nonpersistent_flags+=("--sofort.country")
    local_nonpersistent_flags+=("--sofort.country=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--us-bank-account.account-holder-type=")
    two_word_flags+=("--us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--us-bank-account.account-holder-type=")
    flags+=("--us-bank-account.account-number=")
    two_word_flags+=("--us-bank-account.account-number")
    local_nonpersistent_flags+=("--us-bank-account.account-number")
    local_nonpersistent_flags+=("--us-bank-account.account-number=")
    flags+=("--us-bank-account.account-type=")
    two_word_flags+=("--us-bank-account.account-type")
    local_nonpersistent_flags+=("--us-bank-account.account-type")
    local_nonpersistent_flags+=("--us-bank-account.account-type=")
    flags+=("--us-bank-account.financial-connections-account=")
    two_word_flags+=("--us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--us-bank-account.financial-connections-account=")
    flags+=("--us-bank-account.routing-number=")
    two_word_flags+=("--us-bank-account.routing-number")
    local_nonpersistent_flags+=("--us-bank-account.routing-number")
    local_nonpersistent_flags+=("--us-bank-account.routing-number=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_methods_detach()
{
    last_command="stripe_payment_methods_detach"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_methods_list()
{
    last_command="stripe_payment_methods_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_methods_retrieve()
{
    last_command="stripe_payment_methods_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_methods_update()
{
    last_command="stripe_payment_methods_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--allow-redisplay=")
    two_word_flags+=("--allow-redisplay")
    local_nonpersistent_flags+=("--allow-redisplay")
    local_nonpersistent_flags+=("--allow-redisplay=")
    flags+=("--billing-details.email=")
    two_word_flags+=("--billing-details.email")
    local_nonpersistent_flags+=("--billing-details.email")
    local_nonpersistent_flags+=("--billing-details.email=")
    flags+=("--billing-details.name=")
    two_word_flags+=("--billing-details.name")
    local_nonpersistent_flags+=("--billing-details.name")
    local_nonpersistent_flags+=("--billing-details.name=")
    flags+=("--billing-details.phone=")
    two_word_flags+=("--billing-details.phone")
    local_nonpersistent_flags+=("--billing-details.phone")
    local_nonpersistent_flags+=("--billing-details.phone=")
    flags+=("--card.exp-month=")
    two_word_flags+=("--card.exp-month")
    local_nonpersistent_flags+=("--card.exp-month")
    local_nonpersistent_flags+=("--card.exp-month=")
    flags+=("--card.exp-year=")
    two_word_flags+=("--card.exp-year")
    local_nonpersistent_flags+=("--card.exp-year")
    local_nonpersistent_flags+=("--card.exp-year=")
    flags+=("--card.networks.preferred=")
    two_word_flags+=("--card.networks.preferred")
    local_nonpersistent_flags+=("--card.networks.preferred")
    local_nonpersistent_flags+=("--card.networks.preferred=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--naver-pay.funding=")
    two_word_flags+=("--naver-pay.funding")
    local_nonpersistent_flags+=("--naver-pay.funding")
    local_nonpersistent_flags+=("--naver-pay.funding=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--us-bank-account.account-holder-type=")
    two_word_flags+=("--us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--us-bank-account.account-holder-type=")
    flags+=("--us-bank-account.account-type=")
    two_word_flags+=("--us-bank-account.account-type")
    local_nonpersistent_flags+=("--us-bank-account.account-type")
    local_nonpersistent_flags+=("--us-bank-account.account-type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_methods()
{
    last_command="stripe_payment_methods"

    command_aliases=()

    commands=()
    commands+=("attach")
    commands+=("create")
    commands+=("detach")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_sources_create()
{
    last_command="stripe_payment_sources_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--source=")
    two_word_flags+=("--source")
    local_nonpersistent_flags+=("--source")
    local_nonpersistent_flags+=("--source=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--validate=")
    two_word_flags+=("--validate")
    local_nonpersistent_flags+=("--validate")
    local_nonpersistent_flags+=("--validate=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_sources_list()
{
    last_command="stripe_payment_sources_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--object=")
    two_word_flags+=("--object")
    local_nonpersistent_flags+=("--object")
    local_nonpersistent_flags+=("--object=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_sources_retrieve()
{
    last_command="stripe_payment_sources_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payment_sources()
{
    last_command="stripe_payment_sources"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payouts_cancel()
{
    last_command="stripe_payouts_cancel"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payouts_create()
{
    last_command="stripe_payouts_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--destination=")
    two_word_flags+=("--destination")
    local_nonpersistent_flags+=("--destination")
    local_nonpersistent_flags+=("--destination=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--method=")
    two_word_flags+=("--method")
    local_nonpersistent_flags+=("--method")
    local_nonpersistent_flags+=("--method=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--source-type=")
    two_word_flags+=("--source-type")
    local_nonpersistent_flags+=("--source-type")
    local_nonpersistent_flags+=("--source-type=")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payouts_list()
{
    last_command="stripe_payouts_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--arrival-date=")
    two_word_flags+=("--arrival-date")
    local_nonpersistent_flags+=("--arrival-date")
    local_nonpersistent_flags+=("--arrival-date=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--destination=")
    two_word_flags+=("--destination")
    local_nonpersistent_flags+=("--destination")
    local_nonpersistent_flags+=("--destination=")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payouts_retrieve()
{
    last_command="stripe_payouts_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payouts_reverse()
{
    last_command="stripe_payouts_reverse"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payouts_update()
{
    last_command="stripe_payouts_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_payouts()
{
    last_command="stripe_payouts"

    command_aliases=()

    commands=()
    commands+=("cancel")
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("reverse")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_persons_create()
{
    last_command="stripe_persons_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--additional-tos-acceptances.account.date=")
    two_word_flags+=("--additional-tos-acceptances.account.date")
    local_nonpersistent_flags+=("--additional-tos-acceptances.account.date")
    local_nonpersistent_flags+=("--additional-tos-acceptances.account.date=")
    flags+=("--additional-tos-acceptances.account.ip=")
    two_word_flags+=("--additional-tos-acceptances.account.ip")
    local_nonpersistent_flags+=("--additional-tos-acceptances.account.ip")
    local_nonpersistent_flags+=("--additional-tos-acceptances.account.ip=")
    flags+=("--additional-tos-acceptances.account.user-agent=")
    two_word_flags+=("--additional-tos-acceptances.account.user-agent")
    local_nonpersistent_flags+=("--additional-tos-acceptances.account.user-agent")
    local_nonpersistent_flags+=("--additional-tos-acceptances.account.user-agent=")
    flags+=("--address-kana.city=")
    two_word_flags+=("--address-kana.city")
    local_nonpersistent_flags+=("--address-kana.city")
    local_nonpersistent_flags+=("--address-kana.city=")
    flags+=("--address-kana.country=")
    two_word_flags+=("--address-kana.country")
    local_nonpersistent_flags+=("--address-kana.country")
    local_nonpersistent_flags+=("--address-kana.country=")
    flags+=("--address-kana.line1=")
    two_word_flags+=("--address-kana.line1")
    local_nonpersistent_flags+=("--address-kana.line1")
    local_nonpersistent_flags+=("--address-kana.line1=")
    flags+=("--address-kana.line2=")
    two_word_flags+=("--address-kana.line2")
    local_nonpersistent_flags+=("--address-kana.line2")
    local_nonpersistent_flags+=("--address-kana.line2=")
    flags+=("--address-kana.postal-code=")
    two_word_flags+=("--address-kana.postal-code")
    local_nonpersistent_flags+=("--address-kana.postal-code")
    local_nonpersistent_flags+=("--address-kana.postal-code=")
    flags+=("--address-kana.state=")
    two_word_flags+=("--address-kana.state")
    local_nonpersistent_flags+=("--address-kana.state")
    local_nonpersistent_flags+=("--address-kana.state=")
    flags+=("--address-kana.town=")
    two_word_flags+=("--address-kana.town")
    local_nonpersistent_flags+=("--address-kana.town")
    local_nonpersistent_flags+=("--address-kana.town=")
    flags+=("--address-kanji.city=")
    two_word_flags+=("--address-kanji.city")
    local_nonpersistent_flags+=("--address-kanji.city")
    local_nonpersistent_flags+=("--address-kanji.city=")
    flags+=("--address-kanji.country=")
    two_word_flags+=("--address-kanji.country")
    local_nonpersistent_flags+=("--address-kanji.country")
    local_nonpersistent_flags+=("--address-kanji.country=")
    flags+=("--address-kanji.line1=")
    two_word_flags+=("--address-kanji.line1")
    local_nonpersistent_flags+=("--address-kanji.line1")
    local_nonpersistent_flags+=("--address-kanji.line1=")
    flags+=("--address-kanji.line2=")
    two_word_flags+=("--address-kanji.line2")
    local_nonpersistent_flags+=("--address-kanji.line2")
    local_nonpersistent_flags+=("--address-kanji.line2=")
    flags+=("--address-kanji.postal-code=")
    two_word_flags+=("--address-kanji.postal-code")
    local_nonpersistent_flags+=("--address-kanji.postal-code")
    local_nonpersistent_flags+=("--address-kanji.postal-code=")
    flags+=("--address-kanji.state=")
    two_word_flags+=("--address-kanji.state")
    local_nonpersistent_flags+=("--address-kanji.state")
    local_nonpersistent_flags+=("--address-kanji.state=")
    flags+=("--address-kanji.town=")
    two_word_flags+=("--address-kanji.town")
    local_nonpersistent_flags+=("--address-kanji.town")
    local_nonpersistent_flags+=("--address-kanji.town=")
    flags+=("--address.city=")
    two_word_flags+=("--address.city")
    local_nonpersistent_flags+=("--address.city")
    local_nonpersistent_flags+=("--address.city=")
    flags+=("--address.country=")
    two_word_flags+=("--address.country")
    local_nonpersistent_flags+=("--address.country")
    local_nonpersistent_flags+=("--address.country=")
    flags+=("--address.line1=")
    two_word_flags+=("--address.line1")
    local_nonpersistent_flags+=("--address.line1")
    local_nonpersistent_flags+=("--address.line1=")
    flags+=("--address.line2=")
    two_word_flags+=("--address.line2")
    local_nonpersistent_flags+=("--address.line2")
    local_nonpersistent_flags+=("--address.line2=")
    flags+=("--address.postal-code=")
    two_word_flags+=("--address.postal-code")
    local_nonpersistent_flags+=("--address.postal-code")
    local_nonpersistent_flags+=("--address.postal-code=")
    flags+=("--address.state=")
    two_word_flags+=("--address.state")
    local_nonpersistent_flags+=("--address.state")
    local_nonpersistent_flags+=("--address.state=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--documents.company-authorization.files=")
    two_word_flags+=("--documents.company-authorization.files")
    local_nonpersistent_flags+=("--documents.company-authorization.files")
    local_nonpersistent_flags+=("--documents.company-authorization.files=")
    flags+=("--documents.passport.files=")
    two_word_flags+=("--documents.passport.files")
    local_nonpersistent_flags+=("--documents.passport.files")
    local_nonpersistent_flags+=("--documents.passport.files=")
    flags+=("--documents.visa.files=")
    two_word_flags+=("--documents.visa.files")
    local_nonpersistent_flags+=("--documents.visa.files")
    local_nonpersistent_flags+=("--documents.visa.files=")
    flags+=("--email=")
    two_word_flags+=("--email")
    local_nonpersistent_flags+=("--email")
    local_nonpersistent_flags+=("--email=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--first-name=")
    two_word_flags+=("--first-name")
    local_nonpersistent_flags+=("--first-name")
    local_nonpersistent_flags+=("--first-name=")
    flags+=("--first-name-kana=")
    two_word_flags+=("--first-name-kana")
    local_nonpersistent_flags+=("--first-name-kana")
    local_nonpersistent_flags+=("--first-name-kana=")
    flags+=("--first-name-kanji=")
    two_word_flags+=("--first-name-kanji")
    local_nonpersistent_flags+=("--first-name-kanji")
    local_nonpersistent_flags+=("--first-name-kanji=")
    flags+=("--full-name-aliases=")
    two_word_flags+=("--full-name-aliases")
    local_nonpersistent_flags+=("--full-name-aliases")
    local_nonpersistent_flags+=("--full-name-aliases=")
    flags+=("--gender=")
    two_word_flags+=("--gender")
    local_nonpersistent_flags+=("--gender")
    local_nonpersistent_flags+=("--gender=")
    flags+=("--id-number=")
    two_word_flags+=("--id-number")
    local_nonpersistent_flags+=("--id-number")
    local_nonpersistent_flags+=("--id-number=")
    flags+=("--id-number-secondary=")
    two_word_flags+=("--id-number-secondary")
    local_nonpersistent_flags+=("--id-number-secondary")
    local_nonpersistent_flags+=("--id-number-secondary=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--last-name=")
    two_word_flags+=("--last-name")
    local_nonpersistent_flags+=("--last-name")
    local_nonpersistent_flags+=("--last-name=")
    flags+=("--last-name-kana=")
    two_word_flags+=("--last-name-kana")
    local_nonpersistent_flags+=("--last-name-kana")
    local_nonpersistent_flags+=("--last-name-kana=")
    flags+=("--last-name-kanji=")
    two_word_flags+=("--last-name-kanji")
    local_nonpersistent_flags+=("--last-name-kanji")
    local_nonpersistent_flags+=("--last-name-kanji=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--maiden-name=")
    two_word_flags+=("--maiden-name")
    local_nonpersistent_flags+=("--maiden-name")
    local_nonpersistent_flags+=("--maiden-name=")
    flags+=("--nationality=")
    two_word_flags+=("--nationality")
    local_nonpersistent_flags+=("--nationality")
    local_nonpersistent_flags+=("--nationality=")
    flags+=("--person-token=")
    two_word_flags+=("--person-token")
    local_nonpersistent_flags+=("--person-token")
    local_nonpersistent_flags+=("--person-token=")
    flags+=("--phone=")
    two_word_flags+=("--phone")
    local_nonpersistent_flags+=("--phone")
    local_nonpersistent_flags+=("--phone=")
    flags+=("--political-exposure=")
    two_word_flags+=("--political-exposure")
    local_nonpersistent_flags+=("--political-exposure")
    local_nonpersistent_flags+=("--political-exposure=")
    flags+=("--registered-address.city=")
    two_word_flags+=("--registered-address.city")
    local_nonpersistent_flags+=("--registered-address.city")
    local_nonpersistent_flags+=("--registered-address.city=")
    flags+=("--registered-address.country=")
    two_word_flags+=("--registered-address.country")
    local_nonpersistent_flags+=("--registered-address.country")
    local_nonpersistent_flags+=("--registered-address.country=")
    flags+=("--registered-address.line1=")
    two_word_flags+=("--registered-address.line1")
    local_nonpersistent_flags+=("--registered-address.line1")
    local_nonpersistent_flags+=("--registered-address.line1=")
    flags+=("--registered-address.line2=")
    two_word_flags+=("--registered-address.line2")
    local_nonpersistent_flags+=("--registered-address.line2")
    local_nonpersistent_flags+=("--registered-address.line2=")
    flags+=("--registered-address.postal-code=")
    two_word_flags+=("--registered-address.postal-code")
    local_nonpersistent_flags+=("--registered-address.postal-code")
    local_nonpersistent_flags+=("--registered-address.postal-code=")
    flags+=("--registered-address.state=")
    two_word_flags+=("--registered-address.state")
    local_nonpersistent_flags+=("--registered-address.state")
    local_nonpersistent_flags+=("--registered-address.state=")
    flags+=("--relationship.director=")
    two_word_flags+=("--relationship.director")
    local_nonpersistent_flags+=("--relationship.director")
    local_nonpersistent_flags+=("--relationship.director=")
    flags+=("--relationship.executive=")
    two_word_flags+=("--relationship.executive")
    local_nonpersistent_flags+=("--relationship.executive")
    local_nonpersistent_flags+=("--relationship.executive=")
    flags+=("--relationship.legal-guardian=")
    two_word_flags+=("--relationship.legal-guardian")
    local_nonpersistent_flags+=("--relationship.legal-guardian")
    local_nonpersistent_flags+=("--relationship.legal-guardian=")
    flags+=("--relationship.owner=")
    two_word_flags+=("--relationship.owner")
    local_nonpersistent_flags+=("--relationship.owner")
    local_nonpersistent_flags+=("--relationship.owner=")
    flags+=("--relationship.percent-ownership=")
    two_word_flags+=("--relationship.percent-ownership")
    local_nonpersistent_flags+=("--relationship.percent-ownership")
    local_nonpersistent_flags+=("--relationship.percent-ownership=")
    flags+=("--relationship.representative=")
    two_word_flags+=("--relationship.representative")
    local_nonpersistent_flags+=("--relationship.representative")
    local_nonpersistent_flags+=("--relationship.representative=")
    flags+=("--relationship.title=")
    two_word_flags+=("--relationship.title")
    local_nonpersistent_flags+=("--relationship.title")
    local_nonpersistent_flags+=("--relationship.title=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--ssn-last-4=")
    two_word_flags+=("--ssn-last-4")
    local_nonpersistent_flags+=("--ssn-last-4")
    local_nonpersistent_flags+=("--ssn-last-4=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--verification.additional-document.back=")
    two_word_flags+=("--verification.additional-document.back")
    local_nonpersistent_flags+=("--verification.additional-document.back")
    local_nonpersistent_flags+=("--verification.additional-document.back=")
    flags+=("--verification.additional-document.front=")
    two_word_flags+=("--verification.additional-document.front")
    local_nonpersistent_flags+=("--verification.additional-document.front")
    local_nonpersistent_flags+=("--verification.additional-document.front=")
    flags+=("--verification.document.back=")
    two_word_flags+=("--verification.document.back")
    local_nonpersistent_flags+=("--verification.document.back")
    local_nonpersistent_flags+=("--verification.document.back=")
    flags+=("--verification.document.front=")
    two_word_flags+=("--verification.document.front")
    local_nonpersistent_flags+=("--verification.document.front")
    local_nonpersistent_flags+=("--verification.document.front=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_persons_delete()
{
    last_command="stripe_persons_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_persons_list()
{
    last_command="stripe_persons_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_persons_retrieve()
{
    last_command="stripe_persons_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_persons_update()
{
    last_command="stripe_persons_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--additional-tos-acceptances.account.date=")
    two_word_flags+=("--additional-tos-acceptances.account.date")
    local_nonpersistent_flags+=("--additional-tos-acceptances.account.date")
    local_nonpersistent_flags+=("--additional-tos-acceptances.account.date=")
    flags+=("--additional-tos-acceptances.account.ip=")
    two_word_flags+=("--additional-tos-acceptances.account.ip")
    local_nonpersistent_flags+=("--additional-tos-acceptances.account.ip")
    local_nonpersistent_flags+=("--additional-tos-acceptances.account.ip=")
    flags+=("--additional-tos-acceptances.account.user-agent=")
    two_word_flags+=("--additional-tos-acceptances.account.user-agent")
    local_nonpersistent_flags+=("--additional-tos-acceptances.account.user-agent")
    local_nonpersistent_flags+=("--additional-tos-acceptances.account.user-agent=")
    flags+=("--address-kana.city=")
    two_word_flags+=("--address-kana.city")
    local_nonpersistent_flags+=("--address-kana.city")
    local_nonpersistent_flags+=("--address-kana.city=")
    flags+=("--address-kana.country=")
    two_word_flags+=("--address-kana.country")
    local_nonpersistent_flags+=("--address-kana.country")
    local_nonpersistent_flags+=("--address-kana.country=")
    flags+=("--address-kana.line1=")
    two_word_flags+=("--address-kana.line1")
    local_nonpersistent_flags+=("--address-kana.line1")
    local_nonpersistent_flags+=("--address-kana.line1=")
    flags+=("--address-kana.line2=")
    two_word_flags+=("--address-kana.line2")
    local_nonpersistent_flags+=("--address-kana.line2")
    local_nonpersistent_flags+=("--address-kana.line2=")
    flags+=("--address-kana.postal-code=")
    two_word_flags+=("--address-kana.postal-code")
    local_nonpersistent_flags+=("--address-kana.postal-code")
    local_nonpersistent_flags+=("--address-kana.postal-code=")
    flags+=("--address-kana.state=")
    two_word_flags+=("--address-kana.state")
    local_nonpersistent_flags+=("--address-kana.state")
    local_nonpersistent_flags+=("--address-kana.state=")
    flags+=("--address-kana.town=")
    two_word_flags+=("--address-kana.town")
    local_nonpersistent_flags+=("--address-kana.town")
    local_nonpersistent_flags+=("--address-kana.town=")
    flags+=("--address-kanji.city=")
    two_word_flags+=("--address-kanji.city")
    local_nonpersistent_flags+=("--address-kanji.city")
    local_nonpersistent_flags+=("--address-kanji.city=")
    flags+=("--address-kanji.country=")
    two_word_flags+=("--address-kanji.country")
    local_nonpersistent_flags+=("--address-kanji.country")
    local_nonpersistent_flags+=("--address-kanji.country=")
    flags+=("--address-kanji.line1=")
    two_word_flags+=("--address-kanji.line1")
    local_nonpersistent_flags+=("--address-kanji.line1")
    local_nonpersistent_flags+=("--address-kanji.line1=")
    flags+=("--address-kanji.line2=")
    two_word_flags+=("--address-kanji.line2")
    local_nonpersistent_flags+=("--address-kanji.line2")
    local_nonpersistent_flags+=("--address-kanji.line2=")
    flags+=("--address-kanji.postal-code=")
    two_word_flags+=("--address-kanji.postal-code")
    local_nonpersistent_flags+=("--address-kanji.postal-code")
    local_nonpersistent_flags+=("--address-kanji.postal-code=")
    flags+=("--address-kanji.state=")
    two_word_flags+=("--address-kanji.state")
    local_nonpersistent_flags+=("--address-kanji.state")
    local_nonpersistent_flags+=("--address-kanji.state=")
    flags+=("--address-kanji.town=")
    two_word_flags+=("--address-kanji.town")
    local_nonpersistent_flags+=("--address-kanji.town")
    local_nonpersistent_flags+=("--address-kanji.town=")
    flags+=("--address.city=")
    two_word_flags+=("--address.city")
    local_nonpersistent_flags+=("--address.city")
    local_nonpersistent_flags+=("--address.city=")
    flags+=("--address.country=")
    two_word_flags+=("--address.country")
    local_nonpersistent_flags+=("--address.country")
    local_nonpersistent_flags+=("--address.country=")
    flags+=("--address.line1=")
    two_word_flags+=("--address.line1")
    local_nonpersistent_flags+=("--address.line1")
    local_nonpersistent_flags+=("--address.line1=")
    flags+=("--address.line2=")
    two_word_flags+=("--address.line2")
    local_nonpersistent_flags+=("--address.line2")
    local_nonpersistent_flags+=("--address.line2=")
    flags+=("--address.postal-code=")
    two_word_flags+=("--address.postal-code")
    local_nonpersistent_flags+=("--address.postal-code")
    local_nonpersistent_flags+=("--address.postal-code=")
    flags+=("--address.state=")
    two_word_flags+=("--address.state")
    local_nonpersistent_flags+=("--address.state")
    local_nonpersistent_flags+=("--address.state=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--documents.company-authorization.files=")
    two_word_flags+=("--documents.company-authorization.files")
    local_nonpersistent_flags+=("--documents.company-authorization.files")
    local_nonpersistent_flags+=("--documents.company-authorization.files=")
    flags+=("--documents.passport.files=")
    two_word_flags+=("--documents.passport.files")
    local_nonpersistent_flags+=("--documents.passport.files")
    local_nonpersistent_flags+=("--documents.passport.files=")
    flags+=("--documents.visa.files=")
    two_word_flags+=("--documents.visa.files")
    local_nonpersistent_flags+=("--documents.visa.files")
    local_nonpersistent_flags+=("--documents.visa.files=")
    flags+=("--email=")
    two_word_flags+=("--email")
    local_nonpersistent_flags+=("--email")
    local_nonpersistent_flags+=("--email=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--first-name=")
    two_word_flags+=("--first-name")
    local_nonpersistent_flags+=("--first-name")
    local_nonpersistent_flags+=("--first-name=")
    flags+=("--first-name-kana=")
    two_word_flags+=("--first-name-kana")
    local_nonpersistent_flags+=("--first-name-kana")
    local_nonpersistent_flags+=("--first-name-kana=")
    flags+=("--first-name-kanji=")
    two_word_flags+=("--first-name-kanji")
    local_nonpersistent_flags+=("--first-name-kanji")
    local_nonpersistent_flags+=("--first-name-kanji=")
    flags+=("--full-name-aliases=")
    two_word_flags+=("--full-name-aliases")
    local_nonpersistent_flags+=("--full-name-aliases")
    local_nonpersistent_flags+=("--full-name-aliases=")
    flags+=("--gender=")
    two_word_flags+=("--gender")
    local_nonpersistent_flags+=("--gender")
    local_nonpersistent_flags+=("--gender=")
    flags+=("--id-number=")
    two_word_flags+=("--id-number")
    local_nonpersistent_flags+=("--id-number")
    local_nonpersistent_flags+=("--id-number=")
    flags+=("--id-number-secondary=")
    two_word_flags+=("--id-number-secondary")
    local_nonpersistent_flags+=("--id-number-secondary")
    local_nonpersistent_flags+=("--id-number-secondary=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--last-name=")
    two_word_flags+=("--last-name")
    local_nonpersistent_flags+=("--last-name")
    local_nonpersistent_flags+=("--last-name=")
    flags+=("--last-name-kana=")
    two_word_flags+=("--last-name-kana")
    local_nonpersistent_flags+=("--last-name-kana")
    local_nonpersistent_flags+=("--last-name-kana=")
    flags+=("--last-name-kanji=")
    two_word_flags+=("--last-name-kanji")
    local_nonpersistent_flags+=("--last-name-kanji")
    local_nonpersistent_flags+=("--last-name-kanji=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--maiden-name=")
    two_word_flags+=("--maiden-name")
    local_nonpersistent_flags+=("--maiden-name")
    local_nonpersistent_flags+=("--maiden-name=")
    flags+=("--nationality=")
    two_word_flags+=("--nationality")
    local_nonpersistent_flags+=("--nationality")
    local_nonpersistent_flags+=("--nationality=")
    flags+=("--person-token=")
    two_word_flags+=("--person-token")
    local_nonpersistent_flags+=("--person-token")
    local_nonpersistent_flags+=("--person-token=")
    flags+=("--phone=")
    two_word_flags+=("--phone")
    local_nonpersistent_flags+=("--phone")
    local_nonpersistent_flags+=("--phone=")
    flags+=("--political-exposure=")
    two_word_flags+=("--political-exposure")
    local_nonpersistent_flags+=("--political-exposure")
    local_nonpersistent_flags+=("--political-exposure=")
    flags+=("--registered-address.city=")
    two_word_flags+=("--registered-address.city")
    local_nonpersistent_flags+=("--registered-address.city")
    local_nonpersistent_flags+=("--registered-address.city=")
    flags+=("--registered-address.country=")
    two_word_flags+=("--registered-address.country")
    local_nonpersistent_flags+=("--registered-address.country")
    local_nonpersistent_flags+=("--registered-address.country=")
    flags+=("--registered-address.line1=")
    two_word_flags+=("--registered-address.line1")
    local_nonpersistent_flags+=("--registered-address.line1")
    local_nonpersistent_flags+=("--registered-address.line1=")
    flags+=("--registered-address.line2=")
    two_word_flags+=("--registered-address.line2")
    local_nonpersistent_flags+=("--registered-address.line2")
    local_nonpersistent_flags+=("--registered-address.line2=")
    flags+=("--registered-address.postal-code=")
    two_word_flags+=("--registered-address.postal-code")
    local_nonpersistent_flags+=("--registered-address.postal-code")
    local_nonpersistent_flags+=("--registered-address.postal-code=")
    flags+=("--registered-address.state=")
    two_word_flags+=("--registered-address.state")
    local_nonpersistent_flags+=("--registered-address.state")
    local_nonpersistent_flags+=("--registered-address.state=")
    flags+=("--relationship.director=")
    two_word_flags+=("--relationship.director")
    local_nonpersistent_flags+=("--relationship.director")
    local_nonpersistent_flags+=("--relationship.director=")
    flags+=("--relationship.executive=")
    two_word_flags+=("--relationship.executive")
    local_nonpersistent_flags+=("--relationship.executive")
    local_nonpersistent_flags+=("--relationship.executive=")
    flags+=("--relationship.legal-guardian=")
    two_word_flags+=("--relationship.legal-guardian")
    local_nonpersistent_flags+=("--relationship.legal-guardian")
    local_nonpersistent_flags+=("--relationship.legal-guardian=")
    flags+=("--relationship.owner=")
    two_word_flags+=("--relationship.owner")
    local_nonpersistent_flags+=("--relationship.owner")
    local_nonpersistent_flags+=("--relationship.owner=")
    flags+=("--relationship.percent-ownership=")
    two_word_flags+=("--relationship.percent-ownership")
    local_nonpersistent_flags+=("--relationship.percent-ownership")
    local_nonpersistent_flags+=("--relationship.percent-ownership=")
    flags+=("--relationship.representative=")
    two_word_flags+=("--relationship.representative")
    local_nonpersistent_flags+=("--relationship.representative")
    local_nonpersistent_flags+=("--relationship.representative=")
    flags+=("--relationship.title=")
    two_word_flags+=("--relationship.title")
    local_nonpersistent_flags+=("--relationship.title")
    local_nonpersistent_flags+=("--relationship.title=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--ssn-last-4=")
    two_word_flags+=("--ssn-last-4")
    local_nonpersistent_flags+=("--ssn-last-4")
    local_nonpersistent_flags+=("--ssn-last-4=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--verification.additional-document.back=")
    two_word_flags+=("--verification.additional-document.back")
    local_nonpersistent_flags+=("--verification.additional-document.back")
    local_nonpersistent_flags+=("--verification.additional-document.back=")
    flags+=("--verification.additional-document.front=")
    two_word_flags+=("--verification.additional-document.front")
    local_nonpersistent_flags+=("--verification.additional-document.front")
    local_nonpersistent_flags+=("--verification.additional-document.front=")
    flags+=("--verification.document.back=")
    two_word_flags+=("--verification.document.back")
    local_nonpersistent_flags+=("--verification.document.back")
    local_nonpersistent_flags+=("--verification.document.back=")
    flags+=("--verification.document.front=")
    two_word_flags+=("--verification.document.front")
    local_nonpersistent_flags+=("--verification.document.front")
    local_nonpersistent_flags+=("--verification.document.front=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_persons()
{
    last_command="stripe_persons"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_plans_create()
{
    last_command="stripe_plans_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--aggregate-usage=")
    two_word_flags+=("--aggregate-usage")
    local_nonpersistent_flags+=("--aggregate-usage")
    local_nonpersistent_flags+=("--aggregate-usage=")
    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--amount-decimal=")
    two_word_flags+=("--amount-decimal")
    local_nonpersistent_flags+=("--amount-decimal")
    local_nonpersistent_flags+=("--amount-decimal=")
    flags+=("--billing-scheme=")
    two_word_flags+=("--billing-scheme")
    local_nonpersistent_flags+=("--billing-scheme")
    local_nonpersistent_flags+=("--billing-scheme=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--id=")
    two_word_flags+=("--id")
    local_nonpersistent_flags+=("--id")
    local_nonpersistent_flags+=("--id=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--interval=")
    two_word_flags+=("--interval")
    local_nonpersistent_flags+=("--interval")
    local_nonpersistent_flags+=("--interval=")
    flags+=("--interval-count=")
    two_word_flags+=("--interval-count")
    local_nonpersistent_flags+=("--interval-count")
    local_nonpersistent_flags+=("--interval-count=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--meter=")
    two_word_flags+=("--meter")
    local_nonpersistent_flags+=("--meter")
    local_nonpersistent_flags+=("--meter=")
    flags+=("--nickname=")
    two_word_flags+=("--nickname")
    local_nonpersistent_flags+=("--nickname")
    local_nonpersistent_flags+=("--nickname=")
    flags+=("--product=")
    two_word_flags+=("--product")
    local_nonpersistent_flags+=("--product")
    local_nonpersistent_flags+=("--product=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tiers-mode=")
    two_word_flags+=("--tiers-mode")
    local_nonpersistent_flags+=("--tiers-mode")
    local_nonpersistent_flags+=("--tiers-mode=")
    flags+=("--transform-usage.divide-by=")
    two_word_flags+=("--transform-usage.divide-by")
    local_nonpersistent_flags+=("--transform-usage.divide-by")
    local_nonpersistent_flags+=("--transform-usage.divide-by=")
    flags+=("--transform-usage.round=")
    two_word_flags+=("--transform-usage.round")
    local_nonpersistent_flags+=("--transform-usage.round")
    local_nonpersistent_flags+=("--transform-usage.round=")
    flags+=("--trial-period-days=")
    two_word_flags+=("--trial-period-days")
    local_nonpersistent_flags+=("--trial-period-days")
    local_nonpersistent_flags+=("--trial-period-days=")
    flags+=("--usage-type=")
    two_word_flags+=("--usage-type")
    local_nonpersistent_flags+=("--usage-type")
    local_nonpersistent_flags+=("--usage-type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_plans_delete()
{
    last_command="stripe_plans_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_plans_list()
{
    last_command="stripe_plans_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--product=")
    two_word_flags+=("--product")
    local_nonpersistent_flags+=("--product")
    local_nonpersistent_flags+=("--product=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_plans_retrieve()
{
    last_command="stripe_plans_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_plans_update()
{
    last_command="stripe_plans_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--nickname=")
    two_word_flags+=("--nickname")
    local_nonpersistent_flags+=("--nickname")
    local_nonpersistent_flags+=("--nickname=")
    flags+=("--product=")
    two_word_flags+=("--product")
    local_nonpersistent_flags+=("--product")
    local_nonpersistent_flags+=("--product=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--trial-period-days=")
    two_word_flags+=("--trial-period-days")
    local_nonpersistent_flags+=("--trial-period-days")
    local_nonpersistent_flags+=("--trial-period-days=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_plans()
{
    last_command="stripe_plans"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_post()
{
    last_command="stripe_post"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_prices_create()
{
    last_command="stripe_prices_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--billing-scheme=")
    two_word_flags+=("--billing-scheme")
    local_nonpersistent_flags+=("--billing-scheme")
    local_nonpersistent_flags+=("--billing-scheme=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--custom-unit-amount.enabled=")
    two_word_flags+=("--custom-unit-amount.enabled")
    local_nonpersistent_flags+=("--custom-unit-amount.enabled")
    local_nonpersistent_flags+=("--custom-unit-amount.enabled=")
    flags+=("--custom-unit-amount.maximum=")
    two_word_flags+=("--custom-unit-amount.maximum")
    local_nonpersistent_flags+=("--custom-unit-amount.maximum")
    local_nonpersistent_flags+=("--custom-unit-amount.maximum=")
    flags+=("--custom-unit-amount.minimum=")
    two_word_flags+=("--custom-unit-amount.minimum")
    local_nonpersistent_flags+=("--custom-unit-amount.minimum")
    local_nonpersistent_flags+=("--custom-unit-amount.minimum=")
    flags+=("--custom-unit-amount.preset=")
    two_word_flags+=("--custom-unit-amount.preset")
    local_nonpersistent_flags+=("--custom-unit-amount.preset")
    local_nonpersistent_flags+=("--custom-unit-amount.preset=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--lookup-key=")
    two_word_flags+=("--lookup-key")
    local_nonpersistent_flags+=("--lookup-key")
    local_nonpersistent_flags+=("--lookup-key=")
    flags+=("--nickname=")
    two_word_flags+=("--nickname")
    local_nonpersistent_flags+=("--nickname")
    local_nonpersistent_flags+=("--nickname=")
    flags+=("--product=")
    two_word_flags+=("--product")
    local_nonpersistent_flags+=("--product")
    local_nonpersistent_flags+=("--product=")
    flags+=("--product-data.active=")
    two_word_flags+=("--product-data.active")
    local_nonpersistent_flags+=("--product-data.active")
    local_nonpersistent_flags+=("--product-data.active=")
    flags+=("--product-data.id=")
    two_word_flags+=("--product-data.id")
    local_nonpersistent_flags+=("--product-data.id")
    local_nonpersistent_flags+=("--product-data.id=")
    flags+=("--product-data.name=")
    two_word_flags+=("--product-data.name")
    local_nonpersistent_flags+=("--product-data.name")
    local_nonpersistent_flags+=("--product-data.name=")
    flags+=("--product-data.statement-descriptor=")
    two_word_flags+=("--product-data.statement-descriptor")
    local_nonpersistent_flags+=("--product-data.statement-descriptor")
    local_nonpersistent_flags+=("--product-data.statement-descriptor=")
    flags+=("--product-data.tax-code=")
    two_word_flags+=("--product-data.tax-code")
    local_nonpersistent_flags+=("--product-data.tax-code")
    local_nonpersistent_flags+=("--product-data.tax-code=")
    flags+=("--product-data.unit-label=")
    two_word_flags+=("--product-data.unit-label")
    local_nonpersistent_flags+=("--product-data.unit-label")
    local_nonpersistent_flags+=("--product-data.unit-label=")
    flags+=("--recurring.aggregate-usage=")
    two_word_flags+=("--recurring.aggregate-usage")
    local_nonpersistent_flags+=("--recurring.aggregate-usage")
    local_nonpersistent_flags+=("--recurring.aggregate-usage=")
    flags+=("--recurring.interval=")
    two_word_flags+=("--recurring.interval")
    local_nonpersistent_flags+=("--recurring.interval")
    local_nonpersistent_flags+=("--recurring.interval=")
    flags+=("--recurring.interval-count=")
    two_word_flags+=("--recurring.interval-count")
    local_nonpersistent_flags+=("--recurring.interval-count")
    local_nonpersistent_flags+=("--recurring.interval-count=")
    flags+=("--recurring.meter=")
    two_word_flags+=("--recurring.meter")
    local_nonpersistent_flags+=("--recurring.meter")
    local_nonpersistent_flags+=("--recurring.meter=")
    flags+=("--recurring.trial-period-days=")
    two_word_flags+=("--recurring.trial-period-days")
    local_nonpersistent_flags+=("--recurring.trial-period-days")
    local_nonpersistent_flags+=("--recurring.trial-period-days=")
    flags+=("--recurring.usage-type=")
    two_word_flags+=("--recurring.usage-type")
    local_nonpersistent_flags+=("--recurring.usage-type")
    local_nonpersistent_flags+=("--recurring.usage-type=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tax-behavior=")
    two_word_flags+=("--tax-behavior")
    local_nonpersistent_flags+=("--tax-behavior")
    local_nonpersistent_flags+=("--tax-behavior=")
    flags+=("--tiers-mode=")
    two_word_flags+=("--tiers-mode")
    local_nonpersistent_flags+=("--tiers-mode")
    local_nonpersistent_flags+=("--tiers-mode=")
    flags+=("--transfer-lookup-key=")
    two_word_flags+=("--transfer-lookup-key")
    local_nonpersistent_flags+=("--transfer-lookup-key")
    local_nonpersistent_flags+=("--transfer-lookup-key=")
    flags+=("--transform-quantity.divide-by=")
    two_word_flags+=("--transform-quantity.divide-by")
    local_nonpersistent_flags+=("--transform-quantity.divide-by")
    local_nonpersistent_flags+=("--transform-quantity.divide-by=")
    flags+=("--transform-quantity.round=")
    two_word_flags+=("--transform-quantity.round")
    local_nonpersistent_flags+=("--transform-quantity.round")
    local_nonpersistent_flags+=("--transform-quantity.round=")
    flags+=("--unit-amount=")
    two_word_flags+=("--unit-amount")
    local_nonpersistent_flags+=("--unit-amount")
    local_nonpersistent_flags+=("--unit-amount=")
    flags+=("--unit-amount-decimal=")
    two_word_flags+=("--unit-amount-decimal")
    local_nonpersistent_flags+=("--unit-amount-decimal")
    local_nonpersistent_flags+=("--unit-amount-decimal=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_prices_list()
{
    last_command="stripe_prices_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--lookup-keys=")
    two_word_flags+=("--lookup-keys")
    local_nonpersistent_flags+=("--lookup-keys")
    local_nonpersistent_flags+=("--lookup-keys=")
    flags+=("--product=")
    two_word_flags+=("--product")
    local_nonpersistent_flags+=("--product")
    local_nonpersistent_flags+=("--product=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_prices_retrieve()
{
    last_command="stripe_prices_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_prices_search()
{
    last_command="stripe_prices_search"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--page=")
    two_word_flags+=("--page")
    local_nonpersistent_flags+=("--page")
    local_nonpersistent_flags+=("--page=")
    flags+=("--query=")
    two_word_flags+=("--query")
    local_nonpersistent_flags+=("--query")
    local_nonpersistent_flags+=("--query=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_prices_update()
{
    last_command="stripe_prices_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--lookup-key=")
    two_word_flags+=("--lookup-key")
    local_nonpersistent_flags+=("--lookup-key")
    local_nonpersistent_flags+=("--lookup-key=")
    flags+=("--nickname=")
    two_word_flags+=("--nickname")
    local_nonpersistent_flags+=("--nickname")
    local_nonpersistent_flags+=("--nickname=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tax-behavior=")
    two_word_flags+=("--tax-behavior")
    local_nonpersistent_flags+=("--tax-behavior")
    local_nonpersistent_flags+=("--tax-behavior=")
    flags+=("--transfer-lookup-key=")
    two_word_flags+=("--transfer-lookup-key")
    local_nonpersistent_flags+=("--transfer-lookup-key")
    local_nonpersistent_flags+=("--transfer-lookup-key=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_prices()
{
    last_command="stripe_prices"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("search")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_product_features_create()
{
    last_command="stripe_product_features_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--entitlement-feature=")
    two_word_flags+=("--entitlement-feature")
    local_nonpersistent_flags+=("--entitlement-feature")
    local_nonpersistent_flags+=("--entitlement-feature=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_product_features_delete()
{
    last_command="stripe_product_features_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_product_features_list()
{
    last_command="stripe_product_features_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_product_features_retrieve()
{
    last_command="stripe_product_features_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_product_features()
{
    last_command="stripe_product_features"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_products_create()
{
    last_command="stripe_products_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-price-data.currency=")
    two_word_flags+=("--default-price-data.currency")
    local_nonpersistent_flags+=("--default-price-data.currency")
    local_nonpersistent_flags+=("--default-price-data.currency=")
    flags+=("--default-price-data.custom-unit-amount.enabled=")
    two_word_flags+=("--default-price-data.custom-unit-amount.enabled")
    local_nonpersistent_flags+=("--default-price-data.custom-unit-amount.enabled")
    local_nonpersistent_flags+=("--default-price-data.custom-unit-amount.enabled=")
    flags+=("--default-price-data.custom-unit-amount.maximum=")
    two_word_flags+=("--default-price-data.custom-unit-amount.maximum")
    local_nonpersistent_flags+=("--default-price-data.custom-unit-amount.maximum")
    local_nonpersistent_flags+=("--default-price-data.custom-unit-amount.maximum=")
    flags+=("--default-price-data.custom-unit-amount.minimum=")
    two_word_flags+=("--default-price-data.custom-unit-amount.minimum")
    local_nonpersistent_flags+=("--default-price-data.custom-unit-amount.minimum")
    local_nonpersistent_flags+=("--default-price-data.custom-unit-amount.minimum=")
    flags+=("--default-price-data.custom-unit-amount.preset=")
    two_word_flags+=("--default-price-data.custom-unit-amount.preset")
    local_nonpersistent_flags+=("--default-price-data.custom-unit-amount.preset")
    local_nonpersistent_flags+=("--default-price-data.custom-unit-amount.preset=")
    flags+=("--default-price-data.recurring.interval=")
    two_word_flags+=("--default-price-data.recurring.interval")
    local_nonpersistent_flags+=("--default-price-data.recurring.interval")
    local_nonpersistent_flags+=("--default-price-data.recurring.interval=")
    flags+=("--default-price-data.recurring.interval-count=")
    two_word_flags+=("--default-price-data.recurring.interval-count")
    local_nonpersistent_flags+=("--default-price-data.recurring.interval-count")
    local_nonpersistent_flags+=("--default-price-data.recurring.interval-count=")
    flags+=("--default-price-data.tax-behavior=")
    two_word_flags+=("--default-price-data.tax-behavior")
    local_nonpersistent_flags+=("--default-price-data.tax-behavior")
    local_nonpersistent_flags+=("--default-price-data.tax-behavior=")
    flags+=("--default-price-data.unit-amount=")
    two_word_flags+=("--default-price-data.unit-amount")
    local_nonpersistent_flags+=("--default-price-data.unit-amount")
    local_nonpersistent_flags+=("--default-price-data.unit-amount=")
    flags+=("--default-price-data.unit-amount-decimal=")
    two_word_flags+=("--default-price-data.unit-amount-decimal")
    local_nonpersistent_flags+=("--default-price-data.unit-amount-decimal")
    local_nonpersistent_flags+=("--default-price-data.unit-amount-decimal=")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--id=")
    two_word_flags+=("--id")
    local_nonpersistent_flags+=("--id")
    local_nonpersistent_flags+=("--id=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--images=")
    two_word_flags+=("--images")
    local_nonpersistent_flags+=("--images")
    local_nonpersistent_flags+=("--images=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--package-dimensions.height=")
    two_word_flags+=("--package-dimensions.height")
    local_nonpersistent_flags+=("--package-dimensions.height")
    local_nonpersistent_flags+=("--package-dimensions.height=")
    flags+=("--package-dimensions.length=")
    two_word_flags+=("--package-dimensions.length")
    local_nonpersistent_flags+=("--package-dimensions.length")
    local_nonpersistent_flags+=("--package-dimensions.length=")
    flags+=("--package-dimensions.weight=")
    two_word_flags+=("--package-dimensions.weight")
    local_nonpersistent_flags+=("--package-dimensions.weight")
    local_nonpersistent_flags+=("--package-dimensions.weight=")
    flags+=("--package-dimensions.width=")
    two_word_flags+=("--package-dimensions.width")
    local_nonpersistent_flags+=("--package-dimensions.width")
    local_nonpersistent_flags+=("--package-dimensions.width=")
    flags+=("--shippable=")
    two_word_flags+=("--shippable")
    local_nonpersistent_flags+=("--shippable")
    local_nonpersistent_flags+=("--shippable=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tax-code=")
    two_word_flags+=("--tax-code")
    local_nonpersistent_flags+=("--tax-code")
    local_nonpersistent_flags+=("--tax-code=")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--unit-label=")
    two_word_flags+=("--unit-label")
    local_nonpersistent_flags+=("--unit-label")
    local_nonpersistent_flags+=("--unit-label=")
    flags+=("--url=")
    two_word_flags+=("--url")
    local_nonpersistent_flags+=("--url")
    local_nonpersistent_flags+=("--url=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_products_delete()
{
    last_command="stripe_products_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_products_list()
{
    last_command="stripe_products_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--ids=")
    two_word_flags+=("--ids")
    local_nonpersistent_flags+=("--ids")
    local_nonpersistent_flags+=("--ids=")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--shippable=")
    two_word_flags+=("--shippable")
    local_nonpersistent_flags+=("--shippable")
    local_nonpersistent_flags+=("--shippable=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--url=")
    two_word_flags+=("--url")
    local_nonpersistent_flags+=("--url")
    local_nonpersistent_flags+=("--url=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_products_retrieve()
{
    last_command="stripe_products_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_products_search()
{
    last_command="stripe_products_search"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--page=")
    two_word_flags+=("--page")
    local_nonpersistent_flags+=("--page")
    local_nonpersistent_flags+=("--page=")
    flags+=("--query=")
    two_word_flags+=("--query")
    local_nonpersistent_flags+=("--query")
    local_nonpersistent_flags+=("--query=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_products_update()
{
    last_command="stripe_products_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-price=")
    two_word_flags+=("--default-price")
    local_nonpersistent_flags+=("--default-price")
    local_nonpersistent_flags+=("--default-price=")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--images=")
    two_word_flags+=("--images")
    local_nonpersistent_flags+=("--images")
    local_nonpersistent_flags+=("--images=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--shippable=")
    two_word_flags+=("--shippable")
    local_nonpersistent_flags+=("--shippable")
    local_nonpersistent_flags+=("--shippable=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tax-code=")
    two_word_flags+=("--tax-code")
    local_nonpersistent_flags+=("--tax-code")
    local_nonpersistent_flags+=("--tax-code=")
    flags+=("--unit-label=")
    two_word_flags+=("--unit-label")
    local_nonpersistent_flags+=("--unit-label")
    local_nonpersistent_flags+=("--unit-label=")
    flags+=("--url=")
    two_word_flags+=("--url")
    local_nonpersistent_flags+=("--url")
    local_nonpersistent_flags+=("--url=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_products()
{
    last_command="stripe_products"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")
    commands+=("search")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_promotion_codes_create()
{
    last_command="stripe_promotion_codes_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--code=")
    two_word_flags+=("--code")
    local_nonpersistent_flags+=("--code")
    local_nonpersistent_flags+=("--code=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--coupon=")
    two_word_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--expires-at=")
    two_word_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--max-redemptions=")
    two_word_flags+=("--max-redemptions")
    local_nonpersistent_flags+=("--max-redemptions")
    local_nonpersistent_flags+=("--max-redemptions=")
    flags+=("--restrictions.first-time-transaction=")
    two_word_flags+=("--restrictions.first-time-transaction")
    local_nonpersistent_flags+=("--restrictions.first-time-transaction")
    local_nonpersistent_flags+=("--restrictions.first-time-transaction=")
    flags+=("--restrictions.minimum-amount=")
    two_word_flags+=("--restrictions.minimum-amount")
    local_nonpersistent_flags+=("--restrictions.minimum-amount")
    local_nonpersistent_flags+=("--restrictions.minimum-amount=")
    flags+=("--restrictions.minimum-amount-currency=")
    two_word_flags+=("--restrictions.minimum-amount-currency")
    local_nonpersistent_flags+=("--restrictions.minimum-amount-currency")
    local_nonpersistent_flags+=("--restrictions.minimum-amount-currency=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_promotion_codes_list()
{
    last_command="stripe_promotion_codes_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--code=")
    two_word_flags+=("--code")
    local_nonpersistent_flags+=("--code")
    local_nonpersistent_flags+=("--code=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--coupon=")
    two_word_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon=")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_promotion_codes_retrieve()
{
    last_command="stripe_promotion_codes_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_promotion_codes_update()
{
    last_command="stripe_promotion_codes_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_promotion_codes()
{
    last_command="stripe_promotion_codes"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_quotes_accept()
{
    last_command="stripe_quotes_accept"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_quotes_cancel()
{
    last_command="stripe_quotes_cancel"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_quotes_create()
{
    last_command="stripe_quotes_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--application-fee-amount=")
    two_word_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount=")
    flags+=("--application-fee-percent=")
    two_word_flags+=("--application-fee-percent")
    local_nonpersistent_flags+=("--application-fee-percent")
    local_nonpersistent_flags+=("--application-fee-percent=")
    flags+=("--automatic-tax.enabled=")
    two_word_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled=")
    flags+=("--automatic-tax.liability.account=")
    two_word_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account=")
    flags+=("--automatic-tax.liability.type=")
    two_word_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type=")
    flags+=("--collection-method=")
    two_word_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-tax-rates=")
    two_word_flags+=("--default-tax-rates")
    local_nonpersistent_flags+=("--default-tax-rates")
    local_nonpersistent_flags+=("--default-tax-rates=")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--expires-at=")
    two_word_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at=")
    flags+=("--footer=")
    two_word_flags+=("--footer")
    local_nonpersistent_flags+=("--footer")
    local_nonpersistent_flags+=("--footer=")
    flags+=("--from-quote.is-revision=")
    two_word_flags+=("--from-quote.is-revision")
    local_nonpersistent_flags+=("--from-quote.is-revision")
    local_nonpersistent_flags+=("--from-quote.is-revision=")
    flags+=("--from-quote.quote=")
    two_word_flags+=("--from-quote.quote")
    local_nonpersistent_flags+=("--from-quote.quote")
    local_nonpersistent_flags+=("--from-quote.quote=")
    flags+=("--header=")
    two_word_flags+=("--header")
    local_nonpersistent_flags+=("--header")
    local_nonpersistent_flags+=("--header=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--invoice-settings.days-until-due=")
    two_word_flags+=("--invoice-settings.days-until-due")
    local_nonpersistent_flags+=("--invoice-settings.days-until-due")
    local_nonpersistent_flags+=("--invoice-settings.days-until-due=")
    flags+=("--invoice-settings.issuer.account=")
    two_word_flags+=("--invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--invoice-settings.issuer.account=")
    flags+=("--invoice-settings.issuer.type=")
    two_word_flags+=("--invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--invoice-settings.issuer.type=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--on-behalf-of=")
    two_word_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--subscription-data.description=")
    two_word_flags+=("--subscription-data.description")
    local_nonpersistent_flags+=("--subscription-data.description")
    local_nonpersistent_flags+=("--subscription-data.description=")
    flags+=("--subscription-data.effective-date=")
    two_word_flags+=("--subscription-data.effective-date")
    local_nonpersistent_flags+=("--subscription-data.effective-date")
    local_nonpersistent_flags+=("--subscription-data.effective-date=")
    flags+=("--subscription-data.trial-period-days=")
    two_word_flags+=("--subscription-data.trial-period-days")
    local_nonpersistent_flags+=("--subscription-data.trial-period-days")
    local_nonpersistent_flags+=("--subscription-data.trial-period-days=")
    flags+=("--test-clock=")
    two_word_flags+=("--test-clock")
    local_nonpersistent_flags+=("--test-clock")
    local_nonpersistent_flags+=("--test-clock=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_quotes_finalize_quote()
{
    last_command="stripe_quotes_finalize_quote"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--expires-at=")
    two_word_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_quotes_list()
{
    last_command="stripe_quotes_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--test-clock=")
    two_word_flags+=("--test-clock")
    local_nonpersistent_flags+=("--test-clock")
    local_nonpersistent_flags+=("--test-clock=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_quotes_list_computed_upfront_line_items()
{
    last_command="stripe_quotes_list_computed_upfront_line_items"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_quotes_list_line_items()
{
    last_command="stripe_quotes_list_line_items"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_quotes_pdf()
{
    last_command="stripe_quotes_pdf"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_quotes_retrieve()
{
    last_command="stripe_quotes_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_quotes_update()
{
    last_command="stripe_quotes_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--application-fee-amount=")
    two_word_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount")
    local_nonpersistent_flags+=("--application-fee-amount=")
    flags+=("--application-fee-percent=")
    two_word_flags+=("--application-fee-percent")
    local_nonpersistent_flags+=("--application-fee-percent")
    local_nonpersistent_flags+=("--application-fee-percent=")
    flags+=("--automatic-tax.enabled=")
    two_word_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled=")
    flags+=("--automatic-tax.liability.account=")
    two_word_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account=")
    flags+=("--automatic-tax.liability.type=")
    two_word_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type=")
    flags+=("--collection-method=")
    two_word_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-tax-rates=")
    two_word_flags+=("--default-tax-rates")
    local_nonpersistent_flags+=("--default-tax-rates")
    local_nonpersistent_flags+=("--default-tax-rates=")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--expires-at=")
    two_word_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at=")
    flags+=("--footer=")
    two_word_flags+=("--footer")
    local_nonpersistent_flags+=("--footer")
    local_nonpersistent_flags+=("--footer=")
    flags+=("--header=")
    two_word_flags+=("--header")
    local_nonpersistent_flags+=("--header")
    local_nonpersistent_flags+=("--header=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--invoice-settings.days-until-due=")
    two_word_flags+=("--invoice-settings.days-until-due")
    local_nonpersistent_flags+=("--invoice-settings.days-until-due")
    local_nonpersistent_flags+=("--invoice-settings.days-until-due=")
    flags+=("--invoice-settings.issuer.account=")
    two_word_flags+=("--invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--invoice-settings.issuer.account=")
    flags+=("--invoice-settings.issuer.type=")
    two_word_flags+=("--invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--invoice-settings.issuer.type=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--on-behalf-of=")
    two_word_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--subscription-data.description=")
    two_word_flags+=("--subscription-data.description")
    local_nonpersistent_flags+=("--subscription-data.description")
    local_nonpersistent_flags+=("--subscription-data.description=")
    flags+=("--subscription-data.effective-date=")
    two_word_flags+=("--subscription-data.effective-date")
    local_nonpersistent_flags+=("--subscription-data.effective-date")
    local_nonpersistent_flags+=("--subscription-data.effective-date=")
    flags+=("--subscription-data.trial-period-days=")
    two_word_flags+=("--subscription-data.trial-period-days")
    local_nonpersistent_flags+=("--subscription-data.trial-period-days")
    local_nonpersistent_flags+=("--subscription-data.trial-period-days=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_quotes()
{
    last_command="stripe_quotes"

    command_aliases=()

    commands=()
    commands+=("accept")
    commands+=("cancel")
    commands+=("create")
    commands+=("finalize_quote")
    commands+=("list")
    commands+=("list_computed_upfront_line_items")
    commands+=("list_line_items")
    commands+=("pdf")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_radar_early_fraud_warnings_list()
{
    last_command="stripe_radar_early_fraud_warnings_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--charge=")
    two_word_flags+=("--charge")
    local_nonpersistent_flags+=("--charge")
    local_nonpersistent_flags+=("--charge=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-intent=")
    two_word_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_radar_early_fraud_warnings_retrieve()
{
    last_command="stripe_radar_early_fraud_warnings_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_radar_early_fraud_warnings()
{
    last_command="stripe_radar_early_fraud_warnings"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_radar_value_list_items_create()
{
    last_command="stripe_radar_value_list_items_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--value=")
    two_word_flags+=("--value")
    local_nonpersistent_flags+=("--value")
    local_nonpersistent_flags+=("--value=")
    flags+=("--value-list=")
    two_word_flags+=("--value-list")
    local_nonpersistent_flags+=("--value-list")
    local_nonpersistent_flags+=("--value-list=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_radar_value_list_items_delete()
{
    last_command="stripe_radar_value_list_items_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_radar_value_list_items_list()
{
    last_command="stripe_radar_value_list_items_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--value=")
    two_word_flags+=("--value")
    local_nonpersistent_flags+=("--value")
    local_nonpersistent_flags+=("--value=")
    flags+=("--value-list=")
    two_word_flags+=("--value-list")
    local_nonpersistent_flags+=("--value-list")
    local_nonpersistent_flags+=("--value-list=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_radar_value_list_items_retrieve()
{
    last_command="stripe_radar_value_list_items_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_radar_value_list_items()
{
    last_command="stripe_radar_value_list_items"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_radar_value_lists_create()
{
    last_command="stripe_radar_value_lists_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--alias=")
    two_word_flags+=("--alias")
    local_nonpersistent_flags+=("--alias")
    local_nonpersistent_flags+=("--alias=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--item-type=")
    two_word_flags+=("--item-type")
    local_nonpersistent_flags+=("--item-type")
    local_nonpersistent_flags+=("--item-type=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_radar_value_lists_delete()
{
    last_command="stripe_radar_value_lists_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_radar_value_lists_list()
{
    last_command="stripe_radar_value_lists_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--alias=")
    two_word_flags+=("--alias")
    local_nonpersistent_flags+=("--alias")
    local_nonpersistent_flags+=("--alias=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--contains=")
    two_word_flags+=("--contains")
    local_nonpersistent_flags+=("--contains")
    local_nonpersistent_flags+=("--contains=")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_radar_value_lists_retrieve()
{
    last_command="stripe_radar_value_lists_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_radar_value_lists_update()
{
    last_command="stripe_radar_value_lists_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--alias=")
    two_word_flags+=("--alias")
    local_nonpersistent_flags+=("--alias")
    local_nonpersistent_flags+=("--alias=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_radar_value_lists()
{
    last_command="stripe_radar_value_lists"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_radar()
{
    last_command="stripe_radar"

    command_aliases=()

    commands=()
    commands+=("early_fraud_warnings")
    commands+=("value_list_items")
    commands+=("value_lists")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_refunds_cancel()
{
    last_command="stripe_refunds_cancel"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_refunds_create()
{
    last_command="stripe_refunds_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--charge=")
    two_word_flags+=("--charge")
    local_nonpersistent_flags+=("--charge")
    local_nonpersistent_flags+=("--charge=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--instructions-email=")
    two_word_flags+=("--instructions-email")
    local_nonpersistent_flags+=("--instructions-email")
    local_nonpersistent_flags+=("--instructions-email=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--origin=")
    two_word_flags+=("--origin")
    local_nonpersistent_flags+=("--origin")
    local_nonpersistent_flags+=("--origin=")
    flags+=("--payment-intent=")
    two_word_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent=")
    flags+=("--reason=")
    two_word_flags+=("--reason")
    local_nonpersistent_flags+=("--reason")
    local_nonpersistent_flags+=("--reason=")
    flags+=("--refund-application-fee=")
    two_word_flags+=("--refund-application-fee")
    local_nonpersistent_flags+=("--refund-application-fee")
    local_nonpersistent_flags+=("--refund-application-fee=")
    flags+=("--reverse-transfer=")
    two_word_flags+=("--reverse-transfer")
    local_nonpersistent_flags+=("--reverse-transfer")
    local_nonpersistent_flags+=("--reverse-transfer=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_refunds_list()
{
    last_command="stripe_refunds_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--charge=")
    two_word_flags+=("--charge")
    local_nonpersistent_flags+=("--charge")
    local_nonpersistent_flags+=("--charge=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-intent=")
    two_word_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_refunds_retrieve()
{
    last_command="stripe_refunds_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_refunds_test_helpers_expire()
{
    last_command="stripe_refunds_test_helpers_expire"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_refunds_test_helpers()
{
    last_command="stripe_refunds_test_helpers"

    command_aliases=()

    commands=()
    commands+=("expire")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_refunds_update()
{
    last_command="stripe_refunds_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_refunds()
{
    last_command="stripe_refunds"

    command_aliases=()

    commands=()
    commands+=("cancel")
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("test_helpers")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_reporting_report_runs_create()
{
    last_command="stripe_reporting_report_runs_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--parameters.columns=")
    two_word_flags+=("--parameters.columns")
    local_nonpersistent_flags+=("--parameters.columns")
    local_nonpersistent_flags+=("--parameters.columns=")
    flags+=("--parameters.connected-account=")
    two_word_flags+=("--parameters.connected-account")
    local_nonpersistent_flags+=("--parameters.connected-account")
    local_nonpersistent_flags+=("--parameters.connected-account=")
    flags+=("--parameters.currency=")
    two_word_flags+=("--parameters.currency")
    local_nonpersistent_flags+=("--parameters.currency")
    local_nonpersistent_flags+=("--parameters.currency=")
    flags+=("--parameters.interval-end=")
    two_word_flags+=("--parameters.interval-end")
    local_nonpersistent_flags+=("--parameters.interval-end")
    local_nonpersistent_flags+=("--parameters.interval-end=")
    flags+=("--parameters.interval-start=")
    two_word_flags+=("--parameters.interval-start")
    local_nonpersistent_flags+=("--parameters.interval-start")
    local_nonpersistent_flags+=("--parameters.interval-start=")
    flags+=("--parameters.payout=")
    two_word_flags+=("--parameters.payout")
    local_nonpersistent_flags+=("--parameters.payout")
    local_nonpersistent_flags+=("--parameters.payout=")
    flags+=("--parameters.reporting-category=")
    two_word_flags+=("--parameters.reporting-category")
    local_nonpersistent_flags+=("--parameters.reporting-category")
    local_nonpersistent_flags+=("--parameters.reporting-category=")
    flags+=("--parameters.timezone=")
    two_word_flags+=("--parameters.timezone")
    local_nonpersistent_flags+=("--parameters.timezone")
    local_nonpersistent_flags+=("--parameters.timezone=")
    flags+=("--report-type=")
    two_word_flags+=("--report-type")
    local_nonpersistent_flags+=("--report-type")
    local_nonpersistent_flags+=("--report-type=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_reporting_report_runs_list()
{
    last_command="stripe_reporting_report_runs_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_reporting_report_runs_retrieve()
{
    last_command="stripe_reporting_report_runs_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_reporting_report_runs()
{
    last_command="stripe_reporting_report_runs"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_reporting_report_types_list()
{
    last_command="stripe_reporting_report_types_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_reporting_report_types_retrieve()
{
    last_command="stripe_reporting_report_types_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_reporting_report_types()
{
    last_command="stripe_reporting_report_types"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_reporting()
{
    last_command="stripe_reporting"

    command_aliases=()

    commands=()
    commands+=("report_runs")
    commands+=("report_types")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_reviews_approve()
{
    last_command="stripe_reviews_approve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_reviews_list()
{
    last_command="stripe_reviews_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_reviews_retrieve()
{
    last_command="stripe_reviews_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_reviews()
{
    last_command="stripe_reviews"

    command_aliases=()

    commands=()
    commands+=("approve")
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_samples_create()
{
    last_command="stripe_samples_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--force-refresh")
    local_nonpersistent_flags+=("--force-refresh")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_samples_list()
{
    last_command="stripe_samples_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_samples()
{
    last_command="stripe_samples"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_scheduled_query_runs_list()
{
    last_command="stripe_scheduled_query_runs_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_scheduled_query_runs_retrieve()
{
    last_command="stripe_scheduled_query_runs_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_scheduled_query_runs()
{
    last_command="stripe_scheduled_query_runs"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_serve()
{
    last_command="stripe_serve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--port=")
    two_word_flags+=("--port")
    local_nonpersistent_flags+=("--port")
    local_nonpersistent_flags+=("--port=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_setup_attempts_list()
{
    last_command="stripe_setup_attempts_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--setup-intent=")
    two_word_flags+=("--setup-intent")
    local_nonpersistent_flags+=("--setup-intent")
    local_nonpersistent_flags+=("--setup-intent=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_setup_attempts()
{
    last_command="stripe_setup_attempts"

    command_aliases=()

    commands=()
    commands+=("list")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_setup_intents_cancel()
{
    last_command="stripe_setup_intents_cancel"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--cancellation-reason=")
    two_word_flags+=("--cancellation-reason")
    local_nonpersistent_flags+=("--cancellation-reason")
    local_nonpersistent_flags+=("--cancellation-reason=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_setup_intents_confirm()
{
    last_command="stripe_setup_intents_confirm"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--confirmation-token=")
    two_word_flags+=("--confirmation-token")
    local_nonpersistent_flags+=("--confirmation-token")
    local_nonpersistent_flags+=("--confirmation-token=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-method=")
    two_word_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method=")
    flags+=("--payment-method-data.acss-debit.account-number=")
    two_word_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number=")
    flags+=("--payment-method-data.acss-debit.institution-number=")
    two_word_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number=")
    flags+=("--payment-method-data.acss-debit.transit-number=")
    two_word_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number=")
    flags+=("--payment-method-data.allow-redisplay=")
    two_word_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay=")
    flags+=("--payment-method-data.au-becs-debit.account-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number=")
    flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    flags+=("--payment-method-data.bacs-debit.account-number=")
    two_word_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number=")
    flags+=("--payment-method-data.bacs-debit.sort-code=")
    two_word_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code=")
    flags+=("--payment-method-data.billing-details.email=")
    two_word_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email=")
    flags+=("--payment-method-data.billing-details.name=")
    two_word_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name=")
    flags+=("--payment-method-data.billing-details.phone=")
    two_word_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone=")
    flags+=("--payment-method-data.boleto.tax-id=")
    two_word_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id=")
    flags+=("--payment-method-data.eps.bank=")
    two_word_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank=")
    flags+=("--payment-method-data.fpx.account-holder-type=")
    two_word_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type=")
    flags+=("--payment-method-data.fpx.bank=")
    two_word_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank=")
    flags+=("--payment-method-data.ideal.bank=")
    two_word_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank=")
    flags+=("--payment-method-data.klarna.dob.day=")
    two_word_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day=")
    flags+=("--payment-method-data.klarna.dob.month=")
    two_word_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month=")
    flags+=("--payment-method-data.klarna.dob.year=")
    two_word_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year=")
    flags+=("--payment-method-data.naver-pay.funding=")
    two_word_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding=")
    flags+=("--payment-method-data.p24.bank=")
    two_word_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank=")
    flags+=("--payment-method-data.radar-options.session=")
    two_word_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session=")
    flags+=("--payment-method-data.sepa-debit.iban=")
    two_word_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban=")
    flags+=("--payment-method-data.sofort.country=")
    two_word_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country=")
    flags+=("--payment-method-data.type=")
    two_word_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type=")
    flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    flags+=("--payment-method-data.us-bank-account.account-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number=")
    flags+=("--payment-method-data.us-bank-account.account-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type=")
    flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    two_word_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    flags+=("--payment-method-data.us-bank-account.routing-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number=")
    flags+=("--payment-method-options.acss-debit.currency=")
    two_word_flags+=("--payment-method-options.acss-debit.currency")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.currency")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.currency=")
    flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url=")
    flags+=("--payment-method-options.acss-debit.mandate-options.default-for=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.default-for")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.default-for")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.default-for=")
    flags+=("--payment-method-options.acss-debit.mandate-options.interval-description=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.interval-description")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.interval-description")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.interval-description=")
    flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule=")
    flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type=")
    flags+=("--payment-method-options.acss-debit.verification-method=")
    two_word_flags+=("--payment-method-options.acss-debit.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.verification-method=")
    flags+=("--payment-method-options.card.mandate-options.amount=")
    two_word_flags+=("--payment-method-options.card.mandate-options.amount")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.amount")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.amount=")
    flags+=("--payment-method-options.card.mandate-options.amount-type=")
    two_word_flags+=("--payment-method-options.card.mandate-options.amount-type")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.amount-type")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.amount-type=")
    flags+=("--payment-method-options.card.mandate-options.currency=")
    two_word_flags+=("--payment-method-options.card.mandate-options.currency")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.currency")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.currency=")
    flags+=("--payment-method-options.card.mandate-options.description=")
    two_word_flags+=("--payment-method-options.card.mandate-options.description")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.description")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.description=")
    flags+=("--payment-method-options.card.mandate-options.end-date=")
    two_word_flags+=("--payment-method-options.card.mandate-options.end-date")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.end-date")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.end-date=")
    flags+=("--payment-method-options.card.mandate-options.interval=")
    two_word_flags+=("--payment-method-options.card.mandate-options.interval")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.interval")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.interval=")
    flags+=("--payment-method-options.card.mandate-options.interval-count=")
    two_word_flags+=("--payment-method-options.card.mandate-options.interval-count")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.interval-count")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.interval-count=")
    flags+=("--payment-method-options.card.mandate-options.reference=")
    two_word_flags+=("--payment-method-options.card.mandate-options.reference")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.reference")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.reference=")
    flags+=("--payment-method-options.card.mandate-options.start-date=")
    two_word_flags+=("--payment-method-options.card.mandate-options.start-date")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.start-date")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.start-date=")
    flags+=("--payment-method-options.card.mandate-options.supported-types=")
    two_word_flags+=("--payment-method-options.card.mandate-options.supported-types")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.supported-types")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.supported-types=")
    flags+=("--payment-method-options.card.moto=")
    two_word_flags+=("--payment-method-options.card.moto")
    local_nonpersistent_flags+=("--payment-method-options.card.moto")
    local_nonpersistent_flags+=("--payment-method-options.card.moto=")
    flags+=("--payment-method-options.card.network=")
    two_word_flags+=("--payment-method-options.card.network")
    local_nonpersistent_flags+=("--payment-method-options.card.network")
    local_nonpersistent_flags+=("--payment-method-options.card.network=")
    flags+=("--payment-method-options.card.request-three-d-secure=")
    two_word_flags+=("--payment-method-options.card.request-three-d-secure")
    local_nonpersistent_flags+=("--payment-method-options.card.request-three-d-secure")
    local_nonpersistent_flags+=("--payment-method-options.card.request-three-d-secure=")
    flags+=("--payment-method-options.card.three-d-secure.ares-trans-status=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.ares-trans-status")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.ares-trans-status")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.ares-trans-status=")
    flags+=("--payment-method-options.card.three-d-secure.cryptogram=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.cryptogram")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.cryptogram")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.cryptogram=")
    flags+=("--payment-method-options.card.three-d-secure.electronic-commerce-indicator=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.electronic-commerce-indicator")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.electronic-commerce-indicator")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.electronic-commerce-indicator=")
    flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-avalgo=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-avalgo")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-avalgo")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-avalgo=")
    flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-exemption=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-exemption")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-exemption")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-exemption=")
    flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-score=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-score")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-score")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-score=")
    flags+=("--payment-method-options.card.three-d-secure.requestor-challenge-indicator=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.requestor-challenge-indicator")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.requestor-challenge-indicator")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.requestor-challenge-indicator=")
    flags+=("--payment-method-options.card.three-d-secure.transaction-id=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.transaction-id")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.transaction-id")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.transaction-id=")
    flags+=("--payment-method-options.card.three-d-secure.version=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.version")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.version")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.version=")
    flags+=("--payment-method-options.link.persistent-token=")
    two_word_flags+=("--payment-method-options.link.persistent-token")
    local_nonpersistent_flags+=("--payment-method-options.link.persistent-token")
    local_nonpersistent_flags+=("--payment-method-options.link.persistent-token=")
    flags+=("--payment-method-options.paypal.billing-agreement-id=")
    two_word_flags+=("--payment-method-options.paypal.billing-agreement-id")
    local_nonpersistent_flags+=("--payment-method-options.paypal.billing-agreement-id")
    local_nonpersistent_flags+=("--payment-method-options.paypal.billing-agreement-id=")
    flags+=("--payment-method-options.us-bank-account.financial-connections.filters.account-subcategories=")
    two_word_flags+=("--payment-method-options.us-bank-account.financial-connections.filters.account-subcategories")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.filters.account-subcategories")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.filters.account-subcategories=")
    flags+=("--payment-method-options.us-bank-account.financial-connections.permissions=")
    two_word_flags+=("--payment-method-options.us-bank-account.financial-connections.permissions")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.permissions")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.permissions=")
    flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch=")
    two_word_flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch=")
    flags+=("--payment-method-options.us-bank-account.financial-connections.return-url=")
    two_word_flags+=("--payment-method-options.us-bank-account.financial-connections.return-url")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.return-url")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.return-url=")
    flags+=("--payment-method-options.us-bank-account.mandate-options.collection-method=")
    two_word_flags+=("--payment-method-options.us-bank-account.mandate-options.collection-method")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.mandate-options.collection-method")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.mandate-options.collection-method=")
    flags+=("--payment-method-options.us-bank-account.networks.requested=")
    two_word_flags+=("--payment-method-options.us-bank-account.networks.requested")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.networks.requested")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.networks.requested=")
    flags+=("--payment-method-options.us-bank-account.verification-method=")
    two_word_flags+=("--payment-method-options.us-bank-account.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.verification-method=")
    flags+=("--return-url=")
    two_word_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--use-stripe-sdk=")
    two_word_flags+=("--use-stripe-sdk")
    local_nonpersistent_flags+=("--use-stripe-sdk")
    local_nonpersistent_flags+=("--use-stripe-sdk=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_setup_intents_create()
{
    last_command="stripe_setup_intents_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--attach-to-self=")
    two_word_flags+=("--attach-to-self")
    local_nonpersistent_flags+=("--attach-to-self")
    local_nonpersistent_flags+=("--attach-to-self=")
    flags+=("--automatic-payment-methods.allow-redirects=")
    two_word_flags+=("--automatic-payment-methods.allow-redirects")
    local_nonpersistent_flags+=("--automatic-payment-methods.allow-redirects")
    local_nonpersistent_flags+=("--automatic-payment-methods.allow-redirects=")
    flags+=("--automatic-payment-methods.enabled=")
    two_word_flags+=("--automatic-payment-methods.enabled")
    local_nonpersistent_flags+=("--automatic-payment-methods.enabled")
    local_nonpersistent_flags+=("--automatic-payment-methods.enabled=")
    flags+=("--confirm=")
    two_word_flags+=("--confirm")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("--confirm=")
    flags+=("--confirmation-token=")
    two_word_flags+=("--confirmation-token")
    local_nonpersistent_flags+=("--confirmation-token")
    local_nonpersistent_flags+=("--confirmation-token=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--flow-directions=")
    two_word_flags+=("--flow-directions")
    local_nonpersistent_flags+=("--flow-directions")
    local_nonpersistent_flags+=("--flow-directions=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--on-behalf-of=")
    two_word_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of=")
    flags+=("--payment-method=")
    two_word_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method=")
    flags+=("--payment-method-configuration=")
    two_word_flags+=("--payment-method-configuration")
    local_nonpersistent_flags+=("--payment-method-configuration")
    local_nonpersistent_flags+=("--payment-method-configuration=")
    flags+=("--payment-method-data.acss-debit.account-number=")
    two_word_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number=")
    flags+=("--payment-method-data.acss-debit.institution-number=")
    two_word_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number=")
    flags+=("--payment-method-data.acss-debit.transit-number=")
    two_word_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number=")
    flags+=("--payment-method-data.allow-redisplay=")
    two_word_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay=")
    flags+=("--payment-method-data.au-becs-debit.account-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number=")
    flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    flags+=("--payment-method-data.bacs-debit.account-number=")
    two_word_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number=")
    flags+=("--payment-method-data.bacs-debit.sort-code=")
    two_word_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code=")
    flags+=("--payment-method-data.billing-details.email=")
    two_word_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email=")
    flags+=("--payment-method-data.billing-details.name=")
    two_word_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name=")
    flags+=("--payment-method-data.billing-details.phone=")
    two_word_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone=")
    flags+=("--payment-method-data.boleto.tax-id=")
    two_word_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id=")
    flags+=("--payment-method-data.eps.bank=")
    two_word_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank=")
    flags+=("--payment-method-data.fpx.account-holder-type=")
    two_word_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type=")
    flags+=("--payment-method-data.fpx.bank=")
    two_word_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank=")
    flags+=("--payment-method-data.ideal.bank=")
    two_word_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank=")
    flags+=("--payment-method-data.klarna.dob.day=")
    two_word_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day=")
    flags+=("--payment-method-data.klarna.dob.month=")
    two_word_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month=")
    flags+=("--payment-method-data.klarna.dob.year=")
    two_word_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year=")
    flags+=("--payment-method-data.naver-pay.funding=")
    two_word_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding=")
    flags+=("--payment-method-data.p24.bank=")
    two_word_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank=")
    flags+=("--payment-method-data.radar-options.session=")
    two_word_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session=")
    flags+=("--payment-method-data.sepa-debit.iban=")
    two_word_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban=")
    flags+=("--payment-method-data.sofort.country=")
    two_word_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country=")
    flags+=("--payment-method-data.type=")
    two_word_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type=")
    flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    flags+=("--payment-method-data.us-bank-account.account-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number=")
    flags+=("--payment-method-data.us-bank-account.account-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type=")
    flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    two_word_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    flags+=("--payment-method-data.us-bank-account.routing-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number=")
    flags+=("--payment-method-options.acss-debit.currency=")
    two_word_flags+=("--payment-method-options.acss-debit.currency")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.currency")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.currency=")
    flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url=")
    flags+=("--payment-method-options.acss-debit.mandate-options.default-for=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.default-for")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.default-for")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.default-for=")
    flags+=("--payment-method-options.acss-debit.mandate-options.interval-description=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.interval-description")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.interval-description")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.interval-description=")
    flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule=")
    flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type=")
    flags+=("--payment-method-options.acss-debit.verification-method=")
    two_word_flags+=("--payment-method-options.acss-debit.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.verification-method=")
    flags+=("--payment-method-options.card.mandate-options.amount=")
    two_word_flags+=("--payment-method-options.card.mandate-options.amount")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.amount")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.amount=")
    flags+=("--payment-method-options.card.mandate-options.amount-type=")
    two_word_flags+=("--payment-method-options.card.mandate-options.amount-type")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.amount-type")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.amount-type=")
    flags+=("--payment-method-options.card.mandate-options.currency=")
    two_word_flags+=("--payment-method-options.card.mandate-options.currency")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.currency")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.currency=")
    flags+=("--payment-method-options.card.mandate-options.description=")
    two_word_flags+=("--payment-method-options.card.mandate-options.description")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.description")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.description=")
    flags+=("--payment-method-options.card.mandate-options.end-date=")
    two_word_flags+=("--payment-method-options.card.mandate-options.end-date")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.end-date")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.end-date=")
    flags+=("--payment-method-options.card.mandate-options.interval=")
    two_word_flags+=("--payment-method-options.card.mandate-options.interval")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.interval")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.interval=")
    flags+=("--payment-method-options.card.mandate-options.interval-count=")
    two_word_flags+=("--payment-method-options.card.mandate-options.interval-count")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.interval-count")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.interval-count=")
    flags+=("--payment-method-options.card.mandate-options.reference=")
    two_word_flags+=("--payment-method-options.card.mandate-options.reference")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.reference")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.reference=")
    flags+=("--payment-method-options.card.mandate-options.start-date=")
    two_word_flags+=("--payment-method-options.card.mandate-options.start-date")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.start-date")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.start-date=")
    flags+=("--payment-method-options.card.mandate-options.supported-types=")
    two_word_flags+=("--payment-method-options.card.mandate-options.supported-types")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.supported-types")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.supported-types=")
    flags+=("--payment-method-options.card.moto=")
    two_word_flags+=("--payment-method-options.card.moto")
    local_nonpersistent_flags+=("--payment-method-options.card.moto")
    local_nonpersistent_flags+=("--payment-method-options.card.moto=")
    flags+=("--payment-method-options.card.network=")
    two_word_flags+=("--payment-method-options.card.network")
    local_nonpersistent_flags+=("--payment-method-options.card.network")
    local_nonpersistent_flags+=("--payment-method-options.card.network=")
    flags+=("--payment-method-options.card.request-three-d-secure=")
    two_word_flags+=("--payment-method-options.card.request-three-d-secure")
    local_nonpersistent_flags+=("--payment-method-options.card.request-three-d-secure")
    local_nonpersistent_flags+=("--payment-method-options.card.request-three-d-secure=")
    flags+=("--payment-method-options.card.three-d-secure.ares-trans-status=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.ares-trans-status")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.ares-trans-status")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.ares-trans-status=")
    flags+=("--payment-method-options.card.three-d-secure.cryptogram=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.cryptogram")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.cryptogram")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.cryptogram=")
    flags+=("--payment-method-options.card.three-d-secure.electronic-commerce-indicator=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.electronic-commerce-indicator")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.electronic-commerce-indicator")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.electronic-commerce-indicator=")
    flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-avalgo=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-avalgo")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-avalgo")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-avalgo=")
    flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-exemption=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-exemption")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-exemption")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-exemption=")
    flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-score=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-score")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-score")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-score=")
    flags+=("--payment-method-options.card.three-d-secure.requestor-challenge-indicator=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.requestor-challenge-indicator")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.requestor-challenge-indicator")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.requestor-challenge-indicator=")
    flags+=("--payment-method-options.card.three-d-secure.transaction-id=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.transaction-id")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.transaction-id")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.transaction-id=")
    flags+=("--payment-method-options.card.three-d-secure.version=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.version")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.version")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.version=")
    flags+=("--payment-method-options.link.persistent-token=")
    two_word_flags+=("--payment-method-options.link.persistent-token")
    local_nonpersistent_flags+=("--payment-method-options.link.persistent-token")
    local_nonpersistent_flags+=("--payment-method-options.link.persistent-token=")
    flags+=("--payment-method-options.paypal.billing-agreement-id=")
    two_word_flags+=("--payment-method-options.paypal.billing-agreement-id")
    local_nonpersistent_flags+=("--payment-method-options.paypal.billing-agreement-id")
    local_nonpersistent_flags+=("--payment-method-options.paypal.billing-agreement-id=")
    flags+=("--payment-method-options.us-bank-account.financial-connections.filters.account-subcategories=")
    two_word_flags+=("--payment-method-options.us-bank-account.financial-connections.filters.account-subcategories")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.filters.account-subcategories")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.filters.account-subcategories=")
    flags+=("--payment-method-options.us-bank-account.financial-connections.permissions=")
    two_word_flags+=("--payment-method-options.us-bank-account.financial-connections.permissions")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.permissions")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.permissions=")
    flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch=")
    two_word_flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch=")
    flags+=("--payment-method-options.us-bank-account.financial-connections.return-url=")
    two_word_flags+=("--payment-method-options.us-bank-account.financial-connections.return-url")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.return-url")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.return-url=")
    flags+=("--payment-method-options.us-bank-account.mandate-options.collection-method=")
    two_word_flags+=("--payment-method-options.us-bank-account.mandate-options.collection-method")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.mandate-options.collection-method")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.mandate-options.collection-method=")
    flags+=("--payment-method-options.us-bank-account.networks.requested=")
    two_word_flags+=("--payment-method-options.us-bank-account.networks.requested")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.networks.requested")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.networks.requested=")
    flags+=("--payment-method-options.us-bank-account.verification-method=")
    two_word_flags+=("--payment-method-options.us-bank-account.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.verification-method=")
    flags+=("--payment-method-types=")
    two_word_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types=")
    flags+=("--return-url=")
    two_word_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--single-use.amount=")
    two_word_flags+=("--single-use.amount")
    local_nonpersistent_flags+=("--single-use.amount")
    local_nonpersistent_flags+=("--single-use.amount=")
    flags+=("--single-use.currency=")
    two_word_flags+=("--single-use.currency")
    local_nonpersistent_flags+=("--single-use.currency")
    local_nonpersistent_flags+=("--single-use.currency=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--usage=")
    two_word_flags+=("--usage")
    local_nonpersistent_flags+=("--usage")
    local_nonpersistent_flags+=("--usage=")
    flags+=("--use-stripe-sdk=")
    two_word_flags+=("--use-stripe-sdk")
    local_nonpersistent_flags+=("--use-stripe-sdk")
    local_nonpersistent_flags+=("--use-stripe-sdk=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_setup_intents_list()
{
    last_command="stripe_setup_intents_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--attach-to-self=")
    two_word_flags+=("--attach-to-self")
    local_nonpersistent_flags+=("--attach-to-self")
    local_nonpersistent_flags+=("--attach-to-self=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-method=")
    two_word_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_setup_intents_retrieve()
{
    last_command="stripe_setup_intents_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--client-secret=")
    two_word_flags+=("--client-secret")
    local_nonpersistent_flags+=("--client-secret")
    local_nonpersistent_flags+=("--client-secret=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_setup_intents_update()
{
    last_command="stripe_setup_intents_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--attach-to-self=")
    two_word_flags+=("--attach-to-self")
    local_nonpersistent_flags+=("--attach-to-self")
    local_nonpersistent_flags+=("--attach-to-self=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--flow-directions=")
    two_word_flags+=("--flow-directions")
    local_nonpersistent_flags+=("--flow-directions")
    local_nonpersistent_flags+=("--flow-directions=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-method=")
    two_word_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method=")
    flags+=("--payment-method-configuration=")
    two_word_flags+=("--payment-method-configuration")
    local_nonpersistent_flags+=("--payment-method-configuration")
    local_nonpersistent_flags+=("--payment-method-configuration=")
    flags+=("--payment-method-data.acss-debit.account-number=")
    two_word_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number=")
    flags+=("--payment-method-data.acss-debit.institution-number=")
    two_word_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number=")
    flags+=("--payment-method-data.acss-debit.transit-number=")
    two_word_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number=")
    flags+=("--payment-method-data.allow-redisplay=")
    two_word_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay=")
    flags+=("--payment-method-data.au-becs-debit.account-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number=")
    flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    flags+=("--payment-method-data.bacs-debit.account-number=")
    two_word_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number=")
    flags+=("--payment-method-data.bacs-debit.sort-code=")
    two_word_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code=")
    flags+=("--payment-method-data.billing-details.email=")
    two_word_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email=")
    flags+=("--payment-method-data.billing-details.name=")
    two_word_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name=")
    flags+=("--payment-method-data.billing-details.phone=")
    two_word_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone=")
    flags+=("--payment-method-data.boleto.tax-id=")
    two_word_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id=")
    flags+=("--payment-method-data.eps.bank=")
    two_word_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank=")
    flags+=("--payment-method-data.fpx.account-holder-type=")
    two_word_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type=")
    flags+=("--payment-method-data.fpx.bank=")
    two_word_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank=")
    flags+=("--payment-method-data.ideal.bank=")
    two_word_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank=")
    flags+=("--payment-method-data.klarna.dob.day=")
    two_word_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day=")
    flags+=("--payment-method-data.klarna.dob.month=")
    two_word_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month=")
    flags+=("--payment-method-data.klarna.dob.year=")
    two_word_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year=")
    flags+=("--payment-method-data.naver-pay.funding=")
    two_word_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding=")
    flags+=("--payment-method-data.p24.bank=")
    two_word_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank=")
    flags+=("--payment-method-data.radar-options.session=")
    two_word_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session=")
    flags+=("--payment-method-data.sepa-debit.iban=")
    two_word_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban=")
    flags+=("--payment-method-data.sofort.country=")
    two_word_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country=")
    flags+=("--payment-method-data.type=")
    two_word_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type=")
    flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    flags+=("--payment-method-data.us-bank-account.account-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number=")
    flags+=("--payment-method-data.us-bank-account.account-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type=")
    flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    two_word_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    flags+=("--payment-method-data.us-bank-account.routing-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number=")
    flags+=("--payment-method-options.acss-debit.currency=")
    two_word_flags+=("--payment-method-options.acss-debit.currency")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.currency")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.currency=")
    flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.custom-mandate-url=")
    flags+=("--payment-method-options.acss-debit.mandate-options.default-for=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.default-for")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.default-for")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.default-for=")
    flags+=("--payment-method-options.acss-debit.mandate-options.interval-description=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.interval-description")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.interval-description")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.interval-description=")
    flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.payment-schedule=")
    flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type=")
    two_word_flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.mandate-options.transaction-type=")
    flags+=("--payment-method-options.acss-debit.verification-method=")
    two_word_flags+=("--payment-method-options.acss-debit.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.acss-debit.verification-method=")
    flags+=("--payment-method-options.card.mandate-options.amount=")
    two_word_flags+=("--payment-method-options.card.mandate-options.amount")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.amount")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.amount=")
    flags+=("--payment-method-options.card.mandate-options.amount-type=")
    two_word_flags+=("--payment-method-options.card.mandate-options.amount-type")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.amount-type")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.amount-type=")
    flags+=("--payment-method-options.card.mandate-options.currency=")
    two_word_flags+=("--payment-method-options.card.mandate-options.currency")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.currency")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.currency=")
    flags+=("--payment-method-options.card.mandate-options.description=")
    two_word_flags+=("--payment-method-options.card.mandate-options.description")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.description")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.description=")
    flags+=("--payment-method-options.card.mandate-options.end-date=")
    two_word_flags+=("--payment-method-options.card.mandate-options.end-date")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.end-date")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.end-date=")
    flags+=("--payment-method-options.card.mandate-options.interval=")
    two_word_flags+=("--payment-method-options.card.mandate-options.interval")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.interval")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.interval=")
    flags+=("--payment-method-options.card.mandate-options.interval-count=")
    two_word_flags+=("--payment-method-options.card.mandate-options.interval-count")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.interval-count")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.interval-count=")
    flags+=("--payment-method-options.card.mandate-options.reference=")
    two_word_flags+=("--payment-method-options.card.mandate-options.reference")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.reference")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.reference=")
    flags+=("--payment-method-options.card.mandate-options.start-date=")
    two_word_flags+=("--payment-method-options.card.mandate-options.start-date")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.start-date")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.start-date=")
    flags+=("--payment-method-options.card.mandate-options.supported-types=")
    two_word_flags+=("--payment-method-options.card.mandate-options.supported-types")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.supported-types")
    local_nonpersistent_flags+=("--payment-method-options.card.mandate-options.supported-types=")
    flags+=("--payment-method-options.card.moto=")
    two_word_flags+=("--payment-method-options.card.moto")
    local_nonpersistent_flags+=("--payment-method-options.card.moto")
    local_nonpersistent_flags+=("--payment-method-options.card.moto=")
    flags+=("--payment-method-options.card.network=")
    two_word_flags+=("--payment-method-options.card.network")
    local_nonpersistent_flags+=("--payment-method-options.card.network")
    local_nonpersistent_flags+=("--payment-method-options.card.network=")
    flags+=("--payment-method-options.card.request-three-d-secure=")
    two_word_flags+=("--payment-method-options.card.request-three-d-secure")
    local_nonpersistent_flags+=("--payment-method-options.card.request-three-d-secure")
    local_nonpersistent_flags+=("--payment-method-options.card.request-three-d-secure=")
    flags+=("--payment-method-options.card.three-d-secure.ares-trans-status=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.ares-trans-status")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.ares-trans-status")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.ares-trans-status=")
    flags+=("--payment-method-options.card.three-d-secure.cryptogram=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.cryptogram")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.cryptogram")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.cryptogram=")
    flags+=("--payment-method-options.card.three-d-secure.electronic-commerce-indicator=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.electronic-commerce-indicator")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.electronic-commerce-indicator")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.electronic-commerce-indicator=")
    flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-avalgo=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-avalgo")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-avalgo")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-avalgo=")
    flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-exemption=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-exemption")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-exemption")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-exemption=")
    flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-score=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-score")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-score")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.network-options.cartes-bancaires.cb-score=")
    flags+=("--payment-method-options.card.three-d-secure.requestor-challenge-indicator=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.requestor-challenge-indicator")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.requestor-challenge-indicator")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.requestor-challenge-indicator=")
    flags+=("--payment-method-options.card.three-d-secure.transaction-id=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.transaction-id")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.transaction-id")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.transaction-id=")
    flags+=("--payment-method-options.card.three-d-secure.version=")
    two_word_flags+=("--payment-method-options.card.three-d-secure.version")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.version")
    local_nonpersistent_flags+=("--payment-method-options.card.three-d-secure.version=")
    flags+=("--payment-method-options.link.persistent-token=")
    two_word_flags+=("--payment-method-options.link.persistent-token")
    local_nonpersistent_flags+=("--payment-method-options.link.persistent-token")
    local_nonpersistent_flags+=("--payment-method-options.link.persistent-token=")
    flags+=("--payment-method-options.paypal.billing-agreement-id=")
    two_word_flags+=("--payment-method-options.paypal.billing-agreement-id")
    local_nonpersistent_flags+=("--payment-method-options.paypal.billing-agreement-id")
    local_nonpersistent_flags+=("--payment-method-options.paypal.billing-agreement-id=")
    flags+=("--payment-method-options.us-bank-account.financial-connections.filters.account-subcategories=")
    two_word_flags+=("--payment-method-options.us-bank-account.financial-connections.filters.account-subcategories")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.filters.account-subcategories")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.filters.account-subcategories=")
    flags+=("--payment-method-options.us-bank-account.financial-connections.permissions=")
    two_word_flags+=("--payment-method-options.us-bank-account.financial-connections.permissions")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.permissions")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.permissions=")
    flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch=")
    two_word_flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.prefetch=")
    flags+=("--payment-method-options.us-bank-account.financial-connections.return-url=")
    two_word_flags+=("--payment-method-options.us-bank-account.financial-connections.return-url")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.return-url")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.financial-connections.return-url=")
    flags+=("--payment-method-options.us-bank-account.mandate-options.collection-method=")
    two_word_flags+=("--payment-method-options.us-bank-account.mandate-options.collection-method")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.mandate-options.collection-method")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.mandate-options.collection-method=")
    flags+=("--payment-method-options.us-bank-account.networks.requested=")
    two_word_flags+=("--payment-method-options.us-bank-account.networks.requested")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.networks.requested")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.networks.requested=")
    flags+=("--payment-method-options.us-bank-account.verification-method=")
    two_word_flags+=("--payment-method-options.us-bank-account.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.verification-method")
    local_nonpersistent_flags+=("--payment-method-options.us-bank-account.verification-method=")
    flags+=("--payment-method-types=")
    two_word_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types")
    local_nonpersistent_flags+=("--payment-method-types=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_setup_intents_verify_microdeposits()
{
    last_command="stripe_setup_intents_verify_microdeposits"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amounts=")
    two_word_flags+=("--amounts")
    local_nonpersistent_flags+=("--amounts")
    local_nonpersistent_flags+=("--amounts=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--descriptor-code=")
    two_word_flags+=("--descriptor-code")
    local_nonpersistent_flags+=("--descriptor-code")
    local_nonpersistent_flags+=("--descriptor-code=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_setup_intents()
{
    last_command="stripe_setup_intents"

    command_aliases=()

    commands=()
    commands+=("cancel")
    commands+=("confirm")
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")
    commands+=("verify_microdeposits")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_shipping_rates_create()
{
    last_command="stripe_shipping_rates_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--delivery-estimate.maximum.unit=")
    two_word_flags+=("--delivery-estimate.maximum.unit")
    local_nonpersistent_flags+=("--delivery-estimate.maximum.unit")
    local_nonpersistent_flags+=("--delivery-estimate.maximum.unit=")
    flags+=("--delivery-estimate.maximum.value=")
    two_word_flags+=("--delivery-estimate.maximum.value")
    local_nonpersistent_flags+=("--delivery-estimate.maximum.value")
    local_nonpersistent_flags+=("--delivery-estimate.maximum.value=")
    flags+=("--delivery-estimate.minimum.unit=")
    two_word_flags+=("--delivery-estimate.minimum.unit")
    local_nonpersistent_flags+=("--delivery-estimate.minimum.unit")
    local_nonpersistent_flags+=("--delivery-estimate.minimum.unit=")
    flags+=("--delivery-estimate.minimum.value=")
    two_word_flags+=("--delivery-estimate.minimum.value")
    local_nonpersistent_flags+=("--delivery-estimate.minimum.value")
    local_nonpersistent_flags+=("--delivery-estimate.minimum.value=")
    flags+=("--display-name=")
    two_word_flags+=("--display-name")
    local_nonpersistent_flags+=("--display-name")
    local_nonpersistent_flags+=("--display-name=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--fixed-amount.amount=")
    two_word_flags+=("--fixed-amount.amount")
    local_nonpersistent_flags+=("--fixed-amount.amount")
    local_nonpersistent_flags+=("--fixed-amount.amount=")
    flags+=("--fixed-amount.currency=")
    two_word_flags+=("--fixed-amount.currency")
    local_nonpersistent_flags+=("--fixed-amount.currency")
    local_nonpersistent_flags+=("--fixed-amount.currency=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tax-behavior=")
    two_word_flags+=("--tax-behavior")
    local_nonpersistent_flags+=("--tax-behavior")
    local_nonpersistent_flags+=("--tax-behavior=")
    flags+=("--tax-code=")
    two_word_flags+=("--tax-code")
    local_nonpersistent_flags+=("--tax-code")
    local_nonpersistent_flags+=("--tax-code=")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_shipping_rates_list()
{
    last_command="stripe_shipping_rates_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_shipping_rates_retrieve()
{
    last_command="stripe_shipping_rates_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_shipping_rates_update()
{
    last_command="stripe_shipping_rates_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tax-behavior=")
    two_word_flags+=("--tax-behavior")
    local_nonpersistent_flags+=("--tax-behavior")
    local_nonpersistent_flags+=("--tax-behavior=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_shipping_rates()
{
    last_command="stripe_shipping_rates"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_sources_create()
{
    last_command="stripe_sources_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--flow=")
    two_word_flags+=("--flow")
    local_nonpersistent_flags+=("--flow")
    local_nonpersistent_flags+=("--flow=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--mandate.acceptance.date=")
    two_word_flags+=("--mandate.acceptance.date")
    local_nonpersistent_flags+=("--mandate.acceptance.date")
    local_nonpersistent_flags+=("--mandate.acceptance.date=")
    flags+=("--mandate.acceptance.ip=")
    two_word_flags+=("--mandate.acceptance.ip")
    local_nonpersistent_flags+=("--mandate.acceptance.ip")
    local_nonpersistent_flags+=("--mandate.acceptance.ip=")
    flags+=("--mandate.acceptance.offline.contact-email=")
    two_word_flags+=("--mandate.acceptance.offline.contact-email")
    local_nonpersistent_flags+=("--mandate.acceptance.offline.contact-email")
    local_nonpersistent_flags+=("--mandate.acceptance.offline.contact-email=")
    flags+=("--mandate.acceptance.online.date=")
    two_word_flags+=("--mandate.acceptance.online.date")
    local_nonpersistent_flags+=("--mandate.acceptance.online.date")
    local_nonpersistent_flags+=("--mandate.acceptance.online.date=")
    flags+=("--mandate.acceptance.online.ip=")
    two_word_flags+=("--mandate.acceptance.online.ip")
    local_nonpersistent_flags+=("--mandate.acceptance.online.ip")
    local_nonpersistent_flags+=("--mandate.acceptance.online.ip=")
    flags+=("--mandate.acceptance.online.user-agent=")
    two_word_flags+=("--mandate.acceptance.online.user-agent")
    local_nonpersistent_flags+=("--mandate.acceptance.online.user-agent")
    local_nonpersistent_flags+=("--mandate.acceptance.online.user-agent=")
    flags+=("--mandate.acceptance.status=")
    two_word_flags+=("--mandate.acceptance.status")
    local_nonpersistent_flags+=("--mandate.acceptance.status")
    local_nonpersistent_flags+=("--mandate.acceptance.status=")
    flags+=("--mandate.acceptance.type=")
    two_word_flags+=("--mandate.acceptance.type")
    local_nonpersistent_flags+=("--mandate.acceptance.type")
    local_nonpersistent_flags+=("--mandate.acceptance.type=")
    flags+=("--mandate.acceptance.user-agent=")
    two_word_flags+=("--mandate.acceptance.user-agent")
    local_nonpersistent_flags+=("--mandate.acceptance.user-agent")
    local_nonpersistent_flags+=("--mandate.acceptance.user-agent=")
    flags+=("--mandate.amount=")
    two_word_flags+=("--mandate.amount")
    local_nonpersistent_flags+=("--mandate.amount")
    local_nonpersistent_flags+=("--mandate.amount=")
    flags+=("--mandate.currency=")
    two_word_flags+=("--mandate.currency")
    local_nonpersistent_flags+=("--mandate.currency")
    local_nonpersistent_flags+=("--mandate.currency=")
    flags+=("--mandate.interval=")
    two_word_flags+=("--mandate.interval")
    local_nonpersistent_flags+=("--mandate.interval")
    local_nonpersistent_flags+=("--mandate.interval=")
    flags+=("--mandate.notification-method=")
    two_word_flags+=("--mandate.notification-method")
    local_nonpersistent_flags+=("--mandate.notification-method")
    local_nonpersistent_flags+=("--mandate.notification-method=")
    flags+=("--original-source=")
    two_word_flags+=("--original-source")
    local_nonpersistent_flags+=("--original-source")
    local_nonpersistent_flags+=("--original-source=")
    flags+=("--owner.address.city=")
    two_word_flags+=("--owner.address.city")
    local_nonpersistent_flags+=("--owner.address.city")
    local_nonpersistent_flags+=("--owner.address.city=")
    flags+=("--owner.address.country=")
    two_word_flags+=("--owner.address.country")
    local_nonpersistent_flags+=("--owner.address.country")
    local_nonpersistent_flags+=("--owner.address.country=")
    flags+=("--owner.address.line1=")
    two_word_flags+=("--owner.address.line1")
    local_nonpersistent_flags+=("--owner.address.line1")
    local_nonpersistent_flags+=("--owner.address.line1=")
    flags+=("--owner.address.line2=")
    two_word_flags+=("--owner.address.line2")
    local_nonpersistent_flags+=("--owner.address.line2")
    local_nonpersistent_flags+=("--owner.address.line2=")
    flags+=("--owner.address.postal-code=")
    two_word_flags+=("--owner.address.postal-code")
    local_nonpersistent_flags+=("--owner.address.postal-code")
    local_nonpersistent_flags+=("--owner.address.postal-code=")
    flags+=("--owner.address.state=")
    two_word_flags+=("--owner.address.state")
    local_nonpersistent_flags+=("--owner.address.state")
    local_nonpersistent_flags+=("--owner.address.state=")
    flags+=("--owner.email=")
    two_word_flags+=("--owner.email")
    local_nonpersistent_flags+=("--owner.email")
    local_nonpersistent_flags+=("--owner.email=")
    flags+=("--owner.name=")
    two_word_flags+=("--owner.name")
    local_nonpersistent_flags+=("--owner.name")
    local_nonpersistent_flags+=("--owner.name=")
    flags+=("--owner.phone=")
    two_word_flags+=("--owner.phone")
    local_nonpersistent_flags+=("--owner.phone")
    local_nonpersistent_flags+=("--owner.phone=")
    flags+=("--receiver.refund-attributes-method=")
    two_word_flags+=("--receiver.refund-attributes-method")
    local_nonpersistent_flags+=("--receiver.refund-attributes-method")
    local_nonpersistent_flags+=("--receiver.refund-attributes-method=")
    flags+=("--redirect.return-url=")
    two_word_flags+=("--redirect.return-url")
    local_nonpersistent_flags+=("--redirect.return-url")
    local_nonpersistent_flags+=("--redirect.return-url=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--source-order.shipping.address.city=")
    two_word_flags+=("--source-order.shipping.address.city")
    local_nonpersistent_flags+=("--source-order.shipping.address.city")
    local_nonpersistent_flags+=("--source-order.shipping.address.city=")
    flags+=("--source-order.shipping.address.country=")
    two_word_flags+=("--source-order.shipping.address.country")
    local_nonpersistent_flags+=("--source-order.shipping.address.country")
    local_nonpersistent_flags+=("--source-order.shipping.address.country=")
    flags+=("--source-order.shipping.address.line1=")
    two_word_flags+=("--source-order.shipping.address.line1")
    local_nonpersistent_flags+=("--source-order.shipping.address.line1")
    local_nonpersistent_flags+=("--source-order.shipping.address.line1=")
    flags+=("--source-order.shipping.address.line2=")
    two_word_flags+=("--source-order.shipping.address.line2")
    local_nonpersistent_flags+=("--source-order.shipping.address.line2")
    local_nonpersistent_flags+=("--source-order.shipping.address.line2=")
    flags+=("--source-order.shipping.address.postal-code=")
    two_word_flags+=("--source-order.shipping.address.postal-code")
    local_nonpersistent_flags+=("--source-order.shipping.address.postal-code")
    local_nonpersistent_flags+=("--source-order.shipping.address.postal-code=")
    flags+=("--source-order.shipping.address.state=")
    two_word_flags+=("--source-order.shipping.address.state")
    local_nonpersistent_flags+=("--source-order.shipping.address.state")
    local_nonpersistent_flags+=("--source-order.shipping.address.state=")
    flags+=("--source-order.shipping.carrier=")
    two_word_flags+=("--source-order.shipping.carrier")
    local_nonpersistent_flags+=("--source-order.shipping.carrier")
    local_nonpersistent_flags+=("--source-order.shipping.carrier=")
    flags+=("--source-order.shipping.name=")
    two_word_flags+=("--source-order.shipping.name")
    local_nonpersistent_flags+=("--source-order.shipping.name")
    local_nonpersistent_flags+=("--source-order.shipping.name=")
    flags+=("--source-order.shipping.phone=")
    two_word_flags+=("--source-order.shipping.phone")
    local_nonpersistent_flags+=("--source-order.shipping.phone")
    local_nonpersistent_flags+=("--source-order.shipping.phone=")
    flags+=("--source-order.shipping.tracking-number=")
    two_word_flags+=("--source-order.shipping.tracking-number")
    local_nonpersistent_flags+=("--source-order.shipping.tracking-number")
    local_nonpersistent_flags+=("--source-order.shipping.tracking-number=")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--token=")
    two_word_flags+=("--token")
    local_nonpersistent_flags+=("--token")
    local_nonpersistent_flags+=("--token=")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--usage=")
    two_word_flags+=("--usage")
    local_nonpersistent_flags+=("--usage")
    local_nonpersistent_flags+=("--usage=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_sources_detach()
{
    last_command="stripe_sources_detach"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_sources_retrieve()
{
    last_command="stripe_sources_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--client-secret=")
    two_word_flags+=("--client-secret")
    local_nonpersistent_flags+=("--client-secret")
    local_nonpersistent_flags+=("--client-secret=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_sources_source_transactions()
{
    last_command="stripe_sources_source_transactions"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_sources_update()
{
    last_command="stripe_sources_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--mandate.acceptance.date=")
    two_word_flags+=("--mandate.acceptance.date")
    local_nonpersistent_flags+=("--mandate.acceptance.date")
    local_nonpersistent_flags+=("--mandate.acceptance.date=")
    flags+=("--mandate.acceptance.ip=")
    two_word_flags+=("--mandate.acceptance.ip")
    local_nonpersistent_flags+=("--mandate.acceptance.ip")
    local_nonpersistent_flags+=("--mandate.acceptance.ip=")
    flags+=("--mandate.acceptance.offline.contact-email=")
    two_word_flags+=("--mandate.acceptance.offline.contact-email")
    local_nonpersistent_flags+=("--mandate.acceptance.offline.contact-email")
    local_nonpersistent_flags+=("--mandate.acceptance.offline.contact-email=")
    flags+=("--mandate.acceptance.online.date=")
    two_word_flags+=("--mandate.acceptance.online.date")
    local_nonpersistent_flags+=("--mandate.acceptance.online.date")
    local_nonpersistent_flags+=("--mandate.acceptance.online.date=")
    flags+=("--mandate.acceptance.online.ip=")
    two_word_flags+=("--mandate.acceptance.online.ip")
    local_nonpersistent_flags+=("--mandate.acceptance.online.ip")
    local_nonpersistent_flags+=("--mandate.acceptance.online.ip=")
    flags+=("--mandate.acceptance.online.user-agent=")
    two_word_flags+=("--mandate.acceptance.online.user-agent")
    local_nonpersistent_flags+=("--mandate.acceptance.online.user-agent")
    local_nonpersistent_flags+=("--mandate.acceptance.online.user-agent=")
    flags+=("--mandate.acceptance.status=")
    two_word_flags+=("--mandate.acceptance.status")
    local_nonpersistent_flags+=("--mandate.acceptance.status")
    local_nonpersistent_flags+=("--mandate.acceptance.status=")
    flags+=("--mandate.acceptance.type=")
    two_word_flags+=("--mandate.acceptance.type")
    local_nonpersistent_flags+=("--mandate.acceptance.type")
    local_nonpersistent_flags+=("--mandate.acceptance.type=")
    flags+=("--mandate.acceptance.user-agent=")
    two_word_flags+=("--mandate.acceptance.user-agent")
    local_nonpersistent_flags+=("--mandate.acceptance.user-agent")
    local_nonpersistent_flags+=("--mandate.acceptance.user-agent=")
    flags+=("--mandate.amount=")
    two_word_flags+=("--mandate.amount")
    local_nonpersistent_flags+=("--mandate.amount")
    local_nonpersistent_flags+=("--mandate.amount=")
    flags+=("--mandate.currency=")
    two_word_flags+=("--mandate.currency")
    local_nonpersistent_flags+=("--mandate.currency")
    local_nonpersistent_flags+=("--mandate.currency=")
    flags+=("--mandate.interval=")
    two_word_flags+=("--mandate.interval")
    local_nonpersistent_flags+=("--mandate.interval")
    local_nonpersistent_flags+=("--mandate.interval=")
    flags+=("--mandate.notification-method=")
    two_word_flags+=("--mandate.notification-method")
    local_nonpersistent_flags+=("--mandate.notification-method")
    local_nonpersistent_flags+=("--mandate.notification-method=")
    flags+=("--owner.address.city=")
    two_word_flags+=("--owner.address.city")
    local_nonpersistent_flags+=("--owner.address.city")
    local_nonpersistent_flags+=("--owner.address.city=")
    flags+=("--owner.address.country=")
    two_word_flags+=("--owner.address.country")
    local_nonpersistent_flags+=("--owner.address.country")
    local_nonpersistent_flags+=("--owner.address.country=")
    flags+=("--owner.address.line1=")
    two_word_flags+=("--owner.address.line1")
    local_nonpersistent_flags+=("--owner.address.line1")
    local_nonpersistent_flags+=("--owner.address.line1=")
    flags+=("--owner.address.line2=")
    two_word_flags+=("--owner.address.line2")
    local_nonpersistent_flags+=("--owner.address.line2")
    local_nonpersistent_flags+=("--owner.address.line2=")
    flags+=("--owner.address.postal-code=")
    two_word_flags+=("--owner.address.postal-code")
    local_nonpersistent_flags+=("--owner.address.postal-code")
    local_nonpersistent_flags+=("--owner.address.postal-code=")
    flags+=("--owner.address.state=")
    two_word_flags+=("--owner.address.state")
    local_nonpersistent_flags+=("--owner.address.state")
    local_nonpersistent_flags+=("--owner.address.state=")
    flags+=("--owner.email=")
    two_word_flags+=("--owner.email")
    local_nonpersistent_flags+=("--owner.email")
    local_nonpersistent_flags+=("--owner.email=")
    flags+=("--owner.name=")
    two_word_flags+=("--owner.name")
    local_nonpersistent_flags+=("--owner.name")
    local_nonpersistent_flags+=("--owner.name=")
    flags+=("--owner.phone=")
    two_word_flags+=("--owner.phone")
    local_nonpersistent_flags+=("--owner.phone")
    local_nonpersistent_flags+=("--owner.phone=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--source-order.shipping.address.city=")
    two_word_flags+=("--source-order.shipping.address.city")
    local_nonpersistent_flags+=("--source-order.shipping.address.city")
    local_nonpersistent_flags+=("--source-order.shipping.address.city=")
    flags+=("--source-order.shipping.address.country=")
    two_word_flags+=("--source-order.shipping.address.country")
    local_nonpersistent_flags+=("--source-order.shipping.address.country")
    local_nonpersistent_flags+=("--source-order.shipping.address.country=")
    flags+=("--source-order.shipping.address.line1=")
    two_word_flags+=("--source-order.shipping.address.line1")
    local_nonpersistent_flags+=("--source-order.shipping.address.line1")
    local_nonpersistent_flags+=("--source-order.shipping.address.line1=")
    flags+=("--source-order.shipping.address.line2=")
    two_word_flags+=("--source-order.shipping.address.line2")
    local_nonpersistent_flags+=("--source-order.shipping.address.line2")
    local_nonpersistent_flags+=("--source-order.shipping.address.line2=")
    flags+=("--source-order.shipping.address.postal-code=")
    two_word_flags+=("--source-order.shipping.address.postal-code")
    local_nonpersistent_flags+=("--source-order.shipping.address.postal-code")
    local_nonpersistent_flags+=("--source-order.shipping.address.postal-code=")
    flags+=("--source-order.shipping.address.state=")
    two_word_flags+=("--source-order.shipping.address.state")
    local_nonpersistent_flags+=("--source-order.shipping.address.state")
    local_nonpersistent_flags+=("--source-order.shipping.address.state=")
    flags+=("--source-order.shipping.carrier=")
    two_word_flags+=("--source-order.shipping.carrier")
    local_nonpersistent_flags+=("--source-order.shipping.carrier")
    local_nonpersistent_flags+=("--source-order.shipping.carrier=")
    flags+=("--source-order.shipping.name=")
    two_word_flags+=("--source-order.shipping.name")
    local_nonpersistent_flags+=("--source-order.shipping.name")
    local_nonpersistent_flags+=("--source-order.shipping.name=")
    flags+=("--source-order.shipping.phone=")
    two_word_flags+=("--source-order.shipping.phone")
    local_nonpersistent_flags+=("--source-order.shipping.phone")
    local_nonpersistent_flags+=("--source-order.shipping.phone=")
    flags+=("--source-order.shipping.tracking-number=")
    two_word_flags+=("--source-order.shipping.tracking-number")
    local_nonpersistent_flags+=("--source-order.shipping.tracking-number")
    local_nonpersistent_flags+=("--source-order.shipping.tracking-number=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_sources_verify()
{
    last_command="stripe_sources_verify"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--values=")
    two_word_flags+=("--values")
    local_nonpersistent_flags+=("--values")
    local_nonpersistent_flags+=("--values=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_sources()
{
    last_command="stripe_sources"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("detach")
    commands+=("retrieve")
    commands+=("source_transactions")
    commands+=("update")
    commands+=("verify")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscription_items_create()
{
    last_command="stripe_subscription_items_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-behavior=")
    two_word_flags+=("--payment-behavior")
    local_nonpersistent_flags+=("--payment-behavior")
    local_nonpersistent_flags+=("--payment-behavior=")
    flags+=("--plan=")
    two_word_flags+=("--plan")
    local_nonpersistent_flags+=("--plan")
    local_nonpersistent_flags+=("--plan=")
    flags+=("--price=")
    two_word_flags+=("--price")
    local_nonpersistent_flags+=("--price")
    local_nonpersistent_flags+=("--price=")
    flags+=("--price-data.currency=")
    two_word_flags+=("--price-data.currency")
    local_nonpersistent_flags+=("--price-data.currency")
    local_nonpersistent_flags+=("--price-data.currency=")
    flags+=("--price-data.product=")
    two_word_flags+=("--price-data.product")
    local_nonpersistent_flags+=("--price-data.product")
    local_nonpersistent_flags+=("--price-data.product=")
    flags+=("--price-data.recurring.interval=")
    two_word_flags+=("--price-data.recurring.interval")
    local_nonpersistent_flags+=("--price-data.recurring.interval")
    local_nonpersistent_flags+=("--price-data.recurring.interval=")
    flags+=("--price-data.recurring.interval-count=")
    two_word_flags+=("--price-data.recurring.interval-count")
    local_nonpersistent_flags+=("--price-data.recurring.interval-count")
    local_nonpersistent_flags+=("--price-data.recurring.interval-count=")
    flags+=("--price-data.tax-behavior=")
    two_word_flags+=("--price-data.tax-behavior")
    local_nonpersistent_flags+=("--price-data.tax-behavior")
    local_nonpersistent_flags+=("--price-data.tax-behavior=")
    flags+=("--price-data.unit-amount=")
    two_word_flags+=("--price-data.unit-amount")
    local_nonpersistent_flags+=("--price-data.unit-amount")
    local_nonpersistent_flags+=("--price-data.unit-amount=")
    flags+=("--price-data.unit-amount-decimal=")
    two_word_flags+=("--price-data.unit-amount-decimal")
    local_nonpersistent_flags+=("--price-data.unit-amount-decimal")
    local_nonpersistent_flags+=("--price-data.unit-amount-decimal=")
    flags+=("--proration-behavior=")
    two_word_flags+=("--proration-behavior")
    local_nonpersistent_flags+=("--proration-behavior")
    local_nonpersistent_flags+=("--proration-behavior=")
    flags+=("--proration-date=")
    two_word_flags+=("--proration-date")
    local_nonpersistent_flags+=("--proration-date")
    local_nonpersistent_flags+=("--proration-date=")
    flags+=("--quantity=")
    two_word_flags+=("--quantity")
    local_nonpersistent_flags+=("--quantity")
    local_nonpersistent_flags+=("--quantity=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--subscription=")
    two_word_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription=")
    flags+=("--tax-rates=")
    two_word_flags+=("--tax-rates")
    local_nonpersistent_flags+=("--tax-rates")
    local_nonpersistent_flags+=("--tax-rates=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscription_items_delete()
{
    last_command="stripe_subscription_items_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscription_items_list()
{
    last_command="stripe_subscription_items_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--subscription=")
    two_word_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription")
    local_nonpersistent_flags+=("--subscription=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscription_items_retrieve()
{
    last_command="stripe_subscription_items_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscription_items_update()
{
    last_command="stripe_subscription_items_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--off-session=")
    two_word_flags+=("--off-session")
    local_nonpersistent_flags+=("--off-session")
    local_nonpersistent_flags+=("--off-session=")
    flags+=("--payment-behavior=")
    two_word_flags+=("--payment-behavior")
    local_nonpersistent_flags+=("--payment-behavior")
    local_nonpersistent_flags+=("--payment-behavior=")
    flags+=("--plan=")
    two_word_flags+=("--plan")
    local_nonpersistent_flags+=("--plan")
    local_nonpersistent_flags+=("--plan=")
    flags+=("--price=")
    two_word_flags+=("--price")
    local_nonpersistent_flags+=("--price")
    local_nonpersistent_flags+=("--price=")
    flags+=("--price-data.currency=")
    two_word_flags+=("--price-data.currency")
    local_nonpersistent_flags+=("--price-data.currency")
    local_nonpersistent_flags+=("--price-data.currency=")
    flags+=("--price-data.product=")
    two_word_flags+=("--price-data.product")
    local_nonpersistent_flags+=("--price-data.product")
    local_nonpersistent_flags+=("--price-data.product=")
    flags+=("--price-data.recurring.interval=")
    two_word_flags+=("--price-data.recurring.interval")
    local_nonpersistent_flags+=("--price-data.recurring.interval")
    local_nonpersistent_flags+=("--price-data.recurring.interval=")
    flags+=("--price-data.recurring.interval-count=")
    two_word_flags+=("--price-data.recurring.interval-count")
    local_nonpersistent_flags+=("--price-data.recurring.interval-count")
    local_nonpersistent_flags+=("--price-data.recurring.interval-count=")
    flags+=("--price-data.tax-behavior=")
    two_word_flags+=("--price-data.tax-behavior")
    local_nonpersistent_flags+=("--price-data.tax-behavior")
    local_nonpersistent_flags+=("--price-data.tax-behavior=")
    flags+=("--price-data.unit-amount=")
    two_word_flags+=("--price-data.unit-amount")
    local_nonpersistent_flags+=("--price-data.unit-amount")
    local_nonpersistent_flags+=("--price-data.unit-amount=")
    flags+=("--price-data.unit-amount-decimal=")
    two_word_flags+=("--price-data.unit-amount-decimal")
    local_nonpersistent_flags+=("--price-data.unit-amount-decimal")
    local_nonpersistent_flags+=("--price-data.unit-amount-decimal=")
    flags+=("--proration-behavior=")
    two_word_flags+=("--proration-behavior")
    local_nonpersistent_flags+=("--proration-behavior")
    local_nonpersistent_flags+=("--proration-behavior=")
    flags+=("--proration-date=")
    two_word_flags+=("--proration-date")
    local_nonpersistent_flags+=("--proration-date")
    local_nonpersistent_flags+=("--proration-date=")
    flags+=("--quantity=")
    two_word_flags+=("--quantity")
    local_nonpersistent_flags+=("--quantity")
    local_nonpersistent_flags+=("--quantity=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tax-rates=")
    two_word_flags+=("--tax-rates")
    local_nonpersistent_flags+=("--tax-rates")
    local_nonpersistent_flags+=("--tax-rates=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscription_items_usage_record_summaries()
{
    last_command="stripe_subscription_items_usage_record_summaries"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscription_items()
{
    last_command="stripe_subscription_items"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")
    commands+=("usage_record_summaries")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscription_schedules_cancel()
{
    last_command="stripe_subscription_schedules_cancel"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--invoice-now=")
    two_word_flags+=("--invoice-now")
    local_nonpersistent_flags+=("--invoice-now")
    local_nonpersistent_flags+=("--invoice-now=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--prorate=")
    two_word_flags+=("--prorate")
    local_nonpersistent_flags+=("--prorate")
    local_nonpersistent_flags+=("--prorate=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscription_schedules_create()
{
    last_command="stripe_subscription_schedules_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-settings.application-fee-percent=")
    two_word_flags+=("--default-settings.application-fee-percent")
    local_nonpersistent_flags+=("--default-settings.application-fee-percent")
    local_nonpersistent_flags+=("--default-settings.application-fee-percent=")
    flags+=("--default-settings.automatic-tax.enabled=")
    two_word_flags+=("--default-settings.automatic-tax.enabled")
    local_nonpersistent_flags+=("--default-settings.automatic-tax.enabled")
    local_nonpersistent_flags+=("--default-settings.automatic-tax.enabled=")
    flags+=("--default-settings.automatic-tax.liability.account=")
    two_word_flags+=("--default-settings.automatic-tax.liability.account")
    local_nonpersistent_flags+=("--default-settings.automatic-tax.liability.account")
    local_nonpersistent_flags+=("--default-settings.automatic-tax.liability.account=")
    flags+=("--default-settings.automatic-tax.liability.type=")
    two_word_flags+=("--default-settings.automatic-tax.liability.type")
    local_nonpersistent_flags+=("--default-settings.automatic-tax.liability.type")
    local_nonpersistent_flags+=("--default-settings.automatic-tax.liability.type=")
    flags+=("--default-settings.billing-cycle-anchor=")
    two_word_flags+=("--default-settings.billing-cycle-anchor")
    local_nonpersistent_flags+=("--default-settings.billing-cycle-anchor")
    local_nonpersistent_flags+=("--default-settings.billing-cycle-anchor=")
    flags+=("--default-settings.collection-method=")
    two_word_flags+=("--default-settings.collection-method")
    local_nonpersistent_flags+=("--default-settings.collection-method")
    local_nonpersistent_flags+=("--default-settings.collection-method=")
    flags+=("--default-settings.default-payment-method=")
    two_word_flags+=("--default-settings.default-payment-method")
    local_nonpersistent_flags+=("--default-settings.default-payment-method")
    local_nonpersistent_flags+=("--default-settings.default-payment-method=")
    flags+=("--default-settings.description=")
    two_word_flags+=("--default-settings.description")
    local_nonpersistent_flags+=("--default-settings.description")
    local_nonpersistent_flags+=("--default-settings.description=")
    flags+=("--default-settings.invoice-settings.account-tax-ids=")
    two_word_flags+=("--default-settings.invoice-settings.account-tax-ids")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.account-tax-ids")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.account-tax-ids=")
    flags+=("--default-settings.invoice-settings.days-until-due=")
    two_word_flags+=("--default-settings.invoice-settings.days-until-due")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.days-until-due")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.days-until-due=")
    flags+=("--default-settings.invoice-settings.issuer.account=")
    two_word_flags+=("--default-settings.invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.issuer.account=")
    flags+=("--default-settings.invoice-settings.issuer.type=")
    two_word_flags+=("--default-settings.invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.issuer.type=")
    flags+=("--default-settings.on-behalf-of=")
    two_word_flags+=("--default-settings.on-behalf-of")
    local_nonpersistent_flags+=("--default-settings.on-behalf-of")
    local_nonpersistent_flags+=("--default-settings.on-behalf-of=")
    flags+=("--end-behavior=")
    two_word_flags+=("--end-behavior")
    local_nonpersistent_flags+=("--end-behavior")
    local_nonpersistent_flags+=("--end-behavior=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--from-subscription=")
    two_word_flags+=("--from-subscription")
    local_nonpersistent_flags+=("--from-subscription")
    local_nonpersistent_flags+=("--from-subscription=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--start-date=")
    two_word_flags+=("--start-date")
    local_nonpersistent_flags+=("--start-date")
    local_nonpersistent_flags+=("--start-date=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscription_schedules_list()
{
    last_command="stripe_subscription_schedules_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--canceled-at=")
    two_word_flags+=("--canceled-at")
    local_nonpersistent_flags+=("--canceled-at")
    local_nonpersistent_flags+=("--canceled-at=")
    flags+=("--completed-at=")
    two_word_flags+=("--completed-at")
    local_nonpersistent_flags+=("--completed-at")
    local_nonpersistent_flags+=("--completed-at=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--released-at=")
    two_word_flags+=("--released-at")
    local_nonpersistent_flags+=("--released-at")
    local_nonpersistent_flags+=("--released-at=")
    flags+=("--scheduled=")
    two_word_flags+=("--scheduled")
    local_nonpersistent_flags+=("--scheduled")
    local_nonpersistent_flags+=("--scheduled=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscription_schedules_release()
{
    last_command="stripe_subscription_schedules_release"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--preserve-cancel-date=")
    two_word_flags+=("--preserve-cancel-date")
    local_nonpersistent_flags+=("--preserve-cancel-date")
    local_nonpersistent_flags+=("--preserve-cancel-date=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscription_schedules_retrieve()
{
    last_command="stripe_subscription_schedules_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscription_schedules_update()
{
    last_command="stripe_subscription_schedules_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--default-settings.application-fee-percent=")
    two_word_flags+=("--default-settings.application-fee-percent")
    local_nonpersistent_flags+=("--default-settings.application-fee-percent")
    local_nonpersistent_flags+=("--default-settings.application-fee-percent=")
    flags+=("--default-settings.automatic-tax.enabled=")
    two_word_flags+=("--default-settings.automatic-tax.enabled")
    local_nonpersistent_flags+=("--default-settings.automatic-tax.enabled")
    local_nonpersistent_flags+=("--default-settings.automatic-tax.enabled=")
    flags+=("--default-settings.automatic-tax.liability.account=")
    two_word_flags+=("--default-settings.automatic-tax.liability.account")
    local_nonpersistent_flags+=("--default-settings.automatic-tax.liability.account")
    local_nonpersistent_flags+=("--default-settings.automatic-tax.liability.account=")
    flags+=("--default-settings.automatic-tax.liability.type=")
    two_word_flags+=("--default-settings.automatic-tax.liability.type")
    local_nonpersistent_flags+=("--default-settings.automatic-tax.liability.type")
    local_nonpersistent_flags+=("--default-settings.automatic-tax.liability.type=")
    flags+=("--default-settings.billing-cycle-anchor=")
    two_word_flags+=("--default-settings.billing-cycle-anchor")
    local_nonpersistent_flags+=("--default-settings.billing-cycle-anchor")
    local_nonpersistent_flags+=("--default-settings.billing-cycle-anchor=")
    flags+=("--default-settings.collection-method=")
    two_word_flags+=("--default-settings.collection-method")
    local_nonpersistent_flags+=("--default-settings.collection-method")
    local_nonpersistent_flags+=("--default-settings.collection-method=")
    flags+=("--default-settings.default-payment-method=")
    two_word_flags+=("--default-settings.default-payment-method")
    local_nonpersistent_flags+=("--default-settings.default-payment-method")
    local_nonpersistent_flags+=("--default-settings.default-payment-method=")
    flags+=("--default-settings.description=")
    two_word_flags+=("--default-settings.description")
    local_nonpersistent_flags+=("--default-settings.description")
    local_nonpersistent_flags+=("--default-settings.description=")
    flags+=("--default-settings.invoice-settings.account-tax-ids=")
    two_word_flags+=("--default-settings.invoice-settings.account-tax-ids")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.account-tax-ids")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.account-tax-ids=")
    flags+=("--default-settings.invoice-settings.days-until-due=")
    two_word_flags+=("--default-settings.invoice-settings.days-until-due")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.days-until-due")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.days-until-due=")
    flags+=("--default-settings.invoice-settings.issuer.account=")
    two_word_flags+=("--default-settings.invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.issuer.account=")
    flags+=("--default-settings.invoice-settings.issuer.type=")
    two_word_flags+=("--default-settings.invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--default-settings.invoice-settings.issuer.type=")
    flags+=("--default-settings.on-behalf-of=")
    two_word_flags+=("--default-settings.on-behalf-of")
    local_nonpersistent_flags+=("--default-settings.on-behalf-of")
    local_nonpersistent_flags+=("--default-settings.on-behalf-of=")
    flags+=("--end-behavior=")
    two_word_flags+=("--end-behavior")
    local_nonpersistent_flags+=("--end-behavior")
    local_nonpersistent_flags+=("--end-behavior=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--proration-behavior=")
    two_word_flags+=("--proration-behavior")
    local_nonpersistent_flags+=("--proration-behavior")
    local_nonpersistent_flags+=("--proration-behavior=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscription_schedules()
{
    last_command="stripe_subscription_schedules"

    command_aliases=()

    commands=()
    commands+=("cancel")
    commands+=("create")
    commands+=("list")
    commands+=("release")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscriptions_cancel()
{
    last_command="stripe_subscriptions_cancel"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscriptions_create()
{
    last_command="stripe_subscriptions_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--application-fee-percent=")
    two_word_flags+=("--application-fee-percent")
    local_nonpersistent_flags+=("--application-fee-percent")
    local_nonpersistent_flags+=("--application-fee-percent=")
    flags+=("--automatic-tax.enabled=")
    two_word_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled=")
    flags+=("--automatic-tax.liability.account=")
    two_word_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account=")
    flags+=("--automatic-tax.liability.type=")
    two_word_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type=")
    flags+=("--backdate-start-date=")
    two_word_flags+=("--backdate-start-date")
    local_nonpersistent_flags+=("--backdate-start-date")
    local_nonpersistent_flags+=("--backdate-start-date=")
    flags+=("--billing-cycle-anchor=")
    two_word_flags+=("--billing-cycle-anchor")
    local_nonpersistent_flags+=("--billing-cycle-anchor")
    local_nonpersistent_flags+=("--billing-cycle-anchor=")
    flags+=("--billing-cycle-anchor-config.day-of-month=")
    two_word_flags+=("--billing-cycle-anchor-config.day-of-month")
    local_nonpersistent_flags+=("--billing-cycle-anchor-config.day-of-month")
    local_nonpersistent_flags+=("--billing-cycle-anchor-config.day-of-month=")
    flags+=("--billing-cycle-anchor-config.hour=")
    two_word_flags+=("--billing-cycle-anchor-config.hour")
    local_nonpersistent_flags+=("--billing-cycle-anchor-config.hour")
    local_nonpersistent_flags+=("--billing-cycle-anchor-config.hour=")
    flags+=("--billing-cycle-anchor-config.minute=")
    two_word_flags+=("--billing-cycle-anchor-config.minute")
    local_nonpersistent_flags+=("--billing-cycle-anchor-config.minute")
    local_nonpersistent_flags+=("--billing-cycle-anchor-config.minute=")
    flags+=("--billing-cycle-anchor-config.month=")
    two_word_flags+=("--billing-cycle-anchor-config.month")
    local_nonpersistent_flags+=("--billing-cycle-anchor-config.month")
    local_nonpersistent_flags+=("--billing-cycle-anchor-config.month=")
    flags+=("--billing-cycle-anchor-config.second=")
    two_word_flags+=("--billing-cycle-anchor-config.second")
    local_nonpersistent_flags+=("--billing-cycle-anchor-config.second")
    local_nonpersistent_flags+=("--billing-cycle-anchor-config.second=")
    flags+=("--cancel-at=")
    two_word_flags+=("--cancel-at")
    local_nonpersistent_flags+=("--cancel-at")
    local_nonpersistent_flags+=("--cancel-at=")
    flags+=("--cancel-at-period-end=")
    two_word_flags+=("--cancel-at-period-end")
    local_nonpersistent_flags+=("--cancel-at-period-end")
    local_nonpersistent_flags+=("--cancel-at-period-end=")
    flags+=("--collection-method=")
    two_word_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--coupon=")
    two_word_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon=")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--days-until-due=")
    two_word_flags+=("--days-until-due")
    local_nonpersistent_flags+=("--days-until-due")
    local_nonpersistent_flags+=("--days-until-due=")
    flags+=("--default-payment-method=")
    two_word_flags+=("--default-payment-method")
    local_nonpersistent_flags+=("--default-payment-method")
    local_nonpersistent_flags+=("--default-payment-method=")
    flags+=("--default-source=")
    two_word_flags+=("--default-source")
    local_nonpersistent_flags+=("--default-source")
    local_nonpersistent_flags+=("--default-source=")
    flags+=("--default-tax-rates=")
    two_word_flags+=("--default-tax-rates")
    local_nonpersistent_flags+=("--default-tax-rates")
    local_nonpersistent_flags+=("--default-tax-rates=")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--invoice-settings.account-tax-ids=")
    two_word_flags+=("--invoice-settings.account-tax-ids")
    local_nonpersistent_flags+=("--invoice-settings.account-tax-ids")
    local_nonpersistent_flags+=("--invoice-settings.account-tax-ids=")
    flags+=("--invoice-settings.issuer.account=")
    two_word_flags+=("--invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--invoice-settings.issuer.account=")
    flags+=("--invoice-settings.issuer.type=")
    two_word_flags+=("--invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--invoice-settings.issuer.type=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--off-session=")
    two_word_flags+=("--off-session")
    local_nonpersistent_flags+=("--off-session")
    local_nonpersistent_flags+=("--off-session=")
    flags+=("--on-behalf-of=")
    two_word_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of=")
    flags+=("--payment-behavior=")
    two_word_flags+=("--payment-behavior")
    local_nonpersistent_flags+=("--payment-behavior")
    local_nonpersistent_flags+=("--payment-behavior=")
    flags+=("--payment-settings.payment-method-types=")
    two_word_flags+=("--payment-settings.payment-method-types")
    local_nonpersistent_flags+=("--payment-settings.payment-method-types")
    local_nonpersistent_flags+=("--payment-settings.payment-method-types=")
    flags+=("--payment-settings.save-default-payment-method=")
    two_word_flags+=("--payment-settings.save-default-payment-method")
    local_nonpersistent_flags+=("--payment-settings.save-default-payment-method")
    local_nonpersistent_flags+=("--payment-settings.save-default-payment-method=")
    flags+=("--promotion-code=")
    two_word_flags+=("--promotion-code")
    local_nonpersistent_flags+=("--promotion-code")
    local_nonpersistent_flags+=("--promotion-code=")
    flags+=("--proration-behavior=")
    two_word_flags+=("--proration-behavior")
    local_nonpersistent_flags+=("--proration-behavior")
    local_nonpersistent_flags+=("--proration-behavior=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transfer-data.amount-percent=")
    two_word_flags+=("--transfer-data.amount-percent")
    local_nonpersistent_flags+=("--transfer-data.amount-percent")
    local_nonpersistent_flags+=("--transfer-data.amount-percent=")
    flags+=("--transfer-data.destination=")
    two_word_flags+=("--transfer-data.destination")
    local_nonpersistent_flags+=("--transfer-data.destination")
    local_nonpersistent_flags+=("--transfer-data.destination=")
    flags+=("--trial-end=")
    two_word_flags+=("--trial-end")
    local_nonpersistent_flags+=("--trial-end")
    local_nonpersistent_flags+=("--trial-end=")
    flags+=("--trial-from-plan=")
    two_word_flags+=("--trial-from-plan")
    local_nonpersistent_flags+=("--trial-from-plan")
    local_nonpersistent_flags+=("--trial-from-plan=")
    flags+=("--trial-period-days=")
    two_word_flags+=("--trial-period-days")
    local_nonpersistent_flags+=("--trial-period-days")
    local_nonpersistent_flags+=("--trial-period-days=")
    flags+=("--trial-settings.end-behavior.missing-payment-method=")
    two_word_flags+=("--trial-settings.end-behavior.missing-payment-method")
    local_nonpersistent_flags+=("--trial-settings.end-behavior.missing-payment-method")
    local_nonpersistent_flags+=("--trial-settings.end-behavior.missing-payment-method=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscriptions_delete_discount()
{
    last_command="stripe_subscriptions_delete_discount"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscriptions_list()
{
    last_command="stripe_subscriptions_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--collection-method=")
    two_word_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--current-period-end=")
    two_word_flags+=("--current-period-end")
    local_nonpersistent_flags+=("--current-period-end")
    local_nonpersistent_flags+=("--current-period-end=")
    flags+=("--current-period-start=")
    two_word_flags+=("--current-period-start")
    local_nonpersistent_flags+=("--current-period-start")
    local_nonpersistent_flags+=("--current-period-start=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--plan=")
    two_word_flags+=("--plan")
    local_nonpersistent_flags+=("--plan")
    local_nonpersistent_flags+=("--plan=")
    flags+=("--price=")
    two_word_flags+=("--price")
    local_nonpersistent_flags+=("--price")
    local_nonpersistent_flags+=("--price=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--test-clock=")
    two_word_flags+=("--test-clock")
    local_nonpersistent_flags+=("--test-clock")
    local_nonpersistent_flags+=("--test-clock=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscriptions_resume()
{
    last_command="stripe_subscriptions_resume"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--billing-cycle-anchor=")
    two_word_flags+=("--billing-cycle-anchor")
    local_nonpersistent_flags+=("--billing-cycle-anchor")
    local_nonpersistent_flags+=("--billing-cycle-anchor=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--proration-behavior=")
    two_word_flags+=("--proration-behavior")
    local_nonpersistent_flags+=("--proration-behavior")
    local_nonpersistent_flags+=("--proration-behavior=")
    flags+=("--proration-date=")
    two_word_flags+=("--proration-date")
    local_nonpersistent_flags+=("--proration-date")
    local_nonpersistent_flags+=("--proration-date=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscriptions_retrieve()
{
    last_command="stripe_subscriptions_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscriptions_search()
{
    last_command="stripe_subscriptions_search"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--page=")
    two_word_flags+=("--page")
    local_nonpersistent_flags+=("--page")
    local_nonpersistent_flags+=("--page=")
    flags+=("--query=")
    two_word_flags+=("--query")
    local_nonpersistent_flags+=("--query")
    local_nonpersistent_flags+=("--query=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscriptions_update()
{
    last_command="stripe_subscriptions_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--application-fee-percent=")
    two_word_flags+=("--application-fee-percent")
    local_nonpersistent_flags+=("--application-fee-percent")
    local_nonpersistent_flags+=("--application-fee-percent=")
    flags+=("--automatic-tax.enabled=")
    two_word_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled")
    local_nonpersistent_flags+=("--automatic-tax.enabled=")
    flags+=("--automatic-tax.liability.account=")
    two_word_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account")
    local_nonpersistent_flags+=("--automatic-tax.liability.account=")
    flags+=("--automatic-tax.liability.type=")
    two_word_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type")
    local_nonpersistent_flags+=("--automatic-tax.liability.type=")
    flags+=("--billing-cycle-anchor=")
    two_word_flags+=("--billing-cycle-anchor")
    local_nonpersistent_flags+=("--billing-cycle-anchor")
    local_nonpersistent_flags+=("--billing-cycle-anchor=")
    flags+=("--cancel-at=")
    two_word_flags+=("--cancel-at")
    local_nonpersistent_flags+=("--cancel-at")
    local_nonpersistent_flags+=("--cancel-at=")
    flags+=("--cancel-at-period-end=")
    two_word_flags+=("--cancel-at-period-end")
    local_nonpersistent_flags+=("--cancel-at-period-end")
    local_nonpersistent_flags+=("--cancel-at-period-end=")
    flags+=("--cancellation-details.comment=")
    two_word_flags+=("--cancellation-details.comment")
    local_nonpersistent_flags+=("--cancellation-details.comment")
    local_nonpersistent_flags+=("--cancellation-details.comment=")
    flags+=("--cancellation-details.feedback=")
    two_word_flags+=("--cancellation-details.feedback")
    local_nonpersistent_flags+=("--cancellation-details.feedback")
    local_nonpersistent_flags+=("--cancellation-details.feedback=")
    flags+=("--collection-method=")
    two_word_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method")
    local_nonpersistent_flags+=("--collection-method=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--coupon=")
    two_word_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon")
    local_nonpersistent_flags+=("--coupon=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--days-until-due=")
    two_word_flags+=("--days-until-due")
    local_nonpersistent_flags+=("--days-until-due")
    local_nonpersistent_flags+=("--days-until-due=")
    flags+=("--default-payment-method=")
    two_word_flags+=("--default-payment-method")
    local_nonpersistent_flags+=("--default-payment-method")
    local_nonpersistent_flags+=("--default-payment-method=")
    flags+=("--default-source=")
    two_word_flags+=("--default-source")
    local_nonpersistent_flags+=("--default-source")
    local_nonpersistent_flags+=("--default-source=")
    flags+=("--default-tax-rates=")
    two_word_flags+=("--default-tax-rates")
    local_nonpersistent_flags+=("--default-tax-rates")
    local_nonpersistent_flags+=("--default-tax-rates=")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--invoice-settings.account-tax-ids=")
    two_word_flags+=("--invoice-settings.account-tax-ids")
    local_nonpersistent_flags+=("--invoice-settings.account-tax-ids")
    local_nonpersistent_flags+=("--invoice-settings.account-tax-ids=")
    flags+=("--invoice-settings.issuer.account=")
    two_word_flags+=("--invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--invoice-settings.issuer.account")
    local_nonpersistent_flags+=("--invoice-settings.issuer.account=")
    flags+=("--invoice-settings.issuer.type=")
    two_word_flags+=("--invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--invoice-settings.issuer.type")
    local_nonpersistent_flags+=("--invoice-settings.issuer.type=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--off-session=")
    two_word_flags+=("--off-session")
    local_nonpersistent_flags+=("--off-session")
    local_nonpersistent_flags+=("--off-session=")
    flags+=("--on-behalf-of=")
    two_word_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of")
    local_nonpersistent_flags+=("--on-behalf-of=")
    flags+=("--payment-behavior=")
    two_word_flags+=("--payment-behavior")
    local_nonpersistent_flags+=("--payment-behavior")
    local_nonpersistent_flags+=("--payment-behavior=")
    flags+=("--payment-settings.payment-method-types=")
    two_word_flags+=("--payment-settings.payment-method-types")
    local_nonpersistent_flags+=("--payment-settings.payment-method-types")
    local_nonpersistent_flags+=("--payment-settings.payment-method-types=")
    flags+=("--payment-settings.save-default-payment-method=")
    two_word_flags+=("--payment-settings.save-default-payment-method")
    local_nonpersistent_flags+=("--payment-settings.save-default-payment-method")
    local_nonpersistent_flags+=("--payment-settings.save-default-payment-method=")
    flags+=("--promotion-code=")
    two_word_flags+=("--promotion-code")
    local_nonpersistent_flags+=("--promotion-code")
    local_nonpersistent_flags+=("--promotion-code=")
    flags+=("--proration-behavior=")
    two_word_flags+=("--proration-behavior")
    local_nonpersistent_flags+=("--proration-behavior")
    local_nonpersistent_flags+=("--proration-behavior=")
    flags+=("--proration-date=")
    two_word_flags+=("--proration-date")
    local_nonpersistent_flags+=("--proration-date")
    local_nonpersistent_flags+=("--proration-date=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--trial-end=")
    two_word_flags+=("--trial-end")
    local_nonpersistent_flags+=("--trial-end")
    local_nonpersistent_flags+=("--trial-end=")
    flags+=("--trial-from-plan=")
    two_word_flags+=("--trial-from-plan")
    local_nonpersistent_flags+=("--trial-from-plan")
    local_nonpersistent_flags+=("--trial-from-plan=")
    flags+=("--trial-settings.end-behavior.missing-payment-method=")
    two_word_flags+=("--trial-settings.end-behavior.missing-payment-method")
    local_nonpersistent_flags+=("--trial-settings.end-behavior.missing-payment-method")
    local_nonpersistent_flags+=("--trial-settings.end-behavior.missing-payment-method=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_subscriptions()
{
    last_command="stripe_subscriptions"

    command_aliases=()

    commands=()
    commands+=("cancel")
    commands+=("create")
    commands+=("delete_discount")
    commands+=("list")
    commands+=("resume")
    commands+=("retrieve")
    commands+=("search")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_calculations_create()
{
    last_command="stripe_tax_calculations_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--customer-details.address-source=")
    two_word_flags+=("--customer-details.address-source")
    local_nonpersistent_flags+=("--customer-details.address-source")
    local_nonpersistent_flags+=("--customer-details.address-source=")
    flags+=("--customer-details.address.city=")
    two_word_flags+=("--customer-details.address.city")
    local_nonpersistent_flags+=("--customer-details.address.city")
    local_nonpersistent_flags+=("--customer-details.address.city=")
    flags+=("--customer-details.address.country=")
    two_word_flags+=("--customer-details.address.country")
    local_nonpersistent_flags+=("--customer-details.address.country")
    local_nonpersistent_flags+=("--customer-details.address.country=")
    flags+=("--customer-details.address.line1=")
    two_word_flags+=("--customer-details.address.line1")
    local_nonpersistent_flags+=("--customer-details.address.line1")
    local_nonpersistent_flags+=("--customer-details.address.line1=")
    flags+=("--customer-details.address.line2=")
    two_word_flags+=("--customer-details.address.line2")
    local_nonpersistent_flags+=("--customer-details.address.line2")
    local_nonpersistent_flags+=("--customer-details.address.line2=")
    flags+=("--customer-details.address.postal-code=")
    two_word_flags+=("--customer-details.address.postal-code")
    local_nonpersistent_flags+=("--customer-details.address.postal-code")
    local_nonpersistent_flags+=("--customer-details.address.postal-code=")
    flags+=("--customer-details.address.state=")
    two_word_flags+=("--customer-details.address.state")
    local_nonpersistent_flags+=("--customer-details.address.state")
    local_nonpersistent_flags+=("--customer-details.address.state=")
    flags+=("--customer-details.ip-address=")
    two_word_flags+=("--customer-details.ip-address")
    local_nonpersistent_flags+=("--customer-details.ip-address")
    local_nonpersistent_flags+=("--customer-details.ip-address=")
    flags+=("--customer-details.taxability-override=")
    two_word_flags+=("--customer-details.taxability-override")
    local_nonpersistent_flags+=("--customer-details.taxability-override")
    local_nonpersistent_flags+=("--customer-details.taxability-override=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--ship-from-details.address.city=")
    two_word_flags+=("--ship-from-details.address.city")
    local_nonpersistent_flags+=("--ship-from-details.address.city")
    local_nonpersistent_flags+=("--ship-from-details.address.city=")
    flags+=("--ship-from-details.address.country=")
    two_word_flags+=("--ship-from-details.address.country")
    local_nonpersistent_flags+=("--ship-from-details.address.country")
    local_nonpersistent_flags+=("--ship-from-details.address.country=")
    flags+=("--ship-from-details.address.line1=")
    two_word_flags+=("--ship-from-details.address.line1")
    local_nonpersistent_flags+=("--ship-from-details.address.line1")
    local_nonpersistent_flags+=("--ship-from-details.address.line1=")
    flags+=("--ship-from-details.address.line2=")
    two_word_flags+=("--ship-from-details.address.line2")
    local_nonpersistent_flags+=("--ship-from-details.address.line2")
    local_nonpersistent_flags+=("--ship-from-details.address.line2=")
    flags+=("--ship-from-details.address.postal-code=")
    two_word_flags+=("--ship-from-details.address.postal-code")
    local_nonpersistent_flags+=("--ship-from-details.address.postal-code")
    local_nonpersistent_flags+=("--ship-from-details.address.postal-code=")
    flags+=("--ship-from-details.address.state=")
    two_word_flags+=("--ship-from-details.address.state")
    local_nonpersistent_flags+=("--ship-from-details.address.state")
    local_nonpersistent_flags+=("--ship-from-details.address.state=")
    flags+=("--shipping-cost.amount=")
    two_word_flags+=("--shipping-cost.amount")
    local_nonpersistent_flags+=("--shipping-cost.amount")
    local_nonpersistent_flags+=("--shipping-cost.amount=")
    flags+=("--shipping-cost.shipping-rate=")
    two_word_flags+=("--shipping-cost.shipping-rate")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate")
    local_nonpersistent_flags+=("--shipping-cost.shipping-rate=")
    flags+=("--shipping-cost.tax-behavior=")
    two_word_flags+=("--shipping-cost.tax-behavior")
    local_nonpersistent_flags+=("--shipping-cost.tax-behavior")
    local_nonpersistent_flags+=("--shipping-cost.tax-behavior=")
    flags+=("--shipping-cost.tax-code=")
    two_word_flags+=("--shipping-cost.tax-code")
    local_nonpersistent_flags+=("--shipping-cost.tax-code")
    local_nonpersistent_flags+=("--shipping-cost.tax-code=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tax-date=")
    two_word_flags+=("--tax-date")
    local_nonpersistent_flags+=("--tax-date")
    local_nonpersistent_flags+=("--tax-date=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_calculations_list_line_items()
{
    last_command="stripe_tax_calculations_list_line_items"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_calculations_retrieve()
{
    last_command="stripe_tax_calculations_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_calculations()
{
    last_command="stripe_tax_calculations"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list_line_items")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_registrations_create()
{
    last_command="stripe_tax_registrations_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active-from=")
    two_word_flags+=("--active-from")
    local_nonpersistent_flags+=("--active-from")
    local_nonpersistent_flags+=("--active-from=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--country=")
    two_word_flags+=("--country")
    local_nonpersistent_flags+=("--country")
    local_nonpersistent_flags+=("--country=")
    flags+=("--country-options.ae.type=")
    two_word_flags+=("--country-options.ae.type")
    local_nonpersistent_flags+=("--country-options.ae.type")
    local_nonpersistent_flags+=("--country-options.ae.type=")
    flags+=("--country-options.at.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.at.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.at.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.at.standard.place-of-supply-scheme=")
    flags+=("--country-options.at.type=")
    two_word_flags+=("--country-options.at.type")
    local_nonpersistent_flags+=("--country-options.at.type")
    local_nonpersistent_flags+=("--country-options.at.type=")
    flags+=("--country-options.au.type=")
    two_word_flags+=("--country-options.au.type")
    local_nonpersistent_flags+=("--country-options.au.type")
    local_nonpersistent_flags+=("--country-options.au.type=")
    flags+=("--country-options.be.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.be.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.be.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.be.standard.place-of-supply-scheme=")
    flags+=("--country-options.be.type=")
    two_word_flags+=("--country-options.be.type")
    local_nonpersistent_flags+=("--country-options.be.type")
    local_nonpersistent_flags+=("--country-options.be.type=")
    flags+=("--country-options.bg.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.bg.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.bg.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.bg.standard.place-of-supply-scheme=")
    flags+=("--country-options.bg.type=")
    two_word_flags+=("--country-options.bg.type")
    local_nonpersistent_flags+=("--country-options.bg.type")
    local_nonpersistent_flags+=("--country-options.bg.type=")
    flags+=("--country-options.bh.type=")
    two_word_flags+=("--country-options.bh.type")
    local_nonpersistent_flags+=("--country-options.bh.type")
    local_nonpersistent_flags+=("--country-options.bh.type=")
    flags+=("--country-options.by.type=")
    two_word_flags+=("--country-options.by.type")
    local_nonpersistent_flags+=("--country-options.by.type")
    local_nonpersistent_flags+=("--country-options.by.type=")
    flags+=("--country-options.ca.province-standard.province=")
    two_word_flags+=("--country-options.ca.province-standard.province")
    local_nonpersistent_flags+=("--country-options.ca.province-standard.province")
    local_nonpersistent_flags+=("--country-options.ca.province-standard.province=")
    flags+=("--country-options.ca.type=")
    two_word_flags+=("--country-options.ca.type")
    local_nonpersistent_flags+=("--country-options.ca.type")
    local_nonpersistent_flags+=("--country-options.ca.type=")
    flags+=("--country-options.ch.type=")
    two_word_flags+=("--country-options.ch.type")
    local_nonpersistent_flags+=("--country-options.ch.type")
    local_nonpersistent_flags+=("--country-options.ch.type=")
    flags+=("--country-options.cl.type=")
    two_word_flags+=("--country-options.cl.type")
    local_nonpersistent_flags+=("--country-options.cl.type")
    local_nonpersistent_flags+=("--country-options.cl.type=")
    flags+=("--country-options.co.type=")
    two_word_flags+=("--country-options.co.type")
    local_nonpersistent_flags+=("--country-options.co.type")
    local_nonpersistent_flags+=("--country-options.co.type=")
    flags+=("--country-options.cr.type=")
    two_word_flags+=("--country-options.cr.type")
    local_nonpersistent_flags+=("--country-options.cr.type")
    local_nonpersistent_flags+=("--country-options.cr.type=")
    flags+=("--country-options.cy.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.cy.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.cy.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.cy.standard.place-of-supply-scheme=")
    flags+=("--country-options.cy.type=")
    two_word_flags+=("--country-options.cy.type")
    local_nonpersistent_flags+=("--country-options.cy.type")
    local_nonpersistent_flags+=("--country-options.cy.type=")
    flags+=("--country-options.cz.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.cz.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.cz.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.cz.standard.place-of-supply-scheme=")
    flags+=("--country-options.cz.type=")
    two_word_flags+=("--country-options.cz.type")
    local_nonpersistent_flags+=("--country-options.cz.type")
    local_nonpersistent_flags+=("--country-options.cz.type=")
    flags+=("--country-options.de.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.de.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.de.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.de.standard.place-of-supply-scheme=")
    flags+=("--country-options.de.type=")
    two_word_flags+=("--country-options.de.type")
    local_nonpersistent_flags+=("--country-options.de.type")
    local_nonpersistent_flags+=("--country-options.de.type=")
    flags+=("--country-options.dk.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.dk.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.dk.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.dk.standard.place-of-supply-scheme=")
    flags+=("--country-options.dk.type=")
    two_word_flags+=("--country-options.dk.type")
    local_nonpersistent_flags+=("--country-options.dk.type")
    local_nonpersistent_flags+=("--country-options.dk.type=")
    flags+=("--country-options.ec.type=")
    two_word_flags+=("--country-options.ec.type")
    local_nonpersistent_flags+=("--country-options.ec.type")
    local_nonpersistent_flags+=("--country-options.ec.type=")
    flags+=("--country-options.ee.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.ee.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.ee.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.ee.standard.place-of-supply-scheme=")
    flags+=("--country-options.ee.type=")
    two_word_flags+=("--country-options.ee.type")
    local_nonpersistent_flags+=("--country-options.ee.type")
    local_nonpersistent_flags+=("--country-options.ee.type=")
    flags+=("--country-options.eg.type=")
    two_word_flags+=("--country-options.eg.type")
    local_nonpersistent_flags+=("--country-options.eg.type")
    local_nonpersistent_flags+=("--country-options.eg.type=")
    flags+=("--country-options.es.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.es.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.es.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.es.standard.place-of-supply-scheme=")
    flags+=("--country-options.es.type=")
    two_word_flags+=("--country-options.es.type")
    local_nonpersistent_flags+=("--country-options.es.type")
    local_nonpersistent_flags+=("--country-options.es.type=")
    flags+=("--country-options.fi.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.fi.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.fi.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.fi.standard.place-of-supply-scheme=")
    flags+=("--country-options.fi.type=")
    two_word_flags+=("--country-options.fi.type")
    local_nonpersistent_flags+=("--country-options.fi.type")
    local_nonpersistent_flags+=("--country-options.fi.type=")
    flags+=("--country-options.fr.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.fr.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.fr.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.fr.standard.place-of-supply-scheme=")
    flags+=("--country-options.fr.type=")
    two_word_flags+=("--country-options.fr.type")
    local_nonpersistent_flags+=("--country-options.fr.type")
    local_nonpersistent_flags+=("--country-options.fr.type=")
    flags+=("--country-options.gb.type=")
    two_word_flags+=("--country-options.gb.type")
    local_nonpersistent_flags+=("--country-options.gb.type")
    local_nonpersistent_flags+=("--country-options.gb.type=")
    flags+=("--country-options.ge.type=")
    two_word_flags+=("--country-options.ge.type")
    local_nonpersistent_flags+=("--country-options.ge.type")
    local_nonpersistent_flags+=("--country-options.ge.type=")
    flags+=("--country-options.gr.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.gr.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.gr.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.gr.standard.place-of-supply-scheme=")
    flags+=("--country-options.gr.type=")
    two_word_flags+=("--country-options.gr.type")
    local_nonpersistent_flags+=("--country-options.gr.type")
    local_nonpersistent_flags+=("--country-options.gr.type=")
    flags+=("--country-options.hr.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.hr.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.hr.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.hr.standard.place-of-supply-scheme=")
    flags+=("--country-options.hr.type=")
    two_word_flags+=("--country-options.hr.type")
    local_nonpersistent_flags+=("--country-options.hr.type")
    local_nonpersistent_flags+=("--country-options.hr.type=")
    flags+=("--country-options.hu.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.hu.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.hu.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.hu.standard.place-of-supply-scheme=")
    flags+=("--country-options.hu.type=")
    two_word_flags+=("--country-options.hu.type")
    local_nonpersistent_flags+=("--country-options.hu.type")
    local_nonpersistent_flags+=("--country-options.hu.type=")
    flags+=("--country-options.id.type=")
    two_word_flags+=("--country-options.id.type")
    local_nonpersistent_flags+=("--country-options.id.type")
    local_nonpersistent_flags+=("--country-options.id.type=")
    flags+=("--country-options.ie.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.ie.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.ie.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.ie.standard.place-of-supply-scheme=")
    flags+=("--country-options.ie.type=")
    two_word_flags+=("--country-options.ie.type")
    local_nonpersistent_flags+=("--country-options.ie.type")
    local_nonpersistent_flags+=("--country-options.ie.type=")
    flags+=("--country-options.is.type=")
    two_word_flags+=("--country-options.is.type")
    local_nonpersistent_flags+=("--country-options.is.type")
    local_nonpersistent_flags+=("--country-options.is.type=")
    flags+=("--country-options.it.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.it.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.it.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.it.standard.place-of-supply-scheme=")
    flags+=("--country-options.it.type=")
    two_word_flags+=("--country-options.it.type")
    local_nonpersistent_flags+=("--country-options.it.type")
    local_nonpersistent_flags+=("--country-options.it.type=")
    flags+=("--country-options.jp.type=")
    two_word_flags+=("--country-options.jp.type")
    local_nonpersistent_flags+=("--country-options.jp.type")
    local_nonpersistent_flags+=("--country-options.jp.type=")
    flags+=("--country-options.ke.type=")
    two_word_flags+=("--country-options.ke.type")
    local_nonpersistent_flags+=("--country-options.ke.type")
    local_nonpersistent_flags+=("--country-options.ke.type=")
    flags+=("--country-options.kr.type=")
    two_word_flags+=("--country-options.kr.type")
    local_nonpersistent_flags+=("--country-options.kr.type")
    local_nonpersistent_flags+=("--country-options.kr.type=")
    flags+=("--country-options.kz.type=")
    two_word_flags+=("--country-options.kz.type")
    local_nonpersistent_flags+=("--country-options.kz.type")
    local_nonpersistent_flags+=("--country-options.kz.type=")
    flags+=("--country-options.lt.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.lt.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.lt.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.lt.standard.place-of-supply-scheme=")
    flags+=("--country-options.lt.type=")
    two_word_flags+=("--country-options.lt.type")
    local_nonpersistent_flags+=("--country-options.lt.type")
    local_nonpersistent_flags+=("--country-options.lt.type=")
    flags+=("--country-options.lu.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.lu.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.lu.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.lu.standard.place-of-supply-scheme=")
    flags+=("--country-options.lu.type=")
    two_word_flags+=("--country-options.lu.type")
    local_nonpersistent_flags+=("--country-options.lu.type")
    local_nonpersistent_flags+=("--country-options.lu.type=")
    flags+=("--country-options.lv.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.lv.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.lv.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.lv.standard.place-of-supply-scheme=")
    flags+=("--country-options.lv.type=")
    two_word_flags+=("--country-options.lv.type")
    local_nonpersistent_flags+=("--country-options.lv.type")
    local_nonpersistent_flags+=("--country-options.lv.type=")
    flags+=("--country-options.ma.type=")
    two_word_flags+=("--country-options.ma.type")
    local_nonpersistent_flags+=("--country-options.ma.type")
    local_nonpersistent_flags+=("--country-options.ma.type=")
    flags+=("--country-options.md.type=")
    two_word_flags+=("--country-options.md.type")
    local_nonpersistent_flags+=("--country-options.md.type")
    local_nonpersistent_flags+=("--country-options.md.type=")
    flags+=("--country-options.mt.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.mt.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.mt.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.mt.standard.place-of-supply-scheme=")
    flags+=("--country-options.mt.type=")
    two_word_flags+=("--country-options.mt.type")
    local_nonpersistent_flags+=("--country-options.mt.type")
    local_nonpersistent_flags+=("--country-options.mt.type=")
    flags+=("--country-options.mx.type=")
    two_word_flags+=("--country-options.mx.type")
    local_nonpersistent_flags+=("--country-options.mx.type")
    local_nonpersistent_flags+=("--country-options.mx.type=")
    flags+=("--country-options.my.type=")
    two_word_flags+=("--country-options.my.type")
    local_nonpersistent_flags+=("--country-options.my.type")
    local_nonpersistent_flags+=("--country-options.my.type=")
    flags+=("--country-options.ng.type=")
    two_word_flags+=("--country-options.ng.type")
    local_nonpersistent_flags+=("--country-options.ng.type")
    local_nonpersistent_flags+=("--country-options.ng.type=")
    flags+=("--country-options.nl.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.nl.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.nl.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.nl.standard.place-of-supply-scheme=")
    flags+=("--country-options.nl.type=")
    two_word_flags+=("--country-options.nl.type")
    local_nonpersistent_flags+=("--country-options.nl.type")
    local_nonpersistent_flags+=("--country-options.nl.type=")
    flags+=("--country-options.no.type=")
    two_word_flags+=("--country-options.no.type")
    local_nonpersistent_flags+=("--country-options.no.type")
    local_nonpersistent_flags+=("--country-options.no.type=")
    flags+=("--country-options.nz.type=")
    two_word_flags+=("--country-options.nz.type")
    local_nonpersistent_flags+=("--country-options.nz.type")
    local_nonpersistent_flags+=("--country-options.nz.type=")
    flags+=("--country-options.om.type=")
    two_word_flags+=("--country-options.om.type")
    local_nonpersistent_flags+=("--country-options.om.type")
    local_nonpersistent_flags+=("--country-options.om.type=")
    flags+=("--country-options.pl.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.pl.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.pl.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.pl.standard.place-of-supply-scheme=")
    flags+=("--country-options.pl.type=")
    two_word_flags+=("--country-options.pl.type")
    local_nonpersistent_flags+=("--country-options.pl.type")
    local_nonpersistent_flags+=("--country-options.pl.type=")
    flags+=("--country-options.pt.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.pt.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.pt.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.pt.standard.place-of-supply-scheme=")
    flags+=("--country-options.pt.type=")
    two_word_flags+=("--country-options.pt.type")
    local_nonpersistent_flags+=("--country-options.pt.type")
    local_nonpersistent_flags+=("--country-options.pt.type=")
    flags+=("--country-options.ro.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.ro.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.ro.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.ro.standard.place-of-supply-scheme=")
    flags+=("--country-options.ro.type=")
    two_word_flags+=("--country-options.ro.type")
    local_nonpersistent_flags+=("--country-options.ro.type")
    local_nonpersistent_flags+=("--country-options.ro.type=")
    flags+=("--country-options.rs.type=")
    two_word_flags+=("--country-options.rs.type")
    local_nonpersistent_flags+=("--country-options.rs.type")
    local_nonpersistent_flags+=("--country-options.rs.type=")
    flags+=("--country-options.ru.type=")
    two_word_flags+=("--country-options.ru.type")
    local_nonpersistent_flags+=("--country-options.ru.type")
    local_nonpersistent_flags+=("--country-options.ru.type=")
    flags+=("--country-options.sa.type=")
    two_word_flags+=("--country-options.sa.type")
    local_nonpersistent_flags+=("--country-options.sa.type")
    local_nonpersistent_flags+=("--country-options.sa.type=")
    flags+=("--country-options.se.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.se.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.se.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.se.standard.place-of-supply-scheme=")
    flags+=("--country-options.se.type=")
    two_word_flags+=("--country-options.se.type")
    local_nonpersistent_flags+=("--country-options.se.type")
    local_nonpersistent_flags+=("--country-options.se.type=")
    flags+=("--country-options.sg.type=")
    two_word_flags+=("--country-options.sg.type")
    local_nonpersistent_flags+=("--country-options.sg.type")
    local_nonpersistent_flags+=("--country-options.sg.type=")
    flags+=("--country-options.si.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.si.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.si.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.si.standard.place-of-supply-scheme=")
    flags+=("--country-options.si.type=")
    two_word_flags+=("--country-options.si.type")
    local_nonpersistent_flags+=("--country-options.si.type")
    local_nonpersistent_flags+=("--country-options.si.type=")
    flags+=("--country-options.sk.standard.place-of-supply-scheme=")
    two_word_flags+=("--country-options.sk.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.sk.standard.place-of-supply-scheme")
    local_nonpersistent_flags+=("--country-options.sk.standard.place-of-supply-scheme=")
    flags+=("--country-options.sk.type=")
    two_word_flags+=("--country-options.sk.type")
    local_nonpersistent_flags+=("--country-options.sk.type")
    local_nonpersistent_flags+=("--country-options.sk.type=")
    flags+=("--country-options.th.type=")
    two_word_flags+=("--country-options.th.type")
    local_nonpersistent_flags+=("--country-options.th.type")
    local_nonpersistent_flags+=("--country-options.th.type=")
    flags+=("--country-options.tr.type=")
    two_word_flags+=("--country-options.tr.type")
    local_nonpersistent_flags+=("--country-options.tr.type")
    local_nonpersistent_flags+=("--country-options.tr.type=")
    flags+=("--country-options.tz.type=")
    two_word_flags+=("--country-options.tz.type")
    local_nonpersistent_flags+=("--country-options.tz.type")
    local_nonpersistent_flags+=("--country-options.tz.type=")
    flags+=("--country-options.us.local-amusement-tax.jurisdiction=")
    two_word_flags+=("--country-options.us.local-amusement-tax.jurisdiction")
    local_nonpersistent_flags+=("--country-options.us.local-amusement-tax.jurisdiction")
    local_nonpersistent_flags+=("--country-options.us.local-amusement-tax.jurisdiction=")
    flags+=("--country-options.us.local-lease-tax.jurisdiction=")
    two_word_flags+=("--country-options.us.local-lease-tax.jurisdiction")
    local_nonpersistent_flags+=("--country-options.us.local-lease-tax.jurisdiction")
    local_nonpersistent_flags+=("--country-options.us.local-lease-tax.jurisdiction=")
    flags+=("--country-options.us.state=")
    two_word_flags+=("--country-options.us.state")
    local_nonpersistent_flags+=("--country-options.us.state")
    local_nonpersistent_flags+=("--country-options.us.state=")
    flags+=("--country-options.us.type=")
    two_word_flags+=("--country-options.us.type")
    local_nonpersistent_flags+=("--country-options.us.type")
    local_nonpersistent_flags+=("--country-options.us.type=")
    flags+=("--country-options.uz.type=")
    two_word_flags+=("--country-options.uz.type")
    local_nonpersistent_flags+=("--country-options.uz.type")
    local_nonpersistent_flags+=("--country-options.uz.type=")
    flags+=("--country-options.vn.type=")
    two_word_flags+=("--country-options.vn.type")
    local_nonpersistent_flags+=("--country-options.vn.type")
    local_nonpersistent_flags+=("--country-options.vn.type=")
    flags+=("--country-options.za.type=")
    two_word_flags+=("--country-options.za.type")
    local_nonpersistent_flags+=("--country-options.za.type")
    local_nonpersistent_flags+=("--country-options.za.type=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--expires-at=")
    two_word_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_registrations_list()
{
    last_command="stripe_tax_registrations_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_registrations_retrieve()
{
    last_command="stripe_tax_registrations_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_registrations_update()
{
    last_command="stripe_tax_registrations_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active-from=")
    two_word_flags+=("--active-from")
    local_nonpersistent_flags+=("--active-from")
    local_nonpersistent_flags+=("--active-from=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--expires-at=")
    two_word_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at")
    local_nonpersistent_flags+=("--expires-at=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_registrations()
{
    last_command="stripe_tax_registrations"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_settings_retrieve()
{
    last_command="stripe_tax_settings_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_settings_update()
{
    last_command="stripe_tax_settings_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--defaults.tax-behavior=")
    two_word_flags+=("--defaults.tax-behavior")
    local_nonpersistent_flags+=("--defaults.tax-behavior")
    local_nonpersistent_flags+=("--defaults.tax-behavior=")
    flags+=("--defaults.tax-code=")
    two_word_flags+=("--defaults.tax-code")
    local_nonpersistent_flags+=("--defaults.tax-code")
    local_nonpersistent_flags+=("--defaults.tax-code=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--head-office.address.city=")
    two_word_flags+=("--head-office.address.city")
    local_nonpersistent_flags+=("--head-office.address.city")
    local_nonpersistent_flags+=("--head-office.address.city=")
    flags+=("--head-office.address.country=")
    two_word_flags+=("--head-office.address.country")
    local_nonpersistent_flags+=("--head-office.address.country")
    local_nonpersistent_flags+=("--head-office.address.country=")
    flags+=("--head-office.address.line1=")
    two_word_flags+=("--head-office.address.line1")
    local_nonpersistent_flags+=("--head-office.address.line1")
    local_nonpersistent_flags+=("--head-office.address.line1=")
    flags+=("--head-office.address.line2=")
    two_word_flags+=("--head-office.address.line2")
    local_nonpersistent_flags+=("--head-office.address.line2")
    local_nonpersistent_flags+=("--head-office.address.line2=")
    flags+=("--head-office.address.postal-code=")
    two_word_flags+=("--head-office.address.postal-code")
    local_nonpersistent_flags+=("--head-office.address.postal-code")
    local_nonpersistent_flags+=("--head-office.address.postal-code=")
    flags+=("--head-office.address.state=")
    two_word_flags+=("--head-office.address.state")
    local_nonpersistent_flags+=("--head-office.address.state")
    local_nonpersistent_flags+=("--head-office.address.state=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_settings()
{
    last_command="stripe_tax_settings"

    command_aliases=()

    commands=()
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_transactions_create_from_calculation()
{
    last_command="stripe_tax_transactions_create_from_calculation"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--calculation=")
    two_word_flags+=("--calculation")
    local_nonpersistent_flags+=("--calculation")
    local_nonpersistent_flags+=("--calculation=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--posted-at=")
    two_word_flags+=("--posted-at")
    local_nonpersistent_flags+=("--posted-at")
    local_nonpersistent_flags+=("--posted-at=")
    flags+=("--reference=")
    two_word_flags+=("--reference")
    local_nonpersistent_flags+=("--reference")
    local_nonpersistent_flags+=("--reference=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_transactions_create_reversal()
{
    last_command="stripe_tax_transactions_create_reversal"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--flat-amount=")
    two_word_flags+=("--flat-amount")
    local_nonpersistent_flags+=("--flat-amount")
    local_nonpersistent_flags+=("--flat-amount=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--mode=")
    two_word_flags+=("--mode")
    local_nonpersistent_flags+=("--mode")
    local_nonpersistent_flags+=("--mode=")
    flags+=("--original-transaction=")
    two_word_flags+=("--original-transaction")
    local_nonpersistent_flags+=("--original-transaction")
    local_nonpersistent_flags+=("--original-transaction=")
    flags+=("--reference=")
    two_word_flags+=("--reference")
    local_nonpersistent_flags+=("--reference")
    local_nonpersistent_flags+=("--reference=")
    flags+=("--shipping-cost.amount=")
    two_word_flags+=("--shipping-cost.amount")
    local_nonpersistent_flags+=("--shipping-cost.amount")
    local_nonpersistent_flags+=("--shipping-cost.amount=")
    flags+=("--shipping-cost.amount-tax=")
    two_word_flags+=("--shipping-cost.amount-tax")
    local_nonpersistent_flags+=("--shipping-cost.amount-tax")
    local_nonpersistent_flags+=("--shipping-cost.amount-tax=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_transactions_list_line_items()
{
    last_command="stripe_tax_transactions_list_line_items"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_transactions_retrieve()
{
    last_command="stripe_tax_transactions_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_transactions()
{
    last_command="stripe_tax_transactions"

    command_aliases=()

    commands=()
    commands+=("create_from_calculation")
    commands+=("create_reversal")
    commands+=("list_line_items")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax()
{
    last_command="stripe_tax"

    command_aliases=()

    commands=()
    commands+=("calculations")
    commands+=("registrations")
    commands+=("settings")
    commands+=("transactions")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_codes_list()
{
    last_command="stripe_tax_codes_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_codes_retrieve()
{
    last_command="stripe_tax_codes_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_codes()
{
    last_command="stripe_tax_codes"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_ids_create()
{
    last_command="stripe_tax_ids_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--value=")
    two_word_flags+=("--value")
    local_nonpersistent_flags+=("--value")
    local_nonpersistent_flags+=("--value=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_ids_delete()
{
    last_command="stripe_tax_ids_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_ids_list()
{
    last_command="stripe_tax_ids_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_ids_retrieve()
{
    last_command="stripe_tax_ids_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_ids()
{
    last_command="stripe_tax_ids"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_rates_create()
{
    last_command="stripe_tax_rates_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--country=")
    two_word_flags+=("--country")
    local_nonpersistent_flags+=("--country")
    local_nonpersistent_flags+=("--country=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--display-name=")
    two_word_flags+=("--display-name")
    local_nonpersistent_flags+=("--display-name")
    local_nonpersistent_flags+=("--display-name=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--inclusive=")
    two_word_flags+=("--inclusive")
    local_nonpersistent_flags+=("--inclusive")
    local_nonpersistent_flags+=("--inclusive=")
    flags+=("--jurisdiction=")
    two_word_flags+=("--jurisdiction")
    local_nonpersistent_flags+=("--jurisdiction")
    local_nonpersistent_flags+=("--jurisdiction=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--percentage=")
    two_word_flags+=("--percentage")
    local_nonpersistent_flags+=("--percentage")
    local_nonpersistent_flags+=("--percentage=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--state=")
    two_word_flags+=("--state")
    local_nonpersistent_flags+=("--state")
    local_nonpersistent_flags+=("--state=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tax-type=")
    two_word_flags+=("--tax-type")
    local_nonpersistent_flags+=("--tax-type")
    local_nonpersistent_flags+=("--tax-type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_rates_list()
{
    last_command="stripe_tax_rates_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--inclusive=")
    two_word_flags+=("--inclusive")
    local_nonpersistent_flags+=("--inclusive")
    local_nonpersistent_flags+=("--inclusive=")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_rates_retrieve()
{
    last_command="stripe_tax_rates_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_rates_update()
{
    last_command="stripe_tax_rates_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--active=")
    two_word_flags+=("--active")
    local_nonpersistent_flags+=("--active")
    local_nonpersistent_flags+=("--active=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--country=")
    two_word_flags+=("--country")
    local_nonpersistent_flags+=("--country")
    local_nonpersistent_flags+=("--country=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--display-name=")
    two_word_flags+=("--display-name")
    local_nonpersistent_flags+=("--display-name")
    local_nonpersistent_flags+=("--display-name=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--jurisdiction=")
    two_word_flags+=("--jurisdiction")
    local_nonpersistent_flags+=("--jurisdiction")
    local_nonpersistent_flags+=("--jurisdiction=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--state=")
    two_word_flags+=("--state")
    local_nonpersistent_flags+=("--state")
    local_nonpersistent_flags+=("--state=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tax-type=")
    two_word_flags+=("--tax-type")
    local_nonpersistent_flags+=("--tax-type")
    local_nonpersistent_flags+=("--tax-type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tax_rates()
{
    last_command="stripe_tax_rates"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_configurations_create()
{
    last_command="stripe_terminal_configurations_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--bbpos-wisepos-e.splashscreen=")
    two_word_flags+=("--bbpos-wisepos-e.splashscreen")
    local_nonpersistent_flags+=("--bbpos-wisepos-e.splashscreen")
    local_nonpersistent_flags+=("--bbpos-wisepos-e.splashscreen=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--reboot-window.end-hour=")
    two_word_flags+=("--reboot-window.end-hour")
    local_nonpersistent_flags+=("--reboot-window.end-hour")
    local_nonpersistent_flags+=("--reboot-window.end-hour=")
    flags+=("--reboot-window.start-hour=")
    two_word_flags+=("--reboot-window.start-hour")
    local_nonpersistent_flags+=("--reboot-window.start-hour")
    local_nonpersistent_flags+=("--reboot-window.start-hour=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-s700.splashscreen=")
    two_word_flags+=("--stripe-s700.splashscreen")
    local_nonpersistent_flags+=("--stripe-s700.splashscreen")
    local_nonpersistent_flags+=("--stripe-s700.splashscreen=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--verifone-p400.splashscreen=")
    two_word_flags+=("--verifone-p400.splashscreen")
    local_nonpersistent_flags+=("--verifone-p400.splashscreen")
    local_nonpersistent_flags+=("--verifone-p400.splashscreen=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_configurations_delete()
{
    last_command="stripe_terminal_configurations_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_configurations_list()
{
    last_command="stripe_terminal_configurations_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--is-account-default=")
    two_word_flags+=("--is-account-default")
    local_nonpersistent_flags+=("--is-account-default")
    local_nonpersistent_flags+=("--is-account-default=")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_configurations_retrieve()
{
    last_command="stripe_terminal_configurations_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_configurations_update()
{
    last_command="stripe_terminal_configurations_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_configurations()
{
    last_command="stripe_terminal_configurations"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_connection_tokens_create()
{
    last_command="stripe_terminal_connection_tokens_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--location=")
    two_word_flags+=("--location")
    local_nonpersistent_flags+=("--location")
    local_nonpersistent_flags+=("--location=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_connection_tokens()
{
    last_command="stripe_terminal_connection_tokens"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_locations_create()
{
    last_command="stripe_terminal_locations_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--address.city=")
    two_word_flags+=("--address.city")
    local_nonpersistent_flags+=("--address.city")
    local_nonpersistent_flags+=("--address.city=")
    flags+=("--address.country=")
    two_word_flags+=("--address.country")
    local_nonpersistent_flags+=("--address.country")
    local_nonpersistent_flags+=("--address.country=")
    flags+=("--address.line1=")
    two_word_flags+=("--address.line1")
    local_nonpersistent_flags+=("--address.line1")
    local_nonpersistent_flags+=("--address.line1=")
    flags+=("--address.line2=")
    two_word_flags+=("--address.line2")
    local_nonpersistent_flags+=("--address.line2")
    local_nonpersistent_flags+=("--address.line2=")
    flags+=("--address.postal-code=")
    two_word_flags+=("--address.postal-code")
    local_nonpersistent_flags+=("--address.postal-code")
    local_nonpersistent_flags+=("--address.postal-code=")
    flags+=("--address.state=")
    two_word_flags+=("--address.state")
    local_nonpersistent_flags+=("--address.state")
    local_nonpersistent_flags+=("--address.state=")
    flags+=("--configuration-overrides=")
    two_word_flags+=("--configuration-overrides")
    local_nonpersistent_flags+=("--configuration-overrides")
    local_nonpersistent_flags+=("--configuration-overrides=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--display-name=")
    two_word_flags+=("--display-name")
    local_nonpersistent_flags+=("--display-name")
    local_nonpersistent_flags+=("--display-name=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_locations_delete()
{
    last_command="stripe_terminal_locations_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_locations_list()
{
    last_command="stripe_terminal_locations_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_locations_retrieve()
{
    last_command="stripe_terminal_locations_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_locations_update()
{
    last_command="stripe_terminal_locations_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--address.city=")
    two_word_flags+=("--address.city")
    local_nonpersistent_flags+=("--address.city")
    local_nonpersistent_flags+=("--address.city=")
    flags+=("--address.country=")
    two_word_flags+=("--address.country")
    local_nonpersistent_flags+=("--address.country")
    local_nonpersistent_flags+=("--address.country=")
    flags+=("--address.line1=")
    two_word_flags+=("--address.line1")
    local_nonpersistent_flags+=("--address.line1")
    local_nonpersistent_flags+=("--address.line1=")
    flags+=("--address.line2=")
    two_word_flags+=("--address.line2")
    local_nonpersistent_flags+=("--address.line2")
    local_nonpersistent_flags+=("--address.line2=")
    flags+=("--address.postal-code=")
    two_word_flags+=("--address.postal-code")
    local_nonpersistent_flags+=("--address.postal-code")
    local_nonpersistent_flags+=("--address.postal-code=")
    flags+=("--address.state=")
    two_word_flags+=("--address.state")
    local_nonpersistent_flags+=("--address.state")
    local_nonpersistent_flags+=("--address.state=")
    flags+=("--configuration-overrides=")
    two_word_flags+=("--configuration-overrides")
    local_nonpersistent_flags+=("--configuration-overrides")
    local_nonpersistent_flags+=("--configuration-overrides=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--display-name=")
    two_word_flags+=("--display-name")
    local_nonpersistent_flags+=("--display-name")
    local_nonpersistent_flags+=("--display-name=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_locations()
{
    last_command="stripe_terminal_locations"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_quickstart()
{
    last_command="stripe_terminal_quickstart"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_readers_cancel_action()
{
    last_command="stripe_terminal_readers_cancel_action"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_readers_create()
{
    last_command="stripe_terminal_readers_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--label=")
    two_word_flags+=("--label")
    local_nonpersistent_flags+=("--label")
    local_nonpersistent_flags+=("--label=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--location=")
    two_word_flags+=("--location")
    local_nonpersistent_flags+=("--location")
    local_nonpersistent_flags+=("--location=")
    flags+=("--registration-code=")
    two_word_flags+=("--registration-code")
    local_nonpersistent_flags+=("--registration-code")
    local_nonpersistent_flags+=("--registration-code=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_readers_delete()
{
    last_command="stripe_terminal_readers_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_readers_list()
{
    last_command="stripe_terminal_readers_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--device-type=")
    two_word_flags+=("--device-type")
    local_nonpersistent_flags+=("--device-type")
    local_nonpersistent_flags+=("--device-type=")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--location=")
    two_word_flags+=("--location")
    local_nonpersistent_flags+=("--location")
    local_nonpersistent_flags+=("--location=")
    flags+=("--serial-number=")
    two_word_flags+=("--serial-number")
    local_nonpersistent_flags+=("--serial-number")
    local_nonpersistent_flags+=("--serial-number=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_readers_process_payment_intent()
{
    last_command="stripe_terminal_readers_process_payment_intent"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-intent=")
    two_word_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent=")
    flags+=("--process-config.allow-redisplay=")
    two_word_flags+=("--process-config.allow-redisplay")
    local_nonpersistent_flags+=("--process-config.allow-redisplay")
    local_nonpersistent_flags+=("--process-config.allow-redisplay=")
    flags+=("--process-config.enable-customer-cancellation=")
    two_word_flags+=("--process-config.enable-customer-cancellation")
    local_nonpersistent_flags+=("--process-config.enable-customer-cancellation")
    local_nonpersistent_flags+=("--process-config.enable-customer-cancellation=")
    flags+=("--process-config.skip-tipping=")
    two_word_flags+=("--process-config.skip-tipping")
    local_nonpersistent_flags+=("--process-config.skip-tipping")
    local_nonpersistent_flags+=("--process-config.skip-tipping=")
    flags+=("--process-config.tipping.amount-eligible=")
    two_word_flags+=("--process-config.tipping.amount-eligible")
    local_nonpersistent_flags+=("--process-config.tipping.amount-eligible")
    local_nonpersistent_flags+=("--process-config.tipping.amount-eligible=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_readers_process_setup_intent()
{
    last_command="stripe_terminal_readers_process_setup_intent"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--allow-redisplay=")
    two_word_flags+=("--allow-redisplay")
    local_nonpersistent_flags+=("--allow-redisplay")
    local_nonpersistent_flags+=("--allow-redisplay=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--process-config.enable-customer-cancellation=")
    two_word_flags+=("--process-config.enable-customer-cancellation")
    local_nonpersistent_flags+=("--process-config.enable-customer-cancellation")
    local_nonpersistent_flags+=("--process-config.enable-customer-cancellation=")
    flags+=("--setup-intent=")
    two_word_flags+=("--setup-intent")
    local_nonpersistent_flags+=("--setup-intent")
    local_nonpersistent_flags+=("--setup-intent=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_readers_refund_payment()
{
    last_command="stripe_terminal_readers_refund_payment"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--charge=")
    two_word_flags+=("--charge")
    local_nonpersistent_flags+=("--charge")
    local_nonpersistent_flags+=("--charge=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-intent=")
    two_word_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent")
    local_nonpersistent_flags+=("--payment-intent=")
    flags+=("--refund-application-fee=")
    two_word_flags+=("--refund-application-fee")
    local_nonpersistent_flags+=("--refund-application-fee")
    local_nonpersistent_flags+=("--refund-application-fee=")
    flags+=("--refund-payment-config.enable-customer-cancellation=")
    two_word_flags+=("--refund-payment-config.enable-customer-cancellation")
    local_nonpersistent_flags+=("--refund-payment-config.enable-customer-cancellation")
    local_nonpersistent_flags+=("--refund-payment-config.enable-customer-cancellation=")
    flags+=("--reverse-transfer=")
    two_word_flags+=("--reverse-transfer")
    local_nonpersistent_flags+=("--reverse-transfer")
    local_nonpersistent_flags+=("--reverse-transfer=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_readers_retrieve()
{
    last_command="stripe_terminal_readers_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_readers_set_reader_display()
{
    last_command="stripe_terminal_readers_set_reader_display"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--cart.currency=")
    two_word_flags+=("--cart.currency")
    local_nonpersistent_flags+=("--cart.currency")
    local_nonpersistent_flags+=("--cart.currency=")
    flags+=("--cart.tax=")
    two_word_flags+=("--cart.tax")
    local_nonpersistent_flags+=("--cart.tax")
    local_nonpersistent_flags+=("--cart.tax=")
    flags+=("--cart.total=")
    two_word_flags+=("--cart.total")
    local_nonpersistent_flags+=("--cart.total")
    local_nonpersistent_flags+=("--cart.total=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_readers_test_helpers_present_payment_method()
{
    last_command="stripe_terminal_readers_test_helpers_present_payment_method"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount-tip=")
    two_word_flags+=("--amount-tip")
    local_nonpersistent_flags+=("--amount-tip")
    local_nonpersistent_flags+=("--amount-tip=")
    flags+=("--card-present.number=")
    two_word_flags+=("--card-present.number")
    local_nonpersistent_flags+=("--card-present.number")
    local_nonpersistent_flags+=("--card-present.number=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--interac-present.number=")
    two_word_flags+=("--interac-present.number")
    local_nonpersistent_flags+=("--interac-present.number")
    local_nonpersistent_flags+=("--interac-present.number=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_readers_test_helpers()
{
    last_command="stripe_terminal_readers_test_helpers"

    command_aliases=()

    commands=()
    commands+=("present_payment_method")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_readers_update()
{
    last_command="stripe_terminal_readers_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--label=")
    two_word_flags+=("--label")
    local_nonpersistent_flags+=("--label")
    local_nonpersistent_flags+=("--label=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal_readers()
{
    last_command="stripe_terminal_readers"

    command_aliases=()

    commands=()
    commands+=("cancel_action")
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("process_payment_intent")
    commands+=("process_setup_intent")
    commands+=("refund_payment")
    commands+=("retrieve")
    commands+=("set_reader_display")
    commands+=("test_helpers")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_terminal()
{
    last_command="stripe_terminal"

    command_aliases=()

    commands=()
    commands+=("configurations")
    commands+=("connection_tokens")
    commands+=("locations")
    commands+=("quickstart")
    commands+=("readers")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_confirmation_tokens_create()
{
    last_command="stripe_test_helpers_confirmation_tokens_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--payment-method=")
    two_word_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method")
    local_nonpersistent_flags+=("--payment-method=")
    flags+=("--payment-method-data.acss-debit.account-number=")
    two_word_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.account-number=")
    flags+=("--payment-method-data.acss-debit.institution-number=")
    two_word_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.institution-number=")
    flags+=("--payment-method-data.acss-debit.transit-number=")
    two_word_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number")
    local_nonpersistent_flags+=("--payment-method-data.acss-debit.transit-number=")
    flags+=("--payment-method-data.allow-redisplay=")
    two_word_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay")
    local_nonpersistent_flags+=("--payment-method-data.allow-redisplay=")
    flags+=("--payment-method-data.au-becs-debit.account-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.account-number=")
    flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    two_word_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number")
    local_nonpersistent_flags+=("--payment-method-data.au-becs-debit.bsb-number=")
    flags+=("--payment-method-data.bacs-debit.account-number=")
    two_word_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.account-number=")
    flags+=("--payment-method-data.bacs-debit.sort-code=")
    two_word_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code")
    local_nonpersistent_flags+=("--payment-method-data.bacs-debit.sort-code=")
    flags+=("--payment-method-data.billing-details.email=")
    two_word_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.email=")
    flags+=("--payment-method-data.billing-details.name=")
    two_word_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.name=")
    flags+=("--payment-method-data.billing-details.phone=")
    two_word_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--payment-method-data.billing-details.phone=")
    flags+=("--payment-method-data.boleto.tax-id=")
    two_word_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id")
    local_nonpersistent_flags+=("--payment-method-data.boleto.tax-id=")
    flags+=("--payment-method-data.eps.bank=")
    two_word_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank")
    local_nonpersistent_flags+=("--payment-method-data.eps.bank=")
    flags+=("--payment-method-data.fpx.account-holder-type=")
    two_word_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.fpx.account-holder-type=")
    flags+=("--payment-method-data.fpx.bank=")
    two_word_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank")
    local_nonpersistent_flags+=("--payment-method-data.fpx.bank=")
    flags+=("--payment-method-data.ideal.bank=")
    two_word_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank")
    local_nonpersistent_flags+=("--payment-method-data.ideal.bank=")
    flags+=("--payment-method-data.klarna.dob.day=")
    two_word_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.day=")
    flags+=("--payment-method-data.klarna.dob.month=")
    two_word_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.month=")
    flags+=("--payment-method-data.klarna.dob.year=")
    two_word_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year")
    local_nonpersistent_flags+=("--payment-method-data.klarna.dob.year=")
    flags+=("--payment-method-data.naver-pay.funding=")
    two_word_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding")
    local_nonpersistent_flags+=("--payment-method-data.naver-pay.funding=")
    flags+=("--payment-method-data.p24.bank=")
    two_word_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank")
    local_nonpersistent_flags+=("--payment-method-data.p24.bank=")
    flags+=("--payment-method-data.radar-options.session=")
    two_word_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session")
    local_nonpersistent_flags+=("--payment-method-data.radar-options.session=")
    flags+=("--payment-method-data.sepa-debit.iban=")
    two_word_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban")
    local_nonpersistent_flags+=("--payment-method-data.sepa-debit.iban=")
    flags+=("--payment-method-data.sofort.country=")
    two_word_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country")
    local_nonpersistent_flags+=("--payment-method-data.sofort.country=")
    flags+=("--payment-method-data.type=")
    two_word_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type")
    local_nonpersistent_flags+=("--payment-method-data.type=")
    flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-holder-type=")
    flags+=("--payment-method-data.us-bank-account.account-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-number=")
    flags+=("--payment-method-data.us-bank-account.account-type=")
    two_word_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.account-type=")
    flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    two_word_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.financial-connections-account=")
    flags+=("--payment-method-data.us-bank-account.routing-number=")
    two_word_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--payment-method-data.us-bank-account.routing-number=")
    flags+=("--return-url=")
    two_word_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url")
    local_nonpersistent_flags+=("--return-url=")
    flags+=("--setup-future-usage=")
    two_word_flags+=("--setup-future-usage")
    local_nonpersistent_flags+=("--setup-future-usage")
    local_nonpersistent_flags+=("--setup-future-usage=")
    flags+=("--shipping.address.city=")
    two_word_flags+=("--shipping.address.city")
    local_nonpersistent_flags+=("--shipping.address.city")
    local_nonpersistent_flags+=("--shipping.address.city=")
    flags+=("--shipping.address.country=")
    two_word_flags+=("--shipping.address.country")
    local_nonpersistent_flags+=("--shipping.address.country")
    local_nonpersistent_flags+=("--shipping.address.country=")
    flags+=("--shipping.address.line1=")
    two_word_flags+=("--shipping.address.line1")
    local_nonpersistent_flags+=("--shipping.address.line1")
    local_nonpersistent_flags+=("--shipping.address.line1=")
    flags+=("--shipping.address.line2=")
    two_word_flags+=("--shipping.address.line2")
    local_nonpersistent_flags+=("--shipping.address.line2")
    local_nonpersistent_flags+=("--shipping.address.line2=")
    flags+=("--shipping.address.postal-code=")
    two_word_flags+=("--shipping.address.postal-code")
    local_nonpersistent_flags+=("--shipping.address.postal-code")
    local_nonpersistent_flags+=("--shipping.address.postal-code=")
    flags+=("--shipping.address.state=")
    two_word_flags+=("--shipping.address.state")
    local_nonpersistent_flags+=("--shipping.address.state")
    local_nonpersistent_flags+=("--shipping.address.state=")
    flags+=("--shipping.name=")
    two_word_flags+=("--shipping.name")
    local_nonpersistent_flags+=("--shipping.name")
    local_nonpersistent_flags+=("--shipping.name=")
    flags+=("--shipping.phone=")
    two_word_flags+=("--shipping.phone")
    local_nonpersistent_flags+=("--shipping.phone")
    local_nonpersistent_flags+=("--shipping.phone=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_confirmation_tokens()
{
    last_command="stripe_test_helpers_confirmation_tokens"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_customers_fund_cash_balance()
{
    last_command="stripe_test_helpers_customers_fund_cash_balance"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--reference=")
    two_word_flags+=("--reference")
    local_nonpersistent_flags+=("--reference")
    local_nonpersistent_flags+=("--reference=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_customers()
{
    last_command="stripe_test_helpers_customers"

    command_aliases=()

    commands=()
    commands+=("fund_cash_balance")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_authorizations_capture()
{
    last_command="stripe_test_helpers_issuing_authorizations_capture"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--capture-amount=")
    two_word_flags+=("--capture-amount")
    local_nonpersistent_flags+=("--capture-amount")
    local_nonpersistent_flags+=("--capture-amount=")
    flags+=("--close-authorization=")
    two_word_flags+=("--close-authorization")
    local_nonpersistent_flags+=("--close-authorization")
    local_nonpersistent_flags+=("--close-authorization=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number=")
    flags+=("--purchase-details.fleet.purchase-type=")
    two_word_flags+=("--purchase-details.fleet.purchase-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.purchase-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.purchase-type=")
    flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal=")
    flags+=("--purchase-details.fleet.service-type=")
    two_word_flags+=("--purchase-details.fleet.service-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.service-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.service-type=")
    flags+=("--purchase-details.flight.departure-at=")
    two_word_flags+=("--purchase-details.flight.departure-at")
    local_nonpersistent_flags+=("--purchase-details.flight.departure-at")
    local_nonpersistent_flags+=("--purchase-details.flight.departure-at=")
    flags+=("--purchase-details.flight.passenger-name=")
    two_word_flags+=("--purchase-details.flight.passenger-name")
    local_nonpersistent_flags+=("--purchase-details.flight.passenger-name")
    local_nonpersistent_flags+=("--purchase-details.flight.passenger-name=")
    flags+=("--purchase-details.flight.refundable=")
    two_word_flags+=("--purchase-details.flight.refundable")
    local_nonpersistent_flags+=("--purchase-details.flight.refundable")
    local_nonpersistent_flags+=("--purchase-details.flight.refundable=")
    flags+=("--purchase-details.flight.travel-agency=")
    two_word_flags+=("--purchase-details.flight.travel-agency")
    local_nonpersistent_flags+=("--purchase-details.flight.travel-agency")
    local_nonpersistent_flags+=("--purchase-details.flight.travel-agency=")
    flags+=("--purchase-details.fuel.industry-product-code=")
    two_word_flags+=("--purchase-details.fuel.industry-product-code")
    local_nonpersistent_flags+=("--purchase-details.fuel.industry-product-code")
    local_nonpersistent_flags+=("--purchase-details.fuel.industry-product-code=")
    flags+=("--purchase-details.fuel.quantity-decimal=")
    two_word_flags+=("--purchase-details.fuel.quantity-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.quantity-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.quantity-decimal=")
    flags+=("--purchase-details.fuel.type=")
    two_word_flags+=("--purchase-details.fuel.type")
    local_nonpersistent_flags+=("--purchase-details.fuel.type")
    local_nonpersistent_flags+=("--purchase-details.fuel.type=")
    flags+=("--purchase-details.fuel.unit=")
    two_word_flags+=("--purchase-details.fuel.unit")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit=")
    flags+=("--purchase-details.fuel.unit-cost-decimal=")
    two_word_flags+=("--purchase-details.fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit-cost-decimal=")
    flags+=("--purchase-details.lodging.check-in-at=")
    two_word_flags+=("--purchase-details.lodging.check-in-at")
    local_nonpersistent_flags+=("--purchase-details.lodging.check-in-at")
    local_nonpersistent_flags+=("--purchase-details.lodging.check-in-at=")
    flags+=("--purchase-details.lodging.nights=")
    two_word_flags+=("--purchase-details.lodging.nights")
    local_nonpersistent_flags+=("--purchase-details.lodging.nights")
    local_nonpersistent_flags+=("--purchase-details.lodging.nights=")
    flags+=("--purchase-details.reference=")
    two_word_flags+=("--purchase-details.reference")
    local_nonpersistent_flags+=("--purchase-details.reference")
    local_nonpersistent_flags+=("--purchase-details.reference=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_authorizations_create()
{
    last_command="stripe_test_helpers_issuing_authorizations_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--amount-details.atm-fee=")
    two_word_flags+=("--amount-details.atm-fee")
    local_nonpersistent_flags+=("--amount-details.atm-fee")
    local_nonpersistent_flags+=("--amount-details.atm-fee=")
    flags+=("--amount-details.cashback-amount=")
    two_word_flags+=("--amount-details.cashback-amount")
    local_nonpersistent_flags+=("--amount-details.cashback-amount")
    local_nonpersistent_flags+=("--amount-details.cashback-amount=")
    flags+=("--authorization-method=")
    two_word_flags+=("--authorization-method")
    local_nonpersistent_flags+=("--authorization-method")
    local_nonpersistent_flags+=("--authorization-method=")
    flags+=("--card=")
    two_word_flags+=("--card")
    local_nonpersistent_flags+=("--card")
    local_nonpersistent_flags+=("--card=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--fleet.cardholder-prompt-data.driver-id=")
    two_word_flags+=("--fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.driver-id=")
    flags+=("--fleet.cardholder-prompt-data.odometer=")
    two_word_flags+=("--fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.odometer=")
    flags+=("--fleet.cardholder-prompt-data.unspecified-id=")
    two_word_flags+=("--fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.unspecified-id=")
    flags+=("--fleet.cardholder-prompt-data.user-id=")
    two_word_flags+=("--fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.user-id=")
    flags+=("--fleet.cardholder-prompt-data.vehicle-number=")
    two_word_flags+=("--fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.vehicle-number=")
    flags+=("--fleet.purchase-type=")
    two_word_flags+=("--fleet.purchase-type")
    local_nonpersistent_flags+=("--fleet.purchase-type")
    local_nonpersistent_flags+=("--fleet.purchase-type=")
    flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal=")
    flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    flags+=("--fleet.reported-breakdown.tax.local-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.local-amount-decimal=")
    flags+=("--fleet.reported-breakdown.tax.national-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.national-amount-decimal=")
    flags+=("--fleet.service-type=")
    two_word_flags+=("--fleet.service-type")
    local_nonpersistent_flags+=("--fleet.service-type")
    local_nonpersistent_flags+=("--fleet.service-type=")
    flags+=("--fuel.industry-product-code=")
    two_word_flags+=("--fuel.industry-product-code")
    local_nonpersistent_flags+=("--fuel.industry-product-code")
    local_nonpersistent_flags+=("--fuel.industry-product-code=")
    flags+=("--fuel.quantity-decimal=")
    two_word_flags+=("--fuel.quantity-decimal")
    local_nonpersistent_flags+=("--fuel.quantity-decimal")
    local_nonpersistent_flags+=("--fuel.quantity-decimal=")
    flags+=("--fuel.type=")
    two_word_flags+=("--fuel.type")
    local_nonpersistent_flags+=("--fuel.type")
    local_nonpersistent_flags+=("--fuel.type=")
    flags+=("--fuel.unit=")
    two_word_flags+=("--fuel.unit")
    local_nonpersistent_flags+=("--fuel.unit")
    local_nonpersistent_flags+=("--fuel.unit=")
    flags+=("--fuel.unit-cost-decimal=")
    two_word_flags+=("--fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--fuel.unit-cost-decimal=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--is-amount-controllable=")
    two_word_flags+=("--is-amount-controllable")
    local_nonpersistent_flags+=("--is-amount-controllable")
    local_nonpersistent_flags+=("--is-amount-controllable=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--merchant-data.category=")
    two_word_flags+=("--merchant-data.category")
    local_nonpersistent_flags+=("--merchant-data.category")
    local_nonpersistent_flags+=("--merchant-data.category=")
    flags+=("--merchant-data.city=")
    two_word_flags+=("--merchant-data.city")
    local_nonpersistent_flags+=("--merchant-data.city")
    local_nonpersistent_flags+=("--merchant-data.city=")
    flags+=("--merchant-data.country=")
    two_word_flags+=("--merchant-data.country")
    local_nonpersistent_flags+=("--merchant-data.country")
    local_nonpersistent_flags+=("--merchant-data.country=")
    flags+=("--merchant-data.name=")
    two_word_flags+=("--merchant-data.name")
    local_nonpersistent_flags+=("--merchant-data.name")
    local_nonpersistent_flags+=("--merchant-data.name=")
    flags+=("--merchant-data.network-id=")
    two_word_flags+=("--merchant-data.network-id")
    local_nonpersistent_flags+=("--merchant-data.network-id")
    local_nonpersistent_flags+=("--merchant-data.network-id=")
    flags+=("--merchant-data.postal-code=")
    two_word_flags+=("--merchant-data.postal-code")
    local_nonpersistent_flags+=("--merchant-data.postal-code")
    local_nonpersistent_flags+=("--merchant-data.postal-code=")
    flags+=("--merchant-data.state=")
    two_word_flags+=("--merchant-data.state")
    local_nonpersistent_flags+=("--merchant-data.state")
    local_nonpersistent_flags+=("--merchant-data.state=")
    flags+=("--merchant-data.terminal-id=")
    two_word_flags+=("--merchant-data.terminal-id")
    local_nonpersistent_flags+=("--merchant-data.terminal-id")
    local_nonpersistent_flags+=("--merchant-data.terminal-id=")
    flags+=("--merchant-data.url=")
    two_word_flags+=("--merchant-data.url")
    local_nonpersistent_flags+=("--merchant-data.url")
    local_nonpersistent_flags+=("--merchant-data.url=")
    flags+=("--network-data.acquiring-institution-id=")
    two_word_flags+=("--network-data.acquiring-institution-id")
    local_nonpersistent_flags+=("--network-data.acquiring-institution-id")
    local_nonpersistent_flags+=("--network-data.acquiring-institution-id=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--verification-data.address-line1-check=")
    two_word_flags+=("--verification-data.address-line1-check")
    local_nonpersistent_flags+=("--verification-data.address-line1-check")
    local_nonpersistent_flags+=("--verification-data.address-line1-check=")
    flags+=("--verification-data.address-postal-code-check=")
    two_word_flags+=("--verification-data.address-postal-code-check")
    local_nonpersistent_flags+=("--verification-data.address-postal-code-check")
    local_nonpersistent_flags+=("--verification-data.address-postal-code-check=")
    flags+=("--verification-data.authentication-exemption.claimed-by=")
    two_word_flags+=("--verification-data.authentication-exemption.claimed-by")
    local_nonpersistent_flags+=("--verification-data.authentication-exemption.claimed-by")
    local_nonpersistent_flags+=("--verification-data.authentication-exemption.claimed-by=")
    flags+=("--verification-data.authentication-exemption.type=")
    two_word_flags+=("--verification-data.authentication-exemption.type")
    local_nonpersistent_flags+=("--verification-data.authentication-exemption.type")
    local_nonpersistent_flags+=("--verification-data.authentication-exemption.type=")
    flags+=("--verification-data.cvc-check=")
    two_word_flags+=("--verification-data.cvc-check")
    local_nonpersistent_flags+=("--verification-data.cvc-check")
    local_nonpersistent_flags+=("--verification-data.cvc-check=")
    flags+=("--verification-data.expiry-check=")
    two_word_flags+=("--verification-data.expiry-check")
    local_nonpersistent_flags+=("--verification-data.expiry-check")
    local_nonpersistent_flags+=("--verification-data.expiry-check=")
    flags+=("--verification-data.three-d-secure.result=")
    two_word_flags+=("--verification-data.three-d-secure.result")
    local_nonpersistent_flags+=("--verification-data.three-d-secure.result")
    local_nonpersistent_flags+=("--verification-data.three-d-secure.result=")
    flags+=("--wallet=")
    two_word_flags+=("--wallet")
    local_nonpersistent_flags+=("--wallet")
    local_nonpersistent_flags+=("--wallet=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_authorizations_expire()
{
    last_command="stripe_test_helpers_issuing_authorizations_expire"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_authorizations_finalize_amount()
{
    last_command="stripe_test_helpers_issuing_authorizations_finalize_amount"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--final-amount=")
    two_word_flags+=("--final-amount")
    local_nonpersistent_flags+=("--final-amount")
    local_nonpersistent_flags+=("--final-amount=")
    flags+=("--fleet.cardholder-prompt-data.driver-id=")
    two_word_flags+=("--fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.driver-id=")
    flags+=("--fleet.cardholder-prompt-data.odometer=")
    two_word_flags+=("--fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.odometer=")
    flags+=("--fleet.cardholder-prompt-data.unspecified-id=")
    two_word_flags+=("--fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.unspecified-id=")
    flags+=("--fleet.cardholder-prompt-data.user-id=")
    two_word_flags+=("--fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.user-id=")
    flags+=("--fleet.cardholder-prompt-data.vehicle-number=")
    two_word_flags+=("--fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--fleet.cardholder-prompt-data.vehicle-number=")
    flags+=("--fleet.purchase-type=")
    two_word_flags+=("--fleet.purchase-type")
    local_nonpersistent_flags+=("--fleet.purchase-type")
    local_nonpersistent_flags+=("--fleet.purchase-type=")
    flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.fuel.gross-amount-decimal=")
    flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    flags+=("--fleet.reported-breakdown.tax.local-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.local-amount-decimal=")
    flags+=("--fleet.reported-breakdown.tax.national-amount-decimal=")
    two_word_flags+=("--fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--fleet.reported-breakdown.tax.national-amount-decimal=")
    flags+=("--fleet.service-type=")
    two_word_flags+=("--fleet.service-type")
    local_nonpersistent_flags+=("--fleet.service-type")
    local_nonpersistent_flags+=("--fleet.service-type=")
    flags+=("--fuel.industry-product-code=")
    two_word_flags+=("--fuel.industry-product-code")
    local_nonpersistent_flags+=("--fuel.industry-product-code")
    local_nonpersistent_flags+=("--fuel.industry-product-code=")
    flags+=("--fuel.quantity-decimal=")
    two_word_flags+=("--fuel.quantity-decimal")
    local_nonpersistent_flags+=("--fuel.quantity-decimal")
    local_nonpersistent_flags+=("--fuel.quantity-decimal=")
    flags+=("--fuel.type=")
    two_word_flags+=("--fuel.type")
    local_nonpersistent_flags+=("--fuel.type")
    local_nonpersistent_flags+=("--fuel.type=")
    flags+=("--fuel.unit=")
    two_word_flags+=("--fuel.unit")
    local_nonpersistent_flags+=("--fuel.unit")
    local_nonpersistent_flags+=("--fuel.unit=")
    flags+=("--fuel.unit-cost-decimal=")
    two_word_flags+=("--fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--fuel.unit-cost-decimal=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_authorizations_increment()
{
    last_command="stripe_test_helpers_issuing_authorizations_increment"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--increment-amount=")
    two_word_flags+=("--increment-amount")
    local_nonpersistent_flags+=("--increment-amount")
    local_nonpersistent_flags+=("--increment-amount=")
    flags+=("--is-amount-controllable=")
    two_word_flags+=("--is-amount-controllable")
    local_nonpersistent_flags+=("--is-amount-controllable")
    local_nonpersistent_flags+=("--is-amount-controllable=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_authorizations_reverse()
{
    last_command="stripe_test_helpers_issuing_authorizations_reverse"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--reverse-amount=")
    two_word_flags+=("--reverse-amount")
    local_nonpersistent_flags+=("--reverse-amount")
    local_nonpersistent_flags+=("--reverse-amount=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_authorizations()
{
    last_command="stripe_test_helpers_issuing_authorizations"

    command_aliases=()

    commands=()
    commands+=("capture")
    commands+=("create")
    commands+=("expire")
    commands+=("finalize_amount")
    commands+=("increment")
    commands+=("reverse")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_cards_deliver_card()
{
    last_command="stripe_test_helpers_issuing_cards_deliver_card"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_cards_fail_card()
{
    last_command="stripe_test_helpers_issuing_cards_fail_card"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_cards_return_card()
{
    last_command="stripe_test_helpers_issuing_cards_return_card"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_cards_ship_card()
{
    last_command="stripe_test_helpers_issuing_cards_ship_card"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_cards_submit_card()
{
    last_command="stripe_test_helpers_issuing_cards_submit_card"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_cards()
{
    last_command="stripe_test_helpers_issuing_cards"

    command_aliases=()

    commands=()
    commands+=("deliver_card")
    commands+=("fail_card")
    commands+=("return_card")
    commands+=("ship_card")
    commands+=("submit_card")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_personalization_designs_activate()
{
    last_command="stripe_test_helpers_issuing_personalization_designs_activate"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_personalization_designs_deactivate()
{
    last_command="stripe_test_helpers_issuing_personalization_designs_deactivate"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_personalization_designs_reject()
{
    last_command="stripe_test_helpers_issuing_personalization_designs_reject"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--rejection-reasons.card-logo=")
    two_word_flags+=("--rejection-reasons.card-logo")
    local_nonpersistent_flags+=("--rejection-reasons.card-logo")
    local_nonpersistent_flags+=("--rejection-reasons.card-logo=")
    flags+=("--rejection-reasons.carrier-text=")
    two_word_flags+=("--rejection-reasons.carrier-text")
    local_nonpersistent_flags+=("--rejection-reasons.carrier-text")
    local_nonpersistent_flags+=("--rejection-reasons.carrier-text=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_personalization_designs()
{
    last_command="stripe_test_helpers_issuing_personalization_designs"

    command_aliases=()

    commands=()
    commands+=("activate")
    commands+=("deactivate")
    commands+=("reject")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_transactions_create_force_capture()
{
    last_command="stripe_test_helpers_issuing_transactions_create_force_capture"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--card=")
    two_word_flags+=("--card")
    local_nonpersistent_flags+=("--card")
    local_nonpersistent_flags+=("--card=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--merchant-data.category=")
    two_word_flags+=("--merchant-data.category")
    local_nonpersistent_flags+=("--merchant-data.category")
    local_nonpersistent_flags+=("--merchant-data.category=")
    flags+=("--merchant-data.city=")
    two_word_flags+=("--merchant-data.city")
    local_nonpersistent_flags+=("--merchant-data.city")
    local_nonpersistent_flags+=("--merchant-data.city=")
    flags+=("--merchant-data.country=")
    two_word_flags+=("--merchant-data.country")
    local_nonpersistent_flags+=("--merchant-data.country")
    local_nonpersistent_flags+=("--merchant-data.country=")
    flags+=("--merchant-data.name=")
    two_word_flags+=("--merchant-data.name")
    local_nonpersistent_flags+=("--merchant-data.name")
    local_nonpersistent_flags+=("--merchant-data.name=")
    flags+=("--merchant-data.network-id=")
    two_word_flags+=("--merchant-data.network-id")
    local_nonpersistent_flags+=("--merchant-data.network-id")
    local_nonpersistent_flags+=("--merchant-data.network-id=")
    flags+=("--merchant-data.postal-code=")
    two_word_flags+=("--merchant-data.postal-code")
    local_nonpersistent_flags+=("--merchant-data.postal-code")
    local_nonpersistent_flags+=("--merchant-data.postal-code=")
    flags+=("--merchant-data.state=")
    two_word_flags+=("--merchant-data.state")
    local_nonpersistent_flags+=("--merchant-data.state")
    local_nonpersistent_flags+=("--merchant-data.state=")
    flags+=("--merchant-data.terminal-id=")
    two_word_flags+=("--merchant-data.terminal-id")
    local_nonpersistent_flags+=("--merchant-data.terminal-id")
    local_nonpersistent_flags+=("--merchant-data.terminal-id=")
    flags+=("--merchant-data.url=")
    two_word_flags+=("--merchant-data.url")
    local_nonpersistent_flags+=("--merchant-data.url")
    local_nonpersistent_flags+=("--merchant-data.url=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number=")
    flags+=("--purchase-details.fleet.purchase-type=")
    two_word_flags+=("--purchase-details.fleet.purchase-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.purchase-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.purchase-type=")
    flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal=")
    flags+=("--purchase-details.fleet.service-type=")
    two_word_flags+=("--purchase-details.fleet.service-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.service-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.service-type=")
    flags+=("--purchase-details.flight.departure-at=")
    two_word_flags+=("--purchase-details.flight.departure-at")
    local_nonpersistent_flags+=("--purchase-details.flight.departure-at")
    local_nonpersistent_flags+=("--purchase-details.flight.departure-at=")
    flags+=("--purchase-details.flight.passenger-name=")
    two_word_flags+=("--purchase-details.flight.passenger-name")
    local_nonpersistent_flags+=("--purchase-details.flight.passenger-name")
    local_nonpersistent_flags+=("--purchase-details.flight.passenger-name=")
    flags+=("--purchase-details.flight.refundable=")
    two_word_flags+=("--purchase-details.flight.refundable")
    local_nonpersistent_flags+=("--purchase-details.flight.refundable")
    local_nonpersistent_flags+=("--purchase-details.flight.refundable=")
    flags+=("--purchase-details.flight.travel-agency=")
    two_word_flags+=("--purchase-details.flight.travel-agency")
    local_nonpersistent_flags+=("--purchase-details.flight.travel-agency")
    local_nonpersistent_flags+=("--purchase-details.flight.travel-agency=")
    flags+=("--purchase-details.fuel.industry-product-code=")
    two_word_flags+=("--purchase-details.fuel.industry-product-code")
    local_nonpersistent_flags+=("--purchase-details.fuel.industry-product-code")
    local_nonpersistent_flags+=("--purchase-details.fuel.industry-product-code=")
    flags+=("--purchase-details.fuel.quantity-decimal=")
    two_word_flags+=("--purchase-details.fuel.quantity-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.quantity-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.quantity-decimal=")
    flags+=("--purchase-details.fuel.type=")
    two_word_flags+=("--purchase-details.fuel.type")
    local_nonpersistent_flags+=("--purchase-details.fuel.type")
    local_nonpersistent_flags+=("--purchase-details.fuel.type=")
    flags+=("--purchase-details.fuel.unit=")
    two_word_flags+=("--purchase-details.fuel.unit")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit=")
    flags+=("--purchase-details.fuel.unit-cost-decimal=")
    two_word_flags+=("--purchase-details.fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit-cost-decimal=")
    flags+=("--purchase-details.lodging.check-in-at=")
    two_word_flags+=("--purchase-details.lodging.check-in-at")
    local_nonpersistent_flags+=("--purchase-details.lodging.check-in-at")
    local_nonpersistent_flags+=("--purchase-details.lodging.check-in-at=")
    flags+=("--purchase-details.lodging.nights=")
    two_word_flags+=("--purchase-details.lodging.nights")
    local_nonpersistent_flags+=("--purchase-details.lodging.nights")
    local_nonpersistent_flags+=("--purchase-details.lodging.nights=")
    flags+=("--purchase-details.reference=")
    two_word_flags+=("--purchase-details.reference")
    local_nonpersistent_flags+=("--purchase-details.reference")
    local_nonpersistent_flags+=("--purchase-details.reference=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_transactions_create_unlinked_refund()
{
    last_command="stripe_test_helpers_issuing_transactions_create_unlinked_refund"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--card=")
    two_word_flags+=("--card")
    local_nonpersistent_flags+=("--card")
    local_nonpersistent_flags+=("--card=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--merchant-data.category=")
    two_word_flags+=("--merchant-data.category")
    local_nonpersistent_flags+=("--merchant-data.category")
    local_nonpersistent_flags+=("--merchant-data.category=")
    flags+=("--merchant-data.city=")
    two_word_flags+=("--merchant-data.city")
    local_nonpersistent_flags+=("--merchant-data.city")
    local_nonpersistent_flags+=("--merchant-data.city=")
    flags+=("--merchant-data.country=")
    two_word_flags+=("--merchant-data.country")
    local_nonpersistent_flags+=("--merchant-data.country")
    local_nonpersistent_flags+=("--merchant-data.country=")
    flags+=("--merchant-data.name=")
    two_word_flags+=("--merchant-data.name")
    local_nonpersistent_flags+=("--merchant-data.name")
    local_nonpersistent_flags+=("--merchant-data.name=")
    flags+=("--merchant-data.network-id=")
    two_word_flags+=("--merchant-data.network-id")
    local_nonpersistent_flags+=("--merchant-data.network-id")
    local_nonpersistent_flags+=("--merchant-data.network-id=")
    flags+=("--merchant-data.postal-code=")
    two_word_flags+=("--merchant-data.postal-code")
    local_nonpersistent_flags+=("--merchant-data.postal-code")
    local_nonpersistent_flags+=("--merchant-data.postal-code=")
    flags+=("--merchant-data.state=")
    two_word_flags+=("--merchant-data.state")
    local_nonpersistent_flags+=("--merchant-data.state")
    local_nonpersistent_flags+=("--merchant-data.state=")
    flags+=("--merchant-data.terminal-id=")
    two_word_flags+=("--merchant-data.terminal-id")
    local_nonpersistent_flags+=("--merchant-data.terminal-id")
    local_nonpersistent_flags+=("--merchant-data.terminal-id=")
    flags+=("--merchant-data.url=")
    two_word_flags+=("--merchant-data.url")
    local_nonpersistent_flags+=("--merchant-data.url")
    local_nonpersistent_flags+=("--merchant-data.url=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.driver-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.odometer=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.unspecified-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.user-id=")
    flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number=")
    two_word_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number")
    local_nonpersistent_flags+=("--purchase-details.fleet.cardholder-prompt-data.vehicle-number=")
    flags+=("--purchase-details.fleet.purchase-type=")
    two_word_flags+=("--purchase-details.fleet.purchase-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.purchase-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.purchase-type=")
    flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.fuel.gross-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.non-fuel.gross-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.local-amount-decimal=")
    flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal=")
    two_word_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal")
    local_nonpersistent_flags+=("--purchase-details.fleet.reported-breakdown.tax.national-amount-decimal=")
    flags+=("--purchase-details.fleet.service-type=")
    two_word_flags+=("--purchase-details.fleet.service-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.service-type")
    local_nonpersistent_flags+=("--purchase-details.fleet.service-type=")
    flags+=("--purchase-details.flight.departure-at=")
    two_word_flags+=("--purchase-details.flight.departure-at")
    local_nonpersistent_flags+=("--purchase-details.flight.departure-at")
    local_nonpersistent_flags+=("--purchase-details.flight.departure-at=")
    flags+=("--purchase-details.flight.passenger-name=")
    two_word_flags+=("--purchase-details.flight.passenger-name")
    local_nonpersistent_flags+=("--purchase-details.flight.passenger-name")
    local_nonpersistent_flags+=("--purchase-details.flight.passenger-name=")
    flags+=("--purchase-details.flight.refundable=")
    two_word_flags+=("--purchase-details.flight.refundable")
    local_nonpersistent_flags+=("--purchase-details.flight.refundable")
    local_nonpersistent_flags+=("--purchase-details.flight.refundable=")
    flags+=("--purchase-details.flight.travel-agency=")
    two_word_flags+=("--purchase-details.flight.travel-agency")
    local_nonpersistent_flags+=("--purchase-details.flight.travel-agency")
    local_nonpersistent_flags+=("--purchase-details.flight.travel-agency=")
    flags+=("--purchase-details.fuel.industry-product-code=")
    two_word_flags+=("--purchase-details.fuel.industry-product-code")
    local_nonpersistent_flags+=("--purchase-details.fuel.industry-product-code")
    local_nonpersistent_flags+=("--purchase-details.fuel.industry-product-code=")
    flags+=("--purchase-details.fuel.quantity-decimal=")
    two_word_flags+=("--purchase-details.fuel.quantity-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.quantity-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.quantity-decimal=")
    flags+=("--purchase-details.fuel.type=")
    two_word_flags+=("--purchase-details.fuel.type")
    local_nonpersistent_flags+=("--purchase-details.fuel.type")
    local_nonpersistent_flags+=("--purchase-details.fuel.type=")
    flags+=("--purchase-details.fuel.unit=")
    two_word_flags+=("--purchase-details.fuel.unit")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit=")
    flags+=("--purchase-details.fuel.unit-cost-decimal=")
    two_word_flags+=("--purchase-details.fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit-cost-decimal")
    local_nonpersistent_flags+=("--purchase-details.fuel.unit-cost-decimal=")
    flags+=("--purchase-details.lodging.check-in-at=")
    two_word_flags+=("--purchase-details.lodging.check-in-at")
    local_nonpersistent_flags+=("--purchase-details.lodging.check-in-at")
    local_nonpersistent_flags+=("--purchase-details.lodging.check-in-at=")
    flags+=("--purchase-details.lodging.nights=")
    two_word_flags+=("--purchase-details.lodging.nights")
    local_nonpersistent_flags+=("--purchase-details.lodging.nights")
    local_nonpersistent_flags+=("--purchase-details.lodging.nights=")
    flags+=("--purchase-details.reference=")
    two_word_flags+=("--purchase-details.reference")
    local_nonpersistent_flags+=("--purchase-details.reference")
    local_nonpersistent_flags+=("--purchase-details.reference=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_transactions_refund()
{
    last_command="stripe_test_helpers_issuing_transactions_refund"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--refund-amount=")
    two_word_flags+=("--refund-amount")
    local_nonpersistent_flags+=("--refund-amount")
    local_nonpersistent_flags+=("--refund-amount=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing_transactions()
{
    last_command="stripe_test_helpers_issuing_transactions"

    command_aliases=()

    commands=()
    commands+=("create_force_capture")
    commands+=("create_unlinked_refund")
    commands+=("refund")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_issuing()
{
    last_command="stripe_test_helpers_issuing"

    command_aliases=()

    commands=()
    commands+=("authorizations")
    commands+=("cards")
    commands+=("personalization_designs")
    commands+=("transactions")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_refunds_expire()
{
    last_command="stripe_test_helpers_refunds_expire"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_refunds()
{
    last_command="stripe_test_helpers_refunds"

    command_aliases=()

    commands=()
    commands+=("expire")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_terminal_readers_present_payment_method()
{
    last_command="stripe_test_helpers_terminal_readers_present_payment_method"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount-tip=")
    two_word_flags+=("--amount-tip")
    local_nonpersistent_flags+=("--amount-tip")
    local_nonpersistent_flags+=("--amount-tip=")
    flags+=("--card-present.number=")
    two_word_flags+=("--card-present.number")
    local_nonpersistent_flags+=("--card-present.number")
    local_nonpersistent_flags+=("--card-present.number=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--interac-present.number=")
    two_word_flags+=("--interac-present.number")
    local_nonpersistent_flags+=("--interac-present.number")
    local_nonpersistent_flags+=("--interac-present.number=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--type=")
    two_word_flags+=("--type")
    local_nonpersistent_flags+=("--type")
    local_nonpersistent_flags+=("--type=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_terminal_readers()
{
    last_command="stripe_test_helpers_terminal_readers"

    command_aliases=()

    commands=()
    commands+=("present_payment_method")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_terminal()
{
    last_command="stripe_test_helpers_terminal"

    command_aliases=()

    commands=()
    commands+=("readers")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_test_clocks_advance()
{
    last_command="stripe_test_helpers_test_clocks_advance"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--frozen-time=")
    two_word_flags+=("--frozen-time")
    local_nonpersistent_flags+=("--frozen-time")
    local_nonpersistent_flags+=("--frozen-time=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_test_clocks_create()
{
    last_command="stripe_test_helpers_test_clocks_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--frozen-time=")
    two_word_flags+=("--frozen-time")
    local_nonpersistent_flags+=("--frozen-time")
    local_nonpersistent_flags+=("--frozen-time=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--name=")
    two_word_flags+=("--name")
    local_nonpersistent_flags+=("--name")
    local_nonpersistent_flags+=("--name=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_test_clocks_delete()
{
    last_command="stripe_test_helpers_test_clocks_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_test_clocks_list()
{
    last_command="stripe_test_helpers_test_clocks_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_test_clocks_retrieve()
{
    last_command="stripe_test_helpers_test_clocks_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_test_clocks()
{
    last_command="stripe_test_helpers_test_clocks"

    command_aliases=()

    commands=()
    commands+=("advance")
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_inbound_transfers_fail()
{
    last_command="stripe_test_helpers_treasury_inbound_transfers_fail"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--failure-details.code=")
    two_word_flags+=("--failure-details.code")
    local_nonpersistent_flags+=("--failure-details.code")
    local_nonpersistent_flags+=("--failure-details.code=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_inbound_transfers_return_inbound_transfer()
{
    last_command="stripe_test_helpers_treasury_inbound_transfers_return_inbound_transfer"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_inbound_transfers_succeed()
{
    last_command="stripe_test_helpers_treasury_inbound_transfers_succeed"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_inbound_transfers()
{
    last_command="stripe_test_helpers_treasury_inbound_transfers"

    command_aliases=()

    commands=()
    commands+=("fail")
    commands+=("return_inbound_transfer")
    commands+=("succeed")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_outbound_payments_fail()
{
    last_command="stripe_test_helpers_treasury_outbound_payments_fail"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_outbound_payments_post()
{
    last_command="stripe_test_helpers_treasury_outbound_payments_post"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_outbound_payments_return_outbound_payment()
{
    last_command="stripe_test_helpers_treasury_outbound_payments_return_outbound_payment"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--returned-details.code=")
    two_word_flags+=("--returned-details.code")
    local_nonpersistent_flags+=("--returned-details.code")
    local_nonpersistent_flags+=("--returned-details.code=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_outbound_payments_update()
{
    last_command="stripe_test_helpers_treasury_outbound_payments_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tracking-details.ach.trace-id=")
    two_word_flags+=("--tracking-details.ach.trace-id")
    local_nonpersistent_flags+=("--tracking-details.ach.trace-id")
    local_nonpersistent_flags+=("--tracking-details.ach.trace-id=")
    flags+=("--tracking-details.type=")
    two_word_flags+=("--tracking-details.type")
    local_nonpersistent_flags+=("--tracking-details.type")
    local_nonpersistent_flags+=("--tracking-details.type=")
    flags+=("--tracking-details.us-domestic-wire.chips=")
    two_word_flags+=("--tracking-details.us-domestic-wire.chips")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.chips")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.chips=")
    flags+=("--tracking-details.us-domestic-wire.imad=")
    two_word_flags+=("--tracking-details.us-domestic-wire.imad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.imad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.imad=")
    flags+=("--tracking-details.us-domestic-wire.omad=")
    two_word_flags+=("--tracking-details.us-domestic-wire.omad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.omad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.omad=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_outbound_payments()
{
    last_command="stripe_test_helpers_treasury_outbound_payments"

    command_aliases=()

    commands=()
    commands+=("fail")
    commands+=("post")
    commands+=("return_outbound_payment")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_outbound_transfers_fail()
{
    last_command="stripe_test_helpers_treasury_outbound_transfers_fail"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_outbound_transfers_post()
{
    last_command="stripe_test_helpers_treasury_outbound_transfers_post"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_outbound_transfers_return_outbound_transfer()
{
    last_command="stripe_test_helpers_treasury_outbound_transfers_return_outbound_transfer"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--returned-details.code=")
    two_word_flags+=("--returned-details.code")
    local_nonpersistent_flags+=("--returned-details.code")
    local_nonpersistent_flags+=("--returned-details.code=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_outbound_transfers_update()
{
    last_command="stripe_test_helpers_treasury_outbound_transfers_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tracking-details.ach.trace-id=")
    two_word_flags+=("--tracking-details.ach.trace-id")
    local_nonpersistent_flags+=("--tracking-details.ach.trace-id")
    local_nonpersistent_flags+=("--tracking-details.ach.trace-id=")
    flags+=("--tracking-details.type=")
    two_word_flags+=("--tracking-details.type")
    local_nonpersistent_flags+=("--tracking-details.type")
    local_nonpersistent_flags+=("--tracking-details.type=")
    flags+=("--tracking-details.us-domestic-wire.chips=")
    two_word_flags+=("--tracking-details.us-domestic-wire.chips")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.chips")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.chips=")
    flags+=("--tracking-details.us-domestic-wire.imad=")
    two_word_flags+=("--tracking-details.us-domestic-wire.imad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.imad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.imad=")
    flags+=("--tracking-details.us-domestic-wire.omad=")
    two_word_flags+=("--tracking-details.us-domestic-wire.omad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.omad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.omad=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_outbound_transfers()
{
    last_command="stripe_test_helpers_treasury_outbound_transfers"

    command_aliases=()

    commands=()
    commands+=("fail")
    commands+=("post")
    commands+=("return_outbound_transfer")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_received_credits_create()
{
    last_command="stripe_test_helpers_treasury_received_credits_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--initiating-payment-method-details.type=")
    two_word_flags+=("--initiating-payment-method-details.type")
    local_nonpersistent_flags+=("--initiating-payment-method-details.type")
    local_nonpersistent_flags+=("--initiating-payment-method-details.type=")
    flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name=")
    two_word_flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name=")
    flags+=("--initiating-payment-method-details.us-bank-account.account-number=")
    two_word_flags+=("--initiating-payment-method-details.us-bank-account.account-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-number=")
    flags+=("--initiating-payment-method-details.us-bank-account.routing-number=")
    two_word_flags+=("--initiating-payment-method-details.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.routing-number=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--network=")
    two_word_flags+=("--network")
    local_nonpersistent_flags+=("--network")
    local_nonpersistent_flags+=("--network=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_received_credits()
{
    last_command="stripe_test_helpers_treasury_received_credits"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_received_debits_create()
{
    last_command="stripe_test_helpers_treasury_received_debits_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--initiating-payment-method-details.type=")
    two_word_flags+=("--initiating-payment-method-details.type")
    local_nonpersistent_flags+=("--initiating-payment-method-details.type")
    local_nonpersistent_flags+=("--initiating-payment-method-details.type=")
    flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name=")
    two_word_flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name=")
    flags+=("--initiating-payment-method-details.us-bank-account.account-number=")
    two_word_flags+=("--initiating-payment-method-details.us-bank-account.account-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-number=")
    flags+=("--initiating-payment-method-details.us-bank-account.routing-number=")
    two_word_flags+=("--initiating-payment-method-details.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.routing-number=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--network=")
    two_word_flags+=("--network")
    local_nonpersistent_flags+=("--network")
    local_nonpersistent_flags+=("--network=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury_received_debits()
{
    last_command="stripe_test_helpers_treasury_received_debits"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers_treasury()
{
    last_command="stripe_test_helpers_treasury"

    command_aliases=()

    commands=()
    commands+=("inbound_transfers")
    commands+=("outbound_payments")
    commands+=("outbound_transfers")
    commands+=("received_credits")
    commands+=("received_debits")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_test_helpers()
{
    last_command="stripe_test_helpers"

    command_aliases=()

    commands=()
    commands+=("confirmation_tokens")
    commands+=("customers")
    commands+=("issuing")
    commands+=("refunds")
    commands+=("terminal")
    commands+=("test_clocks")
    commands+=("treasury")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tokens_create()
{
    last_command="stripe_tokens_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--account.business-type=")
    two_word_flags+=("--account.business-type")
    local_nonpersistent_flags+=("--account.business-type")
    local_nonpersistent_flags+=("--account.business-type=")
    flags+=("--account.company.address-kana.city=")
    two_word_flags+=("--account.company.address-kana.city")
    local_nonpersistent_flags+=("--account.company.address-kana.city")
    local_nonpersistent_flags+=("--account.company.address-kana.city=")
    flags+=("--account.company.address-kana.country=")
    two_word_flags+=("--account.company.address-kana.country")
    local_nonpersistent_flags+=("--account.company.address-kana.country")
    local_nonpersistent_flags+=("--account.company.address-kana.country=")
    flags+=("--account.company.address-kana.line1=")
    two_word_flags+=("--account.company.address-kana.line1")
    local_nonpersistent_flags+=("--account.company.address-kana.line1")
    local_nonpersistent_flags+=("--account.company.address-kana.line1=")
    flags+=("--account.company.address-kana.line2=")
    two_word_flags+=("--account.company.address-kana.line2")
    local_nonpersistent_flags+=("--account.company.address-kana.line2")
    local_nonpersistent_flags+=("--account.company.address-kana.line2=")
    flags+=("--account.company.address-kana.postal-code=")
    two_word_flags+=("--account.company.address-kana.postal-code")
    local_nonpersistent_flags+=("--account.company.address-kana.postal-code")
    local_nonpersistent_flags+=("--account.company.address-kana.postal-code=")
    flags+=("--account.company.address-kana.state=")
    two_word_flags+=("--account.company.address-kana.state")
    local_nonpersistent_flags+=("--account.company.address-kana.state")
    local_nonpersistent_flags+=("--account.company.address-kana.state=")
    flags+=("--account.company.address-kana.town=")
    two_word_flags+=("--account.company.address-kana.town")
    local_nonpersistent_flags+=("--account.company.address-kana.town")
    local_nonpersistent_flags+=("--account.company.address-kana.town=")
    flags+=("--account.company.address-kanji.city=")
    two_word_flags+=("--account.company.address-kanji.city")
    local_nonpersistent_flags+=("--account.company.address-kanji.city")
    local_nonpersistent_flags+=("--account.company.address-kanji.city=")
    flags+=("--account.company.address-kanji.country=")
    two_word_flags+=("--account.company.address-kanji.country")
    local_nonpersistent_flags+=("--account.company.address-kanji.country")
    local_nonpersistent_flags+=("--account.company.address-kanji.country=")
    flags+=("--account.company.address-kanji.line1=")
    two_word_flags+=("--account.company.address-kanji.line1")
    local_nonpersistent_flags+=("--account.company.address-kanji.line1")
    local_nonpersistent_flags+=("--account.company.address-kanji.line1=")
    flags+=("--account.company.address-kanji.line2=")
    two_word_flags+=("--account.company.address-kanji.line2")
    local_nonpersistent_flags+=("--account.company.address-kanji.line2")
    local_nonpersistent_flags+=("--account.company.address-kanji.line2=")
    flags+=("--account.company.address-kanji.postal-code=")
    two_word_flags+=("--account.company.address-kanji.postal-code")
    local_nonpersistent_flags+=("--account.company.address-kanji.postal-code")
    local_nonpersistent_flags+=("--account.company.address-kanji.postal-code=")
    flags+=("--account.company.address-kanji.state=")
    two_word_flags+=("--account.company.address-kanji.state")
    local_nonpersistent_flags+=("--account.company.address-kanji.state")
    local_nonpersistent_flags+=("--account.company.address-kanji.state=")
    flags+=("--account.company.address-kanji.town=")
    two_word_flags+=("--account.company.address-kanji.town")
    local_nonpersistent_flags+=("--account.company.address-kanji.town")
    local_nonpersistent_flags+=("--account.company.address-kanji.town=")
    flags+=("--account.company.address.city=")
    two_word_flags+=("--account.company.address.city")
    local_nonpersistent_flags+=("--account.company.address.city")
    local_nonpersistent_flags+=("--account.company.address.city=")
    flags+=("--account.company.address.country=")
    two_word_flags+=("--account.company.address.country")
    local_nonpersistent_flags+=("--account.company.address.country")
    local_nonpersistent_flags+=("--account.company.address.country=")
    flags+=("--account.company.address.line1=")
    two_word_flags+=("--account.company.address.line1")
    local_nonpersistent_flags+=("--account.company.address.line1")
    local_nonpersistent_flags+=("--account.company.address.line1=")
    flags+=("--account.company.address.line2=")
    two_word_flags+=("--account.company.address.line2")
    local_nonpersistent_flags+=("--account.company.address.line2")
    local_nonpersistent_flags+=("--account.company.address.line2=")
    flags+=("--account.company.address.postal-code=")
    two_word_flags+=("--account.company.address.postal-code")
    local_nonpersistent_flags+=("--account.company.address.postal-code")
    local_nonpersistent_flags+=("--account.company.address.postal-code=")
    flags+=("--account.company.address.state=")
    two_word_flags+=("--account.company.address.state")
    local_nonpersistent_flags+=("--account.company.address.state")
    local_nonpersistent_flags+=("--account.company.address.state=")
    flags+=("--account.company.directors-provided=")
    two_word_flags+=("--account.company.directors-provided")
    local_nonpersistent_flags+=("--account.company.directors-provided")
    local_nonpersistent_flags+=("--account.company.directors-provided=")
    flags+=("--account.company.executives-provided=")
    two_word_flags+=("--account.company.executives-provided")
    local_nonpersistent_flags+=("--account.company.executives-provided")
    local_nonpersistent_flags+=("--account.company.executives-provided=")
    flags+=("--account.company.export-license-id=")
    two_word_flags+=("--account.company.export-license-id")
    local_nonpersistent_flags+=("--account.company.export-license-id")
    local_nonpersistent_flags+=("--account.company.export-license-id=")
    flags+=("--account.company.export-purpose-code=")
    two_word_flags+=("--account.company.export-purpose-code")
    local_nonpersistent_flags+=("--account.company.export-purpose-code")
    local_nonpersistent_flags+=("--account.company.export-purpose-code=")
    flags+=("--account.company.name=")
    two_word_flags+=("--account.company.name")
    local_nonpersistent_flags+=("--account.company.name")
    local_nonpersistent_flags+=("--account.company.name=")
    flags+=("--account.company.name-kana=")
    two_word_flags+=("--account.company.name-kana")
    local_nonpersistent_flags+=("--account.company.name-kana")
    local_nonpersistent_flags+=("--account.company.name-kana=")
    flags+=("--account.company.name-kanji=")
    two_word_flags+=("--account.company.name-kanji")
    local_nonpersistent_flags+=("--account.company.name-kanji")
    local_nonpersistent_flags+=("--account.company.name-kanji=")
    flags+=("--account.company.owners-provided=")
    two_word_flags+=("--account.company.owners-provided")
    local_nonpersistent_flags+=("--account.company.owners-provided")
    local_nonpersistent_flags+=("--account.company.owners-provided=")
    flags+=("--account.company.ownership-declaration-shown-and-signed=")
    two_word_flags+=("--account.company.ownership-declaration-shown-and-signed")
    local_nonpersistent_flags+=("--account.company.ownership-declaration-shown-and-signed")
    local_nonpersistent_flags+=("--account.company.ownership-declaration-shown-and-signed=")
    flags+=("--account.company.ownership-declaration.date=")
    two_word_flags+=("--account.company.ownership-declaration.date")
    local_nonpersistent_flags+=("--account.company.ownership-declaration.date")
    local_nonpersistent_flags+=("--account.company.ownership-declaration.date=")
    flags+=("--account.company.ownership-declaration.ip=")
    two_word_flags+=("--account.company.ownership-declaration.ip")
    local_nonpersistent_flags+=("--account.company.ownership-declaration.ip")
    local_nonpersistent_flags+=("--account.company.ownership-declaration.ip=")
    flags+=("--account.company.ownership-declaration.user-agent=")
    two_word_flags+=("--account.company.ownership-declaration.user-agent")
    local_nonpersistent_flags+=("--account.company.ownership-declaration.user-agent")
    local_nonpersistent_flags+=("--account.company.ownership-declaration.user-agent=")
    flags+=("--account.company.phone=")
    two_word_flags+=("--account.company.phone")
    local_nonpersistent_flags+=("--account.company.phone")
    local_nonpersistent_flags+=("--account.company.phone=")
    flags+=("--account.company.registration-number=")
    two_word_flags+=("--account.company.registration-number")
    local_nonpersistent_flags+=("--account.company.registration-number")
    local_nonpersistent_flags+=("--account.company.registration-number=")
    flags+=("--account.company.structure=")
    two_word_flags+=("--account.company.structure")
    local_nonpersistent_flags+=("--account.company.structure")
    local_nonpersistent_flags+=("--account.company.structure=")
    flags+=("--account.company.tax-id=")
    two_word_flags+=("--account.company.tax-id")
    local_nonpersistent_flags+=("--account.company.tax-id")
    local_nonpersistent_flags+=("--account.company.tax-id=")
    flags+=("--account.company.tax-id-registrar=")
    two_word_flags+=("--account.company.tax-id-registrar")
    local_nonpersistent_flags+=("--account.company.tax-id-registrar")
    local_nonpersistent_flags+=("--account.company.tax-id-registrar=")
    flags+=("--account.company.vat-id=")
    two_word_flags+=("--account.company.vat-id")
    local_nonpersistent_flags+=("--account.company.vat-id")
    local_nonpersistent_flags+=("--account.company.vat-id=")
    flags+=("--account.company.verification.document.back=")
    two_word_flags+=("--account.company.verification.document.back")
    local_nonpersistent_flags+=("--account.company.verification.document.back")
    local_nonpersistent_flags+=("--account.company.verification.document.back=")
    flags+=("--account.company.verification.document.front=")
    two_word_flags+=("--account.company.verification.document.front")
    local_nonpersistent_flags+=("--account.company.verification.document.front")
    local_nonpersistent_flags+=("--account.company.verification.document.front=")
    flags+=("--account.individual.address-kana.city=")
    two_word_flags+=("--account.individual.address-kana.city")
    local_nonpersistent_flags+=("--account.individual.address-kana.city")
    local_nonpersistent_flags+=("--account.individual.address-kana.city=")
    flags+=("--account.individual.address-kana.country=")
    two_word_flags+=("--account.individual.address-kana.country")
    local_nonpersistent_flags+=("--account.individual.address-kana.country")
    local_nonpersistent_flags+=("--account.individual.address-kana.country=")
    flags+=("--account.individual.address-kana.line1=")
    two_word_flags+=("--account.individual.address-kana.line1")
    local_nonpersistent_flags+=("--account.individual.address-kana.line1")
    local_nonpersistent_flags+=("--account.individual.address-kana.line1=")
    flags+=("--account.individual.address-kana.line2=")
    two_word_flags+=("--account.individual.address-kana.line2")
    local_nonpersistent_flags+=("--account.individual.address-kana.line2")
    local_nonpersistent_flags+=("--account.individual.address-kana.line2=")
    flags+=("--account.individual.address-kana.postal-code=")
    two_word_flags+=("--account.individual.address-kana.postal-code")
    local_nonpersistent_flags+=("--account.individual.address-kana.postal-code")
    local_nonpersistent_flags+=("--account.individual.address-kana.postal-code=")
    flags+=("--account.individual.address-kana.state=")
    two_word_flags+=("--account.individual.address-kana.state")
    local_nonpersistent_flags+=("--account.individual.address-kana.state")
    local_nonpersistent_flags+=("--account.individual.address-kana.state=")
    flags+=("--account.individual.address-kana.town=")
    two_word_flags+=("--account.individual.address-kana.town")
    local_nonpersistent_flags+=("--account.individual.address-kana.town")
    local_nonpersistent_flags+=("--account.individual.address-kana.town=")
    flags+=("--account.individual.address-kanji.city=")
    two_word_flags+=("--account.individual.address-kanji.city")
    local_nonpersistent_flags+=("--account.individual.address-kanji.city")
    local_nonpersistent_flags+=("--account.individual.address-kanji.city=")
    flags+=("--account.individual.address-kanji.country=")
    two_word_flags+=("--account.individual.address-kanji.country")
    local_nonpersistent_flags+=("--account.individual.address-kanji.country")
    local_nonpersistent_flags+=("--account.individual.address-kanji.country=")
    flags+=("--account.individual.address-kanji.line1=")
    two_word_flags+=("--account.individual.address-kanji.line1")
    local_nonpersistent_flags+=("--account.individual.address-kanji.line1")
    local_nonpersistent_flags+=("--account.individual.address-kanji.line1=")
    flags+=("--account.individual.address-kanji.line2=")
    two_word_flags+=("--account.individual.address-kanji.line2")
    local_nonpersistent_flags+=("--account.individual.address-kanji.line2")
    local_nonpersistent_flags+=("--account.individual.address-kanji.line2=")
    flags+=("--account.individual.address-kanji.postal-code=")
    two_word_flags+=("--account.individual.address-kanji.postal-code")
    local_nonpersistent_flags+=("--account.individual.address-kanji.postal-code")
    local_nonpersistent_flags+=("--account.individual.address-kanji.postal-code=")
    flags+=("--account.individual.address-kanji.state=")
    two_word_flags+=("--account.individual.address-kanji.state")
    local_nonpersistent_flags+=("--account.individual.address-kanji.state")
    local_nonpersistent_flags+=("--account.individual.address-kanji.state=")
    flags+=("--account.individual.address-kanji.town=")
    two_word_flags+=("--account.individual.address-kanji.town")
    local_nonpersistent_flags+=("--account.individual.address-kanji.town")
    local_nonpersistent_flags+=("--account.individual.address-kanji.town=")
    flags+=("--account.individual.address.city=")
    two_word_flags+=("--account.individual.address.city")
    local_nonpersistent_flags+=("--account.individual.address.city")
    local_nonpersistent_flags+=("--account.individual.address.city=")
    flags+=("--account.individual.address.country=")
    two_word_flags+=("--account.individual.address.country")
    local_nonpersistent_flags+=("--account.individual.address.country")
    local_nonpersistent_flags+=("--account.individual.address.country=")
    flags+=("--account.individual.address.line1=")
    two_word_flags+=("--account.individual.address.line1")
    local_nonpersistent_flags+=("--account.individual.address.line1")
    local_nonpersistent_flags+=("--account.individual.address.line1=")
    flags+=("--account.individual.address.line2=")
    two_word_flags+=("--account.individual.address.line2")
    local_nonpersistent_flags+=("--account.individual.address.line2")
    local_nonpersistent_flags+=("--account.individual.address.line2=")
    flags+=("--account.individual.address.postal-code=")
    two_word_flags+=("--account.individual.address.postal-code")
    local_nonpersistent_flags+=("--account.individual.address.postal-code")
    local_nonpersistent_flags+=("--account.individual.address.postal-code=")
    flags+=("--account.individual.address.state=")
    two_word_flags+=("--account.individual.address.state")
    local_nonpersistent_flags+=("--account.individual.address.state")
    local_nonpersistent_flags+=("--account.individual.address.state=")
    flags+=("--account.individual.email=")
    two_word_flags+=("--account.individual.email")
    local_nonpersistent_flags+=("--account.individual.email")
    local_nonpersistent_flags+=("--account.individual.email=")
    flags+=("--account.individual.first-name=")
    two_word_flags+=("--account.individual.first-name")
    local_nonpersistent_flags+=("--account.individual.first-name")
    local_nonpersistent_flags+=("--account.individual.first-name=")
    flags+=("--account.individual.first-name-kana=")
    two_word_flags+=("--account.individual.first-name-kana")
    local_nonpersistent_flags+=("--account.individual.first-name-kana")
    local_nonpersistent_flags+=("--account.individual.first-name-kana=")
    flags+=("--account.individual.first-name-kanji=")
    two_word_flags+=("--account.individual.first-name-kanji")
    local_nonpersistent_flags+=("--account.individual.first-name-kanji")
    local_nonpersistent_flags+=("--account.individual.first-name-kanji=")
    flags+=("--account.individual.full-name-aliases=")
    two_word_flags+=("--account.individual.full-name-aliases")
    local_nonpersistent_flags+=("--account.individual.full-name-aliases")
    local_nonpersistent_flags+=("--account.individual.full-name-aliases=")
    flags+=("--account.individual.gender=")
    two_word_flags+=("--account.individual.gender")
    local_nonpersistent_flags+=("--account.individual.gender")
    local_nonpersistent_flags+=("--account.individual.gender=")
    flags+=("--account.individual.id-number=")
    two_word_flags+=("--account.individual.id-number")
    local_nonpersistent_flags+=("--account.individual.id-number")
    local_nonpersistent_flags+=("--account.individual.id-number=")
    flags+=("--account.individual.id-number-secondary=")
    two_word_flags+=("--account.individual.id-number-secondary")
    local_nonpersistent_flags+=("--account.individual.id-number-secondary")
    local_nonpersistent_flags+=("--account.individual.id-number-secondary=")
    flags+=("--account.individual.last-name=")
    two_word_flags+=("--account.individual.last-name")
    local_nonpersistent_flags+=("--account.individual.last-name")
    local_nonpersistent_flags+=("--account.individual.last-name=")
    flags+=("--account.individual.last-name-kana=")
    two_word_flags+=("--account.individual.last-name-kana")
    local_nonpersistent_flags+=("--account.individual.last-name-kana")
    local_nonpersistent_flags+=("--account.individual.last-name-kana=")
    flags+=("--account.individual.last-name-kanji=")
    two_word_flags+=("--account.individual.last-name-kanji")
    local_nonpersistent_flags+=("--account.individual.last-name-kanji")
    local_nonpersistent_flags+=("--account.individual.last-name-kanji=")
    flags+=("--account.individual.maiden-name=")
    two_word_flags+=("--account.individual.maiden-name")
    local_nonpersistent_flags+=("--account.individual.maiden-name")
    local_nonpersistent_flags+=("--account.individual.maiden-name=")
    flags+=("--account.individual.phone=")
    two_word_flags+=("--account.individual.phone")
    local_nonpersistent_flags+=("--account.individual.phone")
    local_nonpersistent_flags+=("--account.individual.phone=")
    flags+=("--account.individual.political-exposure=")
    two_word_flags+=("--account.individual.political-exposure")
    local_nonpersistent_flags+=("--account.individual.political-exposure")
    local_nonpersistent_flags+=("--account.individual.political-exposure=")
    flags+=("--account.individual.registered-address.city=")
    two_word_flags+=("--account.individual.registered-address.city")
    local_nonpersistent_flags+=("--account.individual.registered-address.city")
    local_nonpersistent_flags+=("--account.individual.registered-address.city=")
    flags+=("--account.individual.registered-address.country=")
    two_word_flags+=("--account.individual.registered-address.country")
    local_nonpersistent_flags+=("--account.individual.registered-address.country")
    local_nonpersistent_flags+=("--account.individual.registered-address.country=")
    flags+=("--account.individual.registered-address.line1=")
    two_word_flags+=("--account.individual.registered-address.line1")
    local_nonpersistent_flags+=("--account.individual.registered-address.line1")
    local_nonpersistent_flags+=("--account.individual.registered-address.line1=")
    flags+=("--account.individual.registered-address.line2=")
    two_word_flags+=("--account.individual.registered-address.line2")
    local_nonpersistent_flags+=("--account.individual.registered-address.line2")
    local_nonpersistent_flags+=("--account.individual.registered-address.line2=")
    flags+=("--account.individual.registered-address.postal-code=")
    two_word_flags+=("--account.individual.registered-address.postal-code")
    local_nonpersistent_flags+=("--account.individual.registered-address.postal-code")
    local_nonpersistent_flags+=("--account.individual.registered-address.postal-code=")
    flags+=("--account.individual.registered-address.state=")
    two_word_flags+=("--account.individual.registered-address.state")
    local_nonpersistent_flags+=("--account.individual.registered-address.state")
    local_nonpersistent_flags+=("--account.individual.registered-address.state=")
    flags+=("--account.individual.relationship.director=")
    two_word_flags+=("--account.individual.relationship.director")
    local_nonpersistent_flags+=("--account.individual.relationship.director")
    local_nonpersistent_flags+=("--account.individual.relationship.director=")
    flags+=("--account.individual.relationship.executive=")
    two_word_flags+=("--account.individual.relationship.executive")
    local_nonpersistent_flags+=("--account.individual.relationship.executive")
    local_nonpersistent_flags+=("--account.individual.relationship.executive=")
    flags+=("--account.individual.relationship.owner=")
    two_word_flags+=("--account.individual.relationship.owner")
    local_nonpersistent_flags+=("--account.individual.relationship.owner")
    local_nonpersistent_flags+=("--account.individual.relationship.owner=")
    flags+=("--account.individual.relationship.percent-ownership=")
    two_word_flags+=("--account.individual.relationship.percent-ownership")
    local_nonpersistent_flags+=("--account.individual.relationship.percent-ownership")
    local_nonpersistent_flags+=("--account.individual.relationship.percent-ownership=")
    flags+=("--account.individual.relationship.title=")
    two_word_flags+=("--account.individual.relationship.title")
    local_nonpersistent_flags+=("--account.individual.relationship.title")
    local_nonpersistent_flags+=("--account.individual.relationship.title=")
    flags+=("--account.individual.ssn-last-4=")
    two_word_flags+=("--account.individual.ssn-last-4")
    local_nonpersistent_flags+=("--account.individual.ssn-last-4")
    local_nonpersistent_flags+=("--account.individual.ssn-last-4=")
    flags+=("--account.individual.verification.additional-document.back=")
    two_word_flags+=("--account.individual.verification.additional-document.back")
    local_nonpersistent_flags+=("--account.individual.verification.additional-document.back")
    local_nonpersistent_flags+=("--account.individual.verification.additional-document.back=")
    flags+=("--account.individual.verification.additional-document.front=")
    two_word_flags+=("--account.individual.verification.additional-document.front")
    local_nonpersistent_flags+=("--account.individual.verification.additional-document.front")
    local_nonpersistent_flags+=("--account.individual.verification.additional-document.front=")
    flags+=("--account.individual.verification.document.back=")
    two_word_flags+=("--account.individual.verification.document.back")
    local_nonpersistent_flags+=("--account.individual.verification.document.back")
    local_nonpersistent_flags+=("--account.individual.verification.document.back=")
    flags+=("--account.individual.verification.document.front=")
    two_word_flags+=("--account.individual.verification.document.front")
    local_nonpersistent_flags+=("--account.individual.verification.document.front")
    local_nonpersistent_flags+=("--account.individual.verification.document.front=")
    flags+=("--account.tos-shown-and-accepted=")
    two_word_flags+=("--account.tos-shown-and-accepted")
    local_nonpersistent_flags+=("--account.tos-shown-and-accepted")
    local_nonpersistent_flags+=("--account.tos-shown-and-accepted=")
    flags+=("--bank-account.account-holder-name=")
    two_word_flags+=("--bank-account.account-holder-name")
    local_nonpersistent_flags+=("--bank-account.account-holder-name")
    local_nonpersistent_flags+=("--bank-account.account-holder-name=")
    flags+=("--bank-account.account-holder-type=")
    two_word_flags+=("--bank-account.account-holder-type")
    local_nonpersistent_flags+=("--bank-account.account-holder-type")
    local_nonpersistent_flags+=("--bank-account.account-holder-type=")
    flags+=("--bank-account.account-number=")
    two_word_flags+=("--bank-account.account-number")
    local_nonpersistent_flags+=("--bank-account.account-number")
    local_nonpersistent_flags+=("--bank-account.account-number=")
    flags+=("--bank-account.account-type=")
    two_word_flags+=("--bank-account.account-type")
    local_nonpersistent_flags+=("--bank-account.account-type")
    local_nonpersistent_flags+=("--bank-account.account-type=")
    flags+=("--bank-account.country=")
    two_word_flags+=("--bank-account.country")
    local_nonpersistent_flags+=("--bank-account.country")
    local_nonpersistent_flags+=("--bank-account.country=")
    flags+=("--bank-account.currency=")
    two_word_flags+=("--bank-account.currency")
    local_nonpersistent_flags+=("--bank-account.currency")
    local_nonpersistent_flags+=("--bank-account.currency=")
    flags+=("--bank-account.payment-method=")
    two_word_flags+=("--bank-account.payment-method")
    local_nonpersistent_flags+=("--bank-account.payment-method")
    local_nonpersistent_flags+=("--bank-account.payment-method=")
    flags+=("--bank-account.routing-number=")
    two_word_flags+=("--bank-account.routing-number")
    local_nonpersistent_flags+=("--bank-account.routing-number")
    local_nonpersistent_flags+=("--bank-account.routing-number=")
    flags+=("--card=")
    two_word_flags+=("--card")
    local_nonpersistent_flags+=("--card")
    local_nonpersistent_flags+=("--card=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--cvc-update.cvc=")
    two_word_flags+=("--cvc-update.cvc")
    local_nonpersistent_flags+=("--cvc-update.cvc")
    local_nonpersistent_flags+=("--cvc-update.cvc=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--person.additional-tos-acceptances.account.date=")
    two_word_flags+=("--person.additional-tos-acceptances.account.date")
    local_nonpersistent_flags+=("--person.additional-tos-acceptances.account.date")
    local_nonpersistent_flags+=("--person.additional-tos-acceptances.account.date=")
    flags+=("--person.additional-tos-acceptances.account.ip=")
    two_word_flags+=("--person.additional-tos-acceptances.account.ip")
    local_nonpersistent_flags+=("--person.additional-tos-acceptances.account.ip")
    local_nonpersistent_flags+=("--person.additional-tos-acceptances.account.ip=")
    flags+=("--person.additional-tos-acceptances.account.user-agent=")
    two_word_flags+=("--person.additional-tos-acceptances.account.user-agent")
    local_nonpersistent_flags+=("--person.additional-tos-acceptances.account.user-agent")
    local_nonpersistent_flags+=("--person.additional-tos-acceptances.account.user-agent=")
    flags+=("--person.address-kana.city=")
    two_word_flags+=("--person.address-kana.city")
    local_nonpersistent_flags+=("--person.address-kana.city")
    local_nonpersistent_flags+=("--person.address-kana.city=")
    flags+=("--person.address-kana.country=")
    two_word_flags+=("--person.address-kana.country")
    local_nonpersistent_flags+=("--person.address-kana.country")
    local_nonpersistent_flags+=("--person.address-kana.country=")
    flags+=("--person.address-kana.line1=")
    two_word_flags+=("--person.address-kana.line1")
    local_nonpersistent_flags+=("--person.address-kana.line1")
    local_nonpersistent_flags+=("--person.address-kana.line1=")
    flags+=("--person.address-kana.line2=")
    two_word_flags+=("--person.address-kana.line2")
    local_nonpersistent_flags+=("--person.address-kana.line2")
    local_nonpersistent_flags+=("--person.address-kana.line2=")
    flags+=("--person.address-kana.postal-code=")
    two_word_flags+=("--person.address-kana.postal-code")
    local_nonpersistent_flags+=("--person.address-kana.postal-code")
    local_nonpersistent_flags+=("--person.address-kana.postal-code=")
    flags+=("--person.address-kana.state=")
    two_word_flags+=("--person.address-kana.state")
    local_nonpersistent_flags+=("--person.address-kana.state")
    local_nonpersistent_flags+=("--person.address-kana.state=")
    flags+=("--person.address-kana.town=")
    two_word_flags+=("--person.address-kana.town")
    local_nonpersistent_flags+=("--person.address-kana.town")
    local_nonpersistent_flags+=("--person.address-kana.town=")
    flags+=("--person.address-kanji.city=")
    two_word_flags+=("--person.address-kanji.city")
    local_nonpersistent_flags+=("--person.address-kanji.city")
    local_nonpersistent_flags+=("--person.address-kanji.city=")
    flags+=("--person.address-kanji.country=")
    two_word_flags+=("--person.address-kanji.country")
    local_nonpersistent_flags+=("--person.address-kanji.country")
    local_nonpersistent_flags+=("--person.address-kanji.country=")
    flags+=("--person.address-kanji.line1=")
    two_word_flags+=("--person.address-kanji.line1")
    local_nonpersistent_flags+=("--person.address-kanji.line1")
    local_nonpersistent_flags+=("--person.address-kanji.line1=")
    flags+=("--person.address-kanji.line2=")
    two_word_flags+=("--person.address-kanji.line2")
    local_nonpersistent_flags+=("--person.address-kanji.line2")
    local_nonpersistent_flags+=("--person.address-kanji.line2=")
    flags+=("--person.address-kanji.postal-code=")
    two_word_flags+=("--person.address-kanji.postal-code")
    local_nonpersistent_flags+=("--person.address-kanji.postal-code")
    local_nonpersistent_flags+=("--person.address-kanji.postal-code=")
    flags+=("--person.address-kanji.state=")
    two_word_flags+=("--person.address-kanji.state")
    local_nonpersistent_flags+=("--person.address-kanji.state")
    local_nonpersistent_flags+=("--person.address-kanji.state=")
    flags+=("--person.address-kanji.town=")
    two_word_flags+=("--person.address-kanji.town")
    local_nonpersistent_flags+=("--person.address-kanji.town")
    local_nonpersistent_flags+=("--person.address-kanji.town=")
    flags+=("--person.address.city=")
    two_word_flags+=("--person.address.city")
    local_nonpersistent_flags+=("--person.address.city")
    local_nonpersistent_flags+=("--person.address.city=")
    flags+=("--person.address.country=")
    two_word_flags+=("--person.address.country")
    local_nonpersistent_flags+=("--person.address.country")
    local_nonpersistent_flags+=("--person.address.country=")
    flags+=("--person.address.line1=")
    two_word_flags+=("--person.address.line1")
    local_nonpersistent_flags+=("--person.address.line1")
    local_nonpersistent_flags+=("--person.address.line1=")
    flags+=("--person.address.line2=")
    two_word_flags+=("--person.address.line2")
    local_nonpersistent_flags+=("--person.address.line2")
    local_nonpersistent_flags+=("--person.address.line2=")
    flags+=("--person.address.postal-code=")
    two_word_flags+=("--person.address.postal-code")
    local_nonpersistent_flags+=("--person.address.postal-code")
    local_nonpersistent_flags+=("--person.address.postal-code=")
    flags+=("--person.address.state=")
    two_word_flags+=("--person.address.state")
    local_nonpersistent_flags+=("--person.address.state")
    local_nonpersistent_flags+=("--person.address.state=")
    flags+=("--person.documents.company-authorization.files=")
    two_word_flags+=("--person.documents.company-authorization.files")
    local_nonpersistent_flags+=("--person.documents.company-authorization.files")
    local_nonpersistent_flags+=("--person.documents.company-authorization.files=")
    flags+=("--person.documents.passport.files=")
    two_word_flags+=("--person.documents.passport.files")
    local_nonpersistent_flags+=("--person.documents.passport.files")
    local_nonpersistent_flags+=("--person.documents.passport.files=")
    flags+=("--person.documents.visa.files=")
    two_word_flags+=("--person.documents.visa.files")
    local_nonpersistent_flags+=("--person.documents.visa.files")
    local_nonpersistent_flags+=("--person.documents.visa.files=")
    flags+=("--person.email=")
    two_word_flags+=("--person.email")
    local_nonpersistent_flags+=("--person.email")
    local_nonpersistent_flags+=("--person.email=")
    flags+=("--person.first-name=")
    two_word_flags+=("--person.first-name")
    local_nonpersistent_flags+=("--person.first-name")
    local_nonpersistent_flags+=("--person.first-name=")
    flags+=("--person.first-name-kana=")
    two_word_flags+=("--person.first-name-kana")
    local_nonpersistent_flags+=("--person.first-name-kana")
    local_nonpersistent_flags+=("--person.first-name-kana=")
    flags+=("--person.first-name-kanji=")
    two_word_flags+=("--person.first-name-kanji")
    local_nonpersistent_flags+=("--person.first-name-kanji")
    local_nonpersistent_flags+=("--person.first-name-kanji=")
    flags+=("--person.full-name-aliases=")
    two_word_flags+=("--person.full-name-aliases")
    local_nonpersistent_flags+=("--person.full-name-aliases")
    local_nonpersistent_flags+=("--person.full-name-aliases=")
    flags+=("--person.gender=")
    two_word_flags+=("--person.gender")
    local_nonpersistent_flags+=("--person.gender")
    local_nonpersistent_flags+=("--person.gender=")
    flags+=("--person.id-number=")
    two_word_flags+=("--person.id-number")
    local_nonpersistent_flags+=("--person.id-number")
    local_nonpersistent_flags+=("--person.id-number=")
    flags+=("--person.id-number-secondary=")
    two_word_flags+=("--person.id-number-secondary")
    local_nonpersistent_flags+=("--person.id-number-secondary")
    local_nonpersistent_flags+=("--person.id-number-secondary=")
    flags+=("--person.last-name=")
    two_word_flags+=("--person.last-name")
    local_nonpersistent_flags+=("--person.last-name")
    local_nonpersistent_flags+=("--person.last-name=")
    flags+=("--person.last-name-kana=")
    two_word_flags+=("--person.last-name-kana")
    local_nonpersistent_flags+=("--person.last-name-kana")
    local_nonpersistent_flags+=("--person.last-name-kana=")
    flags+=("--person.last-name-kanji=")
    two_word_flags+=("--person.last-name-kanji")
    local_nonpersistent_flags+=("--person.last-name-kanji")
    local_nonpersistent_flags+=("--person.last-name-kanji=")
    flags+=("--person.maiden-name=")
    two_word_flags+=("--person.maiden-name")
    local_nonpersistent_flags+=("--person.maiden-name")
    local_nonpersistent_flags+=("--person.maiden-name=")
    flags+=("--person.nationality=")
    two_word_flags+=("--person.nationality")
    local_nonpersistent_flags+=("--person.nationality")
    local_nonpersistent_flags+=("--person.nationality=")
    flags+=("--person.phone=")
    two_word_flags+=("--person.phone")
    local_nonpersistent_flags+=("--person.phone")
    local_nonpersistent_flags+=("--person.phone=")
    flags+=("--person.political-exposure=")
    two_word_flags+=("--person.political-exposure")
    local_nonpersistent_flags+=("--person.political-exposure")
    local_nonpersistent_flags+=("--person.political-exposure=")
    flags+=("--person.registered-address.city=")
    two_word_flags+=("--person.registered-address.city")
    local_nonpersistent_flags+=("--person.registered-address.city")
    local_nonpersistent_flags+=("--person.registered-address.city=")
    flags+=("--person.registered-address.country=")
    two_word_flags+=("--person.registered-address.country")
    local_nonpersistent_flags+=("--person.registered-address.country")
    local_nonpersistent_flags+=("--person.registered-address.country=")
    flags+=("--person.registered-address.line1=")
    two_word_flags+=("--person.registered-address.line1")
    local_nonpersistent_flags+=("--person.registered-address.line1")
    local_nonpersistent_flags+=("--person.registered-address.line1=")
    flags+=("--person.registered-address.line2=")
    two_word_flags+=("--person.registered-address.line2")
    local_nonpersistent_flags+=("--person.registered-address.line2")
    local_nonpersistent_flags+=("--person.registered-address.line2=")
    flags+=("--person.registered-address.postal-code=")
    two_word_flags+=("--person.registered-address.postal-code")
    local_nonpersistent_flags+=("--person.registered-address.postal-code")
    local_nonpersistent_flags+=("--person.registered-address.postal-code=")
    flags+=("--person.registered-address.state=")
    two_word_flags+=("--person.registered-address.state")
    local_nonpersistent_flags+=("--person.registered-address.state")
    local_nonpersistent_flags+=("--person.registered-address.state=")
    flags+=("--person.relationship.director=")
    two_word_flags+=("--person.relationship.director")
    local_nonpersistent_flags+=("--person.relationship.director")
    local_nonpersistent_flags+=("--person.relationship.director=")
    flags+=("--person.relationship.executive=")
    two_word_flags+=("--person.relationship.executive")
    local_nonpersistent_flags+=("--person.relationship.executive")
    local_nonpersistent_flags+=("--person.relationship.executive=")
    flags+=("--person.relationship.legal-guardian=")
    two_word_flags+=("--person.relationship.legal-guardian")
    local_nonpersistent_flags+=("--person.relationship.legal-guardian")
    local_nonpersistent_flags+=("--person.relationship.legal-guardian=")
    flags+=("--person.relationship.owner=")
    two_word_flags+=("--person.relationship.owner")
    local_nonpersistent_flags+=("--person.relationship.owner")
    local_nonpersistent_flags+=("--person.relationship.owner=")
    flags+=("--person.relationship.percent-ownership=")
    two_word_flags+=("--person.relationship.percent-ownership")
    local_nonpersistent_flags+=("--person.relationship.percent-ownership")
    local_nonpersistent_flags+=("--person.relationship.percent-ownership=")
    flags+=("--person.relationship.representative=")
    two_word_flags+=("--person.relationship.representative")
    local_nonpersistent_flags+=("--person.relationship.representative")
    local_nonpersistent_flags+=("--person.relationship.representative=")
    flags+=("--person.relationship.title=")
    two_word_flags+=("--person.relationship.title")
    local_nonpersistent_flags+=("--person.relationship.title")
    local_nonpersistent_flags+=("--person.relationship.title=")
    flags+=("--person.ssn-last-4=")
    two_word_flags+=("--person.ssn-last-4")
    local_nonpersistent_flags+=("--person.ssn-last-4")
    local_nonpersistent_flags+=("--person.ssn-last-4=")
    flags+=("--person.verification.additional-document.back=")
    two_word_flags+=("--person.verification.additional-document.back")
    local_nonpersistent_flags+=("--person.verification.additional-document.back")
    local_nonpersistent_flags+=("--person.verification.additional-document.back=")
    flags+=("--person.verification.additional-document.front=")
    two_word_flags+=("--person.verification.additional-document.front")
    local_nonpersistent_flags+=("--person.verification.additional-document.front")
    local_nonpersistent_flags+=("--person.verification.additional-document.front=")
    flags+=("--person.verification.document.back=")
    two_word_flags+=("--person.verification.document.back")
    local_nonpersistent_flags+=("--person.verification.document.back")
    local_nonpersistent_flags+=("--person.verification.document.back=")
    flags+=("--person.verification.document.front=")
    two_word_flags+=("--person.verification.document.front")
    local_nonpersistent_flags+=("--person.verification.document.front")
    local_nonpersistent_flags+=("--person.verification.document.front=")
    flags+=("--pii.id-number=")
    two_word_flags+=("--pii.id-number")
    local_nonpersistent_flags+=("--pii.id-number")
    local_nonpersistent_flags+=("--pii.id-number=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tokens_retrieve()
{
    last_command="stripe_tokens_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_tokens()
{
    last_command="stripe_tokens"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_topups_cancel()
{
    last_command="stripe_topups_cancel"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_topups_create()
{
    last_command="stripe_topups_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--source=")
    two_word_flags+=("--source")
    local_nonpersistent_flags+=("--source")
    local_nonpersistent_flags+=("--source=")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transfer-group=")
    two_word_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_topups_list()
{
    last_command="stripe_topups_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_topups_retrieve()
{
    last_command="stripe_topups_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_topups_update()
{
    last_command="stripe_topups_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_topups()
{
    last_command="stripe_topups"

    command_aliases=()

    commands=()
    commands+=("cancel")
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_transfer_reversals_create()
{
    last_command="stripe_transfer_reversals_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--refund-application-fee=")
    two_word_flags+=("--refund-application-fee")
    local_nonpersistent_flags+=("--refund-application-fee")
    local_nonpersistent_flags+=("--refund-application-fee=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_transfer_reversals_list()
{
    last_command="stripe_transfer_reversals_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_transfer_reversals_retrieve()
{
    last_command="stripe_transfer_reversals_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_transfer_reversals_update()
{
    last_command="stripe_transfer_reversals_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_transfer_reversals()
{
    last_command="stripe_transfer_reversals"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_transfers_create()
{
    last_command="stripe_transfers_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--destination=")
    two_word_flags+=("--destination")
    local_nonpersistent_flags+=("--destination")
    local_nonpersistent_flags+=("--destination=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--source-transaction=")
    two_word_flags+=("--source-transaction")
    local_nonpersistent_flags+=("--source-transaction")
    local_nonpersistent_flags+=("--source-transaction=")
    flags+=("--source-type=")
    two_word_flags+=("--source-type")
    local_nonpersistent_flags+=("--source-type")
    local_nonpersistent_flags+=("--source-type=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transfer-group=")
    two_word_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_transfers_list()
{
    last_command="stripe_transfers_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--destination=")
    two_word_flags+=("--destination")
    local_nonpersistent_flags+=("--destination")
    local_nonpersistent_flags+=("--destination=")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transfer-group=")
    two_word_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group")
    local_nonpersistent_flags+=("--transfer-group=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_transfers_retrieve()
{
    last_command="stripe_transfers_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_transfers_update()
{
    last_command="stripe_transfers_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_transfers()
{
    last_command="stripe_transfers"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_credit_reversals_create()
{
    last_command="stripe_treasury_credit_reversals_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--received-credit=")
    two_word_flags+=("--received-credit")
    local_nonpersistent_flags+=("--received-credit")
    local_nonpersistent_flags+=("--received-credit=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_credit_reversals_list()
{
    last_command="stripe_treasury_credit_reversals_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--received-credit=")
    two_word_flags+=("--received-credit")
    local_nonpersistent_flags+=("--received-credit")
    local_nonpersistent_flags+=("--received-credit=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_credit_reversals_retrieve()
{
    last_command="stripe_treasury_credit_reversals_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_credit_reversals()
{
    last_command="stripe_treasury_credit_reversals"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_debit_reversals_create()
{
    last_command="stripe_treasury_debit_reversals_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--received-debit=")
    two_word_flags+=("--received-debit")
    local_nonpersistent_flags+=("--received-debit")
    local_nonpersistent_flags+=("--received-debit=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_debit_reversals_list()
{
    last_command="stripe_treasury_debit_reversals_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--received-debit=")
    two_word_flags+=("--received-debit")
    local_nonpersistent_flags+=("--received-debit")
    local_nonpersistent_flags+=("--received-debit=")
    flags+=("--resolution=")
    two_word_flags+=("--resolution")
    local_nonpersistent_flags+=("--resolution")
    local_nonpersistent_flags+=("--resolution=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_debit_reversals_retrieve()
{
    last_command="stripe_treasury_debit_reversals_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_debit_reversals()
{
    last_command="stripe_treasury_debit_reversals"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_financial_accounts_create()
{
    last_command="stripe_treasury_financial_accounts_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--features.card-issuing.requested=")
    two_word_flags+=("--features.card-issuing.requested")
    local_nonpersistent_flags+=("--features.card-issuing.requested")
    local_nonpersistent_flags+=("--features.card-issuing.requested=")
    flags+=("--features.deposit-insurance.requested=")
    two_word_flags+=("--features.deposit-insurance.requested")
    local_nonpersistent_flags+=("--features.deposit-insurance.requested")
    local_nonpersistent_flags+=("--features.deposit-insurance.requested=")
    flags+=("--features.financial-addresses.aba.requested=")
    two_word_flags+=("--features.financial-addresses.aba.requested")
    local_nonpersistent_flags+=("--features.financial-addresses.aba.requested")
    local_nonpersistent_flags+=("--features.financial-addresses.aba.requested=")
    flags+=("--features.inbound-transfers.ach.requested=")
    two_word_flags+=("--features.inbound-transfers.ach.requested")
    local_nonpersistent_flags+=("--features.inbound-transfers.ach.requested")
    local_nonpersistent_flags+=("--features.inbound-transfers.ach.requested=")
    flags+=("--features.intra-stripe-flows.requested=")
    two_word_flags+=("--features.intra-stripe-flows.requested")
    local_nonpersistent_flags+=("--features.intra-stripe-flows.requested")
    local_nonpersistent_flags+=("--features.intra-stripe-flows.requested=")
    flags+=("--features.outbound-payments.ach.requested=")
    two_word_flags+=("--features.outbound-payments.ach.requested")
    local_nonpersistent_flags+=("--features.outbound-payments.ach.requested")
    local_nonpersistent_flags+=("--features.outbound-payments.ach.requested=")
    flags+=("--features.outbound-payments.us-domestic-wire.requested=")
    two_word_flags+=("--features.outbound-payments.us-domestic-wire.requested")
    local_nonpersistent_flags+=("--features.outbound-payments.us-domestic-wire.requested")
    local_nonpersistent_flags+=("--features.outbound-payments.us-domestic-wire.requested=")
    flags+=("--features.outbound-transfers.ach.requested=")
    two_word_flags+=("--features.outbound-transfers.ach.requested")
    local_nonpersistent_flags+=("--features.outbound-transfers.ach.requested")
    local_nonpersistent_flags+=("--features.outbound-transfers.ach.requested=")
    flags+=("--features.outbound-transfers.us-domestic-wire.requested=")
    two_word_flags+=("--features.outbound-transfers.us-domestic-wire.requested")
    local_nonpersistent_flags+=("--features.outbound-transfers.us-domestic-wire.requested")
    local_nonpersistent_flags+=("--features.outbound-transfers.us-domestic-wire.requested=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--platform-restrictions.inbound-flows=")
    two_word_flags+=("--platform-restrictions.inbound-flows")
    local_nonpersistent_flags+=("--platform-restrictions.inbound-flows")
    local_nonpersistent_flags+=("--platform-restrictions.inbound-flows=")
    flags+=("--platform-restrictions.outbound-flows=")
    two_word_flags+=("--platform-restrictions.outbound-flows")
    local_nonpersistent_flags+=("--platform-restrictions.outbound-flows")
    local_nonpersistent_flags+=("--platform-restrictions.outbound-flows=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--supported-currencies=")
    two_word_flags+=("--supported-currencies")
    local_nonpersistent_flags+=("--supported-currencies")
    local_nonpersistent_flags+=("--supported-currencies=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_financial_accounts_list()
{
    last_command="stripe_treasury_financial_accounts_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_financial_accounts_retrieve()
{
    last_command="stripe_treasury_financial_accounts_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_financial_accounts_retrieve_features()
{
    last_command="stripe_treasury_financial_accounts_retrieve_features"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_financial_accounts_update()
{
    last_command="stripe_treasury_financial_accounts_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--features.card-issuing.requested=")
    two_word_flags+=("--features.card-issuing.requested")
    local_nonpersistent_flags+=("--features.card-issuing.requested")
    local_nonpersistent_flags+=("--features.card-issuing.requested=")
    flags+=("--features.deposit-insurance.requested=")
    two_word_flags+=("--features.deposit-insurance.requested")
    local_nonpersistent_flags+=("--features.deposit-insurance.requested")
    local_nonpersistent_flags+=("--features.deposit-insurance.requested=")
    flags+=("--features.financial-addresses.aba.requested=")
    two_word_flags+=("--features.financial-addresses.aba.requested")
    local_nonpersistent_flags+=("--features.financial-addresses.aba.requested")
    local_nonpersistent_flags+=("--features.financial-addresses.aba.requested=")
    flags+=("--features.inbound-transfers.ach.requested=")
    two_word_flags+=("--features.inbound-transfers.ach.requested")
    local_nonpersistent_flags+=("--features.inbound-transfers.ach.requested")
    local_nonpersistent_flags+=("--features.inbound-transfers.ach.requested=")
    flags+=("--features.intra-stripe-flows.requested=")
    two_word_flags+=("--features.intra-stripe-flows.requested")
    local_nonpersistent_flags+=("--features.intra-stripe-flows.requested")
    local_nonpersistent_flags+=("--features.intra-stripe-flows.requested=")
    flags+=("--features.outbound-payments.ach.requested=")
    two_word_flags+=("--features.outbound-payments.ach.requested")
    local_nonpersistent_flags+=("--features.outbound-payments.ach.requested")
    local_nonpersistent_flags+=("--features.outbound-payments.ach.requested=")
    flags+=("--features.outbound-payments.us-domestic-wire.requested=")
    two_word_flags+=("--features.outbound-payments.us-domestic-wire.requested")
    local_nonpersistent_flags+=("--features.outbound-payments.us-domestic-wire.requested")
    local_nonpersistent_flags+=("--features.outbound-payments.us-domestic-wire.requested=")
    flags+=("--features.outbound-transfers.ach.requested=")
    two_word_flags+=("--features.outbound-transfers.ach.requested")
    local_nonpersistent_flags+=("--features.outbound-transfers.ach.requested")
    local_nonpersistent_flags+=("--features.outbound-transfers.ach.requested=")
    flags+=("--features.outbound-transfers.us-domestic-wire.requested=")
    two_word_flags+=("--features.outbound-transfers.us-domestic-wire.requested")
    local_nonpersistent_flags+=("--features.outbound-transfers.us-domestic-wire.requested")
    local_nonpersistent_flags+=("--features.outbound-transfers.us-domestic-wire.requested=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--platform-restrictions.inbound-flows=")
    two_word_flags+=("--platform-restrictions.inbound-flows")
    local_nonpersistent_flags+=("--platform-restrictions.inbound-flows")
    local_nonpersistent_flags+=("--platform-restrictions.inbound-flows=")
    flags+=("--platform-restrictions.outbound-flows=")
    two_word_flags+=("--platform-restrictions.outbound-flows")
    local_nonpersistent_flags+=("--platform-restrictions.outbound-flows")
    local_nonpersistent_flags+=("--platform-restrictions.outbound-flows=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_financial_accounts_update_features()
{
    last_command="stripe_treasury_financial_accounts_update_features"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--card-issuing.requested=")
    two_word_flags+=("--card-issuing.requested")
    local_nonpersistent_flags+=("--card-issuing.requested")
    local_nonpersistent_flags+=("--card-issuing.requested=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--deposit-insurance.requested=")
    two_word_flags+=("--deposit-insurance.requested")
    local_nonpersistent_flags+=("--deposit-insurance.requested")
    local_nonpersistent_flags+=("--deposit-insurance.requested=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-addresses.aba.requested=")
    two_word_flags+=("--financial-addresses.aba.requested")
    local_nonpersistent_flags+=("--financial-addresses.aba.requested")
    local_nonpersistent_flags+=("--financial-addresses.aba.requested=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--inbound-transfers.ach.requested=")
    two_word_flags+=("--inbound-transfers.ach.requested")
    local_nonpersistent_flags+=("--inbound-transfers.ach.requested")
    local_nonpersistent_flags+=("--inbound-transfers.ach.requested=")
    flags+=("--intra-stripe-flows.requested=")
    two_word_flags+=("--intra-stripe-flows.requested")
    local_nonpersistent_flags+=("--intra-stripe-flows.requested")
    local_nonpersistent_flags+=("--intra-stripe-flows.requested=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--outbound-payments.ach.requested=")
    two_word_flags+=("--outbound-payments.ach.requested")
    local_nonpersistent_flags+=("--outbound-payments.ach.requested")
    local_nonpersistent_flags+=("--outbound-payments.ach.requested=")
    flags+=("--outbound-payments.us-domestic-wire.requested=")
    two_word_flags+=("--outbound-payments.us-domestic-wire.requested")
    local_nonpersistent_flags+=("--outbound-payments.us-domestic-wire.requested")
    local_nonpersistent_flags+=("--outbound-payments.us-domestic-wire.requested=")
    flags+=("--outbound-transfers.ach.requested=")
    two_word_flags+=("--outbound-transfers.ach.requested")
    local_nonpersistent_flags+=("--outbound-transfers.ach.requested")
    local_nonpersistent_flags+=("--outbound-transfers.ach.requested=")
    flags+=("--outbound-transfers.us-domestic-wire.requested=")
    two_word_flags+=("--outbound-transfers.us-domestic-wire.requested")
    local_nonpersistent_flags+=("--outbound-transfers.us-domestic-wire.requested")
    local_nonpersistent_flags+=("--outbound-transfers.us-domestic-wire.requested=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_financial_accounts()
{
    last_command="stripe_treasury_financial_accounts"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("retrieve_features")
    commands+=("update")
    commands+=("update_features")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_inbound_transfers_cancel()
{
    last_command="stripe_treasury_inbound_transfers_cancel"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_inbound_transfers_create()
{
    last_command="stripe_treasury_inbound_transfers_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--origin-payment-method=")
    two_word_flags+=("--origin-payment-method")
    local_nonpersistent_flags+=("--origin-payment-method")
    local_nonpersistent_flags+=("--origin-payment-method=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_inbound_transfers_list()
{
    last_command="stripe_treasury_inbound_transfers_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_inbound_transfers_retrieve()
{
    last_command="stripe_treasury_inbound_transfers_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_inbound_transfers_test_helpers_fail()
{
    last_command="stripe_treasury_inbound_transfers_test_helpers_fail"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--failure-details.code=")
    two_word_flags+=("--failure-details.code")
    local_nonpersistent_flags+=("--failure-details.code")
    local_nonpersistent_flags+=("--failure-details.code=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_inbound_transfers_test_helpers_return_inbound_transfer()
{
    last_command="stripe_treasury_inbound_transfers_test_helpers_return_inbound_transfer"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_inbound_transfers_test_helpers_succeed()
{
    last_command="stripe_treasury_inbound_transfers_test_helpers_succeed"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_inbound_transfers_test_helpers()
{
    last_command="stripe_treasury_inbound_transfers_test_helpers"

    command_aliases=()

    commands=()
    commands+=("fail")
    commands+=("return_inbound_transfer")
    commands+=("succeed")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_inbound_transfers()
{
    last_command="stripe_treasury_inbound_transfers"

    command_aliases=()

    commands=()
    commands+=("cancel")
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("test_helpers")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_payments_cancel()
{
    last_command="stripe_treasury_outbound_payments_cancel"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_payments_create()
{
    last_command="stripe_treasury_outbound_payments_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--destination-payment-method=")
    two_word_flags+=("--destination-payment-method")
    local_nonpersistent_flags+=("--destination-payment-method")
    local_nonpersistent_flags+=("--destination-payment-method=")
    flags+=("--destination-payment-method-data.billing-details.email=")
    two_word_flags+=("--destination-payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--destination-payment-method-data.billing-details.email")
    local_nonpersistent_flags+=("--destination-payment-method-data.billing-details.email=")
    flags+=("--destination-payment-method-data.billing-details.name=")
    two_word_flags+=("--destination-payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--destination-payment-method-data.billing-details.name")
    local_nonpersistent_flags+=("--destination-payment-method-data.billing-details.name=")
    flags+=("--destination-payment-method-data.billing-details.phone=")
    two_word_flags+=("--destination-payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--destination-payment-method-data.billing-details.phone")
    local_nonpersistent_flags+=("--destination-payment-method-data.billing-details.phone=")
    flags+=("--destination-payment-method-data.financial-account=")
    two_word_flags+=("--destination-payment-method-data.financial-account")
    local_nonpersistent_flags+=("--destination-payment-method-data.financial-account")
    local_nonpersistent_flags+=("--destination-payment-method-data.financial-account=")
    flags+=("--destination-payment-method-data.type=")
    two_word_flags+=("--destination-payment-method-data.type")
    local_nonpersistent_flags+=("--destination-payment-method-data.type")
    local_nonpersistent_flags+=("--destination-payment-method-data.type=")
    flags+=("--destination-payment-method-data.us-bank-account.account-holder-type=")
    two_word_flags+=("--destination-payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--destination-payment-method-data.us-bank-account.account-holder-type")
    local_nonpersistent_flags+=("--destination-payment-method-data.us-bank-account.account-holder-type=")
    flags+=("--destination-payment-method-data.us-bank-account.account-number=")
    two_word_flags+=("--destination-payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--destination-payment-method-data.us-bank-account.account-number")
    local_nonpersistent_flags+=("--destination-payment-method-data.us-bank-account.account-number=")
    flags+=("--destination-payment-method-data.us-bank-account.account-type=")
    two_word_flags+=("--destination-payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--destination-payment-method-data.us-bank-account.account-type")
    local_nonpersistent_flags+=("--destination-payment-method-data.us-bank-account.account-type=")
    flags+=("--destination-payment-method-data.us-bank-account.financial-connections-account=")
    two_word_flags+=("--destination-payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--destination-payment-method-data.us-bank-account.financial-connections-account")
    local_nonpersistent_flags+=("--destination-payment-method-data.us-bank-account.financial-connections-account=")
    flags+=("--destination-payment-method-data.us-bank-account.routing-number=")
    two_word_flags+=("--destination-payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--destination-payment-method-data.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--destination-payment-method-data.us-bank-account.routing-number=")
    flags+=("--end-user-details.ip-address=")
    two_word_flags+=("--end-user-details.ip-address")
    local_nonpersistent_flags+=("--end-user-details.ip-address")
    local_nonpersistent_flags+=("--end-user-details.ip-address=")
    flags+=("--end-user-details.present=")
    two_word_flags+=("--end-user-details.present")
    local_nonpersistent_flags+=("--end-user-details.present")
    local_nonpersistent_flags+=("--end-user-details.present=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_payments_list()
{
    last_command="stripe_treasury_outbound_payments_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--customer=")
    two_word_flags+=("--customer")
    local_nonpersistent_flags+=("--customer")
    local_nonpersistent_flags+=("--customer=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_payments_retrieve()
{
    last_command="stripe_treasury_outbound_payments_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_payments_test_helpers_fail()
{
    last_command="stripe_treasury_outbound_payments_test_helpers_fail"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_payments_test_helpers_post()
{
    last_command="stripe_treasury_outbound_payments_test_helpers_post"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_payments_test_helpers_return_outbound_payment()
{
    last_command="stripe_treasury_outbound_payments_test_helpers_return_outbound_payment"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--returned-details.code=")
    two_word_flags+=("--returned-details.code")
    local_nonpersistent_flags+=("--returned-details.code")
    local_nonpersistent_flags+=("--returned-details.code=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_payments_test_helpers_update()
{
    last_command="stripe_treasury_outbound_payments_test_helpers_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tracking-details.ach.trace-id=")
    two_word_flags+=("--tracking-details.ach.trace-id")
    local_nonpersistent_flags+=("--tracking-details.ach.trace-id")
    local_nonpersistent_flags+=("--tracking-details.ach.trace-id=")
    flags+=("--tracking-details.type=")
    two_word_flags+=("--tracking-details.type")
    local_nonpersistent_flags+=("--tracking-details.type")
    local_nonpersistent_flags+=("--tracking-details.type=")
    flags+=("--tracking-details.us-domestic-wire.chips=")
    two_word_flags+=("--tracking-details.us-domestic-wire.chips")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.chips")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.chips=")
    flags+=("--tracking-details.us-domestic-wire.imad=")
    two_word_flags+=("--tracking-details.us-domestic-wire.imad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.imad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.imad=")
    flags+=("--tracking-details.us-domestic-wire.omad=")
    two_word_flags+=("--tracking-details.us-domestic-wire.omad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.omad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.omad=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_payments_test_helpers()
{
    last_command="stripe_treasury_outbound_payments_test_helpers"

    command_aliases=()

    commands=()
    commands+=("fail")
    commands+=("post")
    commands+=("return_outbound_payment")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_payments()
{
    last_command="stripe_treasury_outbound_payments"

    command_aliases=()

    commands=()
    commands+=("cancel")
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("test_helpers")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_transfers_cancel()
{
    last_command="stripe_treasury_outbound_transfers_cancel"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_transfers_create()
{
    last_command="stripe_treasury_outbound_transfers_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--destination-payment-method=")
    two_word_flags+=("--destination-payment-method")
    local_nonpersistent_flags+=("--destination-payment-method")
    local_nonpersistent_flags+=("--destination-payment-method=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--statement-descriptor=")
    two_word_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor")
    local_nonpersistent_flags+=("--statement-descriptor=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_transfers_list()
{
    last_command="stripe_treasury_outbound_transfers_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_transfers_retrieve()
{
    last_command="stripe_treasury_outbound_transfers_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_transfers_test_helpers_fail()
{
    last_command="stripe_treasury_outbound_transfers_test_helpers_fail"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_transfers_test_helpers_post()
{
    last_command="stripe_treasury_outbound_transfers_test_helpers_post"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_transfers_test_helpers_return_outbound_transfer()
{
    last_command="stripe_treasury_outbound_transfers_test_helpers_return_outbound_transfer"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--returned-details.code=")
    two_word_flags+=("--returned-details.code")
    local_nonpersistent_flags+=("--returned-details.code")
    local_nonpersistent_flags+=("--returned-details.code=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_transfers_test_helpers_update()
{
    last_command="stripe_treasury_outbound_transfers_test_helpers_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--tracking-details.ach.trace-id=")
    two_word_flags+=("--tracking-details.ach.trace-id")
    local_nonpersistent_flags+=("--tracking-details.ach.trace-id")
    local_nonpersistent_flags+=("--tracking-details.ach.trace-id=")
    flags+=("--tracking-details.type=")
    two_word_flags+=("--tracking-details.type")
    local_nonpersistent_flags+=("--tracking-details.type")
    local_nonpersistent_flags+=("--tracking-details.type=")
    flags+=("--tracking-details.us-domestic-wire.chips=")
    two_word_flags+=("--tracking-details.us-domestic-wire.chips")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.chips")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.chips=")
    flags+=("--tracking-details.us-domestic-wire.imad=")
    two_word_flags+=("--tracking-details.us-domestic-wire.imad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.imad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.imad=")
    flags+=("--tracking-details.us-domestic-wire.omad=")
    two_word_flags+=("--tracking-details.us-domestic-wire.omad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.omad")
    local_nonpersistent_flags+=("--tracking-details.us-domestic-wire.omad=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_transfers_test_helpers()
{
    last_command="stripe_treasury_outbound_transfers_test_helpers"

    command_aliases=()

    commands=()
    commands+=("fail")
    commands+=("post")
    commands+=("return_outbound_transfer")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_outbound_transfers()
{
    last_command="stripe_treasury_outbound_transfers"

    command_aliases=()

    commands=()
    commands+=("cancel")
    commands+=("create")
    commands+=("list")
    commands+=("retrieve")
    commands+=("test_helpers")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_received_credits_list()
{
    last_command="stripe_treasury_received_credits_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_received_credits_retrieve()
{
    last_command="stripe_treasury_received_credits_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_received_credits_test_helpers_create()
{
    last_command="stripe_treasury_received_credits_test_helpers_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--initiating-payment-method-details.type=")
    two_word_flags+=("--initiating-payment-method-details.type")
    local_nonpersistent_flags+=("--initiating-payment-method-details.type")
    local_nonpersistent_flags+=("--initiating-payment-method-details.type=")
    flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name=")
    two_word_flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name=")
    flags+=("--initiating-payment-method-details.us-bank-account.account-number=")
    two_word_flags+=("--initiating-payment-method-details.us-bank-account.account-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-number=")
    flags+=("--initiating-payment-method-details.us-bank-account.routing-number=")
    two_word_flags+=("--initiating-payment-method-details.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.routing-number=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--network=")
    two_word_flags+=("--network")
    local_nonpersistent_flags+=("--network")
    local_nonpersistent_flags+=("--network=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_received_credits_test_helpers()
{
    last_command="stripe_treasury_received_credits_test_helpers"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_received_credits()
{
    last_command="stripe_treasury_received_credits"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")
    commands+=("test_helpers")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_received_debits_list()
{
    last_command="stripe_treasury_received_debits_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_received_debits_retrieve()
{
    last_command="stripe_treasury_received_debits_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_received_debits_test_helpers_create()
{
    last_command="stripe_treasury_received_debits_test_helpers_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--amount=")
    two_word_flags+=("--amount")
    local_nonpersistent_flags+=("--amount")
    local_nonpersistent_flags+=("--amount=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--currency=")
    two_word_flags+=("--currency")
    local_nonpersistent_flags+=("--currency")
    local_nonpersistent_flags+=("--currency=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--initiating-payment-method-details.type=")
    two_word_flags+=("--initiating-payment-method-details.type")
    local_nonpersistent_flags+=("--initiating-payment-method-details.type")
    local_nonpersistent_flags+=("--initiating-payment-method-details.type=")
    flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name=")
    two_word_flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-holder-name=")
    flags+=("--initiating-payment-method-details.us-bank-account.account-number=")
    two_word_flags+=("--initiating-payment-method-details.us-bank-account.account-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.account-number=")
    flags+=("--initiating-payment-method-details.us-bank-account.routing-number=")
    two_word_flags+=("--initiating-payment-method-details.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.routing-number")
    local_nonpersistent_flags+=("--initiating-payment-method-details.us-bank-account.routing-number=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--network=")
    two_word_flags+=("--network")
    local_nonpersistent_flags+=("--network")
    local_nonpersistent_flags+=("--network=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_received_debits_test_helpers()
{
    last_command="stripe_treasury_received_debits_test_helpers"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_received_debits()
{
    last_command="stripe_treasury_received_debits"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")
    commands+=("test_helpers")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_transaction_entrys_list()
{
    last_command="stripe_treasury_transaction_entrys_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--effective-at=")
    two_word_flags+=("--effective-at")
    local_nonpersistent_flags+=("--effective-at")
    local_nonpersistent_flags+=("--effective-at=")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--order-by=")
    two_word_flags+=("--order-by")
    local_nonpersistent_flags+=("--order-by")
    local_nonpersistent_flags+=("--order-by=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--transaction=")
    two_word_flags+=("--transaction")
    local_nonpersistent_flags+=("--transaction")
    local_nonpersistent_flags+=("--transaction=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_transaction_entrys_retrieve()
{
    last_command="stripe_treasury_transaction_entrys_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_transaction_entrys()
{
    last_command="stripe_treasury_transaction_entrys"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_transactions_list()
{
    last_command="stripe_treasury_transactions_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--created=")
    two_word_flags+=("--created")
    local_nonpersistent_flags+=("--created")
    local_nonpersistent_flags+=("--created=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--financial-account=")
    two_word_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account")
    local_nonpersistent_flags+=("--financial-account=")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--order-by=")
    two_word_flags+=("--order-by")
    local_nonpersistent_flags+=("--order-by")
    local_nonpersistent_flags+=("--order-by=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--status=")
    two_word_flags+=("--status")
    local_nonpersistent_flags+=("--status")
    local_nonpersistent_flags+=("--status=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_transactions_retrieve()
{
    last_command="stripe_treasury_transactions_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury_transactions()
{
    last_command="stripe_treasury_transactions"

    command_aliases=()

    commands=()
    commands+=("list")
    commands+=("retrieve")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_treasury()
{
    last_command="stripe_treasury"

    command_aliases=()

    commands=()
    commands+=("credit_reversals")
    commands+=("debit_reversals")
    commands+=("financial_accounts")
    commands+=("inbound_transfers")
    commands+=("outbound_payments")
    commands+=("outbound_transfers")
    commands+=("received_credits")
    commands+=("received_debits")
    commands+=("transaction_entrys")
    commands+=("transactions")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_trigger()
{
    last_command="stripe_trigger"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--add=")
    two_word_flags+=("--add")
    local_nonpersistent_flags+=("--add")
    local_nonpersistent_flags+=("--add=")
    flags+=("--api-version=")
    two_word_flags+=("--api-version")
    local_nonpersistent_flags+=("--api-version")
    local_nonpersistent_flags+=("--api-version=")
    flags+=("--edit")
    local_nonpersistent_flags+=("--edit")
    flags+=("--override=")
    two_word_flags+=("--override")
    local_nonpersistent_flags+=("--override")
    local_nonpersistent_flags+=("--override=")
    flags+=("--raw=")
    two_word_flags+=("--raw")
    local_nonpersistent_flags+=("--raw")
    local_nonpersistent_flags+=("--raw=")
    flags+=("--remove=")
    two_word_flags+=("--remove")
    local_nonpersistent_flags+=("--remove")
    local_nonpersistent_flags+=("--remove=")
    flags+=("--skip=")
    two_word_flags+=("--skip")
    local_nonpersistent_flags+=("--skip")
    local_nonpersistent_flags+=("--skip=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    must_have_one_noun+=("account.application.deauthorized")
    must_have_one_noun+=("account.updated")
    must_have_one_noun+=("balance.available")
    must_have_one_noun+=("billing_portal.configuration.created")
    must_have_one_noun+=("billing_portal.configuration.updated")
    must_have_one_noun+=("billing_portal.session.created")
    must_have_one_noun+=("cash_balance.funds_available")
    must_have_one_noun+=("charge.captured")
    must_have_one_noun+=("charge.dispute.closed")
    must_have_one_noun+=("charge.dispute.created")
    must_have_one_noun+=("charge.dispute.updated")
    must_have_one_noun+=("charge.failed")
    must_have_one_noun+=("charge.refund.updated")
    must_have_one_noun+=("charge.refunded")
    must_have_one_noun+=("charge.succeeded")
    must_have_one_noun+=("checkout.session.async_payment_failed")
    must_have_one_noun+=("checkout.session.async_payment_succeeded")
    must_have_one_noun+=("checkout.session.completed")
    must_have_one_noun+=("checkout.session.expired")
    must_have_one_noun+=("coupon.created")
    must_have_one_noun+=("coupon.deleted")
    must_have_one_noun+=("coupon.updated")
    must_have_one_noun+=("credit_note.created")
    must_have_one_noun+=("credit_note.updated")
    must_have_one_noun+=("credit_note.voided")
    must_have_one_noun+=("customer.created")
    must_have_one_noun+=("customer.deleted")
    must_have_one_noun+=("customer.discount.created")
    must_have_one_noun+=("customer.discount.deleted")
    must_have_one_noun+=("customer.discount.updated")
    must_have_one_noun+=("customer.source.created")
    must_have_one_noun+=("customer.source.updated")
    must_have_one_noun+=("customer.subscription.created")
    must_have_one_noun+=("customer.subscription.deleted")
    must_have_one_noun+=("customer.subscription.paused")
    must_have_one_noun+=("customer.subscription.trial_will_end")
    must_have_one_noun+=("customer.subscription.updated")
    must_have_one_noun+=("customer.updated")
    must_have_one_noun+=("customer_cash_balance_transaction.created")
    must_have_one_noun+=("identity.verification_session.canceled")
    must_have_one_noun+=("identity.verification_session.created")
    must_have_one_noun+=("identity.verification_session.redacted")
    must_have_one_noun+=("invoice.created")
    must_have_one_noun+=("invoice.deleted")
    must_have_one_noun+=("invoice.finalized")
    must_have_one_noun+=("invoice.marked_uncollectible")
    must_have_one_noun+=("invoice.paid")
    must_have_one_noun+=("invoice.payment_action_required")
    must_have_one_noun+=("invoice.payment_failed")
    must_have_one_noun+=("invoice.payment_succeeded")
    must_have_one_noun+=("invoice.sent")
    must_have_one_noun+=("invoice.updated")
    must_have_one_noun+=("invoice.voided")
    must_have_one_noun+=("invoiceitem.created")
    must_have_one_noun+=("invoiceitem.deleted")
    must_have_one_noun+=("issuing_authorization.request")
    must_have_one_noun+=("issuing_authorization.request.eu")
    must_have_one_noun+=("issuing_authorization.request.gb")
    must_have_one_noun+=("issuing_card.created")
    must_have_one_noun+=("issuing_card.created.eu")
    must_have_one_noun+=("issuing_card.created.gb")
    must_have_one_noun+=("issuing_cardholder.created")
    must_have_one_noun+=("issuing_cardholder.created.eu")
    must_have_one_noun+=("issuing_cardholder.created.gb")
    must_have_one_noun+=("payment_intent.amount_capturable_updated")
    must_have_one_noun+=("payment_intent.canceled")
    must_have_one_noun+=("payment_intent.created")
    must_have_one_noun+=("payment_intent.partially_funded")
    must_have_one_noun+=("payment_intent.payment_failed")
    must_have_one_noun+=("payment_intent.processing")
    must_have_one_noun+=("payment_intent.requires_action")
    must_have_one_noun+=("payment_intent.succeeded")
    must_have_one_noun+=("payment_link.created")
    must_have_one_noun+=("payment_link.updated")
    must_have_one_noun+=("payment_method.attached")
    must_have_one_noun+=("payment_method.detached")
    must_have_one_noun+=("payment_method.updated")
    must_have_one_noun+=("payout.created")
    must_have_one_noun+=("payout.updated")
    must_have_one_noun+=("plan.created")
    must_have_one_noun+=("plan.deleted")
    must_have_one_noun+=("plan.updated")
    must_have_one_noun+=("price.created")
    must_have_one_noun+=("price.updated")
    must_have_one_noun+=("product.created")
    must_have_one_noun+=("product.deleted")
    must_have_one_noun+=("product.updated")
    must_have_one_noun+=("promotion_code.created")
    must_have_one_noun+=("promotion_code.updated")
    must_have_one_noun+=("quote.accepted")
    must_have_one_noun+=("quote.canceled")
    must_have_one_noun+=("quote.created")
    must_have_one_noun+=("quote.finalized")
    must_have_one_noun+=("reporting.report_run.succeeded")
    must_have_one_noun+=("setup_intent.canceled")
    must_have_one_noun+=("setup_intent.created")
    must_have_one_noun+=("setup_intent.requires_action")
    must_have_one_noun+=("setup_intent.setup_failed")
    must_have_one_noun+=("setup_intent.succeeded")
    must_have_one_noun+=("subscription.payment_failed")
    must_have_one_noun+=("subscription.payment_succeeded")
    must_have_one_noun+=("subscription_schedule.canceled")
    must_have_one_noun+=("subscription_schedule.created")
    must_have_one_noun+=("subscription_schedule.released")
    must_have_one_noun+=("subscription_schedule.updated")
    must_have_one_noun+=("tax_rate.created")
    must_have_one_noun+=("tax_rate.updated")
    must_have_one_noun+=("transfer.created")
    must_have_one_noun+=("transfer.reversed")
    must_have_one_noun+=("transfer.updated")
    must_have_one_noun+=("v1.billing.meter.error_report_triggered")
    must_have_one_noun+=("v1.billing.meter.no_meter_found")
    noun_aliases=()
}

_stripe_usage_record_summaries_list()
{
    last_command="stripe_usage_record_summaries_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_usage_record_summaries()
{
    last_command="stripe_usage_record_summaries"

    command_aliases=()

    commands=()
    commands+=("list")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_usage_records_create()
{
    last_command="stripe_usage_records_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--action=")
    two_word_flags+=("--action")
    local_nonpersistent_flags+=("--action")
    local_nonpersistent_flags+=("--action=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--quantity=")
    two_word_flags+=("--quantity")
    local_nonpersistent_flags+=("--quantity")
    local_nonpersistent_flags+=("--quantity=")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--timestamp=")
    two_word_flags+=("--timestamp")
    local_nonpersistent_flags+=("--timestamp")
    local_nonpersistent_flags+=("--timestamp=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_usage_records()
{
    last_command="stripe_usage_records"

    command_aliases=()

    commands=()
    commands+=("create")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_version()
{
    last_command="stripe_version"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_webhook_endpoints_create()
{
    last_command="stripe_webhook_endpoints_create"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-version=")
    two_word_flags+=("--api-version")
    local_nonpersistent_flags+=("--api-version")
    local_nonpersistent_flags+=("--api-version=")
    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--connect=")
    two_word_flags+=("--connect")
    local_nonpersistent_flags+=("--connect")
    local_nonpersistent_flags+=("--connect=")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--enabled-events=")
    two_word_flags+=("--enabled-events")
    local_nonpersistent_flags+=("--enabled-events")
    local_nonpersistent_flags+=("--enabled-events=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--url=")
    two_word_flags+=("--url")
    local_nonpersistent_flags+=("--url")
    local_nonpersistent_flags+=("--url=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_webhook_endpoints_delete()
{
    last_command="stripe_webhook_endpoints_delete"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_webhook_endpoints_list()
{
    last_command="stripe_webhook_endpoints_list"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_webhook_endpoints_retrieve()
{
    last_command="stripe_webhook_endpoints_retrieve"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--ending-before=")
    two_word_flags+=("--ending-before")
    two_word_flags+=("-b")
    local_nonpersistent_flags+=("--ending-before")
    local_nonpersistent_flags+=("--ending-before=")
    local_nonpersistent_flags+=("-b")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--limit=")
    two_word_flags+=("--limit")
    two_word_flags+=("-l")
    local_nonpersistent_flags+=("--limit")
    local_nonpersistent_flags+=("--limit=")
    local_nonpersistent_flags+=("-l")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--starting-after=")
    two_word_flags+=("--starting-after")
    two_word_flags+=("-a")
    local_nonpersistent_flags+=("--starting-after")
    local_nonpersistent_flags+=("--starting-after=")
    local_nonpersistent_flags+=("-a")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_webhook_endpoints_update()
{
    last_command="stripe_webhook_endpoints_update"

    command_aliases=()

    commands=()

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--confirm")
    flags+=("-c")
    local_nonpersistent_flags+=("--confirm")
    local_nonpersistent_flags+=("-c")
    flags+=("--dark-style")
    local_nonpersistent_flags+=("--dark-style")
    flags+=("--data=")
    two_word_flags+=("--data")
    two_word_flags+=("-d")
    local_nonpersistent_flags+=("--data")
    local_nonpersistent_flags+=("--data=")
    local_nonpersistent_flags+=("-d")
    flags+=("--description=")
    two_word_flags+=("--description")
    local_nonpersistent_flags+=("--description")
    local_nonpersistent_flags+=("--description=")
    flags+=("--disabled=")
    two_word_flags+=("--disabled")
    local_nonpersistent_flags+=("--disabled")
    local_nonpersistent_flags+=("--disabled=")
    flags+=("--enabled-events=")
    two_word_flags+=("--enabled-events")
    local_nonpersistent_flags+=("--enabled-events")
    local_nonpersistent_flags+=("--enabled-events=")
    flags+=("--expand=")
    two_word_flags+=("--expand")
    two_word_flags+=("-e")
    local_nonpersistent_flags+=("--expand")
    local_nonpersistent_flags+=("--expand=")
    local_nonpersistent_flags+=("-e")
    flags+=("--idempotency=")
    two_word_flags+=("--idempotency")
    two_word_flags+=("-i")
    local_nonpersistent_flags+=("--idempotency")
    local_nonpersistent_flags+=("--idempotency=")
    local_nonpersistent_flags+=("-i")
    flags+=("--live")
    local_nonpersistent_flags+=("--live")
    flags+=("--show-headers")
    flags+=("-s")
    local_nonpersistent_flags+=("--show-headers")
    local_nonpersistent_flags+=("-s")
    flags+=("--stripe-account=")
    two_word_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account")
    local_nonpersistent_flags+=("--stripe-account=")
    flags+=("--stripe-version=")
    two_word_flags+=("--stripe-version")
    two_word_flags+=("-v")
    local_nonpersistent_flags+=("--stripe-version")
    local_nonpersistent_flags+=("--stripe-version=")
    local_nonpersistent_flags+=("-v")
    flags+=("--url=")
    two_word_flags+=("--url")
    local_nonpersistent_flags+=("--url")
    local_nonpersistent_flags+=("--url=")
    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_webhook_endpoints()
{
    last_command="stripe_webhook_endpoints"

    command_aliases=()

    commands=()
    commands+=("create")
    commands+=("delete")
    commands+=("list")
    commands+=("retrieve")
    commands+=("update")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

_stripe_root_command()
{
    last_command="stripe"

    command_aliases=()

    commands=()
    commands+=("account_links")
    commands+=("account_sessions")
    commands+=("accounts")
    commands+=("apple_pay_domains")
    commands+=("application_fees")
    commands+=("balance")
    commands+=("balance_transactions")
    commands+=("bank_accounts")
    commands+=("billing")
    commands+=("billing_portal")
    commands+=("capabilities")
    commands+=("cards")
    commands+=("cash_balances")
    commands+=("charges")
    commands+=("checkout")
    commands+=("climate")
    commands+=("community")
    if [[ -z "${BASH_VERSION:-}" || "${BASH_VERSINFO[0]:-}" -gt 3 ]]; then
        command_aliases+=("chat")
        aliashash["chat"]="community"
        command_aliases+=("discord")
        aliashash["discord"]="community"
    fi
    commands+=("completion")
    commands+=("config")
    commands+=("confirmation_tokens")
    commands+=("country_specs")
    commands+=("coupons")
    commands+=("credit_note_line_items")
    commands+=("credit_notes")
    commands+=("customer_balance_transactions")
    commands+=("customer_cash_balance_transactions")
    commands+=("customer_sessions")
    commands+=("customers")
    commands+=("delete")
    commands+=("disputes")
    commands+=("entitlements")
    commands+=("ephemeral_keys")
    commands+=("events")
    commands+=("exchange_rates")
    commands+=("external_accounts")
    commands+=("fee_refunds")
    commands+=("feedback")
    commands+=("file_links")
    commands+=("files")
    commands+=("financial_connections")
    commands+=("fixtures")
    commands+=("forwarding")
    commands+=("get")
    commands+=("help")
    commands+=("identity")
    commands+=("invoice_rendering_templates")
    commands+=("invoiceitems")
    commands+=("invoices")
    commands+=("issuing")
    commands+=("line_items")
    commands+=("listen")
    commands+=("login")
    commands+=("login_links")
    commands+=("logout")
    commands+=("logs")
    commands+=("mandates")
    commands+=("open")
    commands+=("payment_intents")
    commands+=("payment_links")
    commands+=("payment_method_configurations")
    commands+=("payment_method_domains")
    commands+=("payment_methods")
    commands+=("payment_sources")
    commands+=("payouts")
    commands+=("persons")
    commands+=("plans")
    commands+=("post")
    commands+=("prices")
    commands+=("product_features")
    commands+=("products")
    commands+=("promotion_codes")
    commands+=("quotes")
    commands+=("radar")
    commands+=("refunds")
    commands+=("reporting")
    commands+=("reviews")
    commands+=("samples")
    commands+=("scheduled_query_runs")
    commands+=("serve")
    if [[ -z "${BASH_VERSION:-}" || "${BASH_VERSINFO[0]:-}" -gt 3 ]]; then
        command_aliases+=("srv")
        aliashash["srv"]="serve"
    fi
    commands+=("setup_attempts")
    commands+=("setup_intents")
    commands+=("shipping_rates")
    commands+=("sources")
    commands+=("subscription_items")
    commands+=("subscription_schedules")
    commands+=("subscriptions")
    commands+=("tax")
    commands+=("tax_codes")
    commands+=("tax_ids")
    commands+=("tax_rates")
    commands+=("terminal")
    commands+=("test_helpers")
    commands+=("tokens")
    commands+=("topups")
    commands+=("transfer_reversals")
    commands+=("transfers")
    commands+=("treasury")
    commands+=("trigger")
    commands+=("usage_record_summaries")
    commands+=("usage_records")
    commands+=("version")
    commands+=("webhook_endpoints")

    flags=()
    two_word_flags=()
    local_nonpersistent_flags=()
    flags_with_completion=()
    flags_completion=()

    flags+=("--api-key=")
    two_word_flags+=("--api-key")
    flags+=("--color=")
    two_word_flags+=("--color")
    flags+=("--config=")
    two_word_flags+=("--config")
    flags+=("--device-name=")
    two_word_flags+=("--device-name")
    flags+=("--log-level=")
    two_word_flags+=("--log-level")
    flags+=("--project-name=")
    two_word_flags+=("--project-name")
    two_word_flags+=("-p")
    flags+=("--version")
    flags+=("-v")
    local_nonpersistent_flags+=("--version")
    local_nonpersistent_flags+=("-v")

    must_have_one_flag=()
    must_have_one_noun=()
    noun_aliases=()
}

__start_stripe()
{
    local cur prev words cword split
    declare -A flaghash 2>/dev/null || :
    declare -A aliashash 2>/dev/null || :
    if declare -F _init_completion >/dev/null 2>&1; then
        _init_completion -s || return
    else
        __stripe_init_completion -n "=" || return
    fi

    local c=0
    local flag_parsing_disabled=
    local flags=()
    local two_word_flags=()
    local local_nonpersistent_flags=()
    local flags_with_completion=()
    local flags_completion=()
    local commands=("stripe")
    local command_aliases=()
    local must_have_one_flag=()
    local must_have_one_noun=()
    local has_completion_function=""
    local last_command=""
    local nouns=()
    local noun_aliases=()

    __stripe_handle_word
}

if [[ $(type -t compopt) = "builtin" ]]; then
    complete -o default -F __start_stripe stripe
else
    complete -o default -o nospace -F __start_stripe stripe
fi

# ex: ts=4 sw=4 et filetype=sh
